OC.L10N.register(
    "contacts",
    {
    "Import contacts" : "Kişileri içe aktar",
    "Details" : "Ayrıntılar",
    "All contacts" : "Tüm kişiler",
    "Email address is required." : "E-posta adresinin yazılması zorunludur.",
    "An open invite already exists." : "Açık bir davet zaten var.",
    "Could not accept invite because no authenticated user was found." : "Kimliği doğrulanmış bir kullanıcı bulunamadığından davet kabul edilemedi.",
    "The invite provider is invalid or not allowed." : "Davet sağlayıcı geçersiz veya ona izin verilmiyor.",
    "Unable to accept this invitation. You are trying to accept an outgoing invitation." : "Bu davet kabul edilemedi. Giden bir daveti kabul etmeye çalışıyorsunuz.",
    "Could not accept invite because the remote provider returned an invalid response." : "Uzak hizmet sağlayıcı geçersiz bir yanıt verdiğinden davet kabul edilemedi.",
    "The remote provider accepted the invite, but this server could not create the local contact." : "Uzak hizmet sağlayıcı daveti kabul etti. Ancak bu sunucu yerel kişiyi oluşturamadı.",
    "Cannot resend: no email address" : "Yeniden gönderilemez: E-posta adresi yok",
    "Invite has already been accepted." : "Davet zaten kabul edilmiş.",
    "Invite has expired. Please create a new one." : "Davetin geçerlilik süresi dolmuş. Lütfen yeni bir davet oluşturun.",
    "This is a copy of an invite sent to you previously by %1$s on %2$s" : "Burada daha önce %2$s zamanında %1$s alıcısına gönderdiğiniz davetin bir kopyası bulunuyor.",
    "Invite already has an email address." : "Davetin zaten bir e-posta adresi var.",
    "An open invite for this email already exists." : "Bu e-posta için açık bir davet zaten var.",
    "Could not claim invite for this email; please refresh and try again." : "Bu e-posta adresi için davet isteğinde bulunulamadı. Lütfen yenileyip yeniden deneyin.",
    "Could not revert invite after delivery failure. Please refresh and try again." : "Aktarım hatasından sonra davet geri alınamadı. Lütfen yenileyip yeniden deneyin.",
    "OCM invites are disabled." : "OCM davetleri kapatılmış.",
    "Recipient email address is invalid." : "Alıcı e-posta adresi geçersiz.",
    "%1$s via %2$s" : "%1$s, %2$s ile",
    "%1$s invites you to exchange contact information." : "%1$s sizi iletişim bilgilerinizi karşılıklı paylaşmaya davet ediyor.",
    "This is a copy of the invitation you've sent to %1$s" : "Burada %1$s alıcısına gönderdiğiniz davetin bir kopyası bulunuyor.",
    "Hi there," : "Merhaba,",
    "%1$s invites you to exchange cloud accounts and contact information." : "%1$s sizi bulut hesaplarınızı ve iletişim bilgilerinizi karşılıklı paylaşmaya davet ediyor.",
    "This will allow you to share data with each other." : "Bu işlem, birbirinizle veri paylaşmanıza izin verecek.",
    "To accept this invite, click the link below and sign in with your cloud provider:" : "Bu daveti kabul etmek için aşağıdaki bağlantıya tıklayın ve bulut hizmeti sağlayıcınızda oturum açın:",
    "Invitation details:" : "Davet ayrıntıları:",
    "Invite code: %1$s" : "Davet kodu: %1$s",
    "Encoded invite: %1$s" : "Kodlanmış davet: %1$s",
    "To accept this invite, use the url below to sign in with your cloud provider:" : "Bu daveti kabul etmek için bulut hizmeti sağlayıcınızla oturum açmak üzere şu adresi kullanın:",
    "_Imported %n contact_::_Imported %n contacts_" : ["%n kişi içe aktarıldı","%n kişi içe aktarıldı"],
    "_(skipped %n contact)_::_(skipped %n contacts)_" : ["(%n kişi atlandı)","(%n kişi atlandı)"],
    "Contacts" : "Kişiler",
    "A contacts app for Nextcloud" : "Nextcloud kişiler uygulaması",
    "The Nextcloud contacts app is a user interface for Nextcloud's CardDAV server. Easily sync contacts from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Currently Mail and Calendar – more to come.\n* 🎉 **Never forget a birthday!** You can sync birthdays and other recurring events with your Nextcloud Calendar.\n* 👥 **Sharing of Adressbooks!** You want to share your contacts with your friends or coworkers? No problem!\n* 🙈 **We’re not reinventing the wheel!** Based on the great and open SabreDAV library." : "Kişiler uygulaması Nextcloud Card DAV sunucusunun ara yüzüdür. Çeşitli aygıtlar üzerindeki kişileri kolayca Nextcloud hesabınız ile eşitler ve çevrim içi olarak düzenlemenizi sağlar.\n\n* 🚀 **Diğer Nextcloud uygulamaları ile bütünleşiktir!** Şu anda Takvim, diğerleri yolda.\n* 🎉 **Doğum günlerini unutmayın!** Doğum günü ve diğer yinelenen etkinlikleri Nextcloud takviminiz üzerinden izleyebilirsiniz.\n* 👥 **Adres defterlerini paylaşma!** Kişilerinizi arkadaşlarınız ve iş arkadaşlarınız ile paylaşmak isterseniz sorun değil!\n* 🙈 **Tekerleği yeniden keşfetmiyoruz!** Harika açık SabreDAV kitaplığını kullanıyoruz.",
    "Copy to full name" : "Tam ada kopyala",
    "Omit year" : "Yıl dikkate alınmasın",
    "Could not save the setting" : "Ayar kaydedilemedi",
    "Allow updating avatars from social media" : "Avatarlar sosyal ağ üzerinden güncellenebilsin",
    "External invitations" : "Dış davetler",
    "Allow creating invites without an email address (link-only)" : "E-posta adresi olmadan davet oluşturulabilsin (yalnızca bağlantı)",
    "Show the \"Copy encoded invite\" button on invite details" : "Davet ayrıntılarında \"Kodlanmış daveti kopyala\" düğmesi görüntülensin",
    "Organization chart" : "Organizasyon şeması",
    "There was an error fetching the member list" : "Üye listesi alınırken bir sorun çıktı",
    "Teams" : "Takımlar",
    "Please select a team" : "Lütfen bir takım seçin",
    "Loading team…" : "Takım yükleniyor…",
    "Loading contacts …" : "Kişiler yükleniyor…",
    "There are no contacts yet" : "Henüz bir kişi kaydı yok",
    "Create contact" : "Kişi oluştur",
    "There are no contacts in this group" : "Bu grupta henüz bir kişi yok",
    "Create contacts" : "Kişiler oluştur",
    "Add contacts" : "Kişileri ekle",
    "Loading invitations…" : "Davetler yükleniyor…",
    "Could not load invitations" : "Davetler yüklenemedi",
    "Retry" : "Yeniden dene",
    "There are no invitations" : "Herhangi bir davet yok",
    "Create invitation" : "Davet oluştur",
    "Loading …" : "Yükleniyor…",
    "Manage team" : "Takım yönetimi",
    "Leave team" : "Takımdan ayrıl",
    "Delete team" : "Takımı sil",
    "Setting saved" : "Ayar kaydedildi",
    "Failed to save setting" : "Ayar kaydedilemedi",
    "Contacts settings" : "Kişiler ayarları",
    "General" : "Genel",
    "Update avatars from social media" : "Avatarlar sosyal ağ üzerinden güncellensin",
    "Refreshed once per week" : "Haftada bir yenilenir",
    "Address books" : "Adres defterleri",
    "Tried to drop an invalid contact!" : "Geçersiz bir kişi kaldırılmaya çalışıldı!",
    "Rename" : "Yeniden adlandır",
    "Export" : "Dışa aktar",
    "Send email" : "E-posta gönder",
    "Send email as BCC" : "E-posta gizli kopya olarak gönderilsin",
    "Delete" : "Sil",
    "Show all groups" : "Tüm grupları görüntüle",
    "Collapse groups" : "Grupları daralt",
    "Show all teams" : "Tüm takımları görüntüle",
    "Collapse teams" : "Takımları daralt",
    "Group name cannot be empty" : "Grup adı boş olamaz",
    "This group already exists" : "Bu grup zaten var",
    "An error occurred while creating the group" : "Grup oluşturulurken bir sorun çıktı",
    "This team already exists" : "Bu takım zaten var",
    "An error happened during the creation of the team" : "Takım eklenirken bir sorun çıktı",
    "Add address book" : "Adres defteri ekle",
    "Recently contacted" : "Son görüşülenler",
    "Contact groups" : "Kişi grupları",
    "Create a new contact group" : "Yeni bir kişi grubu oluştur",
    "Contact group name" : "Kişi grubu adı",
    "Create a new team" : "Yeni takım oluştur",
    "Open the contacts app settings" : "Kişiler uygulaması ayarlarını aç",
    "_Shared with {num} entity_::_Shared with {num} entities_" : ["{num} varlık ile paylaşılmış","{num} varlık ile paylaşılmış"],
    "Copied" : "Kopyalandı",
    "Cannot copy" : "Kopyalanamadı",
    "Copy link" : "Bağlantıyı kopyala",
    "Toggling of address book was not successful" : "Adres defteri değiştirilemedi",
    "This will delete the address book and every contacts within it" : "Bu işlem adres defterini ve içindeki tüm kişileri siler",
    "Delete {addressbook}?" : "{addressbook} silinsin mi?",
    "This will unshare the address book and every contacts within it" : "Bu işlem adres defterini ve içindeki tüm kişileri paylaşımdan kaldıracak",
    "Unshare {addressbook}?" : "{addressbook} paylaşımdan kaldırılsın mı?",
    "Deletion of address book was not successful." : "Adres defteri silinemedi.",
    "Renaming of address book was not successful." : "Adres defteri yeniden adlandırılamadı.",
    "{addressbookname} (Hidden)" : "{addressbookname} (gizli)",
    "Download" : "İndir",
    "Show" : "Görüntüle",
    "Unshare from me" : "Benimle paylaşımı kaldır",
    "_%n contact_::_%n contacts_" : ["%n kişi","%n kişi"],
    "_%n group_::_%n groups_" : ["%n grup","%n grup"],
    "Share with users or groups" : "Kullanıcı ve gruplarla paylaş",
    "Share with users" : "Kullanıcılarla paylaş",
    "No users or groups" : "Herhangi bir kullanıcı ya da grup yok",
    "Unable to delete the share" : "Paylaşım silinemedi",
    "Unable to change permissions" : "İzinler değiştirilemedi",
    "can create and edit" : "oluşturabilir ve düzenleyebilir",
    "Choose a vCard file to import" : "İçe aktarılacak vCard dosyasını seçin",
    "Import into the {addressbookName} address book" : "{addressbookName} adres defteri içine aktar",
    "Select local file" : "Yerel dosyayı seçin",
    "Import from files" : "Dosya ile içe aktar",
    "Importing is disabled because there are no address books available" : "Kullanılabilecek bir adres defteri olmadığından içe aktarma işlemi kullanılamaz",
    "An error occurred, unable to create the address book" : "Bir sorun çıktı, adres defteri oluşturulamadı",
    "New address book" : "Yeni adres defteri",
    "Add new address book" : "Yeni adres defteri ekle",
    "Cancel" : "İptal",
    "Add" : "Ekle",
    "First name" : "Ad",
    "Last name" : "Soyad",
    "Phonetic first name" : "Fonetik ad",
    "Phonetic last name" : "Fonetik soyad",
    "Display name" : "Görüntülenecek ad",
    "Last modified" : "Son değişiklik",
    "Sort contacts by" : "Kişileri şuna göre sırala",
    "Manages" : "Yönetici",
    "Oversees" : "Gözlemci",
    "An error happened during the config change" : "Yapılandırma değiştirilirken bir sorun çıktı",
    "Enforce password protection on files shared to this team" : "Bu takımla paylaşılan dosyalar için parola koruması zorunlu kılınsın",
    "Use a unique password for all shares to this team" : "Bu takımdaki tüm paylaşımlar için benzersiz bir parola kullanılsın",
    "Unique password …" : "Benzersiz parola…",
    "Save" : "Kaydet",
    "Change unique password" : "Benzersiz parolayı değiştir",
    "Failed to save password. Please try again later." : "Parola kaydedilemedi. Lütfen bir süre sonra yeniden deneyin.",
    "Close" : "Kapat",
    "Choose a team picture" : "Bir takım görseli seçin",
    "There is no description for this team" : "Bu takım için bir açıklama yok",
    "Enter a description for the team" : "Takım için bir açıklama yazın",
    "Folder" : "Klasör",
    "New folder" : "Yeni klasör",
    "Folder name" : "Klasör adı",
    "This will create a regular folder shared with the team. To create a Team Folder, please contact your {productName} administrator" : "Bu işlem, takımla paylaşılan normal bir klasör oluşturacak. Bir takım klasörü oluşturmak için lütfen {productName} yöneticinizle görüşün",
    "Talk conversation" : "Konuş görüşmesi",
    "New Talk conversation" : "Yeni Konuş görüşmesi",
    "Conversation name" : "Görüşme adı",
    "Collective" : "Topluluk",
    "Calendar" : "Takvim",
    "New calendar" : "Yeni takvim",
    "Calendar name" : "Takvim adı",
    "Unknown resource type" : "Kaynak türü bilinmiyor",
    "Team calendar \"{resourceName}\" created and shared with team" : "\"{resourceName}\" takım takvimi oluşturuldu ve takımla paylaşıldı",
    "{resourceType} \"{resourceName}\" created and shared with team" : "{resourceType} \"{resourceName}\" oluşturuldu ve takımla paylaşıldı",
    "A calendar named \"{name}\" already exists. Please choose a different name." : "\"{name}\" adında bir takvim zaten var. Lütfen başka bir ad seçin.",
    "Failed to create {resourceType}: {error}" : "{resourceType} oluşturulamadı: {error}",
    "Please select a valid png or jpg file" : "Lütfen geçerli bir png ya da jpg dosyası seçin",
    "Error picking team picture" : "Takım görseli alınırken sorun çıktı",
    "Error cropping avatar picture" : "Avatar görseli kırpılırken sorun çıktı",
    "An error happened while saving {fields}" : "{fields}kaydedilirken bir sorun çıktı",
    "Team name" : "Takım adı",
    "Team owner" : "Takım sahibi",
    "Upload team picture" : "Takım görseli yükle",
    "Choose from Nextcloud Files" : "Nextcloud Dosyalar üzerinden seçin",
    "Delete picture" : "Görseli sil",
    "Edit" : "Düzenle",
    "Request to join" : "Katılma isteğinde bulun",
    "Create" : "Oluştur",
    "Show in Calendar" : "Takvimde görüntülensin",
    "Your request to join this team is pending approval" : "Bu takıma katılma isteğiniz onaylanmayı bekliyor",
    "You are not a member of {circle}" : "{circle} takımının üyesi değilsiniz ",
    "Members" : "Üyeler",
    "Edit team picture" : "Takım görselini düzenle",
    "Apply" : "Uygula",
    "Confirm" : "Onayla",
    "No other contacts available to select as line manager" : "Hat yöneticisi olarak seçilebilecek başka kişi yok",
    "Add more info" : "Başka bilgiler ekleyin",
    "More fields" : "Diğer alanlar",
    "Please select a valid format" : "Lütfen geçerli bir biçim seçin",
    "Invalid image" : "Görsel geçersiz",
    "Error cropping picture" : "Görsel kırpılırken sorun çıktı",
    "Pick an avatar" : "Bir avatar seçin",
    "Pick" : "Seç",
    "Error while processing the picture." : "Görsel işlenirken sorun çıktı.",
    "Avatar downloaded from social network" : "Avatar sosyal ağ üzerinden indirildi",
    "Avatar already up to date" : "Avatar zaten güncel",
    "Avatar download failed" : "Avatar indirilemedi",
    "Crop contact photo" : "Kişi görselini kırp",
    "Upload a new picture" : "Yeni bir görsel yükle",
    "Choose from Files" : "Dosyalardan seçin",
    "Download picture" : "Görseli indir",
    "Clone contact" : "Kişiyi kopyala",
    "This contact is in read-only mode. You do not have permission to edit this contact." : "Bu kişi salt okunur kipte olduğundan kişiyi düzenleme izniniz yok.",
    "The contact you were trying to edit has changed. Please manually refresh the contact. Any further edits will be discarded." : "Düzenlemeye çalıştığınız kişi değiştirilmiş. Lütfen kişiyi el ile yenileyin. Bundan sonra yapılacak düzenlemeler yok sayılacak.",
    "Address book" : "Adres defteri",
    "Add contact to Birthday Calendar" : "Kişiyi doğum günü takvimine ekle",
    "Exclude contact from Birthday Calendar" : "Kişiyi doğum günü takviminden çıkar",
    "{title} at {organization}" : "{organization} kuruluşundaki {title} ",
    "Name" : "Ad",
    "Syntax error. Cannot open the contact." : "Yazım hatası. Kişi bulunamadı.",
    "The contact does not exist on the server anymore." : "Kişi artık sunucu üzerinde değil.",
    "Unable to retrieve the contact from the server, please check your network connection." : "Kişi sunucudan alınamadı. Lütfen ağ bağlantınızı denetleyin.",
    "An error occurred while trying to move the contact" : "Kişi taşınırken bir sorun çıktı",
    "An error occurred while trying to copy the contact" : "Kişi kopyalanırken bir sorun çıktı",
    "Unable to update contact" : "Kişi güncellenemedi",
    "No contact selected" : "Herhangi bir kişi seçilmemiş",
    "Select a contact on the list to begin" : "Başlamak için listeden bir kişi seçin",
    "Title" : "Ünvan",
    "Company" : "Kuruluş",
    "Go to talk conversation" : "Konuş görüşmesine git",
    "View profile" : "Profili görüntüle",
    "This contact was broken and received a fix. Please review the content and click here to save it." : "Bu kişinin bilgileri hatalıydı ve bir düzeltme yapıldı. Lütfen içeriği gözden geçirip kaydetmek için buraya tıklayın.",
    "Edit profile" : "Profili düzenle",
    "Generate QR Code" : "Kare kod oluştur",
    "Contact vCard as QR code" : "Kare kod olarak sanal kişi kartı",
    "Select address book" : "Adres defterini seçin",
    "Media shares with you" : "Sizinle paylaşılan ortamlar",
    "Talk conversations with you" : "Sizinle yapılan Konuş görüşmeleri",
    "Calendar events with you" : "Sizinle ilgili takvim etkinlikleri",
    "Deck cards with you" : "Sizinle ilgili Deste kartları",
    "No shared items with this contact" : "Bu kişi ile paylaşılmış bir öge yok",
    "This contact cannot be moved" : "Bu kişi taşınamaz",
    "This contact cannot be grouped" : "Bu kişi gruba eklenemez",
    "Add contacts to groups" : "Kişileri gruplara ekle",
    "Move contacts to addressbook" : "Kişileri adres defterine taşı",
    "Select groups" : "Grupları seçin",
    "Select addressbook" : "Adres defterini seçin",
    "Selected contacts" : "Seçilmiş kişiler",
    "Please note that only {count} of the {total} contacts can be added to a group" : "Yalnızca {count} / {total} kişinin bir gruba eklenebileceğini lütfen unutmayın",
    "Please note that only {count} of the {total} contacts can be moved" : "Yalnızca {count} / {total} kişinin taşınabileceğini lütfen unutmayın",
    "Move" : "Taşı",
    "Unselect {name}" : "{name} kişisini bırak",
    "Select {name}" : "{name} kişisini seç",
    "Could not update favorite status" : "Sık kullanılan durumu değiştirilemedi",
    "from {addressbook}" : "{addressbook} adres defterinden",
    "Remove from favorites" : "Sık kullanılanlardan kaldır",
    "Add to favorites" : "Sık kullanılanlara ekle",
    "Confirm merging contacts" : "Kişileri birleştirmeyi onayla",
    "The selected contacts have conflicting information. Choose which information to keep" : "Seçilmiş kişilerde çatışan bilgiler var. Hangi bilgilerin tutulacağını seçin",
    "Contacts can be merged" : "Kişiler birleştirilebilir",
    "Groups" : "Gruplar",
    "Select groups to add the merged contact to" : "Birleştirilecek kişilerin ekleneceği grupları seçin",
    "Merge contacts" : "Kişileri birleştir",
    "_Delete {number} contact_::_Delete {number} contacts_" : ["{number} kişiyi sil","{number} kişiyi sil"],
    "Please select at least one editable contact to delete" : "Lütfen silmek için en az bir düzenlenebilir kişi seçin",
    "Please select two editable contacts to merge" : "Lütfen birleştirmek için iki düzenlenebilir kişi seçin",
    "_Add {number} contact to group_::_Add {number} contacts to group_" : ["Gruba {number} kişi ekle","Gruba {number} kişi ekle"],
    "Please select at least one editable contact to add to a group" : "Lütfen bir gruba eklemek için en az bir düzenlenebilir kişi seçin",
    "_Move {number} contact to addressbook_::_Move {number} contacts to addressbook_" : ["{number} kişiyi adres defterine taşı","{number} kişiyi adres defterine taşı"],
    "Please select at least one editable contact to move to an addressbook" : "Lütfen bir adres defterine taşımak için en az bir düzenlenebilir kişi seçin",
    "Are you sure you want to proceed?" : "İlerlemek istediğinize emin misiniz?",
    "Add contacts to group" : "Kişileri gruba ekle",
    "Search contacts …" : "Kişi ara…",
    "Unselect {number}" : "{number} kişiyi bırak",
    "Add to {group}" : "{group} grubuna ekle",
    "Add members to {group}" : "{group} üzerine üye ekle",
    "Please note that you can only add contacts from writable address books to contact groups. Contacts from read-only address books, such as the system address book, cannot be added." : "Yalnızca yazılabilir adres defterlerinden kişi gruplarına kişi ekleyebileceğinizi lütfen unutmayın. Sistem adres defteri gibi salt okunur adres defterlerinden kişiler eklenemez.",
    "Remove {type}" : "{type} sil",
    "Add to group" : "Gruba ekle",
    "Add members to group" : "Gruba üye ekle",
    "Search {types}" : "{types} ara",
    "Add guest" : "Konuk ekle",
    "Search for people to add" : "Eklenecek kişileri ara",
    "No results" : "Herhangi bir sonuç bulunamadı",
    "Add {type}" : "{type} ekle",
    "New team name" : "Yeni takım adı",
    "Personal team" : "Kişisel takım",
    "This team will only be visible to you. Other members will not be able to see or use it." : "Bu takımı yalnızca siz görebilirsiniz. Diğer üyeler bu takımı göremez ya da kullanamaz.",
    "Local team" : "Yerel takım",
    "This team will not be shared with the other instances of the global scale" : "Bu takım küresel ölçekte diğer kopyalar ile paylaşılamaz",
    "Create team" : "Takım oluştur",
    "Promote as sole owner" : "Sahip olarak ata",
    "Promote to {level}" : "{level} düzeyine yükselt",
    "Demote to {level}" : "{level} düzeyine düşür",
    "Are you sure you want to leave this team? This action cannot be undone." : "Bu takımdan ayrılmak istediğinize emin misiniz? Bu işlem geri alınamaz.",
    "Leave team failed." : "Takımdan ayrılma tamamlanamadı.",
    "Could not delete the member {displayName}" : "{displayName} üyesi silinemedi",
    "Could not change the member level to {level}" : "Üye düzeyi {level} olarak değiştirilemedi",
    "Could not accept membership request" : "Üyelik isteği kabul edilemedi",
    "Accept membership request" : "Üyelik isteğini kabul et",
    "Reject membership request" : "Üyelik isteğini reddet",
    "Manage level" : "Düzeyi değiştir",
    "Remove member" : "Üyeyi sil",
    "Unable to get the results" : "Sonuçlar alınamadı",
    "Some members could not be added" : "Bazı üyeler eklenemedi",
    "There was an issue adding members to the team" : "Üyeler takıma eklenirken bir sorun çıktı",
    "Loading members list …" : "Üye listesi ekleniyor…",
    "The list of members is only visible to members of this team" : "Üye listesi yalnızca bu takımdaki üyeler tarafından görülebilir",
    "You currently have no access to the member list" : "Üye listesine erişme izniniz yok ",
    "Add to {team}" : "{team} takımına ekle",
    "Invite members to {team}" : "{team} takıma üyeler davet edin",
    "Pending" : "Bekleyen",
    "This invite does not look valid. Check that you copied it completely or ask the sender to generate a new one." : "Bu davet geçerli görünmüyor. Tümüyle kopyalayıp kopyalamadığınızı kontrol edin veya göndericiden yeni bir davet oluşturmasını isteyin.",
    "Accept invitation" : "Daveti kabul et",
    "Accepting will add the inviter to your contacts list and in return, your contact info will be sent to the inviter. From there on you can start sharing data with each other." : "Kabul etmek, davet edeni kişi listenize ekler ve karşılığında iletişim bilgileriniz davet edene gönderilir. Ondan sonra birbirinizle veri paylaşmaya başlayabilirsiniz.",
    "Invite link or code (required)" : "Davet bağlantısı veya kodu (gerekli)",
    "Paste the invite link, or an invite code (token@provider), you received from the other person." : "Diğer kişiden aldığınız davet bağlantısını veya bir davet kodunu (kod@saglayici) yapıştırın.",
    "Accept" : "Kabul et",
    "Please enter an email address." : "Lütfen bir e-posta adresi yazın",
    "The recipient will receive an email with the invite link. Their email address will be saved on the invite so you can resend later." : "Alıcı, davet bağlantısının bulunduğu bir e-posta alacak. E-posta adresleri davete kaydedilecek. Böylece daha sonra yeniden gönderebilirsiniz.",
    "Recipient email (required)" : "Alıcı e-postası (zorunlu)",
    "email@example.com" : "alici@ornek.com",
    "Personal message (optional)" : "Kişisel ileti (isteğe bağlı)",
    "Message to include in the email" : "E-posta ile gönderilecek ileti",
    "Sending…" : "Gönderiliyor…",
    "Send" : "Gönder",
    "Invite code" : "Davet kodu",
    "Cloud provider" : "Bulut hizmeti sağlayıcı",
    "Encoded invite copied to clipboard" : "Kodlanmış davet panoya kopyalandı",
    "Invite code copied to clipboard" : "Davet kodu panoya kopyalandı",
    "Invite link copied to clipboard" : "Davet bağlantısı panoya kopyalandı",
    "Copied to clipboard" : "Panoya kopyalandı",
    "Failed to copy to clipboard" : "Panoya kopyalanamadı",
    "Could not resend invite" : "Davet yeniden gönderilemedi",
    "Invite revoked" : "Davet geri çekildi",
    "Could not revoke invite" : "Davet geri çekilemedi",
    "Invite sent to {email}" : "Davet {email} adresine gönderildi",
    "Could not send invite" : "Davet gönderilemedi",
    "No invitation selected" : "Herhangi bir davet seçilmemiş",
    "Select an invitation on the list to begin" : "Başlamak için listeden bir davet seçin",
    "External invitation" : "Dış davet",
    "Label" : "Etiket",
    "Sent to" : "Şuraya gönderildi",
    "Created" : "Oluşturulma",
    "Expires" : "Geçerlilik sonu",
    "More ways to share" : "Paylaşmanın diğer yolları",
    "Useful for sharing through a chat app or for manual acceptance." : "Bir sohbet uygulaması ile paylaşmak ya da el ile kabul etmek için kullanışlıdır.",
    "Revoke invitation" : "Daveti geri çek",
    "Resend email" : "E-postayı yeniden gönder",
    "Send via email" : "E-posta ile gönder",
    "Send invitation via email" : "Daveti e-posta ile gönder",
    "{name} invites you to exchange cloud accounts and contact information." : "{name} sizi bulut hesaplarınızı ve iletişim bilgilerinizi karşılıklı paylaşmaya davet ediyor.",
    "The invite link and code are added automatically when you send the invitation." : "Daveti gönderdiğinizde davet bağlantısı ve kodu otomatik olarak eklenir.",
    "Recipient email" : "Alıcı e-posta adresi",
    "Invite someone outside your organization to collaborate" : "Kuruluşunuzun dışındaki birini iş birliği yapmaya davet edin",
    "After the invitee accepts the invite, both of you will appear in each other's contacts list and you can start sharing data with each other." : "Davet edilen kişi daveti kabul ettikten sonra, ikiniz de birbirinizin kişi listesinde görüneceks ve birbirinizle veri paylaşmaya başlayabileceksiniz.",
    "Send invite via email" : "Daveti e-posta ile gönder",
    "Hide email preview" : "E-posta ön izlemesini gizle",
    "Show email preview" : "E-posta ön izlemesini görüntüle",
    "This is what {recipient} will receive:" : "{recipient} tarafından alınacak ileti",
    "If you do not send an email, you will need to share the invite link yourself." : "Bir e-posta göndermezseniz, davet bağlantısını sizin paylaşmanız gerekecek.",
    "Invite link" : "Davet bağlantısı",
    "Copy invite link to clipboard" : "Davet bağlantısını panoya kopyala",
    "Copy invite code to clipboard" : "Davet kodunu panoya kopyala",
    "Encoded invite" : "Kodlanmış davet",
    "Copy encoded invite to clipboard" : "Kodlanmış daveti panoya kopyala",
    "Search invites…" : "Davet ara…",
    "Could not discover that provider. Check the address and try again." : "O sağlayıcı bulunamadı. Adresi kontrol edip yeniden deneyin.",
    "Select your server" : "Sunucunuzu seçin",
    "Type to search" : "Aramak için yazın",
    "No servers match your search." : "Aramanızla eşleşen bir sunucu bulunamadı",
    "No servers are currently available." : "Şu anda kullanılabilecek bir sunucu yok.",
    "Your server not listed? Enter one manually." : "Sunucunuz listede yok mu? El ile bir sunucu yazın.",
    "Continue" : "İlerle",
    "You need an invite link for this feature to work." : "Bu özelliğin çalışması için bir davet bağlantınız olmalı.",
    "Select chart …" : "Çizelge seçin…",
    "Chart" : "Çizelge",
    "Select type" : "Türü seçin",
    "Add contact in group" : "Kişiyi şu gruba ekle",
    "None" : "Yok",
    "copy" : "kopya",
    "Select option" : "Seçeneği seçin",
    "JavaScript URIs are not allowed" : "JavaScript adreslerine izin verilmiyor",
    "Notes" : "Notlar",
    "send an email" : "bir e-posta gönder",
    "Personal dates" : "Kişisel tarihler",
    "Add property of this type" : "Bu türün özniteliğini ekle",
    "Member" : "Üye",
    "This is a read-only group managed by administrators. Group members can only view this group." : "Bu grup, yöneticiler tarafından yönetilen salt okunur bir gruptur. Grup üyeleri bu grubu yalnızca görüntüleyebilir.",
    "Send invitation" : "Davet gönder",
    "Generate invitation" : "Davet oluştur",
    "This invite link is incomplete. Ask the sender to generate a new one." : "Bu davet bağlantısı eksik. Göndericiden yeni bir davet oluşturmasını isteyin.",
    "Unable to create the contact." : "Kişi oluşturulamadı.",
    "Contact not found" : "Kişi bulunamadı",
    "Address book {addressbook} not found" : "{addressbook} adres defteri bulunamadı",
    "Group {group} not found" : "{group} grubu bulunamadı",
    "Could not accept invite" : "Davet kabul edilemedi",
    "Could not create invite" : "Davet oluşturulamadı",
    "Add member" : "Üye ekle",
    "New contact" : "Yeni kişi",
    "_{success} contact added to {name}_::_{success} contacts added to {name}_" : ["{success} kişi {name} üzerine eklendi","{success} kişi {name} üzerine eklendi"],
    "_Adding {success} contact to {name}_::_Adding {success} contacts to {name}_" : ["{success} kişi {name} üzerine ekleniyor","{success} kişi {name} üzerine ekleniyor"],
    "_{count} error_::_{count} errors_" : ["{count} hata","{count} hata"],
    "_Importing %n contact into {addressbook}_::_Importing %n contacts into {addressbook}_" : ["%n kişi {addressbook} içine aktarılıyor","%n kişi {addressbook} içine aktarılıyor"],
    "_Done importing %n contact into {addressbook}_::_Done importing %n contacts into {addressbook}_" : ["%n kişi {addressbook} içine aktarıldı","%n kişi {addressbook} içine aktarıldı"],
    "No data for this contact" : "Bu kişi için herhangi bir veri yok",
    "No data for this contact on their profile" : "Bu kişinin profilinde herhangi bir veri yok",
    "Import" : "İçe aktar",
    "Are you sure you want to import this contact file?" : "Bu kişi dosyasını içe aktarmak istediğinize emin misiniz?",
    "Could not copy" : "Kopyalanamadı",
    "Join team" : "Takıma katıl",
    "You are about to leave {circle}.\nAre you sure?" : "{circle} takımından çıkmak üzeresiniz.\nBunu yapmak istediğinize emin misiniz?",
    "Please confirm team leave" : "Lütfen takımdan ayrılmak istediğinizi onaylayın",
    "Could not leave the team {displayName}" : "{displayName} takımından çıkılamadı",
    "Unable to join the team" : "Takıma girilemedi",
    "You are about to delete {circle}.\nAre you sure?" : "{circle} takımını silmek üzeresiniz.\nBunu yapmak istediğinize emin misiniz?",
    "Please confirm team deletion" : "Lütfen takımı silmek istediğinizi onaylayın",
    "Unable to delete the team" : "Takım silinemedi",
    "Confirm enabling federation" : "Birliği açmayı onayla",
    "Enabling this will prevent {circle} from being a member of other teams.\nAre you sure?" : "Bu açıldığında, {circle} diğer takımların üyesi olamayacak.\nEmin misiniz?",
    "Enable federation" : "Birliği aç",
    "Link copied to the clipboard" : "Bağlantı panoya kopyalandı",
    "Could not copy link to the clipboard." : "Bağlantı panoya kopyalanamadı.",
    "Not grouped" : "Gruplanmamış",
    "Create your own teams for sharing. Add Nextcloud users, contacts, or anyone via email." : "Paylaşmak için kendi takımlarınızı oluşturun. Nextcloud kullanıcılarını, kişilerini veya herhangi birini e-posta ile ekleyin.",
    "Team" : "Takım",
    "User" : "Kullanıcı",
    "Group" : "Grup",
    "Email" : "E-posta",
    "Contact" : "Kişi",
    "Moderator" : "Sorumlu",
    "Admin" : "Yönetici",
    "Owner" : "Sahip",
    "Invites" : "Davetler",
    "Anyone can request membership" : "Herkes üyelik isteğinde bulunabilir",
    "Members need to accept invitation" : "Üyeler daveti kabul etmelidir",
    "Memberships must be confirmed/accepted by a Moderator (requires \"Anyone can request membership\")" : "Üyelikler bir sorumlu tarafından onaylanmalıdır (\"Herkes üyelik isteğinde bulunabilir\" seçeneği açık olmalıdır)",
    "Members can also invite" : "Üyeler de davet gönderebilir",
    "Membership" : "Üyelik",
    "Prevent teams from being a member of another team" : "Bu takım başka bir takıma üye olarak eklenemesin",
    "Federation" : "Birleşim",
    "Allow federated members" : "Birleşik üyelere izin verilsin",
    "Privacy" : "Gizlilik",
    "Visible to everyone" : "Herkes görebilir",
    "users" : "kullanıcı",
    "Users" : "Kullanıcılar",
    "groups" : "grup",
    "federated users" : "birleşik kullanıcılar",
    "Federated users" : "Birleşik kullanıcılar",
    "teams" : "takım",
    "email addresses" : "e-posta adresi",
    "Email addresses" : "E-posta adresleri",
    "contacts" : "kişi",
    "Link-only invite" : "Yalnızca bağlantı daveti",
    "Detailed name" : "Ayrıntılı ad",
    "Additional names" : "Ek adlar",
    "Prefix" : "Ön ek",
    "Suffix" : "Son ek",
    "Nickname" : "Takma ad",
    "Website" : "Site",
    "Location" : "Konum",
    "Federated Cloud ID" : "Birleşik bulut kimliği",
    "Home" : "Ev",
    "Work" : "İş",
    "Other" : "Diğer",
    "Address" : "Adres",
    "Post office box" : "Posta kutusu",
    "Extended address" : "Uzun adres",
    "City" : "İlçe",
    "State or province" : "İl",
    "Postal code" : "Posta kodu",
    "Country" : "Ülke",
    "Birthday" : "Doğum günü",
    "Place of birth" : "Doğum yeri",
    "Anniversary" : "Yıl dönümü",
    "Date of death" : "Ölüm tarihi",
    "Place of death" : "Ölüm yeri",
    "Instant messaging" : "Anlık iletişim",
    "Phone" : "Telefon",
    "Mobile" : "Cep telefonu",
    "Work mobile" : "İş cep telefonu",
    "Home mobile" : "Ev cep telefonu",
    "Fax" : "Faks",
    "Fax home" : "Ev faksı",
    "Fax work" : "İş faksı",
    "Pager" : "Çağrı cihazı",
    "Voice" : "Ses",
    "Car" : "Araç telefonu",
    "Work pager" : "İş çağrı cihazı",
    "Line manager" : "Hat yöneticisi",
    "Social network" : "Sosyal ağ",
    "Relationship to you" : "Sizinle ilişkili",
    "Spouse" : "Eş",
    "Child" : "Çocuk",
    "Mother" : "Anne",
    "Father" : "Baba",
    "Parent" : "Ebeveyn",
    "Brother" : "Erkek kardeş",
    "Sister" : "Kız kardeş",
    "Relative" : "Akraba",
    "Friend" : "Arkadaş",
    "Colleague" : "Çalışma arkadaşı",
    "Assistant" : "Yardımcı",
    "Related contacts" : "İlişkili kişiler",
    "Agent" : "Ajan",
    "Emergency" : "Acil",
    "Co-worker" : "Çalışma arkadaşı",
    "Gender" : "Cinsiyet",
    "Female" : "Kadın",
    "Male" : "Erkek",
    "Unknown" : "Bilinmiyor",
    "Time zone" : "Saat dilimi",
    "Spoken languages" : "Konuşulan diller",
    "_{failed} contact failed to be read_::_{failed} contacts failed to be read_" : ["{failed} kişi okunamadı","{failed} kişi okunamadı"],
    "An error has occurred in team(s). Check the console for more details." : "Takımlarda bir sorun çıktı. Ayrıntılı bilgi almak için konsola bakabilirsiniz.",
    "Unable to create team {circleName}" : "{circleName} takımı oluşturulamadı",
    "Unable to delete team {circleId}" : "{circleName} takımı silinemedi",
    "Could not update favorite state" : "Sık kullanılan durumu güncellenemedi",
    "Unable to delete contact" : "Kişi silinemedi",
    "Value copied to the clipboard" : "Değer panoya kopyalandı",
    "Could not copy value to the clipboard." : "Değer panoya kopyalanamadı.",
    "Deck board" : "Deste panosu",
    "New Deck board" : "Yeni Deste panosu",
    "Board name" : "Pano adı",
    "Deck app is not installed. Please install it to create team boards." : "Deste uygulaması kurulmamış. Lütfen takım panoları oluşturmak için kurun.",
    "Pick an address book" : "Bir adres defteri seçin",
    "Select Date" : "Tarih seçin",
    "note" : "not",
    "email" : "e-posta",
    "Create your own groups for sharing. Add Nextcloud users, contacts, or anyone via email." : "Paylaşmak için kendi gruplarınızı oluşturun. Nextcloud kullanıcılarını, kişilerini veya herhangi birini e-posta ile ekleyin."
},
"nplurals=2; plural=(n > 1);");
