OC.L10N.register(
    "contacts",
    {
    "Import contacts" : "Увези контакти",
    "Details" : "Детали",
    "All contacts" : "Сите контакти",
    "_Imported %n contact_::_Imported %n contacts_" : ["Увезен %n контакт","Увезени %n контакти"],
    "_(skipped %n contact)_::_(skipped %n contacts)_" : ["(прескокнат %n контакт)","(прескокнати %n контакти)"],
    "Contacts" : "Контакти",
    "A contacts app for Nextcloud" : "Апликација за контакти за Nextcloud",
    "The Nextcloud contacts app is a user interface for Nextcloud's CardDAV server. Easily sync contacts from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Currently Mail and Calendar – more to come.\n* 🎉 **Never forget a birthday!** You can sync birthdays and other recurring events with your Nextcloud Calendar.\n* 👥 **Sharing of Adressbooks!** You want to share your contacts with your friends or coworkers? No problem!\n* 🙈 **We’re not reinventing the wheel!** Based on the great and open SabreDAV library." : "Апликацијата Контакти за Nextcloud е кориснички интерфејс за  „CardDAV“ на Nextcloud сервер. Лесно синхронизирајте контакти од разни уреди со вашиот Nextcloud и изменете ги на Интернет.\n\n* 🚀 ** Интеграција со други апликации Nextcloud! ** Моментално со Е-пошта и календар.\n* 🎉 ** Никогаш не заборавајте роденден! ** Може да ги синхронизирате родендените и другите настани од вашиот Календар.\n* 👥 ** Споделување на адресари! ** Дали сакате да ги споделите вашите контакти со вашите пријатели или соработници? Нема проблем!\n* 🙈 ** Ние не го реинвестираме тркалото! ** Врз основа на одличната и отворена библиотека SabreDAV .",
    "Copy to full name" : "Копирај во Име и презиме",
    "Omit year" : "Изостави година",
    "Allow updating avatars from social media" : "Дозволи ажурирање на аватарите од социјалните мрежи",
    "Organization chart" : "Огранизациски графил",
    "There was an error fetching the member list" : "Настана грешка при вчитувањето на листата на членови",
    "Teams" : "Тимови",
    "Please select a team" : "Изберете тим",
    "Loading team…" : "Вчитување тим...",
    "Loading contacts …" : "Вчитување на контактите …",
    "There are no contacts yet" : "Сеуште нема контакти",
    "Create contact" : "Креирај контакт",
    "There are no contacts in this group" : "Нема контакти во оваа група",
    "Create contacts" : "Креирај контакти",
    "Add contacts" : "Додади контакти",
    "Loading …" : "Се вчитува …",
    "Manage team" : "Уреди тим",
    "Leave team" : "Напушти тим",
    "Delete team" : "Избриши тим",
    "Setting saved" : "Параматарот е зачуван",
    "Failed to save setting" : "Неуспешно зачувување на параметарот",
    "Contacts settings" : "Параметри за контактите",
    "General" : "Општо",
    "Update avatars from social media" : "Ажурирај ги аватарите од социјалните мрежи",
    "Refreshed once per week" : "Освежи еднаш неделно",
    "Address books" : "Адресари",
    "Rename" : "Преименувај",
    "Export" : "Извези",
    "Send email" : "Испрати е-пошта",
    "Send email as BCC" : "Испрати е-пошта како BCC",
    "Delete" : "Избриши",
    "Show all groups" : "Прикажи ги сите групи",
    "Collapse groups" : "Сокриј ги групите",
    "Show all teams" : "Прикажи ги сите тимови",
    "Collapse teams" : "Сокриј тимови",
    "Group name cannot be empty" : "Името на групата неможе да биде празно",
    "This group already exists" : "Оваа група веќе постои",
    "An error occurred while creating the group" : "Настана грешка при креирање на група",
    "This team already exists" : "Овој тим веќе постои",
    "An error happened during the creation of the team" : "Настана грешка при обидот за креирање на тим",
    "Recently contacted" : "Неодамна контактирани",
    "Contact groups" : "Групи со контакти",
    "Create a new contact group" : "Креирај нова група со контакти",
    "Contact group name" : "Име на група со контакти",
    "Create a new team" : "Креирај нов тим",
    "Open the contacts app settings" : "Отвори ги параметрите за контактите",
    "_Shared with {num} entity_::_Shared with {num} entities_" : ["Споделено со едно {num} лице","Споделено со {num} лица"],
    "Copied" : "Копирано",
    "Cannot copy" : "Не може да се копира",
    "Copy link" : "Копирај линк",
    "Toggling of address book was not successful" : "Промената во адресарот на беше успешна",
    "This will delete the address book and every contacts within it" : "Ова ќе ги избрише адресарот и сите контакти во него",
    "Delete {addressbook}?" : "Избриши {addressbook}?",
    "This will unshare the address book and every contacts within it" : "Ова ќе го отстрани споделувањето на адресарот и сите контакти во него",
    "Unshare {addressbook}?" : "Отстрани споделување {addressbook}?",
    "Deletion of address book was not successful." : "Неуспешно бришење на адресарот.",
    "Renaming of address book was not successful." : "Неуспешно преименување на адресарот",
    "{addressbookname} (Hidden)" : "{addressbookname} (Невидлив)",
    "Download" : "Преземи",
    "Show" : "Прикажи",
    "Unshare from me" : "Не споделувај со мене",
    "_%n contact_::_%n contacts_" : ["%n контакт","%n контакти"],
    "_%n group_::_%n groups_" : ["%n група","%n групи"],
    "Share with users or groups" : "Сподели со корисници или групи",
    "Share with users" : "Споделено со корисници",
    "No users or groups" : "Нема корисници или групи",
    "Unable to delete the share" : "Неможе да се избрише споделениот контакт",
    "Unable to change permissions" : "Неможе да се променат дозволите",
    "Choose a vCard file to import" : "Избери vCard датотека за увоз",
    "Import into the {addressbookName} address book" : "Увези во адресарот {addressbookName}",
    "Select local file" : "Избери локална датотека",
    "Import from files" : "Увези од датотеките",
    "Importing is disabled because there are no address books available" : "Увезувањето е оневозможено бидејќи нема достапен адресар",
    "An error occurred, unable to create the address book" : "Настана грешка, неможе да се креира адресар",
    "New address book" : "Нов адресар",
    "Add new address book" : "Додади нов адресар",
    "Cancel" : "Откажи",
    "Add" : "Add",
    "First name" : "Име",
    "Last name" : "Презиме",
    "Phonetic first name" : "Име Фонетски",
    "Phonetic last name" : "Презиме Фонетски",
    "Display name" : "Име и презиме",
    "Last modified" : "Последно изменето",
    "Sort contacts by" : "Подреди ги контактите по",
    "Manages" : "Менаџмент",
    "Oversees" : "Надгледувачи",
    "An error happened during the config change" : "Настана грешка при обидот за промена на конфигурацијата",
    "Enforce password protection on files shared to this team" : "Задолжителна лозинка за датотеките споделени во овој тим",
    "Use a unique password for all shares to this team" : "Користи уникатна лозинка за сите споделувања во овој тим",
    "Unique password …" : "Уникатна лозинка …",
    "Save" : "Зачувај",
    "Change unique password" : "Промени лозинка",
    "Failed to save password. Please try again later." : "Неуспешно зачувување на лозинката. Обидете се повторно.",
    "Close" : "Затвори",
    "There is no description for this team" : "Нема опис за овој тим",
    "Enter a description for the team" : "Внеси опис за тимот",
    "Folder" : "Folder",
    "New folder" : "Нова папка",
    "Folder name" : "Име на папка",
    "Talk conversation" : "Talk раговор",
    "New Talk conversation" : "Нов Talk разговор",
    "Conversation name" : "Име на разговорот",
    "Calendar" : "Календар",
    "New calendar" : "Нов календар",
    "Calendar name" : "Име на календар",
    "Unknown resource type" : "Непознат вид на ресурс",
    "Team calendar \"{resourceName}\" created and shared with team" : "Календар \"{resourceName}\" е креиран и споделен со тимот",
    "{resourceType} \"{resourceName}\" created and shared with team" : "{resourceType} \"{resourceName}\" е креирано и споделено со тимот",
    "A calendar named \"{name}\" already exists. Please choose a different name." : "Календар со име \"{name}\" веќе постои. Изберете друго име.",
    "Failed to create {resourceType}: {error}" : "Неуспешно креирање {resourceType}: {error}",
    "An error happened while saving {fields}" : "Настана грешка при обид за зачувување {fields}",
    "Team name" : "Име на тимот",
    "Team owner" : "Сопственик на тимот",
    "Delete picture" : "Избриши слика",
    "Edit" : "Уреди",
    "Request to join" : "Барање за членство",
    "Create" : "Креирај",
    "Show in Calendar" : "Прикажи во календар",
    "Your request to join this team is pending approval" : "Вашето барање за приклучување во тимот е на чекање за одобрување",
    "You are not a member of {circle}" : "Вие не сте член на {circle}",
    "Members" : "Членови",
    "Confirm" : "Потврди",
    "Add more info" : "Додади повеќе информации",
    "More fields" : "Повеќе полиња",
    "Please select a valid format" : "Изберете валиден формат",
    "Invalid image" : "Невалидна фотографија",
    "Error cropping picture" : "Грешка при сечење на фотографија",
    "Pick an avatar" : "Избери аватар",
    "Pick" : "Избери",
    "Error while processing the picture." : "Грешка при процесоирање на сликата",
    "Avatar downloaded from social network" : "Аватари превземени од социјалните мрежи",
    "Avatar already up to date" : "Аватарите се ажурирани",
    "Avatar download failed" : "Неуспешно превземање на аватар",
    "Crop contact photo" : "Исечи фотографија на контакт",
    "Upload a new picture" : "Прикачи нова слика",
    "Choose from Files" : "Избери од датотеките",
    "Download picture" : "Преземи слика",
    "Clone contact" : "Клонирај контакт",
    "This contact is in read-only mode. You do not have permission to edit this contact." : "Овој контакт е со дозволи само за читање. Немате дозвола за да го промените контактот.",
    "The contact you were trying to edit has changed. Please manually refresh the contact. Any further edits will be discarded." : "Контактот кој се обидувате да го измените веќе е изменет. Ве молиме проверете го контактот. Сите наредни измени ќе бидат отфрлени.",
    "Address book" : "Адресар",
    "Add contact to Birthday Calendar" : "Додади контакт во Роденденскиот календар",
    "Exclude contact from Birthday Calendar" : "Исклучи контакт од Роденденскиот календар",
    "{title} at {organization}" : "{title} во {organization}",
    "Name" : "Име",
    "Syntax error. Cannot open the contact." : "Грешка во синтаксата. Неможе да се отвори овој контакт.",
    "The contact does not exist on the server anymore." : "Контактот повеќе не постои на серверот.",
    "Unable to retrieve the contact from the server, please check your network connection." : "Неможе да се вчита контактот од серверот, проверете ја вашата конекција.",
    "An error occurred while trying to move the contact" : "Настана грешка при обидот за преместување на конктактот",
    "An error occurred while trying to copy the contact" : "Настана грешка при обидот за копирање на конктактот",
    "Unable to update contact" : "Не може да се ажурира контактот",
    "No contact selected" : "Нема избрано контакт",
    "Select a contact on the list to begin" : "Изберете контакт од листата со контакти",
    "Title" : "Наслов",
    "Company" : "Фирма",
    "Go to talk conversation" : "Оди до разговори",
    "View profile" : "Прегледај профил",
    "This contact was broken and received a fix. Please review the content and click here to save it." : "Овој контакт беше неточен и доби исправка. Прегледајте го контактот и кликнете тука за да го зачувате.",
    "Generate QR Code" : "Генерирај QR код",
    "Contact vCard as QR code" : "Картичка за контакт во QR-код",
    "Select address book" : "Избери адресар",
    "Media shares with you" : "Медиа датотеки споделени со вас",
    "Talk conversations with you" : "Разговори со вас",
    "Calendar events with you" : "Настани во календарот со вас",
    "Deck cards with you" : "Deck картици со вас",
    "No shared items with this contact" : "Нема споделени работи со овој контакт",
    "Select addressbook" : "Означи адресар",
    "Move" : "Move",
    "from {addressbook}" : "од {addressbook}",
    "Remove from favorites" : "Отстрани од фаворити",
    "Add to favorites" : "Додади во фаворити",
    "Confirm merging contacts" : "Потврда за спојување на контакти",
    "The selected contacts have conflicting information. Choose which information to keep" : "Избраните контакти имаат конфликтни информации. Избери кои информации да се чуваат",
    "Contacts can be merged" : "Контактите може да се спојат",
    "Groups" : "Групи",
    "Select groups to add the merged contact to" : "Избери групи за да се додадат споените контакти",
    "Merge contacts" : "Спои контакти",
    "_Delete {number} contact_::_Delete {number} contacts_" : ["Избриши {number} контакт","Избриши {number} контакти"],
    "Please select at least one editable contact to delete" : "Изберете најмалку еден контакт за да го избришете",
    "Please select two editable contacts to merge" : "Изберете два контакти за спојување",
    "Are you sure you want to proceed?" : "Дали си сигурен дека сакаш да продолжиш?",
    "Search contacts …" : "Пребарување контакти …",
    "Unselect {number}" : "Од-означи {number}",
    "Add to {group}" : "Додади во {group}",
    "Add members to {group}" : "Додади членови во {group}",
    "Remove {type}" : "Отстрани {type}",
    "Add to group" : "Додади во група",
    "Add members to group" : "Додади членови во група",
    "Search {types}" : "Барај {types}",
    "Add guest" : "Додај гостин",
    "Search for people to add" : "Барај луѓе за да додадеш",
    "No results" : "Нема резултати",
    "Add {type}" : "Додади {type}",
    "New team name" : "Ново име на тимот",
    "Personal team" : "Личен тим",
    "This team will only be visible to you. Other members will not be able to see or use it." : "Овој тим ќе биде единствено видлив за вас. Другите членови нема да може да се гледаат помеѓу себе.",
    "Local team" : "Локален тим",
    "This team will not be shared with the other instances of the global scale" : "Овој тим нема да биде споделуван со други истанци",
    "Create team" : "Креирај тим",
    "Promote as sole owner" : "Промовирај во единствен сопственик",
    "Promote to {level}" : "Промовирај во {level}",
    "Demote to {level}" : "Деградирај во {level}",
    "Are you sure you want to leave this team? This action cannot be undone." : "Дали си сигурен дека сакаш да го напуштиш тимот? Оваа акција неможе да се поврати.",
    "Leave team failed." : "Неуспешно напуштање на тиммот.",
    "Could not delete the member {displayName}" : "Неможе да се избрише членот {displayName}",
    "Could not change the member level to {level}" : "Неможе да се промени улогата во {level}",
    "Could not accept membership request" : "Не може да се прифати барањето за членство",
    "Accept membership request" : "Прифати барање за членство",
    "Reject membership request" : "Одбиј барање за членство",
    "Manage level" : "Уреди ги улогите",
    "Remove member" : "Отстрани член",
    "Unable to get the results" : "Неможе да се вчитаат резултатите",
    "Some members could not be added" : "Некој членови неможе да бидат додадени",
    "There was an issue adding members to the team" : "Има проблеми со додавање на членови во овој тим",
    "Loading members list …" : "Вчитување на листата со членови …",
    "The list of members is only visible to members of this team" : "Листата на членови е видлива само за членовите на овој тим",
    "You currently have no access to the member list" : "Немате пристап до листата со членови",
    "Add to {team}" : "Add to {team}",
    "Invite members to {team}" : "Покани членови во {team}",
    "Pending" : "Чекање",
    "Send" : "Испрати",
    "Select chart …" : "Избери график …",
    "Chart" : "График",
    "Select type" : "Избери вид",
    "Add contact in group" : "Додади контакт во група",
    "None" : "Ништо",
    "Select option" : "Изберете опција",
    "Notes" : "Белешки",
    "Personal dates" : "Лични датуми",
    "Add property of this type" : "Додај имот од овој тип",
    "Member" : "Член",
    "This is a read-only group managed by administrators. Group members can only view this group." : "Ова е група само за читање која е менаџирана од администраторот. Членовите во групата можат само да гледаат работи во групата.",
    "Unable to create the contact." : "Неможе да се креира контакт.",
    "Contact not found" : "Контактот не е пронајден",
    "Group {group} not found" : "Групата {group} не е пронајдена",
    "Add member" : "Додади член",
    "New contact" : "Нов контакт",
    "_{success} contact added to {name}_::_{success} contacts added to {name}_" : ["1 контак додаден во {name}","{success} контакти додадени во {name}"],
    "_Adding {success} contact to {name}_::_Adding {success} contacts to {name}_" : ["Додавање 1контакт во {name}","Додавање {success} контакти во {name}"],
    "_{count} error_::_{count} errors_" : ["1 грешка","{count} грешки"],
    "_Importing %n contact into {addressbook}_::_Importing %n contacts into {addressbook}_" : ["Импортирање на %n контакт во {addressbook}","Импортирање на %n контакти во {addressbook}"],
    "_Done importing %n contact into {addressbook}_::_Done importing %n contacts into {addressbook}_" : ["Импортиран е  %n контакт во  {addressbook}","Импортирани се %n контакти во {addressbook}"],
    "No data for this contact" : "Нема податоци за овој контакт",
    "No data for this contact on their profile" : "Нема податоци за овој контакт на неговиот профил",
    "Import" : "Увези",
    "Are you sure you want to import this contact file?" : "Дали си сигурен дека сакаш да ја увезеш оваа контакт датотека?",
    "Could not copy" : "Неможе да се копира",
    "Join team" : "Приклучи се на тимот",
    "You are about to leave {circle}.\nAre you sure?" : "Сакате да го напуштите {circle}.\nДали сте сигурни?",
    "Please confirm team leave" : "Потврди го напуштањето на тимот",
    "Could not leave the team {displayName}" : "{displayName} не може да го напушти тимот",
    "Unable to join the team" : "Не може да се приклучиш на тимот",
    "You are about to delete {circle}.\nAre you sure?" : "Сакате да го избришете {circle}.\nДали сте сигурни?",
    "Please confirm team deletion" : "Потврдете го бришењето на тимот",
    "Unable to delete the team" : "Неможе да се избрише тимот",
    "Link copied to the clipboard" : "Линкот е копиран во клипборд",
    "Could not copy link to the clipboard." : "Линкот неможе да се копира во клипборд.",
    "Not grouped" : "Не групирани",
    "Team" : "Тим",
    "User" : "Корисник",
    "Group" : "Група",
    "Email" : "Е-пошта",
    "Contact" : "Контакт",
    "Moderator" : "Модератор",
    "Admin" : "Администратор",
    "Owner" : "Сопственик",
    "Invites" : "Покани",
    "Anyone can request membership" : "Секој може да побара членство",
    "Members need to accept invitation" : "Членовите треба да го прифатат членството",
    "Memberships must be confirmed/accepted by a Moderator (requires \"Anyone can request membership\")" : " Членството мора предходно да се одобри/прифати од модератор (потребно \"Секој може да испрати барање за членство\")",
    "Members can also invite" : "Членовите можат да испраќаат покани",
    "Membership" : "Членство",
    "Prevent teams from being a member of another team" : "Спречете ги тимовите да бидат членови на друг тим",
    "Privacy" : "Приватност",
    "Visible to everyone" : "Видлив за сите",
    "users" : "корисници",
    "Users" : "Корисници",
    "groups" : "групи",
    "teams" : "тимови",
    "email addresses" : "Е-пошта адреси",
    "Email addresses" : "Е-пошта адреси",
    "contacts" : "контакти",
    "Detailed name" : "Детално име",
    "Additional names" : "Дополнителни имиња",
    "Prefix" : "Префикс",
    "Suffix" : "Суфикс",
    "Nickname" : "Прекар",
    "Website" : "Веб сајт",
    "Location" : "Локација",
    "Federated Cloud ID" : "Федерален клауд ID",
    "Home" : "Дома",
    "Work" : "Работа",
    "Other" : "Останато",
    "Address" : "Адреса",
    "Post office box" : "Поштенска кутија",
    "Extended address" : "Целосна адреса",
    "City" : "Град",
    "State or province" : "Град или провинција",
    "Postal code" : "Поштенски број",
    "Country" : "Држава",
    "Birthday" : "Роденден",
    "Place of birth" : "Место на раѓање",
    "Anniversary" : "Годишнина",
    "Date of death" : "Датум на смрт",
    "Place of death" : "Место на смрт",
    "Instant messaging" : "Инстантни пораки",
    "Phone" : "Телефон",
    "Mobile" : "Мобилен",
    "Work mobile" : "Службен мобилен",
    "Home mobile" : "Приватен мобилен",
    "Fax" : "Факс",
    "Fax home" : "Fax дома",
    "Fax work" : "Fax на работа",
    "Pager" : "Пејџер",
    "Voice" : "Глас",
    "Car" : "Автомобил",
    "Work pager" : "Службен пејџер",
    "Line manager" : "Менаџер",
    "Social network" : "Социјална мрежа",
    "Relationship to you" : "Врска со вас",
    "Spouse" : "Брачен другар",
    "Child" : "Дете",
    "Mother" : "Мајка",
    "Father" : "Татко",
    "Parent" : "Родител",
    "Brother" : "Брат",
    "Sister" : "Сестра",
    "Relative" : "Роднина",
    "Friend" : "Пријател",
    "Colleague" : "Колега",
    "Assistant" : "Асистент",
    "Related contacts" : "Поврзани контакти",
    "Agent" : "Агент",
    "Emergency" : "За итни случаи",
    "Co-worker" : "Соработник",
    "Gender" : "Пол",
    "Female" : "Женско",
    "Male" : "Машко",
    "Unknown" : "Непознат",
    "Time zone" : "Временска зона",
    "Spoken languages" : "Говорни јазици",
    "_{failed} contact failed to be read_::_{failed} contacts failed to be read_" : ["{failed} еден контакт неможе да се прочита","{failed} контакти неможат да се прочитат"],
    "An error has occurred in team(s). Check the console for more details." : "Настана грешка во некои тим(ови). Проверете ја конзолата за повеќе детали.",
    "Unable to create team {circleName}" : "Неможе да се креира тим {circleName}",
    "Unable to delete team {circleId}" : "Неможе да се избрише тимот {circleId}",
    "Unable to delete contact" : "Неможе да се избрише контакт",
    "Deck board" : "Deck табла",
    "New Deck board" : "Нова Deck табла",
    "Board name" : "Име на табла",
    "Deck app is not installed. Please install it to create team boards." : "Deck апликацијата не е инсталирана. Инсталирајте ја за да креирате тимски табли.",
    "Pick an address book" : "Избери адресар",
    "Select Date" : "Избери датум"
},
"nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");
