OC.L10N.register(
    "contacts",
    {
    "Import contacts" : "وارد کردن مخاطبین",
    "Details" : "جزئیات",
    "All contacts" : "همه مخاطبین",
    "_Imported %n contact_::_Imported %n contacts_" : ["%n Ù…Ø®Ø§Ø·Ø¨ Ø¯Ø±ÙˆÙ†â€ŒØ±ÛŒØ²ÛŒ Ø´Ø¯","%n Ù…Ø®Ø§Ø·Ø¨ Ø¯Ø±ÙˆÙ†â€ŒØ±ÛŒØ²ÛŒ Ø´Ø¯"],
    "_(skipped %n contact)_::_(skipped %n contacts)_" : ["(%n Ù…Ø®Ø§Ø·Ø¨ Ù†Ø§Ø¯ÛŒØ¯Ù‡ Ú¯Ø±Ù�ØªÙ‡ Ø´Ø¯)","(%n Ù…Ø®Ø§Ø·Ø¨ Ù†Ø§Ø¯ÛŒØ¯Ù‡ Ú¯Ø±Ù�ØªÙ‡ Ø´Ø¯)"],
    "Contacts" : "مخاطبین",
    "A contacts app for Nextcloud" : "یک برنامه مخاطبین برای نکست‌کلود",
    "The Nextcloud contacts app is a user interface for Nextcloud's CardDAV server. Easily sync contacts from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Currently Mail and Calendar – more to come.\n* 🎉 **Never forget a birthday!** You can sync birthdays and other recurring events with your Nextcloud Calendar.\n* 👥 **Sharing of Adressbooks!** You want to share your contacts with your friends or coworkers? No problem!\n* 🙈 **We’re not reinventing the wheel!** Based on the great and open SabreDAV library." : "برنامه Nextcloud Contacts یک رابط کاربری برای سرور CardDAV Nextcloud است. به راحتی مخاطبین دستگاه های مختلف را با Nextcloud خود همگام کنید و آنها را به صورت آنلاین ویرایش کنید.\n\n* 🚀 **ادغام با سایر برنامه های Nextcloud!** در حال حاضر Mail و Calendar - موارد بیشتری در راه است.\n* 🎉 **هرگز تولد را فراموش نکنید!** می توانید تولدها و سایر رویدادهای تکرار شونده را با تقویم Nextcloud خود همگام کنید.\n* 👥 **اشتراک گذاری دفترچه آدرس!** می خواهید مخاطبین خود را با دوستان یا همکاران خود به اشتراک بگذارید؟ مشکلی نیست!\n* 🙈 **ما چرخ را دوباره اختراع نمی کنیم!** بر اساس کتابخانه بزرگ و باز SabreDAV.",
    "Copy to full name" : "کپی به نام کامل",
    "Omit year" : "حذف سال",
    "Allow updating avatars from social media" : "اجازه به‌روزرسانی آواتارها از شبکه‌های اجتماعی",
    "Organization chart" : "چارت سازمانی",
    "There was an error fetching the member list" : "خطا در دریافت لیست اعضا",
    "Teams" : "تیم‌ها",
    "Please select a team" : "لطفاً یک تیم انتخاب کنید",
    "Loading team…" : "در حال بارگذاری تیم…",
    "Loading contacts …" : "در حال بارگذاری مخاطبین …",
    "There are no contacts yet" : "هنوز هیچ مخاطبی وجود ندارد",
    "Create contact" : "ایجاد مخاطب",
    "There are no contacts in this group" : "هیچ مخاطبی در این گروه وجود ندارد",
    "Create contacts" : "ایجاد مخاطبین",
    "Add contacts" : "افزودن مخاطبین",
    "Retry" : "تلاش مجدد",
    "Loading …" : "در حال بارگذاری …",
    "Manage team" : "مدیریت تیم",
    "Leave team" : "ترک تیم",
    "Delete team" : "حذف تیم",
    "Setting saved" : "تنظیمات ذخیره شد",
    "Failed to save setting" : "ذخیره تنظیمات انجام نشد",
    "Contacts settings" : "تنظیمات مخاطبین",
    "General" : "عمومی",
    "Update avatars from social media" : "به‌روزرسانی آواتارها از شبکه‌های اجتماعی",
    "Refreshed once per week" : "هفته‌ای یک بار به‌روزرسانی می‌شود",
    "Address books" : "دفترچه‌های آدرس",
    "Tried to drop an invalid contact!" : "تلاش برای رها کردن یک مخاطب نامعتبر!",
    "Rename" : "تغییر نام",
    "Export" : "خروجی",
    "Send email" : "ارسال ایمیل",
    "Send email as BCC" : "ارسال ایمیل به صورت BCC",
    "Delete" : "حذف",
    "Show all groups" : "نمایش همه گروه‌ها",
    "Collapse groups" : "جمع کردن گروه‌ها",
    "Show all teams" : "نمایش همه تیم‌ها",
    "Collapse teams" : "جمع کردن تیم‌ها",
    "Group name cannot be empty" : "نام گروه نمی‌تواند خالی باشد",
    "This group already exists" : "این گروه از قبل وجود دارد",
    "An error occurred while creating the group" : "هنگام ایجاد گروه خطایی رخ داد",
    "This team already exists" : "این تیم از قبل وجود دارد",
    "An error happened during the creation of the team" : "هنگام ایجاد تیم خطایی رخ داد",
    "Recently contacted" : "اخیراً تماس گرفته شده",
    "Contact groups" : "گروه‌های مخاطبین",
    "Create a new contact group" : "ایجاد یک گروه مخاطب جدید",
    "Contact group name" : "نام گروه مخاطب",
    "Create a new team" : "ایجاد تیم جدید",
    "Open the contacts app settings" : "باز کردن تنظیمات برنامه مخاطبین",
    "_Shared with {num} entity_::_Shared with {num} entities_" : ["Ù‡Ù…â€ŒØ±Ø³Ø§Ù†Ø¯Ù‡ Ø¨Ø§ {num} Ù…ÙˆØ¬ÙˆØ¯ÛŒØª","Ù‡Ù…â€ŒØ±Ø³Ø§Ù†Ø¯Ù‡ Ø¨Ø§ {num} Ù…ÙˆØ¬ÙˆØ¯ÛŒØª"],
    "Copied" : "کپی شد",
    "Cannot copy" : "امکان کپی وجود ندارد",
    "Copy link" : "کپی لینک",
    "Toggling of address book was not successful" : "تغییر وضعیت دفترچه آدرس موفقیت‌آمیز نبود",
    "This will delete the address book and every contacts within it" : "این کار دفترچه آدرس و تمام مخاطبین داخل آن را حذف خواهد کرد",
    "Delete {addressbook}?" : "{addressbook} حذف شود؟",
    "This will unshare the address book and every contacts within it" : "این کار اشتراک‌گذاری دفترچه آدرس و تمام مخاطبین داخل آن را لغو خواهد کرد",
    "Unshare {addressbook}?" : "{addressbook} لغو اشتراک شود؟",
    "Deletion of address book was not successful." : "حذف دفترچه آدرس موفقیت‌آمیز نبود",
    "Renaming of address book was not successful." : "تغییر نام دفترچه آدرس موفقیت‌آمیز نبود",
    "{addressbookname} (Hidden)" : "{addressbookname} (مخفی)",
    "Download" : "دانلود",
    "Show" : "نمایش",
    "Unshare from me" : "لغو اشتراک از من",
    "_%n contact_::_%n contacts_" : ["%n Ø¢Ø´Ù†Ø§","%n Ø¢Ø´Ù†Ø§"],
    "_%n group_::_%n groups_" : ["%n Ú¯Ø±ÙˆÙ‡","%n Ú¯Ø±ÙˆÙ‡"],
    "Share with users or groups" : "اشتراک‌گذاری با کاربران یا گروه‌ها",
    "Share with users" : "اشتراک‌گذاری با کاربران",
    "No users or groups" : "هیچ کاربر یا گروهی وجود ندارد",
    "Unable to delete the share" : "امکان حذف اشتراک‌گذاری وجود ندارد",
    "Unable to change permissions" : "امکان تغییر مجوزها وجود ندارد",
    "can create and edit" : "می‌تواند ایجاد و ویرایش کند",
    "Choose a vCard file to import" : "انتخاب یک فایل vCard برای وارد کردن",
    "Import into the {addressbookName} address book" : "وارد کردن به دفترچه آدرس {addressbookName}",
    "Select local file" : "انتخاب فایل محلی",
    "Import from files" : "وارد کردن از فایل‌ها",
    "Importing is disabled because there are no address books available" : "وارد کردن غیرفعال است زیرا هیچ دفترچه آدرسی در دسترس نیست",
    "An error occurred, unable to create the address book" : "خطایی رخ داد، امکان ایجاد دفترچه آدرس وجود ندارد",
    "New address book" : "دفترچه آدرس جدید",
    "Add new address book" : "افزودن دفترچه آدرس جدید",
    "Cancel" : "لغو",
    "Add" : "افزودن",
    "First name" : "نام",
    "Last name" : "نام خانوادگی",
    "Phonetic first name" : "نام آوایی",
    "Phonetic last name" : "نام خانوادگی آوایی",
    "Display name" : "نام نمایشی",
    "Last modified" : "آخرین تغییر",
    "Sort contacts by" : "مرتب‌سازی مخاطبین بر اساس",
    "Manages" : "مدیریت می‌کند",
    "Oversees" : "نظارت می‌کند",
    "An error happened during the config change" : "خطایی در طول تغییر تنظیمات رخ داد",
    "Enforce password protection on files shared to this team" : "اعمال محافظت از رمز عبور بر روی فایل‌های به اشتراک‌گذاشته شده با این تیم",
    "Use a unique password for all shares to this team" : "استفاده از یک رمز عبور یکتا برای تمام اشتراک‌گذاری‌های این تیم",
    "Unique password …" : "گذرواژهٔ یکتا …",
    "Save" : "ذخیره",
    "Change unique password" : "تغییر رمز عبور یکتا",
    "Failed to save password. Please try again later." : "ذخیره‌سازی رمز عبور انجام نشد. لطفاً بعداً دوباره تلاش کنید.",
    "Close" : "بستن",
    "Choose a team picture" : "انتخاب تصویر تیم",
    "There is no description for this team" : "توضیحاتی برای این تیم وجود ندارد",
    "Enter a description for the team" : "توضیحاتی برای تیم وارد کنید",
    "Folder" : "پوشه",
    "New folder" : "پوشه جدید",
    "Folder name" : "نام پوشه",
    "This will create a regular folder shared with the team. To create a Team Folder, please contact your {productName} administrator" : "این کار یک پوشه معمولی ایجاد می‌کند که با تیم به اشتراک گذاشته می‌شود. برای ایجاد یک پوشه تیمی، با مدیر {productName} خود تماس بگیرید",
    "Talk conversation" : "گفتگوی Talk",
    "New Talk conversation" : "گفتگوی Talk جدید",
    "Conversation name" : "نام گفتگو",
    "Collective" : "اشتراکی",
    "Calendar" : "تقویم",
    "New calendar" : "تقویم جدید",
    "Calendar name" : "نام تقویم",
    "Unknown resource type" : "نوع منبع ناشناخته",
    "Team calendar \"{resourceName}\" created and shared with team" : "تقویم تیم \"{resourceName}\" ایجاد و با تیم به اشتراک گذاشته شد",
    "{resourceType} \"{resourceName}\" created and shared with team" : "{resourceType} \"{resourceName}\" ایجاد و با تیم به اشتراک گذاشته شد",
    "A calendar named \"{name}\" already exists. Please choose a different name." : "تقویمی با نام \"{name}\" از قبل وجود دارد. لطفاً نام دیگری انتخاب کنید.",
    "Failed to create {resourceType}: {error}" : "ایجاد {resourceType} انجام نشد: {error}",
    "Please select a valid png or jpg file" : "لطفاً یک فایل png یا jpg معتبر انتخاب کنید",
    "Error picking team picture" : "خطا در انتخاب تصویر تیم",
    "Error cropping avatar picture" : "خطا در برش تصویر آواتار",
    "An error happened while saving {fields}" : "هنگام ذخیره‌سازی {fields} خطایی رخ داد",
    "Team name" : "نام تیم",
    "Team owner" : "مالک تیم",
    "Upload team picture" : "بارگذاری تصویر تیم",
    "Choose from Nextcloud Files" : "انتخاب از نکست‌کلود فایل‌ها",
    "Delete picture" : "حذف تصویر",
    "Edit" : "ویرایش",
    "Request to join" : "درخواست عضویت",
    "Create" : "ایجاد",
    "Show in Calendar" : "نمایش در تقویم",
    "Your request to join this team is pending approval" : "درخواست شما برای پیوستن به این تیم در انتظار تأیید است",
    "You are not a member of {circle}" : "شما عضو {circle} نیستید",
    "Members" : "اعضا",
    "Edit team picture" : "ویرایش تصویر تیم",
    "Apply" : "اعمال",
    "Confirm" : "تأیید",
    "No other contacts available to select as line manager" : "هیچ مخاطب دیگری برای انتخاب به عنوان مدیر خط در دسترس نیست.",
    "Add more info" : "افزودن اطلاعات بیشتر",
    "More fields" : "فیلدهای بیشتر",
    "Please select a valid format" : "لطفاً یک فرمت معتبر انتخاب کنید",
    "Invalid image" : "تصویر نامعتبر",
    "Error cropping picture" : "خطا در برش تصویر",
    "Pick an avatar" : "یک آواتار انتخاب کنید",
    "Pick" : "انتخاب کنید",
    "Error while processing the picture." : "خطا در پردازش تصویر",
    "Avatar downloaded from social network" : "آواتار دانلود شده از شبکه اجتماعی",
    "Avatar already up to date" : "آواتار قبلاً به‌روز است",
    "Avatar download failed" : "دانلود آواتار ناموفق بود",
    "Crop contact photo" : "برش عکس مخاطب",
    "Upload a new picture" : "آپلود یک تصویر جدید",
    "Choose from Files" : "انتخاب از فایل‌ها",
    "Download picture" : "دانلود تصویر",
    "Clone contact" : "کلون کردن مخاطب",
    "This contact is in read-only mode. You do not have permission to edit this contact." : "این مخاطب در حالت فقط‌خواندنی است. شما مجوز ویرایش این مخاطب را ندارید.",
    "The contact you were trying to edit has changed. Please manually refresh the contact. Any further edits will be discarded." : "مخاطبی که قصد ویرایش آن را داشتید تغییر کرده است. لطفاً مخاطب را به‌صورت دستی بازخوانی کنید. هر ویرایش دیگری نادیده گرفته خواهد شد.",
    "Address book" : "دفترچه آدرس",
    "Add contact to Birthday Calendar" : "افزودن مخاطب به تقویم تولد",
    "Exclude contact from Birthday Calendar" : "حذف مخاطب از تقویم تولد",
    "{title} at {organization}" : "{title} در {organization}",
    "Name" : "نام",
    "Syntax error. Cannot open the contact." : "خطای نحوی. امکان باز کردن مخاطب وجود ندارد.",
    "The contact does not exist on the server anymore." : "مخاطب دیگر روی سرور وجود ندارد.",
    "Unable to retrieve the contact from the server, please check your network connection." : "امکان دریافت مخاطب از سرور وجود ندارد، لطفاً اتصال شبکه خود را بررسی کنید.",
    "An error occurred while trying to move the contact" : "هنگام تلاش برای جابجایی مخاطب خطایی رخ داد",
    "An error occurred while trying to copy the contact" : "هنگام تلاش برای کپی کردن مخاطب خطایی رخ داد",
    "Unable to update contact" : "امکان به‌روزرسانی مخاطب وجود ندارد",
    "No contact selected" : "هیچ مخاطبی انتخاب نشده است",
    "Select a contact on the list to begin" : "برای شروع، یک مخاطب از لیست انتخاب کنید",
    "Title" : "عنوان",
    "Company" : "شرکت",
    "Go to talk conversation" : "رفتن به گفتگوی Talk",
    "View profile" : "مشاهده پروفایل",
    "This contact was broken and received a fix. Please review the content and click here to save it." : "این مخاطب خراب بود و تعمیر شد. لطفاً محتوا را بررسی کنید و برای ذخیره آن اینجا کلیک کنید.",
    "Edit profile" : "ویرایش پروفایل",
    "Generate QR Code" : "تولید کد QR",
    "Contact vCard as QR code" : "vCard مخاطب به‌عنوان کد QR",
    "Select address book" : "انتخاب دفترچه آدرس",
    "Media shares with you" : "رسانه‌های به اشتراک‌گذاشته شده با شما",
    "Talk conversations with you" : "گفتگوهای Talk با شما",
    "Calendar events with you" : "رویدادهای تقویم با شما",
    "Deck cards with you" : "کارت‌های کارتابل با شما",
    "No shared items with this contact" : "هیچ آیتم مشترکی با این مخاطب وجود ندارد",
    "This contact cannot be moved" : "این مخاطب قابل جابجایی نیست",
    "This contact cannot be grouped" : "این مخاطب قابل گروه‌بندی نیست",
    "Add contacts to groups" : "افزودن مخاطبان به گروه‌ها",
    "Move contacts to addressbook" : "انتقال مخاطبان به دفترچه آدرس",
    "Select groups" : "انتخاب گروه‌ها",
    "Select addressbook" : "انتخاب دفترچه آدرس",
    "Selected contacts" : "مخاطبان انتخاب شده",
    "Please note that only {count} of the {total} contacts can be added to a group" : "لطفاً توجه داشته باشید که فقط {count} از {total} مخاطب می‌توانند به یک گروه اضافه شوند",
    "Please note that only {count} of the {total} contacts can be moved" : "لطفاً توجه داشته باشید که فقط {count} از {total} مخاطب می‌توانند جابجا شوند",
    "Move" : "انتقال",
    "Unselect {name}" : "لغو انتخاب {name}",
    "Select {name}" : "انتخاب {name}",
    "Could not update favorite status" : "به‌روزرسانی وضعیت موردعلاقه امکان‌پذیر نیست",
    "from {addressbook}" : "از {addressbook}",
    "Remove from favorites" : "حذف از موارد دلخواه",
    "Add to favorites" : "افزودن به موارد دلخواه",
    "Confirm merging contacts" : "تأیید ادغام مخاطبان",
    "The selected contacts have conflicting information. Choose which information to keep" : "مخاطبان انتخاب‌شده اطلاعات متناقضی دارند. اطلاعاتی را که می‌خواهید نگه دارید انتخاب کنید",
    "Contacts can be merged" : "مخاطبان قابل ادغام هستند",
    "Groups" : "گروه‌ها",
    "Select groups to add the merged contact to" : "گروه‌هایی را برای افزودن مخاطب ادغام‌شده انتخاب کنید",
    "Merge contacts" : "ادغام مخاطبان",
    "_Delete {number} contact_::_Delete {number} contacts_" : ["Ø­Ø°Ù� {number} Ù…Ø®Ø§Ø·Ø¨","Ø­Ø°Ù� {number} Ù…Ø®Ø§Ø·Ø¨"],
    "Please select at least one editable contact to delete" : "لطفاً حداقل یک مخاطب قابل ویرایش برای حذف انتخاب کنید",
    "Please select two editable contacts to merge" : "لطفاً دو مخاطب قابل ویرایش برای ادغام انتخاب کنید",
    "_Add {number} contact to group_::_Add {number} contacts to group_" : ["Ø§Ù�Ø²ÙˆØ¯Ù† {number} Ù…Ø®Ø§Ø·Ø¨ Ø¨Ù‡ Ú¯Ø±ÙˆÙ‡","Ø§Ù�Ø²ÙˆØ¯Ù† {number} Ù…Ø®Ø§Ø·Ø¨ Ø¨Ù‡ Ú¯Ø±ÙˆÙ‡"],
    "Please select at least one editable contact to add to a group" : "لطفاً حداقل یک مخاطب قابل ویرایش برای افزودن به گروه انتخاب کنید",
    "_Move {number} contact to addressbook_::_Move {number} contacts to addressbook_" : ["Ø§Ù†ØªÙ‚Ø§Ù„ {number} Ù…Ø®Ø§Ø·Ø¨ Ø¨Ù‡ Ø¯Ù�ØªØ±Ú†Ù‡ Ø¢Ø¯Ø±Ø³","Ø§Ù†ØªÙ‚Ø§Ù„ {number} Ù…Ø®Ø§Ø·Ø¨ Ø¨Ù‡ Ø¯Ù�ØªØ±Ú†Ù‡ Ø¢Ø¯Ø±Ø³"],
    "Please select at least one editable contact to move to an addressbook" : "لطفاً حداقل یک مخاطب قابل ویرایش برای انتقال به یک دفترچه آدرس انتخاب کنید",
    "Are you sure you want to proceed?" : "آیا مطمئن هستید که می‌خواهید ادامه دهید؟",
    "Add contacts to group" : "افزودن مخاطبان به گروه",
    "Search contacts …" : "جستجوی مخاطبین …",
    "Unselect {number}" : "لغو انتخاب {number}",
    "Add to {group}" : "افزودن به {group}",
    "Add members to {group}" : "افزودن اعضا به {group}",
    "Please note that you can only add contacts from writable address books to contact groups. Contacts from read-only address books, such as the system address book, cannot be added." : "لطفاً توجه داشته باشید که فقط می‌توانید مخاطبان را از دفترچه‌های آدرس قابل نوشتن به گروه‌های مخاطب اضافه کنید. مخاطبان دفترچه‌های آدرس فقط خواندنی، مانند دفترچه آدرس سیستم، قابل افزودن نیستند.",
    "Remove {type}" : "حذف {type}",
    "Add to group" : "افزودن به گروه",
    "Add members to group" : "افزودن اعضا به گروه",
    "Search {types}" : "جستجوی {types}",
    "Add guest" : "افزودن مهمان",
    "Search for people to add" : "جستجوی افراد برای افزودن",
    "No results" : "نتیجه‌ای یافت نشد",
    "Add {type}" : "افزودن {type}",
    "New team name" : "نام جدید تیم",
    "Personal team" : "تیم شخصی",
    "This team will only be visible to you. Other members will not be able to see or use it." : "این تیم فقط برای شما قابل مشاهده خواهد بود. سایر اعضا نمی‌توانند آن را ببینند یا استفاده کنند.",
    "Local team" : "تیم محلی",
    "This team will not be shared with the other instances of the global scale" : "این تیم با سایر نمونه‌های مقیاس جهانی به اشتراک گذاشته نخواهد شد",
    "Create team" : "ایجاد تیم",
    "Promote as sole owner" : "ارتقا به مالک انحصاری",
    "Promote to {level}" : "ارتقا به {level}",
    "Demote to {level}" : "تنزل به {level}",
    "Are you sure you want to leave this team? This action cannot be undone." : "آیا مطمئن هستید که می‌خواهید این تیم را ترک کنید؟ این عمل قابل بازگشت نیست.",
    "Leave team failed." : "ترک تیم انجام نشد.",
    "Could not delete the member {displayName}" : "امکان حذف عضو {displayName} وجود ندارد",
    "Could not change the member level to {level}" : "امکان تغییر سطح عضو به {level} وجود ندارد",
    "Could not accept membership request" : "امکان پذیرش درخواست عضویت وجود ندارد",
    "Accept membership request" : "پذیرش درخواست عضویت",
    "Reject membership request" : "رد درخواست عضویت",
    "Manage level" : "مدیریت سطح",
    "Remove member" : "حذف عضو",
    "Unable to get the results" : "امکان دریافت نتایج وجود ندارد",
    "Some members could not be added" : "برخی از اعضا اضافه نشدند",
    "There was an issue adding members to the team" : "هنگام افزودن اعضا به تیم مشکلی پیش آمد",
    "Loading members list …" : "در حال بارگذاری سیاههٔ اعضا …",
    "The list of members is only visible to members of this team" : "لیست اعضا فقط برای اعضای این تیم قابل مشاهده است",
    "You currently have no access to the member list" : "شما در حال حاضر به لیست اعضا دسترسی ندارید",
    "Add to {team}" : "افزودن به {team}",
    "Invite members to {team}" : "دعوت از اعضا به {team}",
    "Pending" : "در انتظار",
    "Accept" : "قبول کردن",
    "Continue" : "ادامه دادن",
    "Select chart …" : "انتخاب نمودار …",
    "Chart" : "نمودار",
    "Select type" : "انتخاب نوع",
    "Add contact in group" : "افزودن مخاطب در گروه",
    "None" : "هیچ‌کدام",
    "copy" : "کپی",
    "Select option" : "انتخاب گزینه",
    "JavaScript URIs are not allowed" : "URIهای جاوااسکریپت مجاز نیستند",
    "Notes" : "یادداشت‌ها",
    "send an email" : "ارسال ایمیل",
    "Personal dates" : "تاریخ‌های شخصی",
    "Add property of this type" : "افزودن ویژگی از این نوع",
    "Member" : "عضو",
    "This is a read-only group managed by administrators. Group members can only view this group." : "این یک گروه فقط‌خواندنی است که توسط مدیران مدیریت می‌شود. اعضای گروه فقط می‌توانند این گروه را مشاهده کنند.",
    "Unable to create the contact." : "امکان ایجاد مخاطب وجود ندارد.",
    "Contact not found" : "مخاطب یافت نشد",
    "Group {group} not found" : "گروه {group} یافت نشد",
    "Add member" : "افزودن عضو",
    "New contact" : "مخاطب جدید",
    "_{success} contact added to {name}_::_{success} contacts added to {name}_" : ["{success} Ù…Ø®Ø§Ø·Ø¨ Ø¨Ù‡ {name} Ø§Ù�Ø²ÙˆØ¯Ù‡ Ø´Ø¯","{success} Ù…Ø®Ø§Ø·Ø¨ Ø¨Ù‡ {name} Ø§Ù�Ø²ÙˆØ¯Ù‡ Ø´Ø¯"],
    "_Adding {success} contact to {name}_::_Adding {success} contacts to {name}_" : ["Adding {success} contact to {name}","Ø§Ù�Ø²ÙˆØ¯Ù† Ù…Ø®Ø§Ø·Ø¨ÛŒÙ† {success} Ø¨Ù‡ {name}"],
    "_{count} error_::_{count} errors_" : ["{count} Ø®Ø·Ø§","{count} Ø®Ø·Ø§"],
    "_Importing %n contact into {addressbook}_::_Importing %n contacts into {addressbook}_" : ["Importing %n contact into {addressbook}","ÙˆØ§Ø±Ø¯ Ú©Ø±Ø¯Ù† Ù…Ø®Ø§Ø·Ø¨ÛŒÙ† Ø¨Ù‡ {addressbook}"],
    "_Done importing %n contact into {addressbook}_::_Done importing %n contacts into {addressbook}_" : ["Done importing %n contact into {addressbook}","ÙˆØ§Ø±Ø¯ Ú©Ø±Ø¯Ù† Ù…Ø®Ø§Ø·Ø¨ÛŒÙ† Ø¨Ù‡ {addressbook} Ø§Ù†Ø¬Ø§Ù… Ø´Ø¯"],
    "No data for this contact" : "داده‌ای برای این مخاطب وجود ندارد",
    "No data for this contact on their profile" : "داده‌ای برای این مخاطب در نمایه او وجود ندارد",
    "Import" : "وارد کردن",
    "Are you sure you want to import this contact file?" : "آیا مطمئن هستید که می‌خواهید این فایل مخاطب را وارد کنید؟",
    "Could not copy" : "امکان کپی وجود ندارد",
    "Join team" : "پیوستن به تیم",
    "You are about to leave {circle}.\nAre you sure?" : "شما در حال ترک {circle} هستید.",
    "Please confirm team leave" : "لطفاً ترک تیم را تأیید کنید",
    "Could not leave the team {displayName}" : "امکان ترک تیم {displayName} وجود ندارد",
    "Unable to join the team" : "امکان پیوستن به تیم وجود ندارد",
    "You are about to delete {circle}.\nAre you sure?" : "شما در حال حذف {circle} هستید.",
    "Please confirm team deletion" : "لطفاً حذف تیم را تأیید کنید",
    "Unable to delete the team" : "امکان حذف تیم وجود ندارد",
    "Confirm enabling federation" : "تأیید فعال‌سازی فدراسیون",
    "Enabling this will prevent {circle} from being a member of other teams.\nAre you sure?" : "فعال‌سازی این گزینه از عضویت {circle} در سایر تیم‌ها جلوگیری می‌کند.",
    "Enable federation" : "فعال‌سازی فدراسیون",
    "Link copied to the clipboard" : "لینک در کلیپ‌بورد کپی شد",
    "Could not copy link to the clipboard." : "امکان کپی کردن لینک در کلیپ‌بورد وجود نداشت",
    "Not grouped" : "گروه‌بندی نشده",
    "Create your own teams for sharing. Add Nextcloud users, contacts, or anyone via email." : "تیم‌های خود را برای اشتراک‌گذاری ایجاد کنید. کاربران نکست‌کلود، مخاطبان یا هر کسی را از طریق ایمیل اضافه کنید.",
    "Team" : "تیم",
    "User" : "کاربر",
    "Group" : "گروه",
    "Email" : "ایمیل",
    "Contact" : "مخاطب",
    "Moderator" : "ناظر",
    "Admin" : "مدیر",
    "Owner" : "مالک",
    "Invites" : "دعوت‌نامه‌ها",
    "Anyone can request membership" : "هر کسی می‌تواند درخواست عضویت دهد",
    "Members need to accept invitation" : "اعضا باید دعوت‌نامه را بپذیرند",
    "Memberships must be confirmed/accepted by a Moderator (requires \"Anyone can request membership\")" : "عضویت باید توسط یک ناظر تأیید/پذیرفته شود (نیازمند گزینه \"هر کسی می‌تواند درخواست عضویت دهد\")",
    "Members can also invite" : "اعضا همچنین می‌توانند دعوت کنند",
    "Membership" : "عضویت",
    "Prevent teams from being a member of another team" : "جلوگیری از عضویت تیم‌ها در تیم دیگر",
    "Federation" : "فدراسیون",
    "Allow federated members" : "اجازه اعضای فدرال",
    "Privacy" : "حریم خصوصی",
    "Visible to everyone" : "قابل مشاهده برای همه",
    "users" : "کاربران",
    "Users" : "کاربران",
    "groups" : "گروه‌ها",
    "federated users" : "کاربران فدرال",
    "Federated users" : "کاربران فدرال",
    "teams" : "تیم‌ها",
    "email addresses" : "آدرس‌های ایمیل",
    "Email addresses" : "آدرس‌های ایمیل",
    "contacts" : "مخاطبان",
    "Detailed name" : "نام دقیق",
    "Additional names" : "نام‌های اضافی",
    "Prefix" : "پیشوند",
    "Suffix" : "پسوند",
    "Nickname" : "نام مستعار",
    "Website" : "وب‌سایت",
    "Location" : "مکان",
    "Federated Cloud ID" : "شناسه ابر فدرال",
    "Home" : "خانه",
    "Work" : "محل کار",
    "Other" : "سایر",
    "Address" : "آدرس",
    "Post office box" : "صندوق پستی",
    "Extended address" : "آدرس تکمیلی",
    "City" : "شهر",
    "State or province" : "استان یا ایالت",
    "Postal code" : "کد پستی",
    "Country" : "کشور",
    "Birthday" : "تاریخ تولد",
    "Place of birth" : "محل تولد",
    "Anniversary" : "سالگرد",
    "Date of death" : "تاریخ فوت",
    "Place of death" : "محل فوت",
    "Instant messaging" : "پیام‌رسان فوری",
    "Phone" : "تلفن",
    "Mobile" : "همراه",
    "Work mobile" : "همراه محل کار",
    "Home mobile" : "همراه منزل",
    "Fax" : "نمابر",
    "Fax home" : "نمابر منزل",
    "Fax work" : "نمابر محل کار",
    "Pager" : "پیجر",
    "Voice" : "صدا",
    "Car" : "خودرو",
    "Work pager" : "پیجر محل کار",
    "Line manager" : "مدیر مستقیم",
    "Social network" : "شبکه اجتماعی",
    "Relationship to you" : "نسبت با شما",
    "Spouse" : "همسر",
    "Child" : "فرزند",
    "Mother" : "مادر",
    "Father" : "پدر",
    "Parent" : "والدین",
    "Brother" : "برادر",
    "Sister" : "خواهر",
    "Relative" : "خویشاوند",
    "Friend" : "دوست",
    "Colleague" : "همکار",
    "Assistant" : "دستیار",
    "Related contacts" : "مخاطبان مرتبط",
    "Agent" : "نماینده",
    "Emergency" : "اضطراری",
    "Co-worker" : "هم‌کار",
    "Gender" : "جنسیت",
    "Female" : "زن",
    "Male" : "مرد",
    "Unknown" : "نامشخص",
    "Time zone" : "منطقه زمانی",
    "Spoken languages" : "زبان‌های گفتاری",
    "_{failed} contact failed to be read_::_{failed} contacts failed to be read_" : ["Ø®ÙˆØ§Ù†Ø¯Ù† {failed} Ù…Ø®Ø§Ø·Ø¨ Ù†Ø§Ù…ÙˆÙ�Ù‚ Ø¨ÙˆØ¯","Ø®ÙˆØ§Ù†Ø¯Ù† {failed} Ù…Ø®Ø§Ø·Ø¨ Ù†Ø§Ù…ÙˆÙ�Ù‚ Ø¨ÙˆØ¯"],
    "An error has occurred in team(s). Check the console for more details." : "در تیم(ها) خطایی رخ داده است. برای جزئیات بیشتر کنسول را بررسی کنید.",
    "Unable to create team {circleName}" : "امکان ایجاد تیم {circleName} وجود ندارد",
    "Unable to delete team {circleId}" : "امکان حذف تیم {circleId} وجود ندارد",
    "Could not update favorite state" : "به‌روزرسانی وضعیت موردعلاقه امکان‌پذیر نیست",
    "Unable to delete contact" : "امکان حذف مخاطب وجود ندارد",
    "Value copied to the clipboard" : "مقدار در کلیپ‌بورد کپی شد",
    "Could not copy value to the clipboard." : "امکان کپی کردن مقدار در کلیپ‌بورد وجود نداشت.",
    "Deck board" : "تابلو کارتابل",
    "New Deck board" : "تابلود کارتابل جدید",
    "Board name" : "نام برد",
    "Deck app is not installed. Please install it to create team boards." : "برنامه کارتابل نصب نشده است. لطفاً برای ایجاد بردهای تیمی آن را نصب کنید.",
    "Pick an address book" : "انتخاب یک دفترچه آدرس",
    "Select Date" : "انتخاب تاریخ",
    "note" : "یادداشت",
    "email" : "ایمیل",
    "Create your own groups for sharing. Add Nextcloud users, contacts, or anyone via email." : "گروه‌های خود را برای اشتراک‌گذاری ایجاد کنید. کاربران نکست‌کلود، مخاطبان یا هر فردی را از طریق ایمیل اضافه کنید."
},
"nplurals=2; plural=(n > 1);");
