OC.L10N.register(
    "contacts",
    {
    "Import contacts" : "Inportatu kontaktuak",
    "Details" : "Xehetasuna",
    "All contacts" : "Kontaktu guztiak",
    "Contacts" : "Kontaktuak",
    "A contacts app for Nextcloud" : "Nextclouderako kontaktu aplikazio bat",
    "The Nextcloud contacts app is a user interface for Nextcloud's CardDAV server. Easily sync contacts from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Currently Mail and Calendar – more to come.\n* 🎉 **Never forget a birthday!** You can sync birthdays and other recurring events with your Nextcloud Calendar.\n* 👥 **Sharing of Adressbooks!** You want to share your contacts with your friends or coworkers? No problem!\n* 🙈 **We’re not reinventing the wheel!** Based on the great and open SabreDAV library." : "Nextclouden kontaktuen apliazioa Nextcloudeko CardDAV zerbitzariarentzako erabiltzaile-interfaze bat da. Sinkronizatu hainbat gailuen kontaktuak erraz eta editatu itzazu linean.\n\n* 🚀 **Beste Nextcloud aplikazioekin integratuta!** Oraingoz Posta eta Egutegia – laster gehiago.\n* 🎉 **Ez ezazu urtebetetze bat inoiz ahaztu!** Urtebetetzeak eta beste gertaera errepikariak sinkronizatu ditzakezu Nextcloud Egutegian.\n* 👥 **Helbide-liburuen partekatzea!** Zure kontaktuak partekatu nahi dituzu lagun eta lankideekin? Arazorik ez!\n* 🙈 **Ez gaude gurpila berriro asmatzen!** SabreDAV liburutegi bikain eta irekian oinarrituta.",
    "Copy to full name" : "Kopiatu izen osora",
    "Omit year" : "Kendu urtea",
    "Allow updating avatars from social media" : "Baimendu abatarrak eguneratzea sare sozialetatik",
    "Organization chart" : "Erakundearen diagrama",
    "There was an error fetching the member list" : "Errore bat gertatu da kideen zerrenda eskuratzean",
    "Teams" : "Lantaldeak",
    "Please select a team" : "Mesedez, hautatu lantalde bat",
    "Loading team…" : "Lantaldea kargatzen...",
    "There are no contacts yet" : "Oraindik ez dago kontakturik",
    "Create contact" : "Sortu kontaktua",
    "There are no contacts in this group" : "Ez dago kontakturik talde honetan",
    "Create contacts" : "Sortu kontaktuak",
    "Add contacts" : "Gehitu kontaktuak",
    "Retry" : "Saiatu berriro",
    "Manage team" : "Kudeatu taldea",
    "Leave team" : "Utzi lantaldea",
    "Delete team" : "Ezabatu lantaldea",
    "Contacts settings" : "Kontaktuen ezarpenak",
    "Update avatars from social media" : "Eguneratu avatarrak sare sozialetatik",
    "Address books" : "Helbide liburuak",
    "Rename" : "Aldatu izena",
    "Export" : "Esportatu",
    "Send email" : "Bidali posta-mezua",
    "Send email as BCC" : "Bidali mezu elektronikoa BCC moduan",
    "Delete" : "Ezabatu",
    "Show all groups" : "Erakutsi talde guztiak",
    "Collapse groups" : "Tolestu taldeak",
    "Show all teams" : "Erakutsi lantalde guztiak",
    "Collapse teams" : "Tolestu lantaldeak",
    "This group already exists" : "Talde hau existitzen da dagoeneko",
    "An error occurred while creating the group" : "Errorea gertatu da taldea sortzean",
    "This team already exists" : "Lantalde hau existitzen da dagoeneko",
    "An error happened during the creation of the team" : "Errore bat gertatu da lantaldea sortzean",
    "Recently contacted" : "Berriki kontaktatuak",
    "Contact groups" : "Kontaktuen taldeak",
    "Create a new contact group" : "Sortu kontaktu-talde berria",
    "Contact group name" : "Kontaktu taldearen izena",
    "Create a new team" : "Sortu lantalde berri bat",
    "Open the contacts app settings" : "Ireki kontaktuen aplikazioaren ezarpenak",
    "_Shared with {num} entity_::_Shared with {num} entities_" : ["Entitate {num}ekin partekatuta","{num} entitaterekin partekatuta"],
    "Copied" : "Kopiatuta",
    "Cannot copy" : "Ezin da kopiatu",
    "Copy link" : "Esteka kopiatu",
    "Toggling of address book was not successful" : "Ezin izan da helbide-liburuaren egoera aldatu",
    "This will delete the address book and every contacts within it" : "Honek helbide-liburua eta bere barruan dauden kontaktu guztiak ezabatuko ditu",
    "Delete {addressbook}?" : "Ezabatu {addressbook}?",
    "This will unshare the address book and every contacts within it" : "Honek helbide-liburua eta bere barruan dauden kontaktu guztiak partekatzeari utziko ditu",
    "Unshare {addressbook}?" : "Partekatzeari utzi {addressbook}?",
    "Deletion of address book was not successful." : "Ezin izan da helbide-liburua ezabatu.",
    "Renaming of address book was not successful." : "Ezin izan da helbide-liburua berrizendatu",
    "Download" : "Deskargatu",
    "Show" : "Erakutsi",
    "Unshare from me" : "Kendu nirekin partekatzea",
    "_%n contact_::_%n contacts_" : ["Kontaktu %n","%n kontaktu"],
    "_%n group_::_%n groups_" : ["Talde %n","%n talde"],
    "Share with users or groups" : "Erabiltzaile edo taldeekin partekatu",
    "Share with users" : "Partekatu erabiltzaileekin",
    "No users or groups" : "Erabiltzaile edo talderik ez",
    "Unable to delete the share" : "Ezin izan da partekatzea ezabatu",
    "Unable to change permissions" : "Ezin dira baimenak aldatu",
    "Choose a vCard file to import" : "Aukeratu inportatzeko vCard fitxategi bat",
    "Import into the {addressbookName} address book" : "Inportatu {addressbookName} helbide-liburura",
    "Select local file" : "Hautatu fitxategi lokala",
    "Import from files" : "Inportatu fitxategietatik",
    "Importing is disabled because there are no address books available" : "Inportatzea desgaituta dago ez dagoelako helbide-libururik eskuragarri",
    "An error occurred, unable to create the address book" : "Errore bat gertatu da, ezin izan da helbide liburua sortu",
    "Add new address book" : "Gehitu helbide-liburu berria",
    "Cancel" : "Utzi",
    "Add" : "Add",
    "First name" : "Izena",
    "Last name" : "Abizena",
    "Phonetic first name" : "Izen fonetikoa",
    "Phonetic last name" : "Abizen fonetikoa",
    "Display name" : "Pantaila-izena",
    "Last modified" : "Azken aldaketa",
    "Manages" : "Kudeatzen du",
    "Oversees" : "Gainbegiratzen du",
    "An error happened during the config change" : "Errore bat gertatu da ezarpenak aldatzerakoan",
    "Enforce password protection on files shared to this team" : "Ezarri pasahitz babesa lantalde honekin partekatutako fitxategietan",
    "Use a unique password for all shares to this team" : "Erabili pasahitz esklusibo bat lantalde honetan partekatzeko",
    "Save" : "Gorde",
    "Change unique password" : "Aldatu pasahitz bakarra",
    "Failed to save password. Please try again later." : "Ezin izan da pasahitza gorde. Saiatu berriro geroago.",
    "Close" : "Itxi",
    "There is no description for this team" : "Ez dago deskribapenik lantalde honentzat",
    "Enter a description for the team" : "Gehitu deskribapen bat lantalde honentzat",
    "Folder" : "Folder",
    "Conversation name" : "Elkarrizketaren izena",
    "Team name" : "Lantaldearen izena",
    "Delete picture" : "Ezabatu irudia",
    "Edit" : "Aldatu",
    "Request to join" : "Eskatu elkartzeko baimena",
    "Create" : "Sortu",
    "Your request to join this team is pending approval" : "Lantalde honetan sartzeko zure eskaera onarpenaren zain dago",
    "You are not a member of {circle}" : "Zu ez zara  {circle}-ko kidea",
    "Members" : "Kideak",
    "Confirm" : "Berretsi",
    "Add more info" : "Gehitu informazio gehiago",
    "More fields" : "Eremu gehiago",
    "Please select a valid format" : "Hautatu baliozko formatu bat",
    "Invalid image" : "Baliogabeko irudia",
    "Error cropping picture" : "Errore bat gertatu da argazkia moztean",
    "Pick an avatar" : "Aukeratu avatar bat",
    "Pick" : "Aukeratu",
    "Error while processing the picture." : "Errorea irudia prozesatzen.",
    "Avatar downloaded from social network" : "Abatarra deskargatu da sare sozialetik ",
    "Avatar already up to date" : "Abatarra eguneratuta",
    "Avatar download failed" : "Abatarra deskargatzeak huts egin du",
    "Crop contact photo" : "Moztu kontaktuaren argazkia",
    "Upload a new picture" : "Igo irudi berri bat",
    "Choose from Files" : "Aukeratu Fitxategiak-etik",
    "Download picture" : "Deskargatu irudia",
    "Clone contact" : "Klonatu kontaktua",
    "This contact is in read-only mode. You do not have permission to edit this contact." : "Kontaktu hau irakurtzeko soilik moduan dago. Ez daukazu baimenik kontaktu hau editatzeko.",
    "The contact you were trying to edit has changed. Please manually refresh the contact. Any further edits will be discarded." : "Editatzen saiatu zaren kontaktua aldatu egin da. Mesedez freskatu kontaktua eskuz. Hurrengo editatze guztiak baztertu egingo dira.",
    "Address book" : "Helbide liburua",
    "Add contact to Birthday Calendar" : "Gehitu kontaktua urtebetetze egutegira",
    "Exclude contact from Birthday Calendar" : "Kendu kontaktua urtebetetze egutegitik",
    "{title} at {organization}" : "{organization}-ko {title}",
    "Name" : "Izena",
    "Syntax error. Cannot open the contact." : "Sintaxi-errorea. Ezin da kontaktua ireki.",
    "The contact does not exist on the server anymore." : "Kontaktua ez dago jada zerbitzarian.",
    "Unable to retrieve the contact from the server, please check your network connection." : "Ezin izan da kontaktua lortu zerbitzaritik, begiratu internet konexio ona duzun.",
    "An error occurred while trying to move the contact" : "Errorea gertatu da kontaktua mugitzen saiatzerakoan",
    "An error occurred while trying to copy the contact" : "Errorea gertatu da kontaktua kopiatzen saiatzerakoan",
    "Unable to update contact" : "Ezin da eguneratu kontaktua",
    "No contact selected" : "Ez dago kontakturik hautatuta",
    "Select a contact on the list to begin" : "Hautatu zerrendako kontaktu bat lanean hasteko",
    "Title" : "Izenburua",
    "Company" : "Konpainia",
    "Go to talk conversation" : "Joan talk elkarrizketara",
    "View profile" : "Ikusi profila",
    "This contact was broken and received a fix. Please review the content and click here to save it." : "Kontaktu hau apurtuta zegoen eta konpondu egin da. Mesedez berrikusi edukia eta egin klik hemen gordetzeko.",
    "Edit profile" : "Editatu profila",
    "Generate QR Code" : "Sortu QR kodea",
    "Contact vCard as QR code" : "Kontaktuaren vCard QR kode bezala",
    "Select address book" : "Hautatu helbide-liburua",
    "Media shares with you" : "Multimedia partekatzeak zurekin",
    "Talk conversations with you" : "Talk elkarrizketak zurekin",
    "Calendar events with you" : "Egutegiko gertaerak zurekin",
    "Deck cards with you" : "Deck txartelak zurekin",
    "No shared items with this contact" : "Ez dago partekatutako elementurik kontaktu honekin",
    "Move" : "Move",
    "Remove from favorites" : "Remove from favorites",
    "Add to favorites" : "Gehitu gogokoetan",
    "Add to {group}" : "Gehitu {group} taldera",
    "Remove {type}" : "Kendu {type}",
    "Add to group" : "Gehitu taldera",
    "Search {types}" : "Bilatu {types}",
    "Search for people to add" : "Bilatu gehitzeko pertsonak",
    "No results" : "Emaitzarik ez",
    "Add {type}" : "Gehitu {type}",
    "New team name" : "Lantaldearen izen berria",
    "Personal team" : "Lantalde pertsonala",
    "This team will only be visible to you. Other members will not be able to see or use it." : "Lantalde hau zuretzat bakarrik egongo da ikusgarri. Beste kideek ezingo dute ikusi edo erabili.",
    "Local team" : "Lantalde lokala",
    "This team will not be shared with the other instances of the global scale" : "Lantalde hau ez da eskala globaleko beste instantziekin partekatuko",
    "Create team" : "Sortu lantaldea",
    "Promote as sole owner" : "Igo jabe bakar mailara",
    "Promote to {level}" : "Igo {level} mailara",
    "Demote to {level}" : "Jaitsi {level} mailara",
    "Could not delete the member {displayName}" : "Ezin izan da {displayName} kidea ezabatu",
    "Could not change the member level to {level}" : "Ezin izan da kidearen maila {level} mailara aldatu",
    "Could not accept membership request" : "Ezin izan da kidetze eskaera onartu",
    "Accept membership request" : "Onartu kidetze eskaera",
    "Reject membership request" : "Ukatu kidetze eskaera",
    "Manage level" : "Kudeatu maila",
    "Remove member" : "Kendu kidea",
    "Unable to get the results" : "Ezin dira emaitzak eskuratu",
    "Some members could not be added" : "Kide batzuk ezin izan dira gehitu",
    "There was an issue adding members to the team" : "Arazo bat izan da kideak lantaldera gehitzean",
    "The list of members is only visible to members of this team" : "Kideen zerrenda lantalde honetako kideentzat bakarrik dago ikusgarri",
    "You currently have no access to the member list" : "Ez duzu sarbiderik kideen zerrendara",
    "Pending" : "Zain",
    "Accept" : "Onartu",
    "Created" : "Sortuta",
    "Chart" : "Diagrama",
    "Select type" : "Hautatu mota",
    "Add contact in group" : "Gehitu kontaktua taldera",
    "None" : "Bat ere ez",
    "Select option" : "Hautatu aukera",
    "Notes" : "Oharrak",
    "Add property of this type" : "Gehitu mota honetako propietatea",
    "Member" : "Kidea",
    "Unable to create the contact." : "Ezin izan da kontaktua sortu.",
    "Contact not found" : "Kontaktua ez da aurkitu",
    "Group {group} not found" : "Ez da {group} taldea aurkitu",
    "Add member" : "Gehitu kidea",
    "New contact" : "Kontaktu berria",
    "_{success} contact added to {name}_::_{success} contacts added to {name}_" : ["{success} kontaktuak gehitu dira {name}-ra","{success} kontaktuak gehitu dira {name}-ra"],
    "_Adding {success} contact to {name}_::_Adding {success} contacts to {name}_" : ["{success} kontaktuak {name}-ra gehitzen","{success} kontaktuak gehitu dira {name}-ra"],
    "_{count} error_::_{count} errors_" : ["{count} errorea","{count} erroreak"],
    "_Importing %n contact into {addressbook}_::_Importing %n contacts into {addressbook}_" : ["Kontaktu %n inportatzen {addressbook}(e)ra","%n kontaktu inportatzen {addressbook}(e)ra"],
    "_Done importing %n contact into {addressbook}_::_Done importing %n contacts into {addressbook}_" : ["Kontaktu %n inportatu da {addressbook}(e)ra"," %n kontaktu inportatu dira {addressbook}(e)ra"],
    "Import" : "Inportatu",
    "Are you sure you want to import this contact file?" : "Ziur kontaktuen fitxategi hau inportatu nahi duzula?",
    "Could not copy" : "Ezin izan da kopiatu",
    "Join team" : "Sartu lantaldera",
    "You are about to leave {circle}.\nAre you sure?" : "{circle} zirkulua uztear zaude. \nZiur zaude?",
    "Please confirm team leave" : "Mesedez, berretsi lantaldea uztea",
    "Could not leave the team {displayName}" : "Ezin izan da {displayName} lantaldea utzi",
    "Unable to join the team" : "Ezin izab da lantaldera batu",
    "You are about to delete {circle}.\nAre you sure?" : "{circle} zirkulua ezabatzear zaude.\nZiur zaude?",
    "Please confirm team deletion" : "Mesedez, berretsi lantaldearen ezabapena",
    "Unable to delete the team" : "Ezin izan da lantaldea ezabatu",
    "Link copied to the clipboard" : "Esteka arbelera kopiatu da",
    "Could not copy link to the clipboard." : "Ezin izan da esteka arbelera kopiatu",
    "Not grouped" : "Taldekatu gabe",
    "Team" : "Lantaldea",
    "User" : "Erabiltzailea",
    "Group" : "Taldea",
    "Email" : "E-posta",
    "Contact" : "Kontaktua",
    "Moderator" : "Moderatzailea",
    "Admin" : "Administratzailea",
    "Owner" : "Jabea",
    "Invites" : "Gonbidapenak",
    "Anyone can request membership" : "Edonork eskatu dezake kidetza",
    "Members need to accept invitation" : "Kideek gonbidapena onartu behar dute",
    "Memberships must be confirmed/accepted by a Moderator (requires \"Anyone can request membership\")" : "Moderatzaile batek berretsi / onartu behar ditu kidetzak (\"Edonork kidetza eskatu dezake\" behar du)",
    "Members can also invite" : "Kideek ere gonbidapenak egin ditzakete",
    "Prevent teams from being a member of another team" : "Lantalde bat beste lantalde baten kidea izatea ukatu",
    "Visible to everyone" : "Denontzat ikusgai",
    "users" : "erabiltzaileak",
    "Users" : "Erabiltzaileak",
    "groups" : "taldeak",
    "teams" : "taldeak",
    "email addresses" : "Helbide elektronikoak",
    "Email addresses" : "E-posta helbideak",
    "Detailed name" : "Izen osoa",
    "Additional names" : "Tarteko izenak",
    "Prefix" : "Aurrizkia",
    "Suffix" : "Atzizkia",
    "Nickname" : "Ezizena",
    "Website" : "Webgunea",
    "Location" : "Kokapena",
    "Federated Cloud ID" : "Federatutako hodei IDa",
    "Home" : "Etxekoa",
    "Work" : "Lanekoa",
    "Other" : "Bestelakoa",
    "Address" : "Helbidea",
    "Post office box" : "Posta kutxatila",
    "Extended address" : "Helbide hedatua",
    "City" : "Hiria",
    "State or province" : "Estatu edo probintzia",
    "Postal code" : "Posta kodea",
    "Country" : "Herrialdea",
    "Birthday" : "Jaioteguna",
    "Place of birth" : "Jaiote-lekua",
    "Anniversary" : "Urtebetetzea / urteurrena",
    "Date of death" : "Heriotza data",
    "Place of death" : "Heriotza lekua",
    "Instant messaging" : "Istanteko mezularitza",
    "Phone" : "Telefonoa",
    "Mobile" : "Mugikorra",
    "Work mobile" : "Laneko mugikorra",
    "Home mobile" : "Etxeko mugikorra",
    "Fax" : "Faxa",
    "Fax home" : "Etxeko Faxa",
    "Fax work" : "Laneko faxa",
    "Pager" : "Bilagailua",
    "Voice" : "Ahotsa",
    "Car" : "Kotxea",
    "Work pager" : "Laneko orriztapena",
    "Line manager" : "Linea kudeatzailea",
    "Social network" : "Sare soziala",
    "Relationship to you" : "Zureganako erlazioa",
    "Spouse" : "Emaztea",
    "Child" : "Semea",
    "Mother" : "Ama",
    "Father" : "Aita",
    "Parent" : "Ondokoa",
    "Brother" : "Anaia",
    "Sister" : "Arreba",
    "Relative" : "Familiakoa",
    "Friend" : "Laguna",
    "Colleague" : "Lankidea",
    "Assistant" : "Asistentea",
    "Related contacts" : "Erlazionatutako kontaktuak",
    "Agent" : "Agentea",
    "Emergency" : "Larrialdia",
    "Co-worker" : "Lankidea",
    "Gender" : "Generoa",
    "Female" : "Emakumea",
    "Male" : "Gizonezkoa",
    "Unknown" : "Ezezaguna",
    "Time zone" : "Ordu-zona",
    "Spoken languages" : "Hitz egiteko erabilitako hizkuntzak",
    "_{failed} contact failed to be read_::_{failed} contacts failed to be read_" : ["Ezin izan da kontaktu {failed} irakurri","Ezin izan dira {failed} kontaktu irakurri"],
    "An error has occurred in team(s). Check the console for more details." : "Errore bat gertatu da lantaldeetan. Begiratu kontsola xehetasun gehiago lortzeko.",
    "Unable to create team {circleName}" : "Ezin izan da {circleName} lantaldea sortu",
    "Unable to delete team {circleId}" : "Ezin izan da {circleId} lantaldea ezabatu",
    "Unable to delete contact" : "Ezin izan da kontaktua ezabatu",
    "Pick an address book" : "Aukeratu helbide-liburu bat",
    "Select Date" : "Hautatu data"
},
"nplurals=2; plural=(n != 1);");
