import{_ as i,o as e,c as d,a as o,t as s,w as u,v as S,b as p,g as r,l as m,d as w,L as g}from"./modulepreload-polyfill-CUNWF7kj.chunk.mjs";const y={name:"AdminSettings",data(){return{allowSocialSync:m("contacts","allowSocialSync",!0)}},methods:{updateSetting(a){p.put(r("apps/contacts/api/v1/social/config/global/"+a),{allow:this[a]?"yes":"no"})}}},f={id:"contacts",class:"section"},h={for:"allow-social-sync"};function b(a,t,C,k,n,l){return e(),d("div",f,[o("h2",null,s(a.t("contacts","Contacts")),1),o("p",null,[u(o("input",{id:"allow-social-sync","onUpdate:modelValue":t[0]||(t[0]=c=>n.allowSocialSync=c),type:"checkbox",class:"checkbox",onChange:t[1]||(t[1]=c=>l.updateSetting("allowSocialSync"))},null,544),[[S,n.allowSocialSync]]),o("label",h,s(a.t("contacts","Allow updating avatars from social media")),1)])])}const v=i(y,[["render",b]]);document.addEventListener("DOMContentLoaded",x);function x(){const a=w(v);a.mixin(g),a.mount("#contacts-settings")}
//# sourceMappingURL=contacts-admin-settings.mjs.map
