OC.L10N.register(
    "contacts",
    {
    "Import contacts" : "Importar contatos",
    "Details" : "Detalhes",
    "All contacts" : "Todos os contatos",
    "Email address is required." : "É necessário informar um endereço de e-mail.",
    "An open invite already exists." : "Já existe um convite aberto.",
    "Could not accept invite because no authenticated user was found." : "Não foi possível aceitar o convite porque não foi encontrado nenhum usuário autenticado.",
    "The invite provider is invalid or not allowed." : "O provedor de convites é inválido ou não está autorizado.",
    "Unable to accept this invitation. You are trying to accept an outgoing invitation." : "Não é possível aceitar este convite. Você está tentando aceitar um convite de saída.",
    "Could not accept invite because the remote provider returned an invalid response." : "Não foi possível aceitar o convite porque o provedor remoto retornou uma resposta inválida.",
    "The remote provider accepted the invite, but this server could not create the local contact." : "O provedor remoto aceitou o convite, mas este servidor não conseguiu criar o contato local.",
    "Cannot resend: no email address" : "Não é possível reenviar: não há endereço de e-mail",
    "Invite has already been accepted." : "O convite já foi aceito.",
    "Invite has expired. Please create a new one." : "O convite expirou. Por favor, crie um novo.",
    "This is a copy of an invite sent to you previously by %1$s on %2$s" : "Esta é uma cópia de um convite que lhe foi enviado anteriormente por %1$s em %2$s",
    "Invite already has an email address." : "O destinatário do convite já possui um endereço de e-mail.",
    "An open invite for this email already exists." : "Já existe um convite aberto para este e-mail.",
    "Could not claim invite for this email; please refresh and try again." : "Não foi possível usar o convite para este e-mail; atualize a página e tente novamente.",
    "Could not revert invite after delivery failure. Please refresh and try again." : "Não foi possível reverter o convite após uma falha na entrega. Atualize a página e tente novamente.",
    "OCM invites are disabled." : "Os convites OCM estão desativados.",
    "Recipient email address is invalid." : "O endereço de e-mail do destinatário é inválido.",
    "%1$s via %2$s" : "%1$s via %2$s",
    "%1$s invites you to exchange contact information." : "%1$s convida você a trocar informações de contato.",
    "This is a copy of the invitation you've sent to %1$s" : "Esta é uma cópia do convite que você enviou para %1$s",
    "Hi there," : "Olá,",
    "%1$s invites you to exchange cloud accounts and contact information." : "%1$s convida você a trocar contas na nuvem e informações de contato.",
    "This will allow you to share data with each other." : "Isso permitirá que vocês compartilhem dados entre si.",
    "To accept this invite, click the link below and sign in with your cloud provider:" : "Para aceitar este convite, clique no link abaixo e faça login com seu provedor de nuvem:",
    "Invitation details:" : "Detalhes do convite:",
    "Invite code: %1$s" : "Código de convite: %1$s",
    "Encoded invite: %1$s" : "Convite codificado: %1$s",
    "To accept this invite, use the url below to sign in with your cloud provider:" : "Para aceitar este convite, use o URL abaixo para fazer login com seu provedor de nuvem:",
    "_Imported %n contact_::_Imported %n contacts_" : ["%n contato importado","%n de contatos importados","%n contatos importados"],
    "_(skipped %n contact)_::_(skipped %n contacts)_" : ["(%n contato ignorado)","(%n de contatos ignorados)","(%n contatos ignorados)"],
    "Contacts" : "Contatos",
    "A contacts app for Nextcloud" : "Um aplicativo de contatos para Nextcloud",
    "The Nextcloud contacts app is a user interface for Nextcloud's CardDAV server. Easily sync contacts from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Currently Mail and Calendar – more to come.\n* 🎉 **Never forget a birthday!** You can sync birthdays and other recurring events with your Nextcloud Calendar.\n* 👥 **Sharing of Adressbooks!** You want to share your contacts with your friends or coworkers? No problem!\n* 🙈 **We’re not reinventing the wheel!** Based on the great and open SabreDAV library." : "O aplicativo Nextcloud Contatos é uma interface de usuário para o servidor CardDAV do Nextcloud. Sincronize facilmente os contatos em vários dispositivos e edite-os on-line.\n\n* 🚀 **Integração com outros aplicativos Nextcloud!** Atualmente, E-mail e Calendário – mais por vir.\n* 🎉 **Nunca esqueça um aniversário!** Você pode sincronizar aniversários e outros eventos recorrentes com o seu Calendário do Nextcloud.\n* 👥 **Compartilhamento de Catálogo de Endereços!** Você quer compartilhar seus contatos com seus amigos ou colegas de trabalho? Tranquilo!\n* 🙈 **Não estamos reinventando a roda!** Com base na grande e aberta biblioteca SabreDAV.",
    "Copy to full name" : "Copiar para o nome completo",
    "Omit year" : "Omitir ano",
    "Could not save the setting" : "Não foi possível salvar a configuração",
    "Allow updating avatars from social media" : "Permitir atualização de avatares das mídias sociais",
    "External invitations" : "Convites externos",
    "Allow creating invites without an email address (link-only)" : "Permitir a criação de convites sem endereço de e-mail (apenas por link)",
    "Show the \"Copy encoded invite\" button on invite details" : "Mostrar o botão “Copiar convite codificado” nos detalhes do convite",
    "Organization chart" : "Organograma",
    "There was an error fetching the member list" : "Ocorreu um erro ao obter a lista de membros",
    "Teams" : "Equipes",
    "Please select a team" : "Por favor, selecione uma equipe",
    "Loading team…" : "Carregando equipe…",
    "Loading contacts …" : "Carregando contatos …",
    "There are no contacts yet" : "Ainda não há contatos",
    "Create contact" : "Criar contato",
    "There are no contacts in this group" : "Não há contatos neste grupo",
    "Create contacts" : "Criar contatos",
    "Add contacts" : "Adicionar contatos",
    "Loading invitations…" : "Carregando convites…",
    "Could not load invitations" : "Não foi possível carregar os convites",
    "Retry" : "Retentar",
    "There are no invitations" : "Não há convites",
    "Create invitation" : "Criar convite",
    "Loading …" : "Carregando …",
    "Manage team" : "Gerenciar equipe",
    "Leave team" : "Sair da equipe",
    "Delete team" : "Excluir equipe",
    "Setting saved" : "Configuração salva",
    "Failed to save setting" : "Falha ao salvar a configuração",
    "Contacts settings" : "Configurações de Contatos",
    "General" : "Geral",
    "Update avatars from social media" : "Atualizar avatares pela mídia social",
    "Refreshed once per week" : "Atualizado uma vez por semana",
    "Address books" : "Catálogos de endereços",
    "Tried to drop an invalid contact!" : "Tentou excluir um contato inválido!",
    "Rename" : "Renomear",
    "Export" : "Exportar",
    "Send email" : "Enviar e-mail",
    "Send email as BCC" : "Enviar e-mail como CCO",
    "Delete" : "Excluir",
    "Show all groups" : "Mostrar todos os grupos",
    "Collapse groups" : "Recolher grupos",
    "Show all teams" : "Mostrar todas as equipes",
    "Collapse teams" : "Recolher equipes",
    "Group name cannot be empty" : "Nome do grupo não pode ser vazio",
    "This group already exists" : "Este grupo já existe",
    "An error occurred while creating the group" : "Ocorreu um erro ao criar o grupo",
    "This team already exists" : "Essa equipe já existe",
    "An error happened during the creation of the team" : "Ocorreu um erro durante a criação da equipe",
    "Add address book" : "Adicionar catálogo de endereços",
    "Recently contacted" : "Contactados recentemente",
    "Contact groups" : "Grupos de contatos",
    "Create a new contact group" : "Criar um novo grupo de contatos",
    "Contact group name" : "Nome do grupo de contatos",
    "Create a new team" : "Criar uma nova equipe",
    "Open the contacts app settings" : "Abrir as configurações do aplicativo Contatos",
    "_Shared with {num} entity_::_Shared with {num} entities_" : ["Compartilhado com {num} entidade","Compartilhado com {num} entidades","Compartilhado com {num} entidades"],
    "Copied" : "Copiado",
    "Cannot copy" : "Não pode copiar ",
    "Copy link" : "Copiar link",
    "Toggling of address book was not successful" : "A alternância do catálogo de endereços não foi bem-sucedida",
    "This will delete the address book and every contacts within it" : "Isso excluirá o catálogo de endereços e todos os contatos nele",
    "Delete {addressbook}?" : "Excluir {addressbook}?",
    "This will unshare the address book and every contacts within it" : "Isso descompartilhará o catálogo de endereços e de todos os contatos nele",
    "Unshare {addressbook}?" : "Descompartilhar {addressbook}?",
    "Deletion of address book was not successful." : "A exclusão do catálogo de endereços não foi bem-sucedida.",
    "Renaming of address book was not successful." : "A renomeação do catálogo de endereços não foi bem-sucedida.",
    "{addressbookname} (Hidden)" : "{addressbookname} (Oculto)",
    "Download" : "Baixar",
    "Show" : "Mostrar",
    "Unshare from me" : "Descompartilhar de mim",
    "_%n contact_::_%n contacts_" : ["%n contato","%n contatos","%n contatos"],
    "_%n group_::_%n groups_" : ["%n grupo","%n grupos","%n grupos"],
    "Share with users or groups" : "Compartilhar com usuários ou grupos",
    "Share with users" : "Compartilhar com usuários",
    "No users or groups" : "Nenhum usuário ou grupo",
    "Unable to delete the share" : "Não foi possível excluir o compartilhamento",
    "Unable to change permissions" : "Não é possível alterar as permissões",
    "can create and edit" : "pode criar e editar",
    "Choose a vCard file to import" : "Escolha um arquivo vCard para importar",
    "Import into the {addressbookName} address book" : "Importar para o catálogo de endereços  {addressbookName}",
    "Select local file" : "Selecionar um arquivo local",
    "Import from files" : "Importar de Arquivos",
    "Importing is disabled because there are no address books available" : "A importação está desativada porque não há catálogos de endereços disponíveis",
    "An error occurred, unable to create the address book" : "Ocorreu um erro ao criar o catálogo de endereços",
    "New address book" : "Novo catálogo de endereços",
    "Add new address book" : "Adicionar novo catálogo de endereços",
    "Cancel" : "Cancelar",
    "Add" : "Adicionar",
    "First name" : "Primeiro nome",
    "Last name" : "Sobrenome",
    "Phonetic first name" : "Primeiro nome fonético",
    "Phonetic last name" : "Último nome fonético",
    "Display name" : "Nome de exibição",
    "Last modified" : "Última modificação",
    "Sort contacts by" : "Ordenar contatos por",
    "Manages" : "Gerencia",
    "Oversees" : "Supervisiona",
    "An error happened during the config change" : "Ocorreu um erro durante a mudança das configurações",
    "Enforce password protection on files shared to this team" : "Impor proteção por senha aos arquivos compartilhados com esta equipe",
    "Use a unique password for all shares to this team" : "Usar uma senha única para todos os compartilhamentos desta equipe",
    "Unique password …" : "Senha única …",
    "Save" : "Salvar",
    "Change unique password" : "Alterar senha única",
    "Failed to save password. Please try again later." : "Falha ao salvar a senha. Por favor, tente novamente mais tarde.",
    "Close" : "Fechar",
    "Choose a team picture" : "Escolha uma imagem de equipe",
    "There is no description for this team" : "Não há descrição para esta equipe",
    "Enter a description for the team" : "Insira uma descrição para a equipe",
    "Folder" : "Pasta",
    "New folder" : "Nova pasta",
    "Folder name" : "Nome da pasta",
    "This will create a regular folder shared with the team. To create a Team Folder, please contact your {productName} administrator" : "Isso criará uma pasta comum compartilhada com a equipe. Para criar uma pasta da equipe, entre em contato com a administração do {productName}.",
    "Talk conversation" : "Conversa Talk",
    "New Talk conversation" : "Nova conversa do Talk",
    "Conversation name" : "Nome da conversa",
    "Collective" : "Coletivo",
    "Calendar" : "Calendário",
    "New calendar" : "Novo calendário",
    "Calendar name" : "Nome do calendário",
    "Unknown resource type" : "Tipo de recurso desconhecido",
    "Team calendar \"{resourceName}\" created and shared with team" : "Calendário de equipe \"{resourceName}\" criado e compartilhado com a equipe",
    "{resourceType} \"{resourceName}\" created and shared with team" : "{resourceType} \"{resourceName}\" criado e compartilhado com a equipe",
    "A calendar named \"{name}\" already exists. Please choose a different name." : "Já existe um calendário chamado \"{name}\". Escolha um nome diferente.",
    "Failed to create {resourceType}: {error}" : "Falha ao criar {resourceType}: {error}",
    "Please select a valid png or jpg file" : "Por favor, selecione um arquivo PNG ou JPG válido",
    "Error picking team picture" : "Erro ao selecionar a imagem de equipe",
    "Error cropping avatar picture" : "Erro ao recortar a foto do avatar",
    "An error happened while saving {fields}" : "Ocorreu um erro ao salvar {fields}",
    "Team name" : "Nome da equipe",
    "Team owner" : "Proprietário da equipe",
    "Upload team picture" : "Enviar imagem de equipe",
    "Choose from Nextcloud Files" : "Escolher do Nextcloud Arquivos",
    "Delete picture" : "Excluir imagem",
    "Edit" : "Editar",
    "Request to join" : "Solicitar adesão",
    "Create" : "Criar",
    "Show in Calendar" : "Mostrar no Calendário",
    "Your request to join this team is pending approval" : "Seu pedido de adesão a esta equipe está pendente de aprovação",
    "You are not a member of {circle}" : "Você não é membro de {circle}",
    "Members" : "Membros",
    "Edit team picture" : "Editar imagem de equipe",
    "Apply" : "Aplicar",
    "Confirm" : "Confirmar",
    "No other contacts available to select as line manager" : "Não há outros contatos disponíveis para selecionar como superior hierárquico",
    "Add more info" : "Adicionar mais informações",
    "More fields" : "Mais campos",
    "Please select a valid format" : "Selecione um formato válido",
    "Invalid image" : "Imagem inválida",
    "Error cropping picture" : "Erro ao recortar imagem",
    "Pick an avatar" : "Escolha um avatar",
    "Pick" : "Escolha",
    "Error while processing the picture." : "Erro ao processar a imagem.",
    "Avatar downloaded from social network" : "Avatar baixado da rede social",
    "Avatar already up to date" : "Avatar já atualizado",
    "Avatar download failed" : "Falha no download do avatar",
    "Crop contact photo" : "Cortar foto do contato",
    "Upload a new picture" : "Enviar uma nova imagem",
    "Choose from Files" : "Escolher de Arquivos",
    "Download picture" : "Baixar imagem",
    "Clone contact" : "Clonar contato",
    "This contact is in read-only mode. You do not have permission to edit this contact." : "Este contato é somente leitura. Você não tem permissão para editar este contato.",
    "The contact you were trying to edit has changed. Please manually refresh the contact. Any further edits will be discarded." : "O contato que você estava tentando editar foi alterado. Atualize manualmente o contato. Qualquer outra edição será descartada.",
    "Address book" : "Catálogo de endereços",
    "Add contact to Birthday Calendar" : "Adicionar contato ao Calendário de Aniversários",
    "Exclude contact from Birthday Calendar" : "Excluir contato do Calendário de Aniversários",
    "{title} at {organization}" : "{title} em {organization}",
    "Name" : "Nome",
    "Syntax error. Cannot open the contact." : "Erro de sintaxe. Não é possível abrir o contato.",
    "The contact does not exist on the server anymore." : "O contato não existe mais no servidor.",
    "Unable to retrieve the contact from the server, please check your network connection." : "Não foi possível recuperar o contato do servidor, verifique sua conexão de rede.",
    "An error occurred while trying to move the contact" : "Ocorreu um erro ao mover o contato",
    "An error occurred while trying to copy the contact" : "Ocorreu um erro ao copiar o contato",
    "Unable to update contact" : "Não foi possível atualizar o contato",
    "No contact selected" : "Nenhum contato selecionado",
    "Select a contact on the list to begin" : "Selecione um contato na lista para começar",
    "Title" : "Título",
    "Company" : "Empresa",
    "Go to talk conversation" : "Ir para conversa do Talk",
    "View profile" : "Ver perfil",
    "This contact was broken and received a fix. Please review the content and click here to save it." : "Este contato foi corrompido e recebeu uma correção. Revise o conteúdo e clique aqui para salvá-lo.",
    "Edit profile" : "Editar perfil",
    "Generate QR Code" : "Gerar Código QR",
    "Contact vCard as QR code" : "vCard do contato como código QR",
    "Select address book" : "Selecione o catálogo de endereços",
    "Media shares with you" : "Compartilhamentos de mídia com você",
    "Talk conversations with you" : "Conversas do Talk com você",
    "Calendar events with you" : "Eventos de calendário com você",
    "Deck cards with you" : "Cartões de Deck com você",
    "No shared items with this contact" : "Nenhum item compartilhado com este contato",
    "This contact cannot be moved" : "Este contato não pode ser movido",
    "This contact cannot be grouped" : "Este contato não pode ser agrupado",
    "Add contacts to groups" : "Adicionar contatos a grupos",
    "Move contacts to addressbook" : "Mover contatos para o catálogo de endereços",
    "Select groups" : "Selecionar grupos",
    "Select addressbook" : "Selecionar catálogo de endereços",
    "Selected contacts" : "Contatos selecionados",
    "Please note that only {count} of the {total} contacts can be added to a group" : "Observe que apenas {count} dos {total} contatos podem ser adicionados a um grupo",
    "Please note that only {count} of the {total} contacts can be moved" : "Observe que apenas {count} dos {total} contatos podem ser movidos",
    "Move" : "Mover",
    "Unselect {name}" : "Desselecionar {name}",
    "Select {name}" : "Selecionar {name}",
    "Could not update favorite status" : "Não foi possível atualizar o status de favorito",
    "from {addressbook}" : "de {addressbook}",
    "Remove from favorites" : "Remover dos favoritos",
    "Add to favorites" : "Adicionar aos favoritos",
    "Confirm merging contacts" : "Confirmar a fusão de contatos",
    "The selected contacts have conflicting information. Choose which information to keep" : "Os contatos selecionados têm informações conflitantes. Escolha quais informações deseja manter.",
    "Contacts can be merged" : "Os contatos podem ser mesclados",
    "Groups" : "Grupos",
    "Select groups to add the merged contact to" : "Selecione os grupos aos quais deseja adicionar o contato mesclado",
    "Merge contacts" : "Mesclar contatos",
    "_Delete {number} contact_::_Delete {number} contacts_" : ["Excluir {number} contato","Excluir {number} de contatos","Excluir {number} contatos"],
    "Please select at least one editable contact to delete" : "Selecione pelo menos um contato editável para excluir",
    "Please select two editable contacts to merge" : "Por favor, selecione dois contatos editáveis para mesclar",
    "_Add {number} contact to group_::_Add {number} contacts to group_" : ["Adicionar {number} contato ao grupo","Adicionar {number} de contatos ao grupo","Adicionar {number} contatos ao grupo"],
    "Please select at least one editable contact to add to a group" : "Selecione pelo menos um contato editável para adicionar a um grupo",
    "_Move {number} contact to addressbook_::_Move {number} contacts to addressbook_" : ["Mover {number} contato para o catálogo de endereços","Mover {number} de contatos para o catálogo de endereços","Mover {number} contatos para o catálogo de endereços"],
    "Please select at least one editable contact to move to an addressbook" : "Selecione pelo menos um contato editável para mover para um catálogo de endereços",
    "Are you sure you want to proceed?" : "Tem certeza de que deseja continuar?",
    "Add contacts to group" : "Adicionar contatos ao grupo",
    "Search contacts …" : "Pesquisando contatos …",
    "Unselect {number}" : "Desselecionar {number}",
    "Add to {group}" : "Adicionar a {group}",
    "Add members to {group}" : "Adicionar membros a {group}",
    "Please note that you can only add contacts from writable address books to contact groups. Contacts from read-only address books, such as the system address book, cannot be added." : "Observe que só é possível adicionar contatos de catálogos de endereços graváveis a grupos de contatos. Os contatos de catálogos de endereços somente leitura, como o catálogo de endereços do sistema, não podem ser adicionados.",
    "Remove {type}" : "Excluir {type}",
    "Add to group" : "Adicionar ao grupo",
    "Add members to group" : "Adicionar membros ao grupo",
    "Search {types}" : "Pesquisar {types}",
    "Add guest" : "Adicionar visitante",
    "Search for people to add" : "Pesquisar pessoas para adicionar",
    "No results" : "Sem resultados",
    "Add {type}" : "Adicionar {type}",
    "New team name" : "Nome da nova equipe",
    "Personal team" : "Equipe pessoal",
    "This team will only be visible to you. Other members will not be able to see or use it." : "Esta equipe ficará visível apenas para você. Outros membros não poderão vê-lo ou usá-lo.",
    "Local team" : "Equipe local",
    "This team will not be shared with the other instances of the global scale" : "Esta equipe não será compartilhada com as outras instâncias da escala global",
    "Create team" : "Criar equipe",
    "Promote as sole owner" : "Promover como único proprietário",
    "Promote to {level}" : "Promover para {level}",
    "Demote to {level}" : "Rebaixar para {level}",
    "Are you sure you want to leave this team? This action cannot be undone." : "Tem certeza de que deseja deixar esta equipe? Esta ação não pode ser desfeita.",
    "Leave team failed." : "Falha na saída da equipe.",
    "Could not delete the member {displayName}" : "Não foi possível excluir o membro {displayName}",
    "Could not change the member level to {level}" : "Não foi possível alterar o nível de membro para {level}",
    "Could not accept membership request" : "Não foi possível aceitar o pedido de adesão ",
    "Accept membership request" : "Aceitar pedido de adesão",
    "Reject membership request" : "Rejeitar pedido de adesão",
    "Manage level" : "Gerenciar nível",
    "Remove member" : "Remover membro",
    "Unable to get the results" : "Não é possível obter os resultados",
    "Some members could not be added" : "Alguns membros não puderam ser adicionados",
    "There was an issue adding members to the team" : "Ocorreu um problema ao adicionar membros à equipe",
    "Loading members list …" : "Carregando lista de membros …",
    "The list of members is only visible to members of this team" : "A lista de membros só é visível para membros desta equipe",
    "You currently have no access to the member list" : "No momento, você não tem acesso à lista de membros",
    "Add to {team}" : "Adicionar a {team}",
    "Invite members to {team}" : "Convidar membros para {team}",
    "Pending" : "Pendente",
    "This invite does not look valid. Check that you copied it completely or ask the sender to generate a new one." : "Este convite não parece válido. Verifique se você o copiou na íntegra ou peça ao remetente para gerar um novo.",
    "Accept invitation" : "Aceitar convite",
    "Accepting will add the inviter to your contacts list and in return, your contact info will be sent to the inviter. From there on you can start sharing data with each other." : "Ao aceitar, o convidante será adicionado à sua lista de contatos e, em troca, suas informações de contato serão enviadas a ele. A partir daí, vocês poderão começar a compartilhar dados entre si.",
    "Invite link or code (required)" : "Link ou código de convite (obrigatório)",
    "Paste the invite link, or an invite code (token@provider), you received from the other person." : "Cole o link de convite ou um código de convite (token@provedor) que você recebeu da outra pessoa.",
    "Accept" : "Aceitar",
    "Please enter an email address." : "Por favor, insira um endereço de e-mail.",
    "The recipient will receive an email with the invite link. Their email address will be saved on the invite so you can resend later." : "O destinatário receberá um e-mail com o link de convite. O endereço de e-mail dele será salvo no convite para que você possa reenviá-lo mais tarde.",
    "Recipient email (required)" : "E-mail do destinatário (obrigatório)",
    "email@example.com" : "email@example.com",
    "Personal message (optional)" : "Mensagem pessoal (opcional)",
    "Message to include in the email" : "Mensagem a ser incluída no e-mail",
    "Sending…" : "Enviando…",
    "Send" : "Enviar",
    "Invite code" : "Código de convite",
    "Cloud provider" : "Provedor de serviços em nuvem",
    "Encoded invite copied to clipboard" : "Convite codificado copiado para a área de transferência",
    "Invite code copied to clipboard" : "Código de convite copiado para a área de transferência",
    "Invite link copied to clipboard" : "Link de convite copiado para a área de transferência",
    "Copied to clipboard" : "Copiado para a área de transferência",
    "Failed to copy to clipboard" : "Falha ao copiar para a área de transferência",
    "Could not resend invite" : "Não foi possível reenviar o convite",
    "Invite revoked" : "Convite revogado",
    "Could not revoke invite" : "Não foi possível revogar o convite",
    "Invite sent to {email}" : "Convite enviado para {email}",
    "Could not send invite" : "Não foi possível enviar o convite",
    "No invitation selected" : "Nenhum convite selecionado",
    "Select an invitation on the list to begin" : "Selecione um convite na lista para começar",
    "External invitation" : "Convite externo",
    "Label" : "Rótulo",
    "Sent to" : "Enviado para",
    "Created" : "Criado",
    "Expires" : "Expira",
    "More ways to share" : "Mais maneiras de compartilhar",
    "Useful for sharing through a chat app or for manual acceptance." : "Útil para compartilhar por meio de um aplicativo de bate-papo ou para aceitação manual.",
    "Revoke invitation" : "Revogar convites",
    "Resend email" : "Reenviar e-mail",
    "Send via email" : "Enviar por e-mail",
    "Send invitation via email" : "Enviar convite por e-mail",
    "{name} invites you to exchange cloud accounts and contact information." : "{name} convida você a trocar contas na nuvem e informações de contato.",
    "The invite link and code are added automatically when you send the invitation." : "O link e o código de convite são adicionados automaticamente quando você envia o convite.",
    "Recipient email" : "E-mail do destinatário",
    "Invite someone outside your organization to collaborate" : "Convide alguém de fora da sua organização para colaborar",
    "After the invitee accepts the invite, both of you will appear in each other's contacts list and you can start sharing data with each other." : "Depois que o convidado aceitar o convite, vocês dois aparecerão na lista de contatos um do outro e poderão começar a compartilhar dados entre si.",
    "Send invite via email" : "Enviar convite por e-mail",
    "Hide email preview" : "Ocultar pré-visualização do e-mail",
    "Show email preview" : "Exibir pré-visualização do e-mail",
    "This is what {recipient} will receive:" : "É isso que {recipient} receberá:",
    "If you do not send an email, you will need to share the invite link yourself." : "Se você não enviar um e-mail, precisará compartilhar o link de convite por conta própria.",
    "Invite link" : "Link de convite",
    "Copy invite link to clipboard" : "Copiar o link de convite para a área de transferência",
    "Copy invite code to clipboard" : "Copiar o código de convite para a área de transferência",
    "Encoded invite" : "Convite codificado",
    "Copy encoded invite to clipboard" : "Copiar o convite codificado para a área de transferência",
    "Search invites…" : "Pesquisar convites…",
    "Could not discover that provider. Check the address and try again." : "Não foi possível localizar esse provedor. Verifique o endereço e tente novamente.",
    "Select your server" : "Selecione seu servidor",
    "Type to search" : "Digite para pesquisar",
    "No servers match your search." : "Nenhum servidor corresponde à sua pesquisa.",
    "No servers are currently available." : "No momento, não há servidores disponíveis.",
    "Your server not listed? Enter one manually." : "Seu servidor não está na lista? Insira-o manualmente.",
    "Continue" : "Continuar",
    "You need an invite link for this feature to work." : "Você precisa de um link de convite para que esse recurso funcione.",
    "Select chart …" : "Selecione um gráfico …",
    "Chart" : "Gráfico",
    "Select type" : "Selecionar tipo",
    "Add contact in group" : "Adicionar contato ao grupo",
    "None" : "Nenhum",
    "copy" : "copiar",
    "Select option" : "Selecionar a opção",
    "JavaScript URIs are not allowed" : "URIs de JavaScript não são permitidos",
    "Notes" : "Anotações",
    "send an email" : "enviar um e-mail",
    "Personal dates" : "Datas pessoais",
    "Add property of this type" : "Adicionar propriedade deste tipo",
    "Member" : "Membro",
    "This is a read-only group managed by administrators. Group members can only view this group." : "Este é um grupo somente leitura gerenciado por administradores. Os membros do grupo só podem visualizar este grupo.",
    "Send invitation" : "Enviar convite",
    "Generate invitation" : "Gerar convite",
    "This invite link is incomplete. Ask the sender to generate a new one." : "Este link de convite está incompleto. Peça ao remetente para gerar um novo.",
    "Unable to create the contact." : "Não foi possível criar o contato.",
    "Contact not found" : "Contato não encontrado",
    "Address book {addressbook} not found" : "Catálogo de endereços {addressbook} não encontrado",
    "Group {group} not found" : "Grupo {group} não encontrado",
    "Could not accept invite" : "Não foi possível aceitar o convite",
    "Could not create invite" : "Não foi possível criar o convite",
    "Add member" : "Adicionar membro",
    "New contact" : "Novo contato",
    "_{success} contact added to {name}_::_{success} contacts added to {name}_" : ["{success} contato adicionado a {name}","{success} contatos adicionados a {name}","{success} contatos adicionados a {name}"],
    "_Adding {success} contact to {name}_::_Adding {success} contacts to {name}_" : ["Adicionando {success} contato a {name}","Adicionando {success} contatos a {name}","Adicionando {success} contatos a {name}"],
    "_{count} error_::_{count} errors_" : ["{count} erro","{count} erros","{count} erros"],
    "_Importing %n contact into {addressbook}_::_Importing %n contacts into {addressbook}_" : ["Importando %n contato para {addressbook}","Importando %n contatos para {addressbook}","Importando %n contatos para {addressbook}"],
    "_Done importing %n contact into {addressbook}_::_Done importing %n contacts into {addressbook}_" : ["Importação concluída de %n contato para {addressbook}","Importação concluída de %n contatos para {addressbook}","Importação concluída de %n contatos para {addressbook}"],
    "No data for this contact" : "Sem dados para este contato",
    "No data for this contact on their profile" : "Sem dados para este contato em seu perfil",
    "Import" : "Importar",
    "Are you sure you want to import this contact file?" : "Tem certeza de que deseja importar este arquivo de contato?",
    "Could not copy" : "Não foi possível copiar",
    "Join team" : "Entrar na equipe",
    "You are about to leave {circle}.\nAre you sure?" : "Você está prestes a sair do {circle}.\nTem certeza?",
    "Please confirm team leave" : "Confirme a saída da equipe",
    "Could not leave the team {displayName}" : "Não foi possível sair da equipe {displayName}",
    "Unable to join the team" : "Não é possível entrar na equipe",
    "You are about to delete {circle}.\nAre you sure?" : "Você está prestes a excluir {circle}.\nTem certeza?",
    "Please confirm team deletion" : "Confirme a exclusão da equipe",
    "Unable to delete the team" : "Não foi possível excluir a equipe",
    "Confirm enabling federation" : "Confirmar a ativação da federação",
    "Enabling this will prevent {circle} from being a member of other teams.\nAre you sure?" : "Ativar essa opção impedirá que {circle} seja membro de outras equipes.\nTem certeza?",
    "Enable federation" : "Ativar federação",
    "Link copied to the clipboard" : "Link copiado para a área de transferência",
    "Could not copy link to the clipboard." : "Não foi possível copiar o link para a área de transferência.",
    "Not grouped" : "Não agrupado",
    "Create your own teams for sharing. Add Nextcloud users, contacts, or anyone via email." : "Crie suas próprias equipes para compartilhar. Adicione usuários do Nextcloud, contatos ou qualquer pessoa por e-mail.",
    "Team" : "Equipe",
    "User" : "Usuário",
    "Group" : "Grupo",
    "Email" : "E-mail",
    "Contact" : "Contactar",
    "Moderator" : "Moderador",
    "Admin" : "Admin",
    "Owner" : "Proprietário",
    "Invites" : "Convites",
    "Anyone can request membership" : "Qualquer pessoa pode solicitar adesão",
    "Members need to accept invitation" : "Os membros precisam aceitar o convite",
    "Memberships must be confirmed/accepted by a Moderator (requires \"Anyone can request membership\")" : "As adesões devem ser confirmadas/aceitas por um moderador (requer \"Qualquer pessoa pode solicitar adesão\")",
    "Members can also invite" : "Os membros também podem convidar",
    "Membership" : "Afiliação",
    "Prevent teams from being a member of another team" : "Impedir que equipes sejam membros de outra equipe",
    "Federation" : "Federação",
    "Allow federated members" : "Permitir membros federados",
    "Privacy" : "Privacidade",
    "Visible to everyone" : "Visível para todos",
    "users" : "usuários",
    "Users" : "Usuários",
    "groups" : "grupos",
    "federated users" : "usuários federados",
    "Federated users" : "Usuários federados",
    "teams" : "equipes",
    "email addresses" : "endereços de e-mail",
    "Email addresses" : "Endereço de e-mail",
    "contacts" : "contatos",
    "Link-only invite" : "Convite apenas por link",
    "Detailed name" : "Nome detalhado",
    "Additional names" : "Nomes adicionais",
    "Prefix" : "Prefixo",
    "Suffix" : "Sufixo",
    "Nickname" : "Apelido",
    "Website" : "Website",
    "Location" : "Localização",
    "Federated Cloud ID" : "ID de Nuvem Federada",
    "Home" : "Casa",
    "Work" : "Trabalho",
    "Other" : "Outro",
    "Address" : "Endereço",
    "Post office box" : "Caixa de correio",
    "Extended address" : "Endereço estendido",
    "City" : "Cidade",
    "State or province" : "Estado ou província",
    "Postal code" : "Código postal",
    "Country" : "País",
    "Birthday" : "Aniversário",
    "Place of birth" : "Local de nascimento",
    "Anniversary" : "Aniversário",
    "Date of death" : "Data do óbito",
    "Place of death" : "Local do óbito",
    "Instant messaging" : "Mensagem instantânea",
    "Phone" : "Telefone",
    "Mobile" : "Celular",
    "Work mobile" : "Celular do trabalho",
    "Home mobile" : "Celular pessoal",
    "Fax" : "Fax",
    "Fax home" : "Fax de casa",
    "Fax work" : "Fax do trabalho",
    "Pager" : "Pager",
    "Voice" : "Voz",
    "Car" : "Carro",
    "Work pager" : "Pager do trabalho",
    "Line manager" : "Superior hierárquico",
    "Social network" : "Rede social",
    "Relationship to you" : "Relacionado com você",
    "Spouse" : "Esposo(a)",
    "Child" : "Filho(a)",
    "Mother" : "Mãe",
    "Father" : "Pai",
    "Parent" : "Pais",
    "Brother" : "Irmão",
    "Sister" : "Irmã",
    "Relative" : "Parente",
    "Friend" : "Amigo",
    "Colleague" : "Colega",
    "Assistant" : "Assistente",
    "Related contacts" : "Contatos relacionados",
    "Agent" : "Agente",
    "Emergency" : "Emergência",
    "Co-worker" : "Colega de trabalho",
    "Gender" : "Gênero",
    "Female" : "Mulher",
    "Male" : "Homem",
    "Unknown" : "Desconhecido",
    "Time zone" : "Fuso horário ",
    "Spoken languages" : "Idiomas falados",
    "_{failed} contact failed to be read_::_{failed} contacts failed to be read_" : ["{failed} contato falhou ao ler","{failed} contatos falharam ao ler","{failed} contatos falharam ao ler"],
    "An error has occurred in team(s). Check the console for more details." : "Ocorreu um erro na(s) equipe(s). Verifique o console para mais detalhes.",
    "Unable to create team {circleName}" : "Não foi possível criar a equipe {circleName}",
    "Unable to delete team {circleId}" : "Não foi possível excluir a equipe {circleId}",
    "Could not update favorite state" : "Não foi possível atualizar o status de favorito",
    "Unable to delete contact" : "Não foi possível excluir o contato",
    "Value copied to the clipboard" : "Valor copiado para a área de transferência",
    "Could not copy value to the clipboard." : "Não foi possível copiar o valor para a área de transferência.",
    "Deck board" : "Painel de Deck",
    "New Deck board" : "Novo painel de Deck",
    "Board name" : "Nome do painel",
    "Deck app is not installed. Please install it to create team boards." : "O aplicativo Deck não está instalado. Por favor, instale-o para criar painéis de equipe.",
    "Pick an address book" : "Escolha um catálogo de endereços",
    "Select Date" : "Selecionar Data",
    "note" : "nota",
    "email" : "e-mail",
    "Create your own groups for sharing. Add Nextcloud users, contacts, or anyone via email." : "Crie seus próprios grupos para compartilhar. Adicione usuários do Nextcloud, contatos ou qualquer pessoa por e-mail."
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
