OC.L10N.register(
    "contacts",
    {
    "Import contacts" : "Import contacts",
    "Details" : "ລາຍລະອຽດ",
    "All contacts" : "All contacts",
    "_Imported %n contact_::_Imported %n contacts_" : ["Imported %n contacts"],
    "Contacts" : "ຕິດຕໍ່",
    "A contacts app for Nextcloud" : "A contacts app for Nextcloud",
    "The Nextcloud contacts app is a user interface for Nextcloud's CardDAV server. Easily sync contacts from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Currently Mail and Calendar – more to come.\n* 🎉 **Never forget a birthday!** You can sync birthdays and other recurring events with your Nextcloud Calendar.\n* 👥 **Sharing of Adressbooks!** You want to share your contacts with your friends or coworkers? No problem!\n* 🙈 **We’re not reinventing the wheel!** Based on the great and open SabreDAV library." : "The Nextcloud contacts app is a user interface for Nextcloud's CardDAV server. Easily sync contacts from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Currently Mail and Calendar – more to come.\n* 🎉 **Never forget a birthday!** You can sync birthdays and other recurring events with your Nextcloud Calendar.\n* 👥 **Sharing of Adressbooks!** You want to share your contacts with your friends or coworkers? No problem!\n* 🙈 **We’re not reinventing the wheel!** Based on the great and open SabreDAV library.",
    "Copy to full name" : "Copy to full name",
    "Omit year" : "Omit year",
    "Allow updating avatars from social media" : "Allow updating avatars from social media",
    "Organization chart" : "Organization chart",
    "There was an error fetching the member list" : "There was an error fetching the member list",
    "Teams" : "Teams",
    "Please select a team" : "Please select a team",
    "Loading team…" : "Loading team…",
    "Loading contacts …" : "Loading contacts …",
    "There are no contacts yet" : "There are no contacts yet",
    "Create contact" : "Create contact",
    "There are no contacts in this group" : "There are no contacts in this group",
    "Create contacts" : "Create contacts",
    "Add contacts" : "Add contacts",
    "Loading …" : "Loading …",
    "Manage team" : "Manage team",
    "Leave team" : "Leave team",
    "Delete team" : "Delete team",
    "Setting saved" : "Setting saved",
    "Failed to save setting" : "Failed to save setting",
    "Contacts settings" : "Contacts settings",
    "General" : "General",
    "Update avatars from social media" : "Update avatars from social media",
    "Refreshed once per week" : "Refreshed once per week",
    "Address books" : "Address books",
    "Rename" : "ປ່ຽນຊື່",
    "Export" : "Export",
    "Send email" : "Send email",
    "Send email as BCC" : "Send email as BCC",
    "Delete" : "ລຶບ",
    "Show all groups" : "Show all groups",
    "Collapse groups" : "Collapse groups",
    "Show all teams" : "Show all teams",
    "Collapse teams" : "Collapse teams",
    "Group name cannot be empty" : "Group name cannot be empty",
    "This group already exists" : "This group already exists",
    "An error occurred while creating the group" : "An error occurred while creating the group",
    "This team already exists" : "This team already exists",
    "An error happened during the creation of the team" : "An error happened during the creation of the team",
    "Recently contacted" : "Recently contacted",
    "Contact groups" : "Contact groups",
    "Create a new contact group" : "Create a new contact group",
    "Contact group name" : "Contact group name",
    "Create a new team" : "Create a new team",
    "Open the contacts app settings" : "Open the contacts app settings",
    "_Shared with {num} entity_::_Shared with {num} entities_" : ["Shared with {num} entities"],
    "Copied" : "Copied",
    "Cannot copy" : "Cannot copy",
    "Copy link" : "ສຳເນົາລິງ",
    "Toggling of address book was not successful" : "Toggling of address book was not successful",
    "This will delete the address book and every contacts within it" : "This will delete the address book and every contacts within it",
    "Delete {addressbook}?" : "Delete {addressbook}?",
    "This will unshare the address book and every contacts within it" : "This will unshare the address book and every contacts within it",
    "Unshare {addressbook}?" : "Unshare {addressbook}?",
    "Deletion of address book was not successful." : "Deletion of address book was not successful.",
    "Renaming of address book was not successful." : "Renaming of address book was not successful.",
    "{addressbookname} (Hidden)" : "{addressbookname} (Hidden)",
    "Download" : "ດາວໂຫລດ",
    "Show" : "Show",
    "Unshare from me" : "Unshare from me",
    "_%n contact_::_%n contacts_" : ["%n contacts"],
    "_%n group_::_%n groups_" : ["%n groups"],
    "Share with users or groups" : "Share with users or groups",
    "Share with users" : "Share with users",
    "No users or groups" : "No users or groups",
    "Unable to delete the share" : "Unable to delete the share",
    "Unable to change permissions" : "Unable to change permissions",
    "Choose a vCard file to import" : "Choose a vCard file to import",
    "Import into the {addressbookName} address book" : "Import into the {addressbookName} address book",
    "Select local file" : "Select local file",
    "Import from files" : "Import from files",
    "Importing is disabled because there are no address books available" : "Importing is disabled because there are no address books available",
    "An error occurred, unable to create the address book" : "An error occurred, unable to create the address book",
    "New address book" : "New address book",
    "Add new address book" : "Add new address book",
    "Cancel" : "ຍົກເລີກ",
    "Add" : "ເພີ່ມ",
    "First name" : "First name",
    "Last name" : "Last name",
    "Phonetic first name" : "Phonetic first name",
    "Phonetic last name" : "Phonetic last name",
    "Display name" : "Display name",
    "Last modified" : "Last modified",
    "Manages" : "Manages",
    "Oversees" : "Oversees",
    "An error happened during the config change" : "An error happened during the config change",
    "Enforce password protection on files shared to this team" : "Enforce password protection on files shared to this team",
    "Use a unique password for all shares to this team" : "Use a unique password for all shares to this team",
    "Unique password …" : "Unique password …",
    "Save" : "ບັນທຶກ",
    "Change unique password" : "Change unique password",
    "Failed to save password. Please try again later." : "Failed to save password. Please try again later.",
    "Close" : "ປິດ",
    "There is no description for this team" : "There is no description for this team",
    "Enter a description for the team" : "Enter a description for the team",
    "Folder" : "ໂຟນເດີ",
    "Folder name" : "Folder name",
    "Talk conversation" : "Talk conversation",
    "New Talk conversation" : "New Talk conversation",
    "Conversation name" : "Conversation name",
    "Collective" : "Collective",
    "Calendar" : "Calendar",
    "New calendar" : "New calendar",
    "Calendar name" : "Calendar name",
    "Unknown resource type" : "Unknown resource type",
    "Team calendar \"{resourceName}\" created and shared with team" : "Team calendar \"{resourceName}\" created and shared with team",
    "{resourceType} \"{resourceName}\" created and shared with team" : "{resourceType} \"{resourceName}\" created and shared with team",
    "A calendar named \"{name}\" already exists. Please choose a different name." : "A calendar named \"{name}\" already exists. Please choose a different name.",
    "Failed to create {resourceType}: {error}" : "Failed to create {resourceType}: {error}",
    "An error happened while saving {fields}" : "An error happened while saving {fields}",
    "Team name" : "Team name",
    "Team owner" : "Team owner",
    "Delete picture" : "Delete picture",
    "Edit" : "Edit",
    "Request to join" : "Request to join",
    "Create" : "Create",
    "Show in Calendar" : "Show in Calendar",
    "Your request to join this team is pending approval" : "Your request to join this team is pending approval",
    "You are not a member of {circle}" : "You are not a member of {circle}",
    "Members" : "Members",
    "Confirm" : "Confirm",
    "Add more info" : "Add more info",
    "More fields" : "More fields",
    "Please select a valid format" : "Please select a valid format",
    "Invalid image" : "ບໍ່ມີຮູບພາບ",
    "Error cropping picture" : "Error cropping picture",
    "Pick an avatar" : "Pick an avatar",
    "Pick" : "Pick",
    "Error while processing the picture." : "Error while processing the picture.",
    "Avatar downloaded from social network" : "Avatar downloaded from social network",
    "Avatar already up to date" : "Avatar already up to date",
    "Avatar download failed" : "Avatar download failed",
    "Crop contact photo" : "Crop contact photo",
    "Upload a new picture" : "Upload a new picture",
    "Choose from Files" : "Choose from Files",
    "Download picture" : "Download picture",
    "Clone contact" : "Clone contact",
    "This contact is in read-only mode. You do not have permission to edit this contact." : "This contact is in read-only mode. You do not have permission to edit this contact.",
    "The contact you were trying to edit has changed. Please manually refresh the contact. Any further edits will be discarded." : "The contact you were trying to edit has changed. Please manually refresh the contact. Any further edits will be discarded.",
    "Address book" : "Address book",
    "Add contact to Birthday Calendar" : "Add contact to Birthday Calendar",
    "Exclude contact from Birthday Calendar" : "Exclude contact from Birthday Calendar",
    "{title} at {organization}" : "{title} at {organization}",
    "Name" : "ຊື່",
    "Syntax error. Cannot open the contact." : "Syntax error. Cannot open the contact.",
    "The contact does not exist on the server anymore." : "The contact does not exist on the server anymore.",
    "Unable to retrieve the contact from the server, please check your network connection." : "Unable to retrieve the contact from the server, please check your network connection.",
    "An error occurred while trying to move the contact" : "An error occurred while trying to move the contact",
    "An error occurred while trying to copy the contact" : "An error occurred while trying to copy the contact",
    "Unable to update contact" : "Unable to update contact",
    "No contact selected" : "No contact selected",
    "Select a contact on the list to begin" : "Select a contact on the list to begin",
    "Title" : "Title",
    "Company" : "ບໍລິສັດ",
    "Go to talk conversation" : "Go to talk conversation",
    "View profile" : "View profile",
    "This contact was broken and received a fix. Please review the content and click here to save it." : "This contact was broken and received a fix. Please review the content and click here to save it.",
    "Edit profile" : "ແກ້ໄຂໜ້າປົກ",
    "Generate QR Code" : "Generate QR Code",
    "Contact vCard as QR code" : "Contact vCard as QR code",
    "Select address book" : "Select address book",
    "Media shares with you" : "Media shares with you",
    "Talk conversations with you" : "Talk conversations with you",
    "Calendar events with you" : "Calendar events with you",
    "Deck cards with you" : "Deck cards with you",
    "No shared items with this contact" : "No shared items with this contact",
    "Remove from favorites" : "ຍ້າຍຈາກລາຍການທີ່ມັກ",
    "Confirm merging contacts" : "Confirm merging contacts",
    "The selected contacts have conflicting information. Choose which information to keep" : "The selected contacts have conflicting information. Choose which information to keep",
    "Contacts can be merged" : "Contacts can be merged",
    "Groups" : "Groups",
    "Select groups to add the merged contact to" : "Select groups to add the merged contact to",
    "Merge contacts" : "Merge contacts",
    "_Delete {number} contact_::_Delete {number} contacts_" : ["Delete {number} contacts"],
    "Please select at least one editable contact to delete" : "Please select at least one editable contact to delete",
    "Please select two editable contacts to merge" : "Please select two editable contacts to merge",
    "Are you sure you want to proceed?" : "Are you sure you want to proceed?",
    "Search contacts …" : "Search contacts …",
    "Unselect {number}" : "Unselect {number}",
    "Add to {group}" : "Add to {group}",
    "Add members to {group}" : "Add members to {group}",
    "Please note that you can only add contacts from writable address books to contact groups. Contacts from read-only address books, such as the system address book, cannot be added." : "Please note that you can only add contacts from writable address books to contact groups. Contacts from read-only address books, such as the system address book, cannot be added.",
    "Remove {type}" : "Remove {type}",
    "Add to group" : "Add to group",
    "Add members to group" : "Add members to group",
    "Search {types}" : "Search {types}",
    "Add guest" : "Add guest",
    "Search for people to add" : "Search for people to add",
    "No results" : "ບໍ່ມີຜົນ",
    "Add {type}" : "Add {type}",
    "New team name" : "New team name",
    "Personal team" : "Personal team",
    "This team will only be visible to you. Other members will not be able to see or use it." : "This team will only be visible to you. Other members will not be able to see or use it.",
    "Local team" : "Local team",
    "This team will not be shared with the other instances of the global scale" : "This team will not be shared with the other instances of the global scale",
    "Create team" : "Create team",
    "Promote as sole owner" : "Promote as sole owner",
    "Promote to {level}" : "Promote to {level}",
    "Demote to {level}" : "Demote to {level}",
    "Are you sure you want to leave this team? This action cannot be undone." : "Are you sure you want to leave this team? This action cannot be undone.",
    "Leave team failed." : "Leave team failed.",
    "Could not delete the member {displayName}" : "Could not delete the member {displayName}",
    "Could not change the member level to {level}" : "Could not change the member level to {level}",
    "Could not accept membership request" : "Could not accept membership request",
    "Accept membership request" : "Accept membership request",
    "Reject membership request" : "Reject membership request",
    "Manage level" : "Manage level",
    "Remove member" : "Remove member",
    "Unable to get the results" : "Unable to get the results",
    "Some members could not be added" : "Some members could not be added",
    "There was an issue adding members to the team" : "There was an issue adding members to the team",
    "Loading members list …" : "Loading members list …",
    "The list of members is only visible to members of this team" : "The list of members is only visible to members of this team",
    "You currently have no access to the member list" : "You currently have no access to the member list",
    "Add to {team}" : "Add to {team}",
    "Invite members to {team}" : "Invite members to {team}",
    "Pending" : "ທີ່ກໍາລັງລໍຖ້າ",
    "Label" : "Label",
    "Select chart …" : "Select chart …",
    "Chart" : "Chart",
    "Select type" : "Select type",
    "Add contact in group" : "Add contact in group",
    "None" : "ບໍ່ມີ",
    "Select option" : "Select option",
    "Notes" : "Notes",
    "Personal dates" : "Personal dates",
    "Add property of this type" : "Add property of this type",
    "Member" : "Member",
    "This is a read-only group managed by administrators. Group members can only view this group." : "This is a read-only group managed by administrators. Group members can only view this group.",
    "Unable to create the contact." : "Unable to create the contact.",
    "Contact not found" : "Contact not found",
    "Group {group} not found" : "Group {group} not found",
    "Add member" : "Add member",
    "New contact" : "New contact",
    "_{success} contact added to {name}_::_{success} contacts added to {name}_" : ["{success} contacts added to {name}"],
    "_Adding {success} contact to {name}_::_Adding {success} contacts to {name}_" : ["Adding {success} contacts to {name}"],
    "_{count} error_::_{count} errors_" : ["{count} errors"],
    "_Importing %n contact into {addressbook}_::_Importing %n contacts into {addressbook}_" : ["Importing %n contacts into {addressbook}"],
    "_Done importing %n contact into {addressbook}_::_Done importing %n contacts into {addressbook}_" : ["Done importing %n contacts into {addressbook}"],
    "No data for this contact" : "No data for this contact",
    "No data for this contact on their profile" : "No data for this contact on their profile",
    "Import" : "Import",
    "Are you sure you want to import this contact file?" : "Are you sure you want to import this contact file?",
    "Could not copy" : "Could not copy",
    "Join team" : "Join team",
    "You are about to leave {circle}.\nAre you sure?" : "You are about to leave {circle}.\nAre you sure?",
    "Please confirm team leave" : "Please confirm team leave",
    "Could not leave the team {displayName}" : "Could not leave the team {displayName}",
    "Unable to join the team" : "Unable to join the team",
    "You are about to delete {circle}.\nAre you sure?" : "You are about to delete {circle}.\nAre you sure?",
    "Please confirm team deletion" : "Please confirm team deletion",
    "Unable to delete the team" : "Unable to delete the team",
    "Link copied to the clipboard" : "Link copied to the clipboard",
    "Could not copy link to the clipboard." : "Could not copy link to the clipboard.",
    "Not grouped" : "Not grouped",
    "Team" : "Team",
    "User" : "ຜູ້ໃຊ້",
    "Group" : "ກຸ່ມ",
    "Email" : "ອິເມວ",
    "Contact" : "Contact",
    "Moderator" : "Moderator",
    "Admin" : "ຜູ້ເບິ່ງເເຍງລະບົບ",
    "Owner" : "ເຈົ້າຂອງ",
    "Invites" : "Invites",
    "Anyone can request membership" : "Anyone can request membership",
    "Members need to accept invitation" : "Members need to accept invitation",
    "Memberships must be confirmed/accepted by a Moderator (requires \"Anyone can request membership\")" : "Memberships must be confirmed/accepted by a Moderator (requires \"Anyone can request membership\")",
    "Members can also invite" : "Members can also invite",
    "Membership" : "Membership",
    "Prevent teams from being a member of another team" : "Prevent teams from being a member of another team",
    "Privacy" : "ຄວາມເປັນສ່ວນຕົວ",
    "Visible to everyone" : "Visible to everyone",
    "users" : "users",
    "Users" : "Users",
    "groups" : "groups",
    "teams" : "teams",
    "email addresses" : "email addresses",
    "Email addresses" : "Email addresses",
    "contacts" : "contacts",
    "Detailed name" : "Detailed name",
    "Additional names" : "Additional names",
    "Prefix" : "Prefix",
    "Suffix" : "Suffix",
    "Nickname" : "Nickname",
    "Website" : "ເວັບໄຊ",
    "Location" : "Location",
    "Federated Cloud ID" : "Federated Cloud ID",
    "Home" : "ໜ້າຫຼັກ",
    "Work" : "Work",
    "Other" : "Other",
    "Address" : "ທີ່ຢູ່",
    "Post office box" : "Post office box",
    "Extended address" : "Extended address",
    "City" : "ເມືອງ",
    "State or province" : "State or province",
    "Postal code" : "Postal code",
    "Country" : "ປະເທດ",
    "Birthday" : "Birthday",
    "Place of birth" : "Place of birth",
    "Anniversary" : "Anniversary",
    "Date of death" : "Date of death",
    "Place of death" : "Place of death",
    "Instant messaging" : "Instant messaging",
    "Phone" : "Phone",
    "Mobile" : "Mobile",
    "Work mobile" : "Work mobile",
    "Home mobile" : "Home mobile",
    "Fax" : "Fax",
    "Fax home" : "Fax home",
    "Fax work" : "Fax work",
    "Pager" : "Pager",
    "Voice" : "Voice",
    "Car" : "Car",
    "Work pager" : "Work pager",
    "Line manager" : "Line manager",
    "Social network" : "Social network",
    "Relationship to you" : "Relationship to you",
    "Spouse" : "Spouse",
    "Child" : "Child",
    "Mother" : "Mother",
    "Father" : "Father",
    "Parent" : "Parent",
    "Brother" : "Brother",
    "Sister" : "Sister",
    "Relative" : "Relative",
    "Friend" : "Friend",
    "Colleague" : "Colleague",
    "Assistant" : "Assistant",
    "Related contacts" : "Related contacts",
    "Agent" : "Agent",
    "Emergency" : "Emergency",
    "Co-worker" : "Co-worker",
    "Gender" : "Gender",
    "Female" : "Female",
    "Male" : "Male",
    "Unknown" : "ບໍ່ຮູ້",
    "Time zone" : "Time zone",
    "Spoken languages" : "Spoken languages",
    "_{failed} contact failed to be read_::_{failed} contacts failed to be read_" : ["{failed} contacts failed to be read"],
    "An error has occurred in team(s). Check the console for more details." : "An error has occurred in team(s). Check the console for more details.",
    "Unable to create team {circleName}" : "Unable to create team {circleName}",
    "Unable to delete team {circleId}" : "Unable to delete team {circleId}",
    "Unable to delete contact" : "Unable to delete contact",
    "Deck board" : "Deck board",
    "New Deck board" : "New Deck board",
    "Board name" : "Board name",
    "Deck app is not installed. Please install it to create team boards." : "Deck app is not installed. Please install it to create team boards.",
    "Pick an address book" : "Pick an address book",
    "Select Date" : "Select Date"
},
"nplurals=1; plural=0;");
