OC.L10N.register(
    "contacts",
    {
    "Import contacts" : "Agiza mawasiliano",
    "Details" : "Maelezo ya kina",
    "All contacts" : "Mawasiliano yote",
    "_Imported %n contact_::_Imported %n contacts_" : ["Imported %n contact","Imeingiza anwani %n"],
    "Contacts" : "Mawasiliano",
    "A contacts app for Nextcloud" : "Programu ya mawasiliano kwa Nextcloud",
    "The Nextcloud contacts app is a user interface for Nextcloud's CardDAV server. Easily sync contacts from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Currently Mail and Calendar – more to come.\n* 🎉 **Never forget a birthday!** You can sync birthdays and other recurring events with your Nextcloud Calendar.\n* 👥 **Sharing of Adressbooks!** You want to share your contacts with your friends or coworkers? No problem!\n* 🙈 **We’re not reinventing the wheel!** Based on the great and open SabreDAV library." : "Programu ya mawasiliano ya Nextcloud ni kiolesura cha mtumiaji cha seva ya Nextcloud ya CardDAV. Sawazisha anwani kutoka kwa vifaa mbalimbali kwa urahisi na Nextcloud yako na uzihariri mtandaoni.\n\n* 🚀 **Muunganisho na programu zingine za Nextcloud!** Kwa sasa Barua pepe na Kalenda - zaidi yajayo.\n* 🎉 **Usisahau kamwe siku ya kuzaliwa!** Unaweza kusawazisha siku za kuzaliwa na matukio mengine yanayojirudia kwa kutumia Kalenda yako ya Nextcloud.\n* 👥 **Kushiriki Vitabu vya Anwani!** Je, ungependa kushiriki anwani zako na marafiki au wafanyakazi wenzako? Hakuna tatizo!\n* 🙈 **Hatubuni tena gurudumu!** Kulingana na maktaba kuu na wazi ya SabreDAV",
    "Copy to full name" : "Nakili jina kamili",
    "Omit year" : "Ondoa mwaka",
    "Allow updating avatars from social media" : "Ruhusu kusasisha avatars kutoka mitandao ya kijamii",
    "Organization chart" : "Chati za shirika",
    "There was an error fetching the member list" : "Kulikuwa na hitilafu iliyoleta orodha ya wanachama",
    "Teams" : "Timu",
    "Please select a team" : "Tafadhali chagua timu",
    "Loading team…" : "Inapakia timu",
    "Loading contacts …" : "Inapakia mawasiliano ...",
    "There are no contacts yet" : "Bado hakuna mawasiliano",
    "Create contact" : "Tengeneza mawasiliano",
    "There are no contacts in this group" : "Hakuna mawasiliano katika kundi",
    "Create contacts" : "Tengeneza mawasiliano",
    "Add contacts" : "Ongeza mawasiliano",
    "Retry" : "Jaribu upya",
    "Loading …" : "Inapakia ...",
    "Manage team" : "Dhibiti timu",
    "Leave team" : "Acha timu",
    "Delete team" : "Futa timu",
    "Setting saved" : "Mipangilio imehifadhiwa",
    "Failed to save setting" : "Imeshindwa kuhifadhi mpangilio",
    "Contacts settings" : "Mpangilio wa mawasiliano",
    "General" : "Kuu",
    "Update avatars from social media" : "Sasisha avastars kutoka mitandao ya kijamii",
    "Refreshed once per week" : "Imerejeshwa mara moja kwa wiki",
    "Address books" : "Vitabu vya anwani",
    "Rename" : "Badili jina",
    "Export" : "Hamisha",
    "Send email" : "Tuma barua pepe",
    "Send email as BCC" : "Tuma barua pepe kama BCC",
    "Delete" : "Futa",
    "Show all groups" : "Onesha makundi yote",
    "Collapse groups" : "Kunja vikundi",
    "Show all teams" : "Onesha timu zote",
    "Collapse teams" : "Kunja timu",
    "Group name cannot be empty" : "Jina la kundi haliwezi kuwa tupu",
    "This group already exists" : "Kundi hili limeshajitokeza",
    "An error occurred while creating the group" : "Hitilafu imetokea wakati wa kutengeneza kundi",
    "This team already exists" : "Timu hii imeshajitokeza",
    "An error happened during the creation of the team" : "Hitilafu ilitokea wakati wa kutengeneza timu",
    "Recently contacted" : "Imewasiliana hivi karibuni",
    "Contact groups" : "Vikundi vya mawasiliano",
    "Create a new contact group" : "Tengeneza kikundi kipya cha mawasiliano",
    "Contact group name" : "Jina la kikundi cha mawasiliano",
    "Create a new team" : "Tengeneza timu mpya",
    "Open the contacts app settings" : "Fungua mipangilio ya programu ya anwani",
    "_Shared with {num} entity_::_Shared with {num} entities_" : ["Shared with {num} entity","Imeshirikiwa na {num} vyombo"],
    "Copied" : "Imenakiliwa",
    "Cannot copy" : "Haiwezi kunakili",
    "Copy link" : "Nakili kiungio",
    "Toggling of address book was not successful" : "Ugeuzaji wa kitabu cha anwani haukufaulu",
    "This will delete the address book and every contacts within it" : "Hii itafuta kitabu cha anwani na kila mawasiliano yaliyomo ndani yake",
    "Delete {addressbook}?" : "Futa {addressbook}",
    "This will unshare the address book and every contacts within it" : "Hii haitashirikisha kitabu cha anwani na mawasiliano yaliyomo ndani yake",
    "Unshare {addressbook}?" : "usishirikishe {addressbook}",
    "Deletion of address book was not successful." : "Ufutaji wa kitabu cha anwani haukufanikiwa",
    "Renaming of address book was not successful." : "Ubadilishaji jina wa kitabu cha anwani haukufanikiwa",
    "{addressbookname} (Hidden)" : "{addressbookname}(Imefichwa) ",
    "Download" : "Pakua",
    "Show" : "Onesha",
    "Unshare from me" : "Usishirikishe kutoka kwangu",
    "_%n contact_::_%n contacts_" : ["%n contact","%nmawasiliano"],
    "_%n group_::_%n groups_" : ["%n group","%n makundi"],
    "Share with users or groups" : "Shiriki na watumiaji au makundi",
    "Share with users" : "Shiriki na watumiaji",
    "No users or groups" : "Hakuna watumiaji au makundi",
    "Unable to delete the share" : "Haiwezi kufuta ushiriki",
    "Unable to change permissions" : "Haiwezi kubadili ruhusa",
    "Choose a vCard file to import" : "Chagua faili la vCard la kuagiza",
    "Import into the {addressbookName} address book" : "Agiza ndani ya {addressbookName} kitabu cha mawasiliano",
    "Select local file" : "Chagua faili la ndani",
    "Import from files" : "Agiza kutoka katika mafaili",
    "Importing is disabled because there are no address books available" : "Uagizaji haukuwezeshwa kwa sababu hakuna kitabu cha mawasiliano kilichopo ",
    "An error occurred, unable to create the address book" : "Hitilafu imetokea, haiwezi kutengeneza kitabu cha mawasiliano",
    "New address book" : "Kitabu kipya cha anwani",
    "Add new address book" : "Ongeza kitabu kipya cha mawasiliano",
    "Cancel" : "Ghaili",
    "Add" : "Ongeza",
    "First name" : "jina la kwanza",
    "Last name" : "Jina la mwisho",
    "Phonetic first name" : "Jina la kwanza la kifonetiki",
    "Phonetic last name" : "Jina la mwisho la kifonetiki",
    "Display name" : "Onesha jina",
    "Last modified" : "Iliyoboreshwa mwisho",
    "Sort contacts by" : "Panga mawasiliano kwa",
    "Manages" : "Inadhibiti",
    "Oversees" : "Inasimamia",
    "An error happened during the config change" : "Hitilafu imetokea wakati wa mabadiliko ya usanidi",
    "Enforce password protection on files shared to this team" : "Tekeleza ulinzi wa nenosiri kwenye mafaili yaliyoshirikishwa kwa timu hii",
    "Use a unique password for all shares to this team" : "Tumia nensiri la kipekee kwa mafaili yote yaliyoshirikishwa kwa timu hii",
    "Unique password …" : "Nenosiri la kipekee ...",
    "Save" : "Hifadhi",
    "Change unique password" : "Badili nenosiri la kipekee",
    "Failed to save password. Please try again later." : "Imeshindwa kuhifadhi nenosiri, Tafadhali jaribu tena baadaye",
    "Close" : "Funga",
    "There is no description for this team" : "Hakuna maelezo ya kina kwa timu hii",
    "Enter a description for the team" : "Ingiza maelezo ya kina kwa timu hii",
    "Folder name" : "Jina la folda",
    "Talk conversation" : "Mazungumzo ya Talk ",
    "New Talk conversation" : "Mazungumzo mapya ya Talk ",
    "Conversation name" : "Jina la mazungumzo",
    "Collective" : "Ya Pamoja",
    "Calendar" : "Kalenda",
    "New calendar" : "Kalenda mpya",
    "Calendar name" : "Jina la kalenda",
    "Unknown resource type" : "Aina ya rasilimali isiyojulikana",
    "Team calendar \"{resourceName}\" created and shared with team" : "Kalenda ya timu \"{resourceName}\" imeundwa na kushirikiwa na timu",
    "{resourceType} \"{resourceName}\" created and shared with team" : "{resourceType} \"{resourceName}\" imeundwa na kushirikiwa na timu",
    "A calendar named \"{name}\" already exists. Please choose a different name." : "Kalenda iitwayo \"{name}\" tayari ipo. Tafadhali chagua jina tofauti.",
    "Failed to create {resourceType}: {error}" : "Imeshindwa kuunda {resourceType}: {error}",
    "An error happened while saving {fields}" : "Hitilafu ilitokea wakati wa kuhifadhi {fields}",
    "Team name" : "Jina la timu",
    "Team owner" : "Mmiliki wa timu",
    "Delete picture" : "Futa picha",
    "Edit" : "Hariri",
    "Request to join" : "Omba kujiunga",
    "Create" : "Unda",
    "Show in Calendar" : "Onesha katika kalenda",
    "Your request to join this team is pending approval" : "Ombi lako la kujiunga katika timu hii inasubiri idhini",
    "You are not a member of {circle}" : "Wewe si mwanachama wa {circle}",
    "Members" : "Wanachama",
    "Confirm" : "Thibitisha",
    "Add more info" : "Ongeza taarifa zaidi",
    "More fields" : "Sehemu zaidi",
    "Please select a valid format" : "Tafadhali chagua umbizo halali",
    "Invalid image" : "Picha isiyohalali",
    "Error cropping picture" : "Hitilafu katika kunakili picha",
    "Pick an avatar" : "Chagua avatar",
    "Pick" : "Chagua",
    "Error while processing the picture." : "Hitilahu wakati wa kuchakata picha",
    "Avatar downloaded from social network" : "Avatar iliyopakuliwa kutoka mitandao ya kijamii",
    "Avatar already up to date" : "Avatar tayari imesasishwa",
    "Avatar download failed" : "Upakuaji wa avatar umeshindikana",
    "Crop contact photo" : "Punguza picha ya mawasiliano",
    "Upload a new picture" : "Pikia picha mpya",
    "Choose from Files" : "Chagua kutoka katika faili",
    "Download picture" : "Pakua picha",
    "Clone contact" : "Zalisha mawasiliano",
    "This contact is in read-only mode. You do not have permission to edit this contact." : "Mawasiliano haya yako katika hali ya utayari tu. Huna ruhusa ya kuhariri mawasiliano haya",
    "The contact you were trying to edit has changed. Please manually refresh the contact. Any further edits will be discarded." : "Mawasiliano ambayo ulijaribu kuhariri yamebadilika. Tafadhali changamsha kwa njia za kawaida mawasiliano haya. Uhariri wa zaidi utasitishwa.",
    "Address book" : "Kitabu cha anwani",
    "Add contact to Birthday Calendar" : "Ongeza mawasiliano kwenye kalenda ya siku ya kuzaliwa",
    "Exclude contact from Birthday Calendar" : "Tenganisha mawasiliano kutoka kwenye kalenda ya siku ya kuzaliwa",
    "{title} at {organization}" : "{title} katika {organization}",
    "Name" : "Jina",
    "Syntax error. Cannot open the contact." : "Hitilafu ya sintaksia. Haiwezi kufungua mawasiliano",
    "The contact does not exist on the server anymore." : "Mawasiliano hayapatikani kwenye seva tena",
    "Unable to retrieve the contact from the server, please check your network connection." : "Haikuweza kurejesha mawasiliano kutoka kwenye seva, tafadhali angalia muunganisho wako wa mtandao.",
    "An error occurred while trying to move the contact" : "Hitilafu imetokea wakati wa kuhamisha mawasiliano",
    "An error occurred while trying to copy the contact" : "Hitilafu imetokea wakati wa kujaribu kunakili mawasiliano",
    "Unable to update contact" : "Haiwezi kusasisha mawasiliano",
    "No contact selected" : "Hakuna mawasiliano yaliyochaguliwa",
    "Select a contact on the list to begin" : "Chagua mawasiliano ya kuanzia katika orodha",
    "Title" : "Kichwa cha habari",
    "Company" : "Kampuni",
    "Go to talk conversation" : "Nenda kwenye mazungumzo ya talk",
    "View profile" : "Angalia wasifu",
    "This contact was broken and received a fix. Please review the content and click here to save it." : "Mawasiliano haya yalivunjwa na kupokea marekebisho. Tafadhali kagua maudhui na ubofye hapa ili kuyahifadhi.",
    "Generate QR Code" : "Tengeneza msimbo wa QR",
    "Contact vCard as QR code" : "Wasiliana na vCard kama msimbo wa QR",
    "Select address book" : "Chagua kitabu cha anwani",
    "Media shares with you" : "Vyombo vya habari vinashitiki nawe",
    "Talk conversations with you" : "Mazungumzo ya talk na wewe",
    "Calendar events with you" : "Matukio ya kalenda na wewe",
    "Deck cards with you" : "Kadi za staha na wewe",
    "No shared items with this contact" : "Hakuna vifungu vilivyoshirikishwa na mawasiliano haya",
    "Move" : "Hama",
    "Remove from favorites" : "Ondoa kutoka katika vipendwa",
    "Add to favorites" : "Ongeza katika vipendwa",
    "Confirm merging contacts" : "Thibitisha kuunganisha mawasiliano",
    "The selected contacts have conflicting information. Choose which information to keep" : "Mawasiliano yalizochaguliwa yana maelezo yanayokinzana. Chagua ni taarifa gani utahifadhi",
    "Contacts can be merged" : "Mawasiliano yanaweza kuunganishwa",
    "Groups" : "Makundi",
    "Select groups to add the merged contact to" : "Chagua vikundi vya kuongeza mawasiliano yaliyounganishwa",
    "Merge contacts" : "Unganisha mawasiliano",
    "_Delete {number} contact_::_Delete {number} contacts_" : ["Delete {number} contact","Futa {number} mawasiliano"],
    "Please select at least one editable contact to delete" : "Tafadhali chagua angalau mwasiliani mmoja anayeweza kuhaririwa ili kufuta",
    "Please select two editable contacts to merge" : "Tafadhali chagua mawasiliano mawili yanayoweza kuhaririwa ili kuyachanganya",
    "Are you sure you want to proceed?" : "Una uhakika unataka kuendelea?",
    "Search contacts …" : "Tafuta mawasiliano ...",
    "Unselect {number}" : " Acha kuchagua {number}",
    "Add to {group}" : "Ongeza hadi {group}",
    "Add members to {group}" : "Ongeza wanachama kwenye {group}",
    "Please note that you can only add contacts from writable address books to contact groups. Contacts from read-only address books, such as the system address book, cannot be added." : "Tafadhali kumbuka kuwa unaweza tu kuongeza anwani kutoka kwa vitabu vya anwani vinavyoweza kuandikwa kwa vikundi vya anwani. Anwani kutoka kwa vitabu vya anwani vya kusoma pekee, kama vile kitabu cha anwani za mfumo, haziwezi kuongezwa.",
    "Remove {type}" : "Ondoa {type}",
    "Add to group" : "Ongeza kwenye kundi",
    "Add members to group" : "Ongeza wanachama kwenye kundi",
    "Search {types}" : "Tafuta {types}",
    "Add guest" : "Ongeza mgeni",
    "Search for people to add" : "Tafuta watu wa kuongeza",
    "No results" : "Hakuna matokeo",
    "Add {type}" : "Ongeza {type}",
    "New team name" : "Jina jipya la timu",
    "Personal team" : "Timu ya binafsi",
    "This team will only be visible to you. Other members will not be able to see or use it." : "Timu hii itaonekana kwako tu. Wanachama wengine hawataweza kuiona au kuitumia",
    "Local team" : "Timu ya ndani",
    "This team will not be shared with the other instances of the global scale" : "Timu hii itashirikishwa na mifano mingine ya kiwango cha kimataifa",
    "Create team" : "Tengeneza timu",
    "Promote as sole owner" : "Kuza kama mmiliki pekee",
    "Promote to {level}" : "Pandisha daraja hadi {level}",
    "Demote to {level}" : "Shusha daraja hadi {level}",
    "Are you sure you want to leave this team? This action cannot be undone." : "Je, una uhakika unataka kuondoka kwenye timu hii? Kitendo hiki hakiwezi kutenduliwa.",
    "Leave team failed." : "Imeshindwa kuondoka kwenye timu.",
    "Could not delete the member {displayName}" : "Haikuweza kufuta mwanachama {displayName}",
    "Could not change the member level to {level}" : "Haikuweza kubadili kiwango cha uanachama kwa {level}",
    "Could not accept membership request" : "Haikuweza kukubali maombi ya uanachama",
    "Accept membership request" : "Kubali maombi ya uanachama",
    "Reject membership request" : "Kataa maombi ya uanachama",
    "Manage level" : "Dhibiti kiwango",
    "Remove member" : "Ondoa mwanachama",
    "Unable to get the results" : "Haiwezi kupata matokeo",
    "Some members could not be added" : "Wanachama baadhi hawakuweza kuongezwa",
    "There was an issue adding members to the team" : "Kulikuwa na jambo katika kuongeza wanachama katika timu",
    "Loading members list …" : "Inapakia orodha ya wanachama ...",
    "The list of members is only visible to members of this team" : "Orodha ya wanachama inaonekana tu kwa wanachama wa timu",
    "You currently have no access to the member list" : "Kwa sasa huna ufukikaji wa orodha ya wanachama",
    "Add to {team}" : "Ongeza kwenye {team}",
    "Invite members to {team}" : "Alika wanachama kwenye {team}",
    "Pending" : "Inasubiri",
    "Accept" : "Kubali",
    "Send" : "Tuma",
    "Label" : "Lebo",
    "Continue" : "Endelea",
    "Select chart …" : "Chagua jedwali ...",
    "Chart" : "Chati",
    "Select type" : "Chagua aina",
    "Add contact in group" : "Ongeza mawasiliano katika kundi",
    "None" : "Hakuna",
    "Select option" : "Chagua mbadala",
    "Notes" : "Vidokezo",
    "Personal dates" : "Tarehe za kibinafsi",
    "Add property of this type" : "Ongeza mali za aina hii",
    "Member" : "Mwanachama",
    "This is a read-only group managed by administrators. Group members can only view this group." : "Hiki ni kikundi cha kusoma pekee kinachosimamiwa na wasimamizi. Wanakikundi wanaweza kutazama kikundi hiki pekee.",
    "Unable to create the contact." : "Haiwezi kutengeneza mawasiliano",
    "Contact not found" : "Mawasiliano hayapatikani",
    "Group {group} not found" : "Kundi {group} halipatikani",
    "Add member" : "Ongeza wanachama",
    "New contact" : "Mawasiliano mapya",
    "_{success} contact added to {name}_::_{success} contacts added to {name}_" : ["{success} contact added to {name}","{success} mawasiliano yameongezwa kwenda{name}"],
    "_Adding {success} contact to {name}_::_Adding {success} contacts to {name}_" : ["Adding {success} contact to {name}","Kuongeza {success} mawasiliano kwenda {name}"],
    "_{count} error_::_{count} errors_" : ["{count} error","{count} hitilafu"],
    "_Importing %n contact into {addressbook}_::_Importing %n contacts into {addressbook}_" : ["Importing %n contact into {addressbook}","Agiza %n mawasiliano katika {addressbook}"],
    "_Done importing %n contact into {addressbook}_::_Done importing %n contacts into {addressbook}_" : ["Done importing %n contact into {addressbook}","Uagizaji umefanyika %n mawasiliano katika {addressbook}"],
    "No data for this contact" : "Hakuna data kwa mawasiliano haya",
    "No data for this contact on their profile" : "Hakuna data kwa mawasiliano haya katika wasifu",
    "Import" : "Agiza",
    "Are you sure you want to import this contact file?" : "Je, unauhakika unataka kuagiza faili la mawasiliano haya?",
    "Could not copy" : "Haikuweza kunakili",
    "Join team" : "Jiunge na timu",
    "You are about to leave {circle}.\nAre you sure?" : "Unaweza kuondoka {circle}\nUna uhakika?",
    "Please confirm team leave" : "Tafadhali thibitisha uondokaji wa timu",
    "Could not leave the team {displayName}" : "Haiwezekani kuondoka katika timu {displayName}",
    "Unable to join the team" : "Haiwezekani kujiunga katika timu",
    "You are about to delete {circle}.\nAre you sure?" : "Unakaribia kufuta {circle}\nUna uhakika?",
    "Please confirm team deletion" : "Tafadhali, thibitisha ufutaji wa timu",
    "Unable to delete the team" : "Haiwezi kufuta timu",
    "Link copied to the clipboard" : "Kiungo kimenakiliwa kwenye clipboard",
    "Could not copy link to the clipboard." : "Haikuweza kunakili kiungio kwenye clipboard",
    "Not grouped" : "Haijawekwa katika kundi",
    "Team" : "Timu",
    "User" : "Mtumiaji",
    "Group" : "Kundi",
    "Email" : "Barua pepe",
    "Contact" : "Mawasiliano",
    "Moderator" : "Mwezeshaji",
    "Admin" : "Msimamizi",
    "Owner" : "Mmiliki",
    "Invites" : "Mialiko",
    "Anyone can request membership" : "Mtu yeyote anaweza kuomba uanachama",
    "Members need to accept invitation" : "Wanachama wanahitaji kukubali mwaliko",
    "Memberships must be confirmed/accepted by a Moderator (requires \"Anyone can request membership\")" : "Uanachama lazima uthibitishwe/ ukubaliwe na msimamizi (Mahitaji \"Kila mtu anaweza kuomba uanachama) ",
    "Members can also invite" : "Wanachama wanaweza pia kualika",
    "Membership" : "Uanachama",
    "Prevent teams from being a member of another team" : "Zuia timu kuwa mwanachama wa timu nyingine",
    "Privacy" : "Faragha",
    "Visible to everyone" : "Inaonekana kwa kila mmoja",
    "users" : "watumiaji",
    "Users" : "Watumiaji",
    "groups" : "makundi",
    "teams" : "timu",
    "email addresses" : "anwani za barua pepe",
    "Email addresses" : "Anwani za barua pepe",
    "contacts" : "mawasiliano",
    "Detailed name" : "Jina la kina",
    "Additional names" : "Jina la nyongeza",
    "Prefix" : "Kiambishi awali",
    "Suffix" : "Kiambishi tamati",
    "Nickname" : "Jina la utani",
    "Website" : "Tovuti",
    "Location" : "Eneo",
    "Federated Cloud ID" : "Kitambulisho cha Cloud kilichishirikishwa",
    "Home" : "Nyumbani",
    "Work" : "Kazi",
    "Other" : "Mengine",
    "Address" : "Anwani",
    "Post office box" : "Sanduku la barua la Posta",
    "Extended address" : "Anwani iliyoongezwa",
    "City" : "Jiji",
    "State or province" : "Jimbo au mkoa",
    "Postal code" : "Msimbo wa Posta",
    "Country" : "Nchi",
    "Birthday" : "Siku ya kuzaliwa",
    "Place of birth" : "Mahali pa kuzaliwa",
    "Anniversary" : "Maadhimisho ya miaka",
    "Date of death" : "Tarehe ya kifo",
    "Place of death" : "Eneo la kifo",
    "Instant messaging" : "Ujumbe wa papo hapo",
    "Phone" : "Simu",
    "Mobile" : "Simu ya mkononi",
    "Work mobile" : "Simu ya mkononi ya kazini",
    "Home mobile" : "Simu ya mkononi ya nyumbani",
    "Fax" : "Faksi",
    "Fax home" : "Faksi ya nyumbani",
    "Fax work" : "Faksi ya kazini",
    "Pager" : "Msimamizi wa ukurusa",
    "Voice" : "Sauti",
    "Car" : "Gari",
    "Work pager" : "Msimamizi wa ukurasa wa kazini",
    "Line manager" : "Msimamizi wa kati",
    "Social network" : "Mitandao ya kijamii",
    "Relationship to you" : "Mahusiano kwako",
    "Spouse" : "Mwenza",
    "Child" : "Mtoto",
    "Mother" : "Mama",
    "Father" : "Baba",
    "Parent" : "Mzazi",
    "Brother" : "Kaka",
    "Sister" : "Dada",
    "Relative" : "Ndugu",
    "Friend" : "Rafiki",
    "Colleague" : "Mwenzako",
    "Assistant" : "Msaidizi",
    "Related contacts" : "Mawasiliano yanayohusiana",
    "Agent" : "Wakala",
    "Emergency" : "Dharula",
    "Co-worker" : "Mfanyakazi mwenza",
    "Gender" : "Jinsia",
    "Female" : "Mwanamke",
    "Male" : "Mwanaume",
    "Unknown" : "Asiyejulikana",
    "Time zone" : "Muda wa eneo",
    "Spoken languages" : "Lugha zinazozungumzwa",
    "_{failed} contact failed to be read_::_{failed} contacts failed to be read_" : ["{failed} contact failed to be read","{failed} mawasiliano hayajasomwa"],
    "An error has occurred in team(s). Check the console for more details." : "Hitilafu imetokea katika vipengele. Angalia mixer kwa maelezo zaidii",
    "Unable to create team {circleName}" : "Haiwezi kutengeneza timu {circleName}",
    "Unable to delete team {circleId}" : "Haiwezi kufuta timu {circleId}",
    "Unable to delete contact" : "Haiwezi kufuta mawasiliano",
    "Deck board" : "Ubao wa deki",
    "New Deck board" : "Ubao mpya wa deki",
    "Board name" : "Jina la ubao",
    "Deck app is not installed. Please install it to create team boards." : "Programu ya sitaha haijasakinishwa. Tafadhali isakinishe ili kuunda bodi za timu.",
    "Pick an address book" : "Chagua kitabu cha anwani",
    "Select Date" : "Chagua tarehe"
},
"nplurals=2; plural=(n != 1);");
