OC.L10N.register(
    "contacts",
    {
    "Import contacts" : "Importuj kontakty",
    "Details" : "Szczegóły",
    "All contacts" : "Wszystkie kontakty",
    "_Imported %n contact_::_Imported %n contacts_" : ["Zaimportowano %n kontakt","Zaimportowano %n kontaktów","Zaimportowano %n kontakty","Zaimportowano %n kontakty"],
    "_(skipped %n contact)_::_(skipped %n contacts)_" : ["(pominięto %n kontakt)","(pominięto %n kontaktów)","(pominięto %n kontakty)","(pominięto %n kontakty)"],
    "Contacts" : "Kontakty",
    "A contacts app for Nextcloud" : "Aplikacja Kontakty dla Nextcloud",
    "The Nextcloud contacts app is a user interface for Nextcloud's CardDAV server. Easily sync contacts from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Currently Mail and Calendar – more to come.\n* 🎉 **Never forget a birthday!** You can sync birthdays and other recurring events with your Nextcloud Calendar.\n* 👥 **Sharing of Adressbooks!** You want to share your contacts with your friends or coworkers? No problem!\n* 🙈 **We’re not reinventing the wheel!** Based on the great and open SabreDAV library." : "Aplikacja kontaktów Nextcloud to interfejs użytkownika dla serwera CardDAV Nextcloud. Łatwo synchronizuj kontakty z różnych urządzeń z Nextcloud i edytuj je online.\n\n* 🚀 **Integracja z innymi aplikacjami Nextcloud!** Obecnie Mail i Kalendarz - więcej w przyszłości.\n* 🎉 **Nigdy nie zapomnisz o urodzinach!** Możesz synchronizować urodziny i inne powtarzające się wydarzenia z kalendarzem Nextcloud.\n* 👥 **Udostępnianie książek adresowych!** Chcesz udostępnić swoje kontakty znajomym lub współpracownikom? Nie ma problemu!\n* 🙈 **Nie wynajdujemy koła na nowo!** Na podstawie znakomitej i otwartej biblioteki SabreDAV.",
    "Copy to full name" : "Kopiuj do pełnej nazwy",
    "Omit year" : "Pomiń rok",
    "Allow updating avatars from social media" : "Pozwól aktualizować awatary z mediów społecznościowych",
    "Organization chart" : "Schemat organizacyjny",
    "There was an error fetching the member list" : "Podczas pobierania listy członków wystąpił błąd",
    "Teams" : "Zespoły",
    "Please select a team" : "Proszę wybrać zespół",
    "Loading team…" : "Wczytywanie zespołu…",
    "Loading contacts …" : "Wczytywanie kontaktów…",
    "There are no contacts yet" : "Nie ma jeszcze żadnych kontaktów",
    "Create contact" : "Stworzyć kontakt",
    "There are no contacts in this group" : "W tej grupie nie ma żadnych kontaktów",
    "Create contacts" : "Utwórz kontakty",
    "Add contacts" : "Dodaj kontakty",
    "Retry" : "Ponów",
    "Loading …" : "Ładowanie …",
    "Manage team" : "Zarządzaj zespołem",
    "Leave team" : "Opuść zespół",
    "Delete team" : "Usuń zespół",
    "Setting saved" : "Ustawienie zapisane",
    "Failed to save setting" : "Nie udało się zapisać ustawienia",
    "Contacts settings" : "Ustawienia Kontaktów",
    "General" : "Ogólne",
    "Update avatars from social media" : "Zaktualizuj awatary z mediów społecznościowych",
    "Refreshed once per week" : "Odświeżane raz w tygodniu",
    "Address books" : "Książki adresowe",
    "Tried to drop an invalid contact!" : "Próbowano zrzucić nieprawidłowy kontakt!",
    "Rename" : "Zmień nazwę",
    "Export" : "Eksportuj",
    "Send email" : "Wyślij e-mail",
    "Send email as BCC" : "Wyślij e-mail jako UDW",
    "Delete" : "Usuń",
    "Show all groups" : "Pokaż wszystkie grupy",
    "Collapse groups" : "Zwiń grupy",
    "Show all teams" : "Pokaż wszystkie zespoły",
    "Collapse teams" : "Zwiń zespoły",
    "Group name cannot be empty" : "Nazwa grupy nie może być pusta",
    "This group already exists" : "Ta grupa już istnieje",
    "An error occurred while creating the group" : "Wystąpił błąd podczas tworzenia grupy",
    "This team already exists" : "Ten zespół już istnieje",
    "An error happened during the creation of the team" : "Podczas tworzenia zespołu wystąpił błąd",
    "Recently contacted" : "Ostatnio skontaktowano się",
    "Contact groups" : "Grupy kontaktów",
    "Create a new contact group" : "Utwórz nową grupę kontaktów",
    "Contact group name" : "Nazwa grupy kontaktów",
    "Create a new team" : "Utwórz nowy zespół",
    "Open the contacts app settings" : "Otwórz ustawienia aplikacji kontaktów",
    "_Shared with {num} entity_::_Shared with {num} entities_" : ["Udostępniono dla {num} podmiotu","Udostępniono dla {num} podmiotów","Udostępniono dla {num} podmiotów","Udostępniono dla  {num} podmiotów"],
    "Copied" : "Skopiowano",
    "Cannot copy" : "Nie można skopiować",
    "Copy link" : "Kopiuj link",
    "Toggling of address book was not successful" : "Przełączanie książki adresowej nie powiodło się",
    "This will delete the address book and every contacts within it" : "Spowoduje to usunięcie książki adresowej i wszystkich kontaktów zawartych w niej",
    "Delete {addressbook}?" : "Usunąć {addressbook}?",
    "This will unshare the address book and every contacts within it" : "Spowoduje to wyłączenie udostępniania książki adresowej i wszystkich znajdujących się w niej kontaktów",
    "Unshare {addressbook}?" : "Przestać udostępniać {addressbook}?",
    "Deletion of address book was not successful." : "Usunięcie książki adresowej nie powiodło się.",
    "Renaming of address book was not successful." : "Zmiana nazwy książki adresowej nie powiodła się.",
    "{addressbookname} (Hidden)" : "{addressbookname} (ukryta)",
    "Download" : "Pobierz",
    "Show" : "Pokaż",
    "Unshare from me" : "Nie udostępniaj mi",
    "_%n contact_::_%n contacts_" : ["%n kontakt","%n kontakty","%n kontaktów","%n kontaktów"],
    "_%n group_::_%n groups_" : ["%n grupa","%n grupy","%n grup","%n grup"],
    "Share with users or groups" : "Udostępnij użytkownikom lub grupom",
    "Share with users" : "Udostępnij użytkownikom",
    "No users or groups" : "Brak użytkowników i grup",
    "Unable to delete the share" : "Nie można usunąć udostępnienia",
    "Unable to change permissions" : "Nie można zmienić uprawnień",
    "can create and edit" : "może tworzyć i edytować",
    "Choose a vCard file to import" : "Wybierz plik vCard do zaimportowania",
    "Import into the {addressbookName} address book" : "Zaimportuj do książki adresowej {addressbookName}",
    "Select local file" : "Wybierz plik lokalny",
    "Import from files" : "Importuj z plików",
    "Importing is disabled because there are no address books available" : "Importowanie jest wyłączone, ponieważ nie ma dostępnych książek adresowych",
    "An error occurred, unable to create the address book" : "Wystąpił błąd, nie można utworzyć książki adresowej",
    "New address book" : "Nowa książka adresowa",
    "Add new address book" : "Dodaj nową książkę adresową",
    "Cancel" : "Anuluj",
    "Add" : "Add",
    "First name" : "Imię",
    "Last name" : "Nazwisko",
    "Phonetic first name" : "Imię fonetycznie",
    "Phonetic last name" : "Nazwisko fonetyczne",
    "Display name" : "Nazwa wyświetlana",
    "Last modified" : "Ostatnio zmodyfikowany",
    "Sort contacts by" : "Sortuj kontakty według",
    "Manages" : "Zarządza",
    "Oversees" : "Nadzoruje",
    "An error happened during the config change" : "Wystąpił błąd podczas zmiany konfiguracji",
    "Enforce password protection on files shared to this team" : "Wymuś ochronę hasłem plików udostępnionych temu zespołowi",
    "Use a unique password for all shares to this team" : "Użyj unikalnego hasła dla wszystkich udostępnień temu zespołowi",
    "Unique password …" : "Unikalne hasło…",
    "Save" : "Zapisz",
    "Change unique password" : "Zmień unikalne hasło",
    "Failed to save password. Please try again later." : "Nie udało się zapisać hasła. Spróbuj ponownie później.",
    "Close" : "Zamknij ",
    "Choose a team picture" : "Wybierz zdjęcie zespołu",
    "There is no description for this team" : "Brak opisu dla tego zespołu",
    "Enter a description for the team" : "Podaj opis dla tego zespołu",
    "Folder" : "Folder",
    "New folder" : "Nowy folder",
    "Folder name" : "Nazwa folderu",
    "This will create a regular folder shared with the team. To create a Team Folder, please contact your {productName} administrator" : "Zostanie utworzony zwykły folder udostępniony zespołowi. Aby utworzyć folder zespołu, skontaktuj się z administratorem {productName}",
    "Talk conversation" : "Rozmowa Talk",
    "New Talk conversation" : "Nowa rozmowa Talk",
    "Conversation name" : "Nazwa rozmowy",
    "Collective" : "Kolektyw",
    "Calendar" : "Kalendarz",
    "New calendar" : "Nowy kalendarz",
    "Calendar name" : "Nazwa kalendarza",
    "Unknown resource type" : "Nieznany typ zasobu",
    "Team calendar \"{resourceName}\" created and shared with team" : "Kalendarz zespołu \"{resourceName}\" został utworzony i udostępniony zespołowi",
    "{resourceType} \"{resourceName}\" created and shared with team" : "{resourceType} \"{resourceName}\" został utworzony i udostępniony zespołowi",
    "A calendar named \"{name}\" already exists. Please choose a different name." : "Kalendarz o nazwie \"{name}\" już istnieje. Wybierz inną nazwę.",
    "Failed to create {resourceType}: {error}" : "Nie udało się utworzyć {resourceType}: {error}",
    "Please select a valid png or jpg file" : "Wybierz prawidłowy plik PNG lub JPG",
    "Error picking team picture" : "Błąd podczas wybierania zdjęcia zespołu",
    "Error cropping avatar picture" : "Błąd podczas przycinania zdjęcia awatara",
    "An error happened while saving {fields}" : "Wystąpił błąd podczas zapisywania {fields}",
    "Team name" : "Nazwa zespołu",
    "Team owner" : "Właściciel zespołu",
    "Upload team picture" : "Prześlij zdjęcie zespołu",
    "Choose from Nextcloud Files" : "Wybierz z plików Nextcloud",
    "Delete picture" : "Usuń zdjęcie",
    "Edit" : "Edytuj",
    "Request to join" : "Prośba o dołączenie",
    "Create" : "Utwórz",
    "Show in Calendar" : "Pokaż w kalendarzu",
    "Your request to join this team is pending approval" : "Twoja prośba o dołączenie do tego zespołu oczekuje na zatwierdzenie",
    "You are not a member of {circle}" : "Nie jesteś członkiem {circle}",
    "Members" : "Członkowie",
    "Edit team picture" : "Edytuj zdjęcie zespołu",
    "Apply" : "Zastosuj",
    "Confirm" : "Potwierdź",
    "No other contacts available to select as line manager" : "Brak innych dostępnych kontaktów do wybrania jako przełożony",
    "Add more info" : "Dodaj więcej informacji",
    "More fields" : "Więcej pól",
    "Please select a valid format" : "Proszę wybrać prawidłowy format",
    "Invalid image" : "Nieprawidłowy obraz",
    "Error cropping picture" : "Błąd podczas przycinania zdjęcia",
    "Pick an avatar" : "Wybierz awatar",
    "Pick" : "Wybierz",
    "Error while processing the picture." : "Błąd podczas przetwarzania obrazu.",
    "Avatar downloaded from social network" : "Awatar pobrany z sieci społecznościowej",
    "Avatar already up to date" : "Awatar już zaktualizowany",
    "Avatar download failed" : "Pobieranie awatara nie powiodło się",
    "Crop contact photo" : "Przytnij zdjęcie kontaktu",
    "Upload a new picture" : "Wyślij nowe zdjęcie",
    "Choose from Files" : "Wybierz z Plików",
    "Download picture" : "Pobierz zdjęcie",
    "Clone contact" : "Klonuj kontakt",
    "This contact is in read-only mode. You do not have permission to edit this contact." : "Ten kontakt jest w trybie \"tylko do odczytu\". Nie masz uprawnień do modyfikowania tego kontaktu.",
    "The contact you were trying to edit has changed. Please manually refresh the contact. Any further edits will be discarded." : "Kontakt który próbujesz zmodyfikować został zmieniony. Odśwież kontakt ręcznie. Wszystkie przyszłe zmiany zostaną odrzucone.",
    "Address book" : "Książka adresowa",
    "Add contact to Birthday Calendar" : "Dodaj kontakt do Kalendarza urodzin",
    "Exclude contact from Birthday Calendar" : "Wyklucz kontakt z Kalendarza urodzin",
    "{title} at {organization}" : "{title} w {organization}",
    "Name" : "Nazwa",
    "Syntax error. Cannot open the contact." : "Błąd składni. Nie można otworzyć kontaktu.",
    "The contact does not exist on the server anymore." : "Kontakt nie istnieje na serwerze.",
    "Unable to retrieve the contact from the server, please check your network connection." : "Nie można pobrać kontaktu z serwera, sprawdź połączenie sieciowe.",
    "An error occurred while trying to move the contact" : "Wystąpił błąd podczas próby przeniesienia kontaktu",
    "An error occurred while trying to copy the contact" : "Wystąpił błąd podczas próby skopiowania kontaktu",
    "Unable to update contact" : "Nie można zaktualizować kontaktu",
    "No contact selected" : "Nie wybrano kontaktu",
    "Select a contact on the list to begin" : "Wybierz kontakt z listy, aby rozpocząć",
    "Title" : "Tytuł",
    "Company" : "Firma",
    "Go to talk conversation" : "Przejdź do rozmowy",
    "View profile" : "Zobacz profil",
    "This contact was broken and received a fix. Please review the content and click here to save it." : "Ten kontakt został zerwany i otrzymał poprawkę. Przejrzyj treść i kliknij tutaj, aby ją zapisać.",
    "Edit profile" : "Edytuj profil",
    "Generate QR Code" : "Wygeneruj kod QR",
    "Contact vCard as QR code" : "Kontakt vCard jako kod QR",
    "Select address book" : "Wybierz książkę adresową",
    "Media shares with you" : "Udostępnienia mediów dla Ciebie",
    "Talk conversations with you" : "Rozmowa Talk z Tobą",
    "Calendar events with you" : "Wydarzenia w Kalendarzu dla Ciebie",
    "Deck cards with you" : "Karta w Tablicy dla Ciebie",
    "No shared items with this contact" : "Brak udostępnionych elementów temu kontaktowi",
    "This contact cannot be moved" : "Tego kontaktu nie można przenieść",
    "This contact cannot be grouped" : "Tego kontaktu nie można pogrupować",
    "Add contacts to groups" : "Dodaj kontakty do grup",
    "Move contacts to addressbook" : "Przenieś kontakty do książki adresowej",
    "Select groups" : "Wybierz grupy",
    "Select addressbook" : "Wybierz książkę adresową",
    "Selected contacts" : "Wybrane kontakty",
    "Please note that only {count} of the {total} contacts can be added to a group" : "Uwaga: tylko {count}z {total} kontaktów można dodać do grupy",
    "Please note that only {count} of the {total} contacts can be moved" : "Uwaga: tylko {count} z {total} kontaktów można przenieść",
    "Move" : "Move",
    "Could not update favorite status" : "Nie udało się zaktualizować statusu ulubionych",
    "from {addressbook}" : "z {addressbook}",
    "Remove from favorites" : "Remove from favorites",
    "Add to favorites" : "Add to favorites",
    "Confirm merging contacts" : "Potwierdź scalanie kontaktów",
    "The selected contacts have conflicting information. Choose which information to keep" : "Wybrane kontakty mają sprzeczne informacje. Wybierz, które informacje zachować",
    "Contacts can be merged" : "Kontakty mogą zostać scalone",
    "Groups" : "Grupy",
    "Select groups to add the merged contact to" : "Wybierz grupy, do których dodać scalony kontakt",
    "Merge contacts" : "Scal kontakty",
    "_Delete {number} contact_::_Delete {number} contacts_" : ["Usuń {number} kontakt","Usuń {number} kontakty","Usuń {number} kontaktów","Usuń {number} kontaktów"],
    "Please select at least one editable contact to delete" : "Wybierz co najmniej jeden edytowalny kontakt do usunięcia",
    "Please select two editable contacts to merge" : "Wybierz dwa edytowalne kontakty do scalenia",
    "_Add {number} contact to group_::_Add {number} contacts to group_" : ["Dodaj {number} kontakt do grupy","Dodaj {number} kontaktów do grupy","Dodaj {number} kontaktów do grupy","Dodaj {number} kontakty do grupy"],
    "Please select at least one editable contact to add to a group" : "Wybierz co najmniej jeden edytowalny kontakt, aby dodać go do grupy",
    "_Move {number} contact to addressbook_::_Move {number} contacts to addressbook_" : ["Przenieś {number} kontakt do książki adresowej","Przenieś {number} kontaktów do książki adresowej","Przenieś {number} kontaktów do książki adresowej","Przenieś {number} kontakty do książki adresowej"],
    "Please select at least one editable contact to move to an addressbook" : "Wybierz co najmniej jeden edytowalny kontakt, aby przenieść go do książki adresowej",
    "Are you sure you want to proceed?" : "Czy na pewno chcesz kontynuować?",
    "Add contacts to group" : "Dodaj kontakty do grupy",
    "Search contacts …" : "Szukaj kontaktów …",
    "Unselect {number}" : "Odznacz {number}",
    "Add to {group}" : "Dodaj do {group}",
    "Add members to {group}" : "Dodaj członków do {group}",
    "Please note that you can only add contacts from writable address books to contact groups. Contacts from read-only address books, such as the system address book, cannot be added." : "Pamiętaj, że do grup kontaktów można dodawać tylko kontakty z edytowalnych książek adresowych. Kontakty z książek tylko do odczytu, takich jak systemowa książka adresowa, nie mogą być dodawane.",
    "Remove {type}" : "Usuń {type}",
    "Add to group" : "Dodaj do grupy",
    "Add members to group" : "Dodaj członków do grupy",
    "Search {types}" : "Szukaj {types}",
    "Add guest" : "Dodaj gościa",
    "Search for people to add" : "Szukaj osoby do dodania",
    "No results" : "Brak wyników",
    "Add {type}" : "Dodaj {type}",
    "New team name" : "Nowa nazwa zespołu",
    "Personal team" : "Zespół osobisty",
    "This team will only be visible to you. Other members will not be able to see or use it." : "Ten zespół będzie widoczny tylko dla Ciebie. Inni członkowie nie będą mogli go zobaczyć ani z niego korzystać.",
    "Local team" : "Zespół lokalny",
    "This team will not be shared with the other instances of the global scale" : "Zespół ten nie będzie udostępniany innym instancjom o skali globalnej",
    "Create team" : "Utwórz zespół",
    "Promote as sole owner" : "Promuj jako jedynego właściciela",
    "Promote to {level}" : "Promuj na {level}",
    "Demote to {level}" : "Zdegraduj do {level}",
    "Are you sure you want to leave this team? This action cannot be undone." : "Czy na pewno chcesz opuścić ten zespół? Tej operacji nie można cofnąć.",
    "Leave team failed." : "Nie udało się opuścić zespołu.",
    "Could not delete the member {displayName}" : "Nie można usunąć członka {displayName}",
    "Could not change the member level to {level}" : "Nie można zmienić poziomu członkostwa na {level}",
    "Could not accept membership request" : "Nie można zaakceptować prośby o członkostwo",
    "Accept membership request" : "Zaakceptuj prośbę o członkostwo",
    "Reject membership request" : "Odrzuć prośbę o członkostwo",
    "Manage level" : "Zarządzaj poziomem",
    "Remove member" : "Usuń członka",
    "Unable to get the results" : "Nie można uzyskać wyników",
    "Some members could not be added" : "Nie można dodać niektórych członków",
    "There was an issue adding members to the team" : "Wystąpił problem z dodaniem członków do zespołu",
    "Loading members list …" : "Wczytywanie listy członków …",
    "The list of members is only visible to members of this team" : "Lista członków jest widoczna tylko dla członków tego zespołu",
    "You currently have no access to the member list" : "Obecnie nie masz dostępu do listy członków",
    "Add to {team}" : "Dodaj do {team}",
    "Invite members to {team}" : "Zaproś członków do {team}",
    "Pending" : "Oczekuje",
    "Accept" : "Zaakceptuj",
    "Select chart …" : "Wybierz wykres …",
    "Chart" : "Wykres",
    "Select type" : "Wybierz rodzaj",
    "Add contact in group" : "Dodaj kontakt do grupy",
    "None" : "Brak",
    "copy" : "kopiuj",
    "Select option" : "Wybierz opcję",
    "JavaScript URIs are not allowed" : "Adresy URI JavaScript nie są dozwolone",
    "Notes" : "Notatki",
    "send an email" : "wyślij e-mail",
    "Personal dates" : "Dane osobiste (daty)",
    "Add property of this type" : "Dodaj właściwość do tego typu",
    "Member" : "Członek",
    "This is a read-only group managed by administrators. Group members can only view this group." : "To jest grupa tylko do odczytu zarządzana przez administratorów. Członkowie grupy mogą jedynie przeglądać tę grupę.",
    "Unable to create the contact." : "Nie można utworzyć kontaktu.",
    "Contact not found" : "Nie znaleziono kontaktu",
    "Group {group} not found" : "Nie znaleziono grupy {group}",
    "Add member" : "Dodaj członka",
    "New contact" : "Nowy kontakt",
    "_{success} contact added to {name}_::_{success} contacts added to {name}_" : ["{success} kontakt dodany do {name}","{success} kontakty dodane do {name}","{success} kontaktów dodanych do {name}","{success} kontaktów dodanych do {name}"],
    "_Adding {success} contact to {name}_::_Adding {success} contacts to {name}_" : ["Dodawanie {success} kontaktu do {name}","Dodawanie {success} kontaktów do {name}","Dodawanie {success} kontaktów do {name}","Dodawanie {success} kontaktów do {name}"],
    "_{count} error_::_{count} errors_" : ["{count} błąd","{count} błędy","{count} błędów","{count} błędów"],
    "_Importing %n contact into {addressbook}_::_Importing %n contacts into {addressbook}_" : ["Importowanie %n kontaktu do {addressbook}","Importowanie %n kontaktów do {addressbook}","Importowanie %n kontaktów do {addressbook}","Importowanie %n kontaktów do {addressbook}"],
    "_Done importing %n contact into {addressbook}_::_Done importing %n contacts into {addressbook}_" : ["Zakończono importowanie %n kontaktu do {addressbook}","Zakończono importowanie %n kontaktów do {addressbook}","Zakończono importowanie %n kontaktów do {addressbook}","Zakończono importowanie %n kontaktów do {addressbook}"],
    "No data for this contact" : "Brak danych dla tego kontaktu",
    "No data for this contact on their profile" : "Brak danych tego kontaktu w jego profilu",
    "Import" : "Importuj",
    "Are you sure you want to import this contact file?" : "Czy na pewno chcesz zaimportować ten plik kontaktu?",
    "Could not copy" : "Nie można skopiować",
    "Join team" : "Dołącz do zespołu",
    "You are about to leave {circle}.\nAre you sure?" : "Zamierzasz opuścić {circle}.\nJesteś pewny?",
    "Please confirm team leave" : "Proszę o potwierdzenie opuszczenia zespołu",
    "Could not leave the team {displayName}" : "Nie można opuścić zespołu {displayName}",
    "Unable to join the team" : "Nie można dołączyć do zespołu",
    "You are about to delete {circle}.\nAre you sure?" : "Zamierzasz usunąć {circle}.\nJesteś pewny?",
    "Please confirm team deletion" : "Potwierdź usunięcie zespołu",
    "Unable to delete the team" : "Nie można usunąć zespołu",
    "Confirm enabling federation" : "Potwierdź włączenie federacji",
    "Enabling this will prevent {circle} from being a member of other teams.\nAre you sure?" : "Włączenie tego uniemożliwi {circle} bycie członkiem innych zespołów.\nCzy na pewno?",
    "Enable federation" : "Włącz federację",
    "Link copied to the clipboard" : "Link skopiowany do schowka",
    "Could not copy link to the clipboard." : "Nie można skopiować linku do schowka.",
    "Not grouped" : "Nie pogrupowane",
    "Create your own teams for sharing. Add Nextcloud users, contacts, or anyone via email." : "Twórz własne zespoły do udostępniania. Dodawaj użytkowników Nextcloud, kontakty lub dowolne osoby przez e-mail",
    "Team" : "Zespół",
    "User" : "Użytkownik",
    "Group" : "Grupa",
    "Email" : "E-mail",
    "Contact" : "Kontakt",
    "Moderator" : "Moderator",
    "Admin" : "Administrator",
    "Owner" : "Właściciel",
    "Invites" : "Zaprasza",
    "Anyone can request membership" : "Każdy może poprosić o członkostwo",
    "Members need to accept invitation" : "Członkowie muszą zaakceptować zaproszenie",
    "Memberships must be confirmed/accepted by a Moderator (requires \"Anyone can request membership\")" : "Członkostwo musi zostać potwierdzone/zaakceptowane przez Moderatora (wymagane jest ustawienie „Każdy może poprosić o członkostwo”)",
    "Members can also invite" : "Członkowie mogą również zapraszać",
    "Membership" : "Członkostwo",
    "Prevent teams from being a member of another team" : "Uniemożliwiaj zespołom przynależność do innego zespołu",
    "Federation" : "Federacja",
    "Allow federated members" : "Zezwalaj członkom federacyjnym",
    "Privacy" : "Prywatność",
    "Visible to everyone" : "Widoczne dla wszystkich",
    "users" : "użytkownicy",
    "Users" : "Użytkownicy",
    "groups" : "grupy",
    "federated users" : "użytkownicy federacyjni",
    "Federated users" : "Użytkownicy federacyjni",
    "teams" : "zespoły",
    "email addresses" : "adresy e-mail",
    "Email addresses" : "Adresy e-mail",
    "contacts" : "kontakty",
    "Detailed name" : "Szczegółowa nazwa",
    "Additional names" : "Dodatkowe nazwy",
    "Prefix" : "Przedrostek",
    "Suffix" : "Przyrostek",
    "Nickname" : "Pseudonim",
    "Website" : "Strona internetowa",
    "Location" : "Lokalizacja",
    "Federated Cloud ID" : "ID Chmury Federacyjnej",
    "Home" : "Dom",
    "Work" : "Praca",
    "Other" : "Inne",
    "Address" : "Adres",
    "Post office box" : "Skrytka pocztowa",
    "Extended address" : "Rozszerzony adres",
    "City" : "Miasto",
    "State or province" : "Województwo ",
    "Postal code" : "Kod pocztowy",
    "Country" : "Kraj",
    "Birthday" : "Urodziny",
    "Place of birth" : "Miejsce urodzenia",
    "Anniversary" : "Rocznica",
    "Date of death" : "Data śmierci",
    "Place of death" : "Miejsce śmierci",
    "Instant messaging" : "Wiadomości natychmiastowe",
    "Phone" : "Telefon",
    "Mobile" : "Komórka",
    "Work mobile" : "Telefon służbowy",
    "Home mobile" : "Telefon domowy",
    "Fax" : "Faks",
    "Fax home" : "Faks domowy",
    "Fax work" : "Faks służbowy",
    "Pager" : "Pager",
    "Voice" : "Połączenie głosowe",
    "Car" : "Samochód",
    "Work pager" : "Pager służbowy",
    "Line manager" : "Menedżer liniowy",
    "Social network" : "Sieć społecznościowa",
    "Relationship to you" : "Powiązane z Tobą",
    "Spouse" : "Współmałżonek",
    "Child" : "Dziecko",
    "Mother" : "Matka",
    "Father" : "Ojciec",
    "Parent" : "Rodzic",
    "Brother" : "Brat",
    "Sister" : "Siostra",
    "Relative" : "Krewny",
    "Friend" : "Przyjaciel",
    "Colleague" : "Kolega/Koleżanka",
    "Assistant" : "Asystent",
    "Related contacts" : "Powiązane kontakty",
    "Agent" : "Agent",
    "Emergency" : "Nagła pomoc",
    "Co-worker" : "Współpracownik",
    "Gender" : "Płeć",
    "Female" : "Kobieta",
    "Male" : "Mężczyzna",
    "Unknown" : "Nieznany",
    "Time zone" : "Strefa czasowa",
    "Spoken languages" : "Języki mówione",
    "_{failed} contact failed to be read_::_{failed} contacts failed to be read_" : ["Nie udało się odczytać {failed} kontaktu","Nie udało się odczytać {failed} kontaktów","Nie udało się odczytać {failed} kontaktów","Nie udało się odczytać {failed} kontaktów"],
    "An error has occurred in team(s). Check the console for more details." : "Wystąpił błąd w zespole(-łach). Sprawdź konsolę po więcej informacji.",
    "Unable to create team {circleName}" : "Nie można utworzyć zespołu {circleName}",
    "Unable to delete team {circleId}" : "Nie można usunąć zespołu {circleId}",
    "Could not update favorite state" : "Nie udało się zaktualizować stanu ulubionych",
    "Unable to delete contact" : "Nie można usunąć kontaktu",
    "Value copied to the clipboard" : "Wartość skopiowana do schowka",
    "Could not copy value to the clipboard." : "Nie można skopiować wartości do schowka.",
    "Deck board" : "Tablica Deck",
    "New Deck board" : "Nowa tablica Deck",
    "Board name" : "Nazwa tablicy",
    "Deck app is not installed. Please install it to create team boards." : "Aplikacja Deck nie jest zainstalowana. Zainstaluj ją, aby tworzyć tablice zespołów.",
    "Pick an address book" : "Wybierz z książki adresowej",
    "Select Date" : "Wybierz datę",
    "note" : "notatka",
    "email" : "e-mail",
    "Create your own groups for sharing. Add Nextcloud users, contacts, or anyone via email." : "Twórz własne grupy do udostępniania. Dodawaj użytkowników Nextcloud, kontakty lub dowolne osoby przez e-mail."
},
"nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");
