OC.L10N.register(
    "contacts",
    {
    "Import contacts" : "Impordi kontaktid",
    "Details" : "Üksikasjad",
    "All contacts" : "Kõik kontaktid",
    "Email address is required." : "E-posti aadress on nõutav.",
    "An open invite already exists." : "Kutse on juba olemas.",
    "Could not accept invite because no authenticated user was found." : "Kuna ühtegi autenditud kasutajat ei leidunud, siis kutse vastuvõtmine ei õnnestunud.",
    "The invite provider is invalid or not allowed." : "Kutse koostaja on vigane või pole lubatud.",
    "Unable to accept this invitation. You are trying to accept an outgoing invitation." : "Kutsega nõustumine ei õnnestu. Sa proovid nõustuda väljasaadetava kutsega.",
    "Could not accept invite because the remote provider returned an invalid response." : "Kutset ei olnud võimalik vastu võtta, kuna teise serveri vastus oli vigane.",
    "The remote provider accepted the invite, but this server could not create the local contact." : "Teine server võttis kutse vastu, aga kohalik server ei suutnud kohalikku kontakti lisada.",
    "Cannot resend: no email address" : "Uuesti saatmine pole võimalik: e-posti aadress on puudu",
    "Invite has already been accepted." : "Saaja on selle kutsega juba nõustunud.",
    "Invite has expired. Please create a new one." : "Kutse on aegunud. Palun koosta uus kutse.",
    "This is a copy of an invite sent to you previously by %1$s on %2$s" : "See on kutse koopia, mille %1$s saatis sulle %2$s",
    "Invite already has an email address." : "Kutsel juba on e-posti aadress olemas.",
    "An open invite for this email already exists." : "Selle e-posti aadressi jaoks on kutse juba olemas.",
    "Could not claim invite for this email; please refresh and try again." : "Selle e-posti aadressiga kutse ei õnnestunud tuvastada. Palun laadi leht uuesti ja proovi veel kord.",
    "Could not revert invite after delivery failure. Please refresh and try again." : "Kutse tühistamine ei õnnestunud pärast edastamise ebaõnnestumist. Palun laadi leht uuesti ja proovi veel kord.",
    "OCM invites are disabled." : "OCM-kutsete kasutamine on lülitatud välja.",
    "Recipient email address is invalid." : "Saaja e-posti aadress on vigane.",
    "%1$s via %2$s" : "%1$s %2$s kaudu",
    "%1$s invites you to exchange contact information." : "%1$s soovib sinuga kontakte vahetada.",
    "This is a copy of the invitation you've sent to %1$s" : "See on kutse koopia, mille oled saatnud kasutajale %1$s",
    "Hi there," : "Tere,",
    "%1$s invites you to exchange cloud accounts and contact information." : "%1$s on saatnud sulle kutse millega soovib vahetada kontakteavet liitpilves.",
    "This will allow you to share data with each other." : "Muu hulgas võimaldab see omavahel teavet ja andmeid jagada.",
    "To accept this invite, click the link below and sign in with your cloud provider:" : "Kutsega nõustumiseks klõpsa järgnevat linki ja logi sisse oma pilveteenuse pakkujaga.",
    "Invitation details:" : "Kutse üksikasjad:",
    "Invite code: %1$s" : "Kutsekood: %1$s",
    "Encoded invite: %1$s" : "Koodipõhine kutse: %1$s",
    "To accept this invite, use the url below to sign in with your cloud provider:" : "Kutsega nõustumiseks klõpsa järgnevat linki ja logi sisse oma teenusepakkuja kasutajakontoga:",
    "_Imported %n contact_::_Imported %n contacts_" : ["Importsin %n kontakti","Importsin %n kontakti"],
    "_(skipped %n contact)_::_(skipped %n contacts)_" : ["(%n kontakt jäi vahele)","(%n kontakti jäi vahele)"],
    "Contacts" : "Kontaktid",
    "A contacts app for Nextcloud" : "Kontaktide rakendus Nextcloudi jaoks",
    "The Nextcloud contacts app is a user interface for Nextcloud's CardDAV server. Easily sync contacts from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Currently Mail and Calendar – more to come.\n* 🎉 **Never forget a birthday!** You can sync birthdays and other recurring events with your Nextcloud Calendar.\n* 👥 **Sharing of Adressbooks!** You want to share your contacts with your friends or coworkers? No problem!\n* 🙈 **We’re not reinventing the wheel!** Based on the great and open SabreDAV library." : "Nextcloudi kontaktirakendus on Nextcloudi CardDAV-i serveri kasutajaliides. Sünkrooni kontakte mugavalt oma Nextcloudi serveriga ja halda neid veebiliideses.\n\n* 🚀 **Lõiming muude Nextcloudi rakendustega!** Hetkel E-post ja Kalender, aga täiendavaid rakendusi lisandub õige pea.\n* 🎉 **Ära enam unusta ühtegi sünnipäeva!** Sa saad sünkroonida sünnipäevi ja muid korduvaid sündmusi oma Nextcloudi Kalendriga.\n* 👥 **Aadressiraamatute jagamine!** Sa tahad omi kontakte jagada sõprade ja kolleegidega? Pole probleemi!\n* 🙈 **Me ei hakanud ratast leiutama!** Aluseks on suurepärane avatud lähtekoodil põhinev SabreDAV-i teek.",
    "Copy to full name" : "Kopeeri täisnimi",
    "Omit year" : "Jäta aasta vahele",
    "Could not save the setting" : "Seadistuse salvestamine ei õnnestunud",
    "Allow updating avatars from social media" : "Luba tunnuspiltide lisamist sotsiaalmeediasaitidest",
    "External invitations" : "Kutsed välistest süsteemidest",
    "Allow creating invites without an email address (link-only)" : "Võimalda kutsete koostamist, mis ei vaja e-posti aadressi (lingipõhised kutsed)",
    "Show the \"Copy encoded invite\" button on invite details" : "Näita kutse üksikasjade vaates nuppu „Kopeeri koodipõhine kutse“",
    "Organization chart" : "Organisatsiooniskeem",
    "There was an error fetching the member list" : "Liikmete loendi laadimisel tekkis viga",
    "Teams" : "Tiimid",
    "Please select a team" : "Palun vali tiim",
    "Loading team…" : "Laadin tiimi…",
    "Loading contacts …" : "Laadin kontakte…",
    "There are no contacts yet" : "Ühtegi kontakti pole veel!",
    "Create contact" : "Loo kontakt",
    "There are no contacts in this group" : "Selle grupis pole kontakte",
    "Create contacts" : "Loo kontakte",
    "Add contacts" : "Lisa kontakte",
    "Loading invitations…" : "Laadin kutseid…",
    "Could not load invitations" : "Kutsete laadimine ei õnnestunud",
    "Retry" : "Proovi uuesti",
    "There are no invitations" : "Ühtegi kutset ei leidu",
    "Create invitation" : "Koosta kutse",
    "Loading …" : "Andmed on laadimisel…",
    "Manage team" : "Halda tiimi",
    "Leave team" : "Lahku tiimist",
    "Delete team" : "Kustuta tiim",
    "Setting saved" : "Seadistus on salvestatud",
    "Failed to save setting" : "Seadistuse salvestamine ei õnnestunud",
    "Contacts settings" : "Kontaktide seadistused",
    "General" : "Üldine",
    "Update avatars from social media" : "Laadi tunnuspildid sotsiaalmeediast",
    "Refreshed once per week" : "Värskendatud kord nädalas",
    "Address books" : "Aadressiraamatud",
    "Tried to drop an invalid contact!" : "Proovisid lohistada vigasele/valele kontaktile!",
    "Rename" : "Muuda nime",
    "Export" : "Ekspordi",
    "Send email" : "Saada e-kiri",
    "Send email as BCC" : "Saada e-kiri pimekoopiana",
    "Delete" : "Kustuta",
    "Show all groups" : "Näita kõiki gruppe",
    "Collapse groups" : "Ahenda grupid",
    "Show all teams" : "Näita kõiki tiime",
    "Collapse teams" : "Ahenda tiime",
    "Group name cannot be empty" : "Grupi nimi ei saa  olla tühi",
    "This group already exists" : "Selline grupp on juba olemas",
    "An error occurred while creating the group" : "Grupi loomisel tekkis viga",
    "This team already exists" : "Selline tiim on juba olemas",
    "An error happened during the creation of the team" : "Tiimi loomisel tekkis viga",
    "Add address book" : "Lisa aadressiraamat",
    "Recently contacted" : "Viimati ühendust võetud",
    "Contact groups" : "Kontaktigrupid",
    "Create a new contact group" : "Loo uus kontaktigrupp",
    "Contact group name" : "Kontaktigrupi nimi",
    "Create a new team" : "Loo uus tiim",
    "Open the contacts app settings" : "Ava kontaktirakenduse seadistused",
    "_Shared with {num} entity_::_Shared with {num} entities_" : ["Jagatud {num} osapoolega","Jagatud {num} osapoolega"],
    "Copied" : "Kopeeritud",
    "Cannot copy" : "Ei õnnestu kopeerida",
    "Copy link" : "Kopeeri link",
    "Toggling of address book was not successful" : "Aadressiraamatu sisse- või väljalülitamine ei õnnestunud.",
    "This will delete the address book and every contacts within it" : "Järgnevaga kustutad aadressiraamatu ja kõik seal sisalduvad kontaktid",
    "Delete {addressbook}?" : "Kas kustutame „{addressbook}“ aadressiraamatu?",
    "This will unshare the address book and every contacts within it" : "Järgnevaga eemaldad endalt selle aadressiraamatu jagamise koos kõigi seal sisalduvate kontaktidega",
    "Unshare {addressbook}?" : "Kas eemaldame „{addressbook}“ aadressiraamatu jagamise?",
    "Deletion of address book was not successful." : "Aadressiraamatu kustutamine ei õnnestunud.",
    "Renaming of address book was not successful." : "Aadressiraamatu nime muutmine ei õnnestunud.",
    "{addressbookname} (Hidden)" : "{addressbookname} (Peidetud)",
    "Download" : "Laadi alla",
    "Show" : "Näita",
    "Unshare from me" : "Eemalda minult see jagamine",
    "_%n contact_::_%n contacts_" : ["%n kontakt","%nkontakti"],
    "_%n group_::_%n groups_" : ["%n grupp","%n gruppi"],
    "Share with users or groups" : "Jaga kasutajate või gruppidega",
    "Share with users" : "Jaga kasutajatega",
    "No users or groups" : "Ei ole kasutajaid või gruppe",
    "Unable to delete the share" : "Ei õnnestu jaosmeediat kustutada",
    "Unable to change permissions" : "Ei õnnestu muuta õigusi",
    "can create and edit" : "võib luua ja muuta",
    "Choose a vCard file to import" : "Vali imporditav vCardi fail",
    "Import into the {addressbookName} address book" : "Impordi aadressiraamatusse „{addressbookName}“",
    "Select local file" : "Vali kohalik fail",
    "Import from files" : "Impordi failirakendusest",
    "Importing is disabled because there are no address books available" : "Kuna ühtegi aadressiraamatut pole saadaval, siis importimine pole võimalik",
    "An error occurred, unable to create the address book" : "Tekkis viga, aadressiraamatu loomine ei õnnestu",
    "New address book" : "Uus aadressiraamat",
    "Add new address book" : "Lisa uus aadressiraamat",
    "Cancel" : "Loobu",
    "Add" : "Lisa",
    "First name" : "Eesnimi",
    "Last name" : "Perenimi",
    "Phonetic first name" : "Foneetiline eesnimi",
    "Phonetic last name" : "Foneetiline perenimi",
    "Display name" : "Kuvatav nimi",
    "Last modified" : "Viimati muudetud",
    "Sort contacts by" : "Kontaktide järjestus",
    "Manages" : "Haldab",
    "Oversees" : "Juhendab",
    "An error happened during the config change" : "Seadistuste muutmisel tekkis viga",
    "Enforce password protection on files shared to this team" : "Lisa sellele tiimile jagatud failide kaitsmine salasõnaga",
    "Use a unique password for all shares to this team" : "Kasuta selle kogu selle tiimi jaosmeedia jaoks unikaalset salasõna",
    "Unique password …" : "Unikaalne salasõna…",
    "Save" : "Salvesta",
    "Change unique password" : "Muuda unikaalset salasõna",
    "Failed to save password. Please try again later." : "Salasõna salvestamine ei õnnestunud. Palun proovi hiljem uuesti.",
    "Close" : "Sulge",
    "Choose a team picture" : "Vali tiimipilt",
    "There is no description for this team" : "Sellel tiimil pole kirjeldust",
    "Enter a description for the team" : "Lisa tiimi kirjeldus",
    "Folder" : "Kaust",
    "New folder" : "Uus kaust",
    "Folder name" : "Kausta nimi",
    "This will create a regular folder shared with the team. To create a Team Folder, please contact your {productName} administrator" : "Järgnevaga luuakse tavaline kaust, mida jagatakse tiimiga. Tiimikausta loomiseks palun küsi abi oma {productName}i serveri haldajalt",
    "Talk conversation" : "Vestlus kõnerakenduses",
    "New Talk conversation" : "Uus vestlus kõnerakenduses",
    "Conversation name" : "Vestluse nimi",
    "Collective" : "Vabaühendus",
    "Calendar" : "Kalender",
    "New calendar" : "Uus kalender",
    "Calendar name" : "Kalendri nimi",
    "Unknown resource type" : "Tundmatu ressursi tüüp",
    "Team calendar \"{resourceName}\" created and shared with team" : "Tiimi kalender „{resourceName}“ on loodud ja tiimiga jagatud",
    "{resourceType} \"{resourceName}\" created and shared with team" : "{resourceType} nimega „{resourceName}“ on  loodud ja tiimiga jagatud",
    "A calendar named \"{name}\" already exists. Please choose a different name." : "Kalender nimega „{name}“ on juba olemas. Palun sisesta muu nimi.",
    "Failed to create {resourceType}: {error}" : "„{resourceType}“ ressursi loomine ei õnnestunud: {error}",
    "Please select a valid png or jpg file" : "Palun vali korrektne png või jpg fail",
    "Error picking team picture" : "Viga tiimipildi valimisel",
    "Error cropping avatar picture" : "Viga tiimipildi kadreerimisel",
    "An error happened while saving {fields}" : "{fields} salvestamisel tekkis viga",
    "Team name" : "Tiimi nimi",
    "Team owner" : "Tiimi omanik",
    "Upload team picture" : "Laadi tiimipilt üles",
    "Choose from Nextcloud Files" : "Vali Nextcloudi failirakendusest",
    "Delete picture" : "Kustuta pilt",
    "Edit" : "Muuda",
    "Request to join" : "Palu võimalust liituda",
    "Create" : "Loo",
    "Show in Calendar" : "Näita kalendris",
    "Your request to join this team is pending approval" : "Sinu liitumissoov tiimiga ootab kinnitust",
    "You are not a member of {circle}" : "Sa pole „{circle}“ tiimi liige",
    "Members" : "Liikmed",
    "Edit team picture" : "Muuda tiimipilti",
    "Apply" : "Rakenda",
    "Confirm" : "Kinnita",
    "No other contacts available to select as line manager" : "Ei leidu muid kontakte, keda saaks valida vahetuks ülemuseks",
    "Add more info" : "Lisa veel teavet",
    "More fields" : "Täiendavad väljad",
    "Please select a valid format" : "Palun vali korrektne vorming",
    "Invalid image" : "Vigane pilt",
    "Error cropping picture" : "Viga pildi kadreerimisel",
    "Pick an avatar" : "Vali tunnuspilt ehk avatar",
    "Pick" : "Vali",
    "Error while processing the picture." : "Viga pildi töötlemisel.",
    "Avatar downloaded from social network" : "Tunnuspilt on allalaaditud sotsiaalmeediasaidist",
    "Avatar already up to date" : "Tunnuspilt on juba ajakohane",
    "Avatar download failed" : "Ei õnnestunud tunnuspilti alla laadida",
    "Crop contact photo" : "Kadreeri kontakti fotot",
    "Upload a new picture" : "Laadi üles uus pilt",
    "Choose from Files" : "Vali failirakendusest",
    "Download picture" : "Laadi pilt alla",
    "Clone contact" : "Tee kontaktist koopia",
    "This contact is in read-only mode. You do not have permission to edit this contact." : "Sul pole õigusi seda kontakti muuta ja saad seda vaid lugeda.",
    "The contact you were trying to edit has changed. Please manually refresh the contact. Any further edits will be discarded." : "Kontakt, mida olid muutmas oli vahepeal muutunud ja edasisi muudatusi pole mõtet teha. Palun uuenda kontakti andmed käsitsi.",
    "Address book" : "Aadressiraamat",
    "Add contact to Birthday Calendar" : "Lisa kontakt sünnipäevade kalendrisse",
    "Exclude contact from Birthday Calendar" : "Eemalda kontakt sünnipäevade kalendrist",
    "{title} at {organization}" : "{title} organisatsioonis {organization}",
    "Name" : "Nimi",
    "Syntax error. Cannot open the contact." : "Süntaksiviga - kontakti avamine ei õnnestu.",
    "The contact does not exist on the server anymore." : "Seda kontakti enam ei leidu serveris.",
    "Unable to retrieve the contact from the server, please check your network connection." : "Kontaktide laadimine serverist ei õnnestunud. Palun kontrolli oma arvuti või seadme internetiühenduse toimivust.",
    "An error occurred while trying to move the contact" : "Kontakti teisaldamisel tekkis viga",
    "An error occurred while trying to copy the contact" : "Kontakti kopeerimisel tekkis viga",
    "Unable to update contact" : "Kontakti uuendamine ei õnnestu",
    "No contact selected" : "Ükski kontakt pole valitud",
    "Select a contact on the list to begin" : "Alustamiseks vali loendist kontakt",
    "Title" : "Pealkiri",
    "Company" : "Äriühing / firma",
    "Go to talk conversation" : "Ava vestlus",
    "View profile" : "Vaata profiili",
    "This contact was broken and received a fix. Please review the content and click here to save it." : "See kontaktikirje oli katki ja sai parandatud. Palun vaata sisu üle ja klõpsi salvestamiseks siin.",
    "Edit profile" : "Muuda profiili",
    "Generate QR Code" : "Loo QR-kood",
    "Contact vCard as QR code" : "Kontakti vCard QR-koodina",
    "Select address book" : "Vali aadressiraamat",
    "Media shares with you" : "Sinuga ühine jaosmeedia",
    "Talk conversations with you" : "Sinuga ühised vestlused",
    "Calendar events with you" : "Sinuga ühised kalendrisündmused",
    "Deck cards with you" : "Sinuga ühised kanbani kaardid",
    "No shared items with this contact" : "Selle kontaktiga pole jagatud ühtegi objekti",
    "This contact cannot be moved" : "Seda kontakti ei saa teisaldada",
    "This contact cannot be grouped" : "Seda kontakti ei saa grupeerida",
    "Add contacts to groups" : "Lisa kontaktid gruppidesse",
    "Move contacts to addressbook" : "Tõsta kontaktid aadressiraamatusse",
    "Select groups" : "Vali grupid",
    "Select addressbook" : "Vali aadressiraamat",
    "Selected contacts" : "Valitud kontaktid",
    "Please note that only {count} of the {total} contacts can be added to a group" : "Palun arvesta, et gruppi lisada saad vaid {count} kontakti {total}-st",
    "Please note that only {count} of the {total} contacts can be moved" : "Palun arvesta, et teisaldada saad vaid {count} kontakti {total}-st",
    "Move" : "Teisalda",
    "Unselect {name}" : "Eemalda valik: {name}",
    "Select {name}" : "Vali {name}",
    "Could not update favorite status" : "Olekut lemmikuna polnud võimalik uuendada",
    "from {addressbook}" : "aadressiraamatust {addressbook}",
    "Remove from favorites" : "Eemalda lemmikutest",
    "Add to favorites" : "Lisa lemmikuks",
    "Confirm merging contacts" : "Kinnita kontaktide mestimine",
    "The selected contacts have conflicting information. Choose which information to keep" : "Valitud kontaktidel on vastuoluline teave. Palun vali, mida neist soovid säilitada",
    "Contacts can be merged" : "Kontaktide mestimine on võimalik",
    "Groups" : "Grupid",
    "Select groups to add the merged contact to" : "Vali, grupid, kuhu tahad mestitud kontaktid lisada",
    "Merge contacts" : "Mesti kontaktid",
    "_Delete {number} contact_::_Delete {number} contacts_" : ["Kustuta {number} kontakt","Kustuta {number} kontakti"],
    "Please select at least one editable contact to delete" : "Kustutamiseks palun vali vähemalt üks muudetav kontakt",
    "Please select two editable contacts to merge" : "Mestimiseks palun vali kaks muudetavat kontakti",
    "_Add {number} contact to group_::_Add {number} contacts to group_" : ["Lisa {number} kontakt gruppi","Lisa {number} kontakti gruppi"],
    "Please select at least one editable contact to add to a group" : "Gruppi lisamiseks palun vali vähemalt üks muudetav kontakt",
    "_Move {number} contact to addressbook_::_Move {number} contacts to addressbook_" : ["Tõsta {number} kontakt aadressiraamatusse","Tõsta {number} kontakti aadressiraamatusse"],
    "Please select at least one editable contact to move to an addressbook" : "Aadressiraamatusse tõstmiseks palun vali vähemalt üks muudetav kontakt",
    "Are you sure you want to proceed?" : "Kas oled kindel, et tahad jätkata?",
    "Add contacts to group" : "Lisa kontaktid gruppi",
    "Search contacts …" : "Otsi kontakte…",
    "Unselect {number}" : "Eemalda {number} kirje(t)",
    "Add to {group}" : "Lisa „{group}“ gruppi",
    "Add members to {group}" : "Lisa liikmeid „{group}“ gruppi",
    "Please note that you can only add contacts from writable address books to contact groups. Contacts from read-only address books, such as the system address book, cannot be added." : "Palun arvesta, et kontaktigruppidesse saad kontakte lisada vaid kirjutusõigustega aadressiraamatutest. Kontakte ainult lugemisõigusega aadressiraamatutest, nagu näiteks süsteemne aadressiraamatut, lisada ei saa.",
    "Remove {type}" : "Eemalda {type}",
    "Add to group" : "Lisa gruppi",
    "Add members to group" : "Lisa liikmeid gruppi",
    "Search {types}" : "Otsi: {types}",
    "Add guest" : "Lisa külaline",
    "Search for people to add" : "Otsi inimesi, keda liikmeks lisada",
    "No results" : "Vasteid ei leidu",
    "Add {type}" : "Lisa {type}",
    "New team name" : "Tiimi uus nimi",
    "Personal team" : "Isiklik tiim",
    "This team will only be visible to you. Other members will not be able to see or use it." : "Seda tiimi näed vaid sina. Tiimi liikmed ja muud kasutajad seda ei näe ega saa kasutada.",
    "Local team" : "Kohalik tiim",
    "This team will not be shared with the other instances of the global scale" : "See tiim on mõeldud kasutamiseks vaid siin serveris ja pole liitpilves nähtav",
    "Create team" : "Loo tiim",
    "Promote as sole owner" : "Muuda ainuomanikuks",
    "Promote to {level}" : "Määra uueks kõrgemaks rolliks „{level}“",
    "Demote to {level}" : "Määra uueks madalamaks rolliks „{level}“",
    "Are you sure you want to leave this team? This action cannot be undone." : "Kas sa oled kindel, et soovid sellest tiimist lahkuda? Seda tegevust ei saa tagasi pöörata.",
    "Leave team failed." : "Tiimist lahkumine ei õnnestunud.",
    "Could not delete the member {displayName}" : "„{displayName}“ liikme kustutamine ei õnnestunud",
    "Could not change the member level to {level}" : "Ei õnnestunud määrata uut õiguste taset „{level}“",
    "Could not accept membership request" : "Liitumispalvega nõustumine ei õnnestunud",
    "Accept membership request" : "Nõustu liitumispalvega",
    "Reject membership request" : "Lükka liitumispalve tagasi",
    "Manage level" : "Halda õiguste taset",
    "Remove member" : "Eemalda liige",
    "Unable to get the results" : "Ei õnnestu laadida tulemusi",
    "Some members could not be added" : "Mõnede liikmete lisamine ei õnnestunud",
    "There was an issue adding members to the team" : "Liikme lisamisel tiimi tekkis viga",
    "Loading members list …" : "Laadin liikmete loendit…",
    "The list of members is only visible to members of this team" : "Liikmete loendit näevad vaid teised tiimi liikmed",
    "You currently have no access to the member list" : "Sul hetkel puudub ligipääs liikmete loendile",
    "Add to {team}" : "Lisa „{team}“ tiimi",
    "Invite members to {team}" : "Kutsu uusi liikmeid „{team}“ tiimi",
    "Pending" : "Ootel",
    "This invite does not look valid. Check that you copied it completely or ask the sender to generate a new one." : "See kutse ei tundu olema korrektne. Palun kontrolli, et oled ta tervikuna kopeerinud või palu saatjal koostada uus.",
    "Accept invitation" : "Nõustu kutsega",
    "Accepting will add the inviter to your contacts list and in return, your contact info will be sent to the inviter. From there on you can start sharing data with each other." : "Kui sa kutse vastu võtad, lisatakse kutsuja sinu kontaktide loendisse ja vastupidi saadetakse sinu kontaktandmed kutsujale. Sellest hetkest alates saate omavahel andmeid jagama hakata.",
    "Invite link or code (required)" : "Kutse link või kood (nõutav)",
    "Paste the invite link, or an invite code (token@provider), you received from the other person." : "Aseta kutse link või kutse kood (vormingus tunnusluba@teenusepakkuja), mille said teiselt osapoolelt.",
    "Accept" : "Nõustu",
    "Please enter an email address." : "Palun sisesta e-posti aadress",
    "The recipient will receive an email with the invite link. Their email address will be saved on the invite so you can resend later." : "Saaja saab e-kirja kutse lingiga. Tema e-posti aadress salvestub kutses ja seega võid seda hiljem uuesti saata.",
    "Recipient email (required)" : "Saaja e-posti aadress (nõutav)",
    "email@example.com" : "epost@toredomeen.ee",
    "Personal message (optional)" : "Isiklik sõnum (kui tahad lisada)",
    "Message to include in the email" : "E-kirja lisatav sõnum",
    "Sending…" : "Saadan...",
    "Send" : "Saada",
    "Invite code" : "Kutsekood",
    "Cloud provider" : "Pilveteenuse pakkuja",
    "Encoded invite copied to clipboard" : "Koodipõhine kutse on kopeeritud lõikelauale",
    "Invite code copied to clipboard" : "Kutse kood on kopeeritud lõikelauale",
    "Invite link copied to clipboard" : "Kutse link on kopeeritud lõikelauale",
    "Copied to clipboard" : "Kopeeritud lõikelauale",
    "Failed to copy to clipboard" : "Lõikelauale kopeerimine ei õnnestunud",
    "Could not resend invite" : "Kutse uuesti saatmine ei õnnestunud",
    "Invite revoked" : "Kutse on tühistatud",
    "Could not revoke invite" : "Kutse tühistamine ei õnnestunud",
    "Invite sent to {email}" : "Kutse on saadetud a-posti aadressile {email}",
    "Could not send invite" : "Kutse saatmine ei õnnestunud",
    "No invitation selected" : "Ühtegi kutset pole valitud",
    "Select an invitation on the list to begin" : "Alustamiseks vali loendist kutse",
    "External invitation" : "Kutse välisest süsteemist",
    "Label" : "Silt",
    "Sent to" : "Adressaat",
    "Created" : "Loodud",
    "Expires" : "Aegub",
    "More ways to share" : "Muud jagamise võimalused",
    "Useful for sharing through a chat app or for manual acceptance." : "Sobib jagamiseks vestlusrakenduses või käsitsi nõustumiseks.",
    "Revoke invitation" : "Tühista kutse",
    "Resend email" : "Saada e-kiri uuesti",
    "Send via email" : "Saada e-kiriga",
    "Send invitation via email" : "Saada kutse e-kirjaga",
    "{name} invites you to exchange cloud accounts and contact information." : "{name} on saatnud sulle kutse millega soovib vahetada kontakteavet liitpilves.",
    "The invite link and code are added automatically when you send the invitation." : "Kutse saatmisel lisatakse kutselink ja kood automaatselt.",
    "Recipient email" : "Saaja e-posti aadress",
    "Invite someone outside your organization to collaborate" : "Kutsu keegi väljastpoolt oma organisatsiooni koostööd tegema",
    "After the invitee accepts the invite, both of you will appear in each other's contacts list and you can start sharing data with each other." : "Kui kutsutu on kutse vastu võtnud, olete mõlemad teineteise kontaktide loendis nähtavad ja võite hakata üksteisega andmeid jagama.",
    "Send invite via email" : "Saada kutse e-kirjaga",
    "Hide email preview" : "Peida e-kirja eelvaade",
    "Show email preview" : "Näita e-kirja eelvaadet",
    "This is what {recipient} will receive:" : "{recipient} saab sellise kirja:",
    "If you do not send an email, you will need to share the invite link yourself." : "Kui sa seda ei saada e-kirjaga, siis pead kutse linki mõnel muul viisil jagama.",
    "Invite link" : "Kutselink",
    "Copy invite link to clipboard" : "Kopeeri kutse link lõikelauale",
    "Copy invite code to clipboard" : "Kopeeri kutse kood lõikelauale",
    "Encoded invite" : "Koodipõhine kutse",
    "Copy encoded invite to clipboard" : "Kopeeri koodipõhine kutse lõikelauale",
    "Search invites…" : "Otsi kutseid…",
    "Could not discover that provider. Check the address and try again." : "Selle teenusepakkuja tuvastamine ei õnnestunud. Kontrolli aadressi õigsust ja proovi uuesti.",
    "Select your server" : "Vali oma server",
    "Type to search" : "Otsimiseks kirjuta midagi",
    "No servers match your search." : "Ükski server ei vasta sinu otsingule.",
    "No servers are currently available." : "Ühtegi serverit pole saadaval.",
    "Your server not listed? Enter one manually." : "Sinu serverit ei leidu loendist? Võid ka aadressi käsitsi sisestada.",
    "Continue" : "Jätka",
    "You need an invite link for this feature to work." : "Et see funktsionaalsus toimiks, vajad kutselinki.",
    "Select chart …" : "Vali joonis…",
    "Chart" : "Joonis",
    "Select type" : "Vali tüüp",
    "Add contact in group" : "Lisa kontakt gruppi",
    "None" : "Pole",
    "copy" : "koopeeri",
    "Select option" : "Vali eelistus",
    "JavaScript URIs are not allowed" : "JavaScripti URI-d pole lubatud",
    "Notes" : "Märkmed",
    "send an email" : "saada e-kiri",
    "Personal dates" : "Isiklikud kuupäevad",
    "Add property of this type" : "Lisa seda tüüpi omadus",
    "Member" : "Liige",
    "This is a read-only group managed by administrators. Group members can only view this group." : "See on vaid lugemisõigustega grupp, mida haldavad peakasutajad. Grupi liikmed saavad vaid vaadata grupi andmeid.",
    "Send invitation" : "Saada kutse",
    "Generate invitation" : "Koosta  kutse",
    "This invite link is incomplete. Ask the sender to generate a new one." : "See kutselink on poolik. Palun saatjal koostada uus.",
    "Unable to create the contact." : "Ei õnnestu luua kontakti",
    "Contact not found" : "Kontakti ei leidu",
    "Address book {addressbook} not found" : "„{addressbook}“ aadressiraamatut ei leidu",
    "Group {group} not found" : "„{group}“ gruppi ei leidu",
    "Could not accept invite" : "Kutsega nõustumine ei õnnestunud",
    "Could not create invite" : "Kutsega koostamine ei õnnestunud",
    "Add member" : "Lisa liige",
    "New contact" : "Uus kontakt",
    "_{success} contact added to {name}_::_{success} contacts added to {name}_" : ["{success} kontakt on lisatud kasutajale {name}","{success} kontakti on lisatud kasutajale {name}"],
    "_Adding {success} contact to {name}_::_Adding {success} contacts to {name}_" : ["Lisan {success} kontakti kasutajale {name}","Lisan {success} kontakti kasutajale {name}"],
    "_{count} error_::_{count} errors_" : ["{count} viga","{count} viga"],
    "_Importing %n contact into {addressbook}_::_Importing %n contacts into {addressbook}_" : ["Impordin %n kontakti teavet {addressbook} aadressiraamatusse","Impordin %n kontakti teavet {addressbook} aadressiraamatusse"],
    "_Done importing %n contact into {addressbook}_::_Done importing %n contacts into {addressbook}_" : ["%n kontakti teabe importimine {addressbook} aadressiraamatusse õnnestus","%n kontakti teabe importimine {addressbook} aadressiraamatusse õnnestus"],
    "No data for this contact" : "Selle kontakti kohta ei leidu andmeid",
    "No data for this contact on their profile" : "Selle kontakti profiilis ei leidu andmeid",
    "Import" : "Impordi",
    "Are you sure you want to import this contact file?" : "Kas oled kindel, et tahad selle kontaktifaili importida?",
    "Could not copy" : "Ei õnnestunud kopeerida",
    "Join team" : "Liitu tiimiga",
    "You are about to leave {circle}.\nAre you sure?" : "Sa oled lahkumas „{circle}“ tiimist.\nKas oled kindel?",
    "Please confirm team leave" : "Palun kinnita tiimist lahkumine",
    "Could not leave the team {displayName}" : "Ei õnnestunud lahkuda tiimist „{displayName}“",
    "Unable to join the team" : "Ei õnnestu liituda tiimiga",
    "You are about to delete {circle}.\nAre you sure?" : "Sa oled kustutamas „{circle}“ tiimi.\nKas oled kindel?",
    "Please confirm team deletion" : "Palun kinnita selle tiimi kustutamine",
    "Unable to delete the team" : "Ei õnnestu tiimi kustutada",
    "Confirm enabling federation" : "Kinnita födereerimise (liitpilve) kasutuselevõtmine",
    "Enabling this will prevent {circle} from being a member of other teams.\nAre you sure?" : "Selle valiku kasutamisel ei saa „{circle}“ tiim olla teiste tiimide liige.\nKas oled oma soovis kindel?",
    "Enable federation" : "Lülita födereerimine (liitpilve kasutamine) sisse",
    "Link copied to the clipboard" : "Link on kopeeritud lõikelauale.",
    "Could not copy link to the clipboard." : "Lingi kopeerimine lõikelauale ei õnnestunud.",
    "Not grouped" : "Pole grupeeritud",
    "Create your own teams for sharing. Add Nextcloud users, contacts, or anyone via email." : "Loo jagamiseks omad tiimid. Lisa sinna Nextcloudi kasutajaid, kontakte või keda iganes e-posti aadressi alusel.",
    "Team" : "Tiim",
    "User" : "Kasutaja",
    "Group" : "Grupp",
    "Email" : "E-post",
    "Contact" : "Kontakt",
    "Moderator" : "Moderaator",
    "Admin" : "Peakasutaja",
    "Owner" : "Omanik",
    "Invites" : "Kutsed",
    "Anyone can request membership" : "Kõik võivad paluda võimalust liituda",
    "Members need to accept invitation" : "Liikmed peavad kutsega nõustuma",
    "Memberships must be confirmed/accepted by a Moderator (requires \"Anyone can request membership\")" : "Liikmelisus peab olema kinnitatud moderaatori poolt (eeldab, et kasutusel on „Kõik võivad paluda võimalust liituda“)",
    "Members can also invite" : "Ka liikmed võivad saata kutseid",
    "Membership" : "Liikmelisus",
    "Prevent teams from being a member of another team" : "Keela tiimide liitumine teiste tiimidega",
    "Federation" : "Liitpilv",
    "Allow federated members" : "Luba kasutajaid liitpilvest",
    "Privacy" : "Privaatsus",
    "Visible to everyone" : "Nähtav kõigile",
    "users" : "kasutajad",
    "Users" : "Kasutajad",
    "groups" : "grupid",
    "federated users" : "kasutajad liitpilves",
    "Federated users" : "Kasutajad liitpilves",
    "teams" : "tiimid",
    "email addresses" : "e-posti aadressid",
    "Email addresses" : "E-posti aadressid",
    "contacts" : "kontaktid",
    "Link-only invite" : "Vaid lingipõhine kutse",
    "Detailed name" : "Üksikasjalik nimi",
    "Additional names" : "Lisanimed",
    "Prefix" : "Eesliide",
    "Suffix" : "Järelliide",
    "Nickname" : "Hüüdnimi",
    "Website" : "Veebileht",
    "Location" : "Asukoht",
    "Federated Cloud ID" : "Liitpilve tunnus",
    "Home" : "Kodu",
    "Work" : "Töö",
    "Other" : "Muu",
    "Address" : "Aadress",
    "Post office box" : "Postkast",
    "Extended address" : "Laiendatud aadress",
    "City" : "Linn",
    "State or province" : "Maakond",
    "Postal code" : "Postiindeks",
    "Country" : "Riik",
    "Birthday" : "Sünnipäev",
    "Place of birth" : "Sünnikoht",
    "Anniversary" : "Aastapäev",
    "Date of death" : "Surma kuupäev",
    "Place of death" : "Surmakoht",
    "Instant messaging" : "Sõnumiteenus",
    "Phone" : "Telefon",
    "Mobile" : "Mobiil",
    "Work mobile" : "Mobiiltelefon tööl",
    "Home mobile" : "Mobiiltelefon kodus",
    "Fax" : "Faks",
    "Fax home" : "Faks kodus",
    "Fax work" : "Faks tööl",
    "Pager" : "Piipar",
    "Voice" : "Hääl",
    "Car" : "Auto",
    "Work pager" : "Piipar (tööl)",
    "Line manager" : "Vahetu ülemus",
    "Social network" : "Sotsiaalvõrk",
    "Relationship to you" : "Seos sinuga",
    "Spouse" : "Abikaasa",
    "Child" : "Laps",
    "Mother" : "Ema",
    "Father" : "Isa",
    "Parent" : "Vanem",
    "Brother" : "Vend",
    "Sister" : "Õde",
    "Relative" : "Sugulane",
    "Friend" : "Sõber",
    "Colleague" : "Kolleeg",
    "Assistant" : "Abiline",
    "Related contacts" : "Seotud kontaktid",
    "Agent" : "Esindaja / agent",
    "Emergency" : "Kontakt eriolukorras",
    "Co-worker" : "Kolleeg",
    "Gender" : "Sugu",
    "Female" : "Naine",
    "Male" : "Mees",
    "Unknown" : "Teadmata",
    "Time zone" : "Ajavöönd",
    "Spoken languages" : "Keelteoskus",
    "_{failed} contact failed to be read_::_{failed} contacts failed to be read_" : ["{failed} kontakti lugemine ei õnnestunud","{failed} kontakti lugemine ei õnnestunud"],
    "An error has occurred in team(s). Check the console for more details." : "Tiimi(de)s tekkis viga. Lisateavet palun vaata konsoolilt.",
    "Unable to create team {circleName}" : "„{circleName}“ tiimi loomine pole võimalik",
    "Unable to delete team {circleId}" : "„{circleId}“ tiimi kustutamine pole võimalik",
    "Could not update favorite state" : "Olekut lemmikuna polnud võimalik uuendada",
    "Unable to delete contact" : "Ei õnnestu kustutada kontakti",
    "Value copied to the clipboard" : "Väärtus on kopeeritud lõikelauale.",
    "Could not copy value to the clipboard." : "Väärtuse kopeerimine lõikelauale ei õnnestunud.",
    "Deck board" : "Kanbani tahvel",
    "New Deck board" : "Uus Kanbani tahvel",
    "Board name" : "Tahvli nimi",
    "Deck app is not installed. Please install it to create team boards." : "Nextcloudi Kanbani rakendus pole paigaldatud. Tiimi tahvlite kasutamiseks palun paigalda rakendus",
    "Pick an address book" : "Vali aadressiraamat",
    "Select Date" : "Vali kuupäev",
    "note" : "märge",
    "email" : "e-post",
    "Create your own groups for sharing. Add Nextcloud users, contacts, or anyone via email." : "Loo oma grupid jagamise jaoks. Lisa Nextcloudi kasutajaid, kontakte ning e-posti aadressi alusel keda iganes."
},
"nplurals=2; plural=(n != 1);");
