OC.L10N.register(
    "contacts",
    {
    "Import contacts" : "Importera kontakter",
    "Details" : "Detaljer",
    "All contacts" : "Alla kontakter",
    "Email address is required." : "E-postadress krävs.",
    "An open invite already exists." : "Det finns redan en öppen inbjudan.",
    "Could not accept invite because no authenticated user was found." : "Det gick inte att acceptera inbjudan eftersom ingen autentiserad användare hittades.",
    "The invite provider is invalid or not allowed." : "Inbjudningsleverantören är ogiltig eller inte tillåten.",
    "Unable to accept this invitation. You are trying to accept an outgoing invitation." : "Det gick inte att acceptera den här inbjudan. Du försöker acceptera en utgående inbjudan.",
    "Could not accept invite because the remote provider returned an invalid response." : "Det gick inte att acceptera inbjudan eftersom fjärrleverantören returnerade ett ogiltigt svar.",
    "The remote provider accepted the invite, but this server could not create the local contact." : "Fjärrleverantören accepterade inbjudan, men den här servern kunde inte skapa den lokala kontakten.",
    "Cannot resend: no email address" : "Det går inte att skicka igen: ingen e-postadress",
    "Invite has already been accepted." : "Inbjudan har redan accepterats.",
    "Invite has expired. Please create a new one." : "Inbjudan har upphört att gälla. Skapa en ny.",
    "This is a copy of an invite sent to you previously by %1$s on %2$s" : "Detta är en kopia av en inbjudan som %1$s tidigare skickade till dig den %2$s",
    "Invite already has an email address." : "Inbjudan har redan en e-postadress.",
    "An open invite for this email already exists." : "Det finns redan en öppen inbjudan för den här e-postadressen.",
    "Could not claim invite for this email; please refresh and try again." : "Det gick inte att göra anspråk på inbjudan för den här e-postadressen. Uppdatera och försök igen.",
    "Could not revert invite after delivery failure. Please refresh and try again." : "Det gick inte att återställa inbjudan efter leveransfel. Uppdatera och försök igen.",
    "OCM invites are disabled." : "OCM-inbjudningar är inaktiverade.",
    "Recipient email address is invalid." : "Mottagarens e-postadress är ogiltig.",
    "%1$s via %2$s" : "%1$s via %2$s",
    "%1$s invites you to exchange contact information." : "%1$s bjuder in dig att utbyta kontaktuppgifter.",
    "This is a copy of the invitation you've sent to %1$s" : "Detta är en kopia av inbjudan du skickade till %1$s",
    "Hi there," : "Hej!",
    "%1$s invites you to exchange cloud accounts and contact information." : "%1$s bjuder in dig att utbyta molnkonton och kontaktuppgifter.",
    "This will allow you to share data with each other." : "Detta gör det möjligt att dela data med varandra.",
    "To accept this invite, click the link below and sign in with your cloud provider:" : "Klicka på länken nedan och logga in med din molnleverantör för att acceptera inbjudan:",
    "Invitation details:" : "Inbjudningsdetaljer:",
    "Invite code: %1$s" : "Inbjudningskod: %1$s",
    "Encoded invite: %1$s" : "Kodad inbjudan: %1$s",
    "To accept this invite, use the url below to sign in with your cloud provider:" : "Använd webbadressen nedan och logga in med din molnleverantör för att acceptera inbjudan:",
    "_Imported %n contact_::_Imported %n contacts_" : ["Importerade %n kontakt","Importerade %n kontakter"],
    "_(skipped %n contact)_::_(skipped %n contacts)_" : ["(hoppade över %n kontakt)","(hoppade över %n kontakter)"],
    "Contacts" : "Kontakter",
    "A contacts app for Nextcloud" : "En kontaktapp för Nextcloud",
    "The Nextcloud contacts app is a user interface for Nextcloud's CardDAV server. Easily sync contacts from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Currently Mail and Calendar – more to come.\n* 🎉 **Never forget a birthday!** You can sync birthdays and other recurring events with your Nextcloud Calendar.\n* 👥 **Sharing of Adressbooks!** You want to share your contacts with your friends or coworkers? No problem!\n* 🙈 **We’re not reinventing the wheel!** Based on the great and open SabreDAV library." : "Nextclouds kontaktapp är ett användargränssnitt för Nextclouds CardDAV-server. Synkronisera enkelt kontakter från olika enheter med Nextcloud och redigera dem online.\n\n* 🚀 **Integration med andra Nextcloud-appar!** För närvarande E-post och Kalender – fler är på gång.\n* 🎉 **Glöm aldrig en födelsedag!** Du kan synkronisera födelsedagar och andra återkommande händelser med Nextcloud Kalender.\n* 👥 **Dela adressböcker!** Vill du dela dina kontakter med vänner eller kollegor? Inga problem!\n* 🙈 **Vi uppfinner inte hjulet på nytt!** Appen bygger på det utmärkta öppna biblioteket SabreDAV.",
    "Copy to full name" : "Kopiera till fullständigt namn",
    "Omit year" : "Utelämna år",
    "Could not save the setting" : "Det gick inte att spara inställningen",
    "Allow updating avatars from social media" : "Tillåt uppdatering av profilbilder från sociala nätverk",
    "External invitations" : "Externa inbjudningar",
    "Allow creating invites without an email address (link-only)" : "Tillåt att inbjudningar skapas utan e-postadress (endast länk)",
    "Show the \"Copy encoded invite\" button on invite details" : "Visa knappen ”Kopiera kodad inbjudan” i inbjudningsdetaljerna",
    "Organization chart" : "Organisationsschema",
    "There was an error fetching the member list" : "Ett fel inträffade när medlemslistan hämtades",
    "Teams" : "Team",
    "Please select a team" : "Välj ett team",
    "Loading team…" : "Läser in team…",
    "Loading contacts …" : "Läser in kontakter …",
    "There are no contacts yet" : "Det finns inga kontakter ännu",
    "Create contact" : "Skapa kontakt",
    "There are no contacts in this group" : "Det finns inga kontakter i denna grupp",
    "Create contacts" : "Skapa kontakter",
    "Add contacts" : "Lägg till kontakter",
    "Loading invitations…" : "Läser in inbjudningar…",
    "Could not load invitations" : "Det gick inte att läsa in inbjudningarna",
    "Retry" : "Försök igen",
    "There are no invitations" : "Det finns inga inbjudningar",
    "Create invitation" : "Skapa inbjudan",
    "Loading …" : "Läser in …",
    "Manage team" : "Hantera team",
    "Leave team" : "Lämna team",
    "Delete team" : "Ta bort team",
    "Setting saved" : "Inställningen har sparats",
    "Failed to save setting" : "Det gick inte att spara inställningen",
    "Contacts settings" : "Kontaktinställningar",
    "General" : "Allmänt",
    "Update avatars from social media" : "Uppdatera avatarer från sociala medier",
    "Refreshed once per week" : "Uppdateras en gång i veckan",
    "Address books" : "Adressböcker",
    "Tried to drop an invalid contact!" : "Försökte släppa en ogiltig kontakt!",
    "Rename" : "Byt namn",
    "Export" : "Exportera",
    "Send email" : "Skicka e-post",
    "Send email as BCC" : "Skicka e-post som BCC",
    "Delete" : "Ta bort",
    "Show all groups" : "Visa alla grupper",
    "Collapse groups" : "Dölj grupper",
    "Show all teams" : "Visa alla team",
    "Collapse teams" : "Dölj team",
    "Group name cannot be empty" : "Gruppnamn kan inte vara tomt",
    "This group already exists" : "Denna grupp finns redan",
    "An error occurred while creating the group" : "Ett fel uppstod när gruppen skulle skapas",
    "This team already exists" : "Detta team finns redan",
    "An error happened during the creation of the team" : "Ett fel uppstod när teamet skapades",
    "Add address book" : "Lägg till adressbok",
    "Recently contacted" : "Nyligen kontaktade",
    "Contact groups" : "Kontaktgrupper",
    "Create a new contact group" : "Skapa en ny kontaktgrupp",
    "Contact group name" : "Namn på kontaktgrupp",
    "Create a new team" : "Skapa ett nytt team",
    "Open the contacts app settings" : "Öppna kontaktappens inställningar",
    "_Shared with {num} entity_::_Shared with {num} entities_" : ["Delad med {num} enhet","Delad med {num} enheter"],
    "Copied" : "Kopierat",
    "Cannot copy" : "Det går inte att kopiera",
    "Copy link" : "Kopiera länk",
    "Toggling of address book was not successful" : "Det gick inte att växla adressbokens status",
    "This will delete the address book and every contacts within it" : "Detta tar bort adressboken och alla kontakter i den",
    "Delete {addressbook}?" : "Vill du ta bort {addressbook}?",
    "This will unshare the address book and every contacts within it" : "Detta kommer att ta bort delning av adressboken och alla kontakter i den",
    "Unshare {addressbook}?" : "Ta bort delning av {addressbook}?",
    "Deletion of address book was not successful." : "Det gick inte att ta bort adressboken.",
    "Renaming of address book was not successful." : "Det gick inte att byta namn på adressboken.",
    "{addressbookname} (Hidden)" : "{addressbookname} (Dold)",
    "Download" : "Hämta",
    "Show" : "Visa",
    "Unshare from me" : "Sluta dela från mig",
    "_%n contact_::_%n contacts_" : ["%n kontakt","%n kontakter"],
    "_%n group_::_%n groups_" : ["%n grupp","%n grupper"],
    "Share with users or groups" : "Dela med användare eller grupper",
    "Share with users" : "Dela med användare",
    "No users or groups" : "Inga användare eller grupper",
    "Unable to delete the share" : "Det gick inte att ta bort delningen",
    "Unable to change permissions" : "Det gick inte att ändra behörigheterna",
    "can create and edit" : "kan skapa och redigera",
    "Choose a vCard file to import" : "Välj en vCard-fil att importera",
    "Import into the {addressbookName} address book" : "Importera till adressboken {addressbookName}",
    "Select local file" : "Välj lokal fil",
    "Import from files" : "Importera från filer",
    "Importing is disabled because there are no address books available" : "Import är inaktiverad eftersom det inte finns några tillgängliga adressböcker",
    "An error occurred, unable to create the address book" : "Ett fel uppstod. Det gick inte att skapa adressboken",
    "New address book" : "Ny adressbok",
    "Add new address book" : "Lägg till ny adressbok",
    "Cancel" : "Avbryt",
    "Add" : "Lägg till",
    "First name" : "Förnamn",
    "Last name" : "Efternamn",
    "Phonetic first name" : "Fonetiskt förnamn",
    "Phonetic last name" : "Fonetiskt efternamn",
    "Display name" : "Visningsnamn",
    "Last modified" : "Senast ändrad",
    "Sort contacts by" : "Sortera kontakter efter",
    "Manages" : "Leder",
    "Oversees" : "Har uppsikt över",
    "An error happened during the config change" : "Ett fel uppstod vid inställningsändringen",
    "Enforce password protection on files shared to this team" : "Tillämpa lösenordsskydd på filer som delas med detta team",
    "Use a unique password for all shares to this team" : "Använd ett unikt lösenord för alla delningar till detta team",
    "Unique password …" : "Unikt lösenord …",
    "Save" : "Spara",
    "Change unique password" : "Ändra unikt lösenord",
    "Failed to save password. Please try again later." : "Det gick inte att spara lösenordet. Försök igen senare.",
    "Close" : "Stäng",
    "Choose a team picture" : "Välj en teambild",
    "There is no description for this team" : "Det finns ingen beskrivning för detta team",
    "Enter a description for the team" : "Ange en beskrivning för teamet",
    "Folder" : "Mapp",
    "New folder" : "Ny mapp",
    "Folder name" : "Mappnamn",
    "This will create a regular folder shared with the team. To create a Team Folder, please contact your {productName} administrator" : "Detta skapar en vanlig mapp som delas med teamet. Kontakta din {productName}-administratör för att skapa en teammapp.",
    "Talk conversation" : "Talk-konversation",
    "New Talk conversation" : "Ny Talk-konversation",
    "Conversation name" : "Konversationens namn",
    "Collective" : "Kollektiv",
    "Calendar" : "Kalender",
    "New calendar" : "Ny kalender",
    "Calendar name" : "Kalendernamn",
    "Unknown resource type" : "Okänd resurstyp",
    "Team calendar \"{resourceName}\" created and shared with team" : "Teamkalender \"{resourceName}\" skapad och delad med team",
    "{resourceType} \"{resourceName}\" created and shared with team" : "{resourceType} \"{resourceName}\" skapad och delad med team",
    "A calendar named \"{name}\" already exists. Please choose a different name." : "En kalender med namn \"{name}\" finns redan. Välj ett annat namn.",
    "Failed to create {resourceType}: {error}" : "Det gick inte att skapa {resourceType}: {error}",
    "Please select a valid png or jpg file" : "Välj en giltig png- eller jpg-fil",
    "Error picking team picture" : "Fel vid val av teambild",
    "Error cropping avatar picture" : "Fel vid beskärning av avatarbild",
    "An error happened while saving {fields}" : "Ett fel uppstod när {fields} skulle sparas",
    "Team name" : "Namn på team",
    "Team owner" : "Teamägare",
    "Upload team picture" : "Ladda upp teambild",
    "Choose from Nextcloud Files" : "Välj från Nextcloud Filer",
    "Delete picture" : "Ta bort bild",
    "Edit" : "Redigera",
    "Request to join" : "Begäran om medlemskap",
    "Create" : "Skapa",
    "Show in Calendar" : "Visa i kalender",
    "Your request to join this team is pending approval" : "Din begäran om medlemskap i teamet väntar på godkännande",
    "You are not a member of {circle}" : "Du är inte med i {circle}",
    "Members" : "Medlemmar",
    "Edit team picture" : "Redigera teambild",
    "Apply" : "Tillämpa",
    "Confirm" : "Bekräfta",
    "No other contacts available to select as line manager" : "Inga andra kontakter tillgängliga att välja som linjechef",
    "Add more info" : "Lägg till mer information",
    "More fields" : "Fler fält",
    "Please select a valid format" : "Välj ett giltigt format",
    "Invalid image" : "Ogiltig bild",
    "Error cropping picture" : "Det gick inte att beskära bilden",
    "Pick an avatar" : "Välj en avatar",
    "Pick" : "Välj",
    "Error while processing the picture." : "Fel vid bearbetning av bilden.",
    "Avatar downloaded from social network" : "Avatar hämtades från socialt nätverk",
    "Avatar already up to date" : "Avataren är redan uppdaterad",
    "Avatar download failed" : "Det gick inte att hämta avataren",
    "Crop contact photo" : "Beskär kontaktfoto",
    "Upload a new picture" : "Ladda upp en ny bild",
    "Choose from Files" : "Välj från Filer",
    "Download picture" : "Hämta bild",
    "Clone contact" : "Klona kontakt",
    "This contact is in read-only mode. You do not have permission to edit this contact." : "Den här kontakten är skrivskyddad. Du har inte behörighet att redigera den här kontakten.",
    "The contact you were trying to edit has changed. Please manually refresh the contact. Any further edits will be discarded." : "Kontakten du försökte redigera har ändrats. Uppdatera kontakten manuellt. Eventuella ytterligare ändringar kommer att kasseras.",
    "Address book" : "Adressbok",
    "Add contact to Birthday Calendar" : "Lägg till kontakt i födelsedagskalendern",
    "Exclude contact from Birthday Calendar" : "Uteslut kontakt från födelsedagskalendern",
    "{title} at {organization}" : "{title} på {organization}",
    "Name" : "Namn",
    "Syntax error. Cannot open the contact." : "Syntaxfel. Kan inte öppna kontakten.",
    "The contact does not exist on the server anymore." : "Kontakten finns inte längre på servern.",
    "Unable to retrieve the contact from the server, please check your network connection." : "Det gick inte att hämta kontakten från servern. Kontrollera nätverksanslutningen.",
    "An error occurred while trying to move the contact" : "Ett fel uppstod när du försökte flytta kontakten",
    "An error occurred while trying to copy the contact" : "Ett fel uppstod vid försök att kopiera kontakten",
    "Unable to update contact" : "Det gick inte att uppdatera kontakten",
    "No contact selected" : "Ingen kontakt vald",
    "Select a contact on the list to begin" : "Välj en kontakt i listan för att börja",
    "Title" : "Titel",
    "Company" : "Företag",
    "Go to talk conversation" : "Gå till Talk-konversation",
    "View profile" : "Visa profil",
    "This contact was broken and received a fix. Please review the content and click here to save it." : "Denna kontakt var felaktig och åtgärdades. Granska innehållet och klicka här för att spara det.",
    "Edit profile" : "Redigera profil",
    "Generate QR Code" : "Generera QR-kod",
    "Contact vCard as QR code" : "Kontaktens vCard som QR-kod",
    "Select address book" : "Välj adressbok",
    "Media shares with you" : "Media-delningar med dig",
    "Talk conversations with you" : "Talk-konversationer med dig",
    "Calendar events with you" : "Kalenderhändelser med dig",
    "Deck cards with you" : "Deck-kort med dig",
    "No shared items with this contact" : "Inga delade objekt med den här kontakten",
    "This contact cannot be moved" : "Denna kontakt kan inte flyttas",
    "This contact cannot be grouped" : "Denna kontakt kan inte grupperas",
    "Add contacts to groups" : "Lägg till kontakter i grupper",
    "Move contacts to addressbook" : "Flytta kontakter till adressbok",
    "Select groups" : "Välj grupper",
    "Select addressbook" : "Välj adressbok",
    "Selected contacts" : "Valda kontakter",
    "Please note that only {count} of the {total} contacts can be added to a group" : "Observera att endast {count} av {total} kontakter kan läggas till i en grupp",
    "Please note that only {count} of the {total} contacts can be moved" : "Observera att endast {count} av {total} kontakter kan flyttas",
    "Move" : "Flytta",
    "Unselect {name}" : "Avmarkera {name}",
    "Select {name}" : "Markera {name}",
    "Could not update favorite status" : "Det gick inte att uppdatera favoritstatusen",
    "from {addressbook}" : "från {addressbook}",
    "Remove from favorites" : "Ta bort från favoriter",
    "Add to favorites" : "Lägg till som favorit",
    "Confirm merging contacts" : "Bekräfta sammanslagning av kontakter",
    "The selected contacts have conflicting information. Choose which information to keep" : "De valda kontakterna har motstridig information. Välj vilken information som ska behållas",
    "Contacts can be merged" : "Kontakter kan slås samman",
    "Groups" : "Grupper",
    "Select groups to add the merged contact to" : "Välj grupper att lägga till den sammanslagna kontakten i",
    "Merge contacts" : "Slå samman kontakter",
    "_Delete {number} contact_::_Delete {number} contacts_" : ["Ta bort {number} kontakt","Ta bort {number} kontakter"],
    "Please select at least one editable contact to delete" : "Välj minst en redigerbar kontakt att ta bort",
    "Please select two editable contacts to merge" : "Välj två redigerbara kontakter att slå samman",
    "_Add {number} contact to group_::_Add {number} contacts to group_" : ["Lägg till {number} kontakt i gruppen","Lägg till {number} kontakter i gruppen"],
    "Please select at least one editable contact to add to a group" : "Välj minst en redigerbar kontakt för att lägga till i en grupp",
    "_Move {number} contact to addressbook_::_Move {number} contacts to addressbook_" : ["Flytta {number} kontakt till adressboken","Flytta {number} kontakter till adressboken"],
    "Please select at least one editable contact to move to an addressbook" : "Välj minst en redigerbar kontakt för att flytta till en adressbok",
    "Are you sure you want to proceed?" : "Är du säker på att du vill fortsätta?",
    "Add contacts to group" : "Lägg till kontakter i gruppen",
    "Search contacts …" : "Sök kontakter …",
    "Unselect {number}" : "Avmarkera {number}",
    "Add to {group}" : "Lägg till i {group}",
    "Add members to {group}" : "Lägg till medlemmar i {group}",
    "Please note that you can only add contacts from writable address books to contact groups. Contacts from read-only address books, such as the system address book, cannot be added." : "Observera att du bara kan lägga till kontakter från skrivbara adressböcker i kontaktgrupper. Kontakter från skrivskyddade adressböcker, såsom systemets adressbok, kan inte läggas till.",
    "Remove {type}" : "Ta bort {type}",
    "Add to group" : "Lägg till i grupp",
    "Add members to group" : "Lägg till medlemmar i grupp",
    "Search {types}" : "Sök {types}",
    "Add guest" : "Lägg till gäst",
    "Search for people to add" : "Sök efter personer att lägga till",
    "No results" : "Inga resultat",
    "Add {type}" : "Lägg till {type}",
    "New team name" : "Nytt namn på team",
    "Personal team" : "Personligt team",
    "This team will only be visible to you. Other members will not be able to see or use it." : "Detta team kommer bara att vara synligt för dig. Andra medlemmar kommer inte att kunna se eller använda det.",
    "Local team" : "Lokalt team",
    "This team will not be shared with the other instances of the global scale" : "Detta team delas inte med andra instanser i den globala infrastrukturen",
    "Create team" : "Skapa team",
    "Promote as sole owner" : "Gör till ensam ägare",
    "Promote to {level}" : "Befordra till {level}",
    "Demote to {level}" : "Degradera till {level}",
    "Are you sure you want to leave this team? This action cannot be undone." : "Är du säker på att du vill lämna det här teamet? Den här åtgärden går inte att ångra.",
    "Leave team failed." : "Det gick inte att lämna teamet.",
    "Could not delete the member {displayName}" : "Det gick inte att ta bort medlemmen {displayName}",
    "Could not change the member level to {level}" : "Det gick inte att ändra medlemmens nivå till {level}",
    "Could not accept membership request" : "Det gick inte att acceptera begäran om medlemskap",
    "Accept membership request" : "Acceptera medlemsförfrågan",
    "Reject membership request" : "Avslå medlemsförfrågan",
    "Manage level" : "Hantera nivå",
    "Remove member" : "Ta bort medlem",
    "Unable to get the results" : "Det gick inte att hämta resultaten",
    "Some members could not be added" : "Vissa medlemmar kunde inte läggas till",
    "There was an issue adding members to the team" : "Det uppstod ett problem med att lägga till medlemmar i teamet",
    "Loading members list …" : "Läser in medlemslista …",
    "The list of members is only visible to members of this team" : "Listan över medlemmar är endast synlig för medlemmar i detta team",
    "You currently have no access to the member list" : "Du har för närvarande inte tillgång till medlemslistan",
    "Add to {team}" : "Lägg till {team}",
    "Invite members to {team}" : "Bjud in medlemmar till {team}",
    "Pending" : "Väntande",
    "This invite does not look valid. Check that you copied it completely or ask the sender to generate a new one." : "Den här inbjudan verkar inte giltig. Kontrollera att du kopierade den helt eller be avsändaren att skapa en ny.",
    "Accept invitation" : "Acceptera inbjudan",
    "Accepting will add the inviter to your contacts list and in return, your contact info will be sent to the inviter. From there on you can start sharing data with each other." : "Genom att acceptera läggs avsändaren till i din kontaktlista och dina kontaktuppgifter skickas i gengäld till avsändaren. Därefter kan ni börja dela data med varandra.",
    "Invite link or code (required)" : "Inbjudningslänk eller -kod (krävs)",
    "Paste the invite link, or an invite code (token@provider), you received from the other person." : "Klistra in inbjudningslänken eller en inbjudningskod (token@provider) som du fått från den andra personen.",
    "Accept" : "Acceptera",
    "Please enter an email address." : "Ange en e-postadress.",
    "The recipient will receive an email with the invite link. Their email address will be saved on the invite so you can resend later." : "Mottagaren får ett e-postmeddelande med inbjudningslänken. E-postadressen sparas i inbjudan så att du kan skicka den igen senare.",
    "Recipient email (required)" : "Mottagarens e-postadress (krävs)",
    "email@example.com" : "email@example.com",
    "Personal message (optional)" : "Personligt meddelande (valfritt)",
    "Message to include in the email" : "Meddelande som ska ingå i e-postmeddelandet",
    "Sending…" : "Skickar…",
    "Send" : "Skicka",
    "Invite code" : "Inbjudningskod",
    "Cloud provider" : "Molnleverantör",
    "Encoded invite copied to clipboard" : "Kodad inbjudan kopierades till urklipp",
    "Invite code copied to clipboard" : "Inbjudningskod kopierades till urklipp",
    "Invite link copied to clipboard" : "Inbjudningslänk kopierades till urklipp",
    "Copied to clipboard" : "Kopierat till urklipp",
    "Failed to copy to clipboard" : "Det gick inte att kopiera till urklipp",
    "Could not resend invite" : "Det gick inte att skicka inbjudan igen",
    "Invite revoked" : "Inbjudan återkallades",
    "Could not revoke invite" : "Det gick inte att återkalla inbjudan",
    "Invite sent to {email}" : "Inbjudan skickades till {email}",
    "Could not send invite" : "Det gick inte att skicka inbjudan",
    "No invitation selected" : "Ingen inbjudan har valts",
    "Select an invitation on the list to begin" : "Välj en inbjudan i listan för att börja",
    "External invitation" : "Extern inbjudan",
    "Label" : "Etikett",
    "Sent to" : "Skickad till",
    "Created" : "Skapad",
    "Expires" : "Upphör att gälla",
    "More ways to share" : "Fler sätt att dela",
    "Useful for sharing through a chat app or for manual acceptance." : "Användbart för att dela via en chattapp eller för manuell accept.",
    "Revoke invitation" : "Återkalla inbjudan",
    "Resend email" : "Skicka e-post igen",
    "Send via email" : "Skicka via e-post",
    "Send invitation via email" : "Skicka inbjudan via e-post",
    "{name} invites you to exchange cloud accounts and contact information." : "{name} bjuder in dig att utbyta molnkonton och kontaktuppgifter.",
    "The invite link and code are added automatically when you send the invitation." : "Inbjudningslänken och koden läggs till automatiskt när du skickar inbjudan.",
    "Recipient email" : "Mottagarens e-postadress",
    "Invite someone outside your organization to collaborate" : "Bjud in någon utanför organisationen att samarbeta",
    "After the invitee accepts the invite, both of you will appear in each other's contacts list and you can start sharing data with each other." : "När mottagaren accepterar inbjudan visas ni båda i varandras kontaktlistor och kan börja dela data med varandra.",
    "Send invite via email" : "Skicka inbjudan via e-post",
    "Hide email preview" : "Dölj e-postförhandsvisning",
    "Show email preview" : "Visa e-postförhandsvisning",
    "This is what {recipient} will receive:" : "Det här är vad {recipient} får:",
    "If you do not send an email, you will need to share the invite link yourself." : "Om du inte skickar ett e-postmeddelande måste du själv dela inbjudningslänken.",
    "Invite link" : "Inbjudningslänk",
    "Copy invite link to clipboard" : "Kopiera inbjudningslänken till urklipp",
    "Copy invite code to clipboard" : "Kopiera inbjudningskoden till urklipp",
    "Encoded invite" : "Kodad inbjudan",
    "Copy encoded invite to clipboard" : "Kopiera den kodade inbjudan till urklipp",
    "Search invites…" : "Sök efter inbjudningar…",
    "Could not discover that provider. Check the address and try again." : "Det gick inte att hitta den leverantören. Kontrollera adressen och försök igen.",
    "Select your server" : "Välj din server",
    "Type to search" : "Skriv för att söka",
    "No servers match your search." : "Inga servrar matchar sökningen.",
    "No servers are currently available." : "Inga servrar är för närvarande tillgängliga.",
    "Your server not listed? Enter one manually." : "Finns inte din server i listan? Ange en manuellt.",
    "Continue" : "Fortsätt",
    "You need an invite link for this feature to work." : "Du behöver en inbjudningslänk för att den här funktionen ska fungera.",
    "Select chart …" : "Välj schema …",
    "Chart" : "Diagram",
    "Select type" : "Välj typ",
    "Add contact in group" : "Lägg till kontakt i grupp",
    "None" : "Ingen",
    "copy" : "kopiera",
    "Select option" : "Välj alternativ",
    "JavaScript URIs are not allowed" : "JavaScript-URI:er är inte tillåtna",
    "Notes" : "Anteckningar",
    "send an email" : "skicka e-post",
    "Personal dates" : "Personliga datum",
    "Add property of this type" : "Lägg till egenskap av denna typ",
    "Member" : "Medlem",
    "This is a read-only group managed by administrators. Group members can only view this group." : "Detta är en skrivskyddad grupp som hanteras av administratörer. Gruppmedlemmar kan endast visa denna grupp.",
    "Send invitation" : "Skicka inbjudan",
    "Generate invitation" : "Generera inbjudan",
    "This invite link is incomplete. Ask the sender to generate a new one." : "Den här inbjudningslänken är ofullständig. Be avsändaren att skapa en ny.",
    "Unable to create the contact." : "Det gick inte att skapa kontakten.",
    "Contact not found" : "Kontakten hittades inte",
    "Address book {addressbook} not found" : "Adressboken {addressbook} hittades inte",
    "Group {group} not found" : "Gruppen {group} hittades inte",
    "Could not accept invite" : "Det gick inte att acceptera inbjudan",
    "Could not create invite" : "Det gick inte att skapa inbjudan",
    "Add member" : "Lägg till medlem",
    "New contact" : "Ny kontakt",
    "_{success} contact added to {name}_::_{success} contacts added to {name}_" : ["{success} kontakt har lagts till i {name}","{success} kontakter har lagts till i {name}"],
    "_Adding {success} contact to {name}_::_Adding {success} contacts to {name}_" : ["Lägger till {success} kontakt i {name}","Lägger till {success} kontakter i {name}"],
    "_{count} error_::_{count} errors_" : ["{count} fel","{count} fel"],
    "_Importing %n contact into {addressbook}_::_Importing %n contacts into {addressbook}_" : ["Importerar %n kontakt till adressboken {addressbook}","Importerar %n kontakter till adressboken {addressbook}"],
    "_Done importing %n contact into {addressbook}_::_Done importing %n contacts into {addressbook}_" : ["Importen av %n kontakt till adressboken {addressbook} är klar","Importen av %n kontakter till adressboken {addressbook} är klar"],
    "No data for this contact" : "Inga uppgifter för den här kontakten",
    "No data for this contact on their profile" : "Inga uppgifter för den här kontakten i kontaktens profil",
    "Import" : "Importera",
    "Are you sure you want to import this contact file?" : "Är du säker på att du vill importera denna kontaktfil?",
    "Could not copy" : "Det gick inte att kopiera",
    "Join team" : "Gå med i team",
    "You are about to leave {circle}.\nAre you sure?" : "Du håller på att lämna {circle}.\nÄr du säker?",
    "Please confirm team leave" : "Bekräfta att du vill lämna teamet",
    "Could not leave the team {displayName}" : "Det gick inte att lämna teamet {displayName}",
    "Unable to join the team" : "Det gick inte att gå med i teamet",
    "You are about to delete {circle}.\nAre you sure?" : "Du håller på att ta bort {circle}.\nÄr du säker?",
    "Please confirm team deletion" : "Bekräfta borttagning av teamet",
    "Unable to delete the team" : "Det gick inte att ta bort teamet",
    "Confirm enabling federation" : "Bekräfta aktivering av federation",
    "Enabling this will prevent {circle} from being a member of other teams.\nAre you sure?" : "Om du aktiverar detta kommer {circle} inte att kunna vara medlem i andra team.\nÄr du säker?",
    "Enable federation" : "Aktivera federation",
    "Link copied to the clipboard" : "Länken har kopierats till urklipp",
    "Could not copy link to the clipboard." : "Det gick inte att kopiera länken till urklipp.",
    "Not grouped" : "Inte grupperad",
    "Create your own teams for sharing. Add Nextcloud users, contacts, or anyone via email." : "Skapa egna team för delning. Lägg till Nextcloud-användare, kontakter eller andra personer via e-post.",
    "Team" : "Team",
    "User" : "Användare",
    "Group" : "Grupp",
    "Email" : "E-post",
    "Contact" : "Kontakt",
    "Moderator" : "Moderator",
    "Admin" : "Administratör",
    "Owner" : "Ägare",
    "Invites" : "Inbjudningar",
    "Anyone can request membership" : "Vem som helst kan begära medlemskap",
    "Members need to accept invitation" : "Medlemmar måste acceptera inbjudan",
    "Memberships must be confirmed/accepted by a Moderator (requires \"Anyone can request membership\")" : "Medlemskap måste bekräftas/accepteras av en moderator (kräver \"Vem som helst kan begära medlemskap\")",
    "Members can also invite" : "Medlemmar kan också bjuda in",
    "Membership" : "Medlemskap",
    "Prevent teams from being a member of another team" : "Förhindra detta team från att bli medlem av ett annat team",
    "Federation" : "Federation",
    "Allow federated members" : "Tillåt federerade medlemmar",
    "Privacy" : "Integritet",
    "Visible to everyone" : "Synlig för alla",
    "users" : "användare",
    "Users" : "Användare",
    "groups" : "grupper",
    "federated users" : "federerade användare",
    "Federated users" : "Federerade användare",
    "teams" : "team",
    "email addresses" : "e-postadresser",
    "Email addresses" : "E-postadresser",
    "contacts" : "kontakter",
    "Link-only invite" : "Inbjudan med endast länk",
    "Detailed name" : "Fullständigt namn",
    "Additional names" : "Ytterligare namn",
    "Prefix" : "Prefix",
    "Suffix" : "Suffix",
    "Nickname" : "Smeknamn",
    "Website" : "Webbplats",
    "Location" : "Plats",
    "Federated Cloud ID" : "Federerat moln-ID",
    "Home" : "Hem",
    "Work" : "Arbete",
    "Other" : "Övrigt",
    "Address" : "Adress",
    "Post office box" : "Postbox",
    "Extended address" : "Utökad adress",
    "City" : "Stad",
    "State or province" : "Delstat eller region",
    "Postal code" : "Postnummer",
    "Country" : "Land",
    "Birthday" : "Födelsedag",
    "Place of birth" : "Födelseort",
    "Anniversary" : "Jubileum",
    "Date of death" : "Dödsdag",
    "Place of death" : "Dödsort",
    "Instant messaging" : "Snabbmeddelanden",
    "Phone" : "Telefon",
    "Mobile" : "Mobil",
    "Work mobile" : "Arbetsmobil",
    "Home mobile" : "Hemmobil",
    "Fax" : "Fax",
    "Fax home" : "Fax, hem",
    "Fax work" : "Fax, arbete",
    "Pager" : "Personsökare",
    "Voice" : "Röst",
    "Car" : "Bil",
    "Work pager" : "Personsökare, arbete",
    "Line manager" : "Närmaste chef",
    "Social network" : "Socialt nätverk",
    "Relationship to you" : "Relation till dig",
    "Spouse" : "Make eller maka",
    "Child" : "Barn",
    "Mother" : "Mor",
    "Father" : "Far",
    "Parent" : "Förälder",
    "Brother" : "Bror",
    "Sister" : "Syster",
    "Relative" : "Släkting",
    "Friend" : "Vän",
    "Colleague" : "Kollega",
    "Assistant" : "Assistent",
    "Related contacts" : "Relaterade kontakter",
    "Agent" : "Agent",
    "Emergency" : "Nödsituation",
    "Co-worker" : "Kollega",
    "Gender" : "Kön",
    "Female" : "Kvinna",
    "Male" : "Man",
    "Unknown" : "Okänd",
    "Time zone" : "Tidszon",
    "Spoken languages" : "Talade språk",
    "_{failed} contact failed to be read_::_{failed} contacts failed to be read_" : ["{failed} kontakt kunde inte läsas","{failed} kontakter kunde inte läsas"],
    "An error has occurred in team(s). Check the console for more details." : "Ett fel har uppstått i ett eller flera team. Mer information finns i konsolen.",
    "Unable to create team {circleName}" : "Det gick inte att skapa teamet {circleName}",
    "Unable to delete team {circleId}" : "Det gick inte att ta bort teamet {circleId}",
    "Could not update favorite state" : "Det gick inte att uppdatera favoritstatusen",
    "Unable to delete contact" : "Det gick inte att ta bort kontakten",
    "Value copied to the clipboard" : "Värdet har kopierats till urklipp",
    "Could not copy value to the clipboard." : "Det gick inte att kopiera värdet till urklipp.",
    "Deck board" : "Deck-tavla",
    "New Deck board" : "Ny Deck-tavla",
    "Board name" : "Tavlans namn",
    "Deck app is not installed. Please install it to create team boards." : "Deck-appen är inte installerad. Installera den för att skapa teamtavlor.",
    "Pick an address book" : "Välj en adressbok",
    "Select Date" : "Välj datum",
    "note" : "anteckning",
    "email" : "e-post",
    "Create your own groups for sharing. Add Nextcloud users, contacts, or anyone via email." : "Skapa egna grupper för delning. Lägg till Nextcloud-användare, kontakter eller vem som helst via e-post."
},
"nplurals=2; plural=(n != 1);");
