OC.L10N.register(
    "contacts",
    {
    "Import contacts" : "匯入連絡人",
    "Details" : "詳細資料",
    "All contacts" : "所有聯絡人",
    "Email address is required." : "電子郵件地址為必填。",
    "An open invite already exists." : "已有開放邀請。",
    "Could not accept invite because no authenticated user was found." : "因為找不到已驗證的使用者，因此無法接受邀請。",
    "The invite provider is invalid or not allowed." : "邀請提供者無效或未獲授權。",
    "Unable to accept this invitation. You are trying to accept an outgoing invitation." : "無法接受邀請。您正嘗試接受一則已發出的邀請。",
    "Could not accept invite because the remote provider returned an invalid response." : "由於遠端服務提供者回傳了無效的回應，因此無法接受邀請。",
    "The remote provider accepted the invite, but this server could not create the local contact." : "遠端提供者已接受邀請，但此伺服器無法建立本機聯絡人。",
    "Cannot resend: no email address" : "無法重新傳送：沒有電子郵件地址",
    "Invite has already been accepted." : "已接受邀請。",
    "Invite has expired. Please create a new one." : "邀請逾期。請建立新的。",
    "This is a copy of an invite sent to you previously by %1$s on %2$s" : "這是先前由 %1$s 於 %2$s 傳送給您的邀請的副本",
    "Invite already has an email address." : "邀請已有電子郵件地址。",
    "An open invite for this email already exists." : "這封電子郵件的開放邀請已存在。",
    "Could not claim invite for this email; please refresh and try again." : "無法為此電子郵件領取邀請；請重新整理頁面並再次嘗試。",
    "Could not revert invite after delivery failure. Please refresh and try again." : "因傳送失敗而無法撤銷邀請。請重新整理頁面並再次嘗試。",
    "OCM invites are disabled." : "已停用 OCM 邀請。",
    "Recipient email address is invalid." : "收件人的電子郵件地址無效。",
    "%1$s via %2$s" : "%1$s 經由 %2$s",
    "%1$s invites you to exchange contact information." : "%1$s 邀請您交換聯絡人資訊。",
    "This is a copy of the invitation you've sent to %1$s" : "這是您傳送給 %1$s 的邀請副本",
    "Hi there," : "您好，",
    "%1$s invites you to exchange cloud accounts and contact information." : "%1$s 邀請您交換雲端帳號與聯絡人資訊。",
    "This will allow you to share data with each other." : "這樣一來，你們就能互相分享資料了。",
    "To accept this invite, click the link below and sign in with your cloud provider:" : "若要接受此邀請，請點擊下方連結，並使用您的雲端服務提供者帳號登入：",
    "Invitation details:" : "邀請詳細資訊：",
    "Invite code: %1$s" : "邀請碼：%1$s",
    "Encoded invite: %1$s" : "編碼後的邀請：%1$s",
    "To accept this invite, use the url below to sign in with your cloud provider:" : "若要接受此邀請，請使用以下網址透過您的雲端服務提供者登入：",
    "_Imported %n contact_::_Imported %n contacts_" : ["已匯入 %n 個聯絡人"],
    "_(skipped %n contact)_::_(skipped %n contacts)_" : ["（已略過 %n 個聯絡人）"],
    "Contacts" : "通訊錄",
    "A contacts app for Nextcloud" : "Nextcloud 的通訊錄應用程式",
    "The Nextcloud contacts app is a user interface for Nextcloud's CardDAV server. Easily sync contacts from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Currently Mail and Calendar – more to come.\n* 🎉 **Never forget a birthday!** You can sync birthdays and other recurring events with your Nextcloud Calendar.\n* 👥 **Sharing of Adressbooks!** You want to share your contacts with your friends or coworkers? No problem!\n* 🙈 **We’re not reinventing the wheel!** Based on the great and open SabreDAV library." : "Nextcloud 通訊錄應用程式是 Nextcloud 的 CardDAV 伺服器的使用者介面。可輕鬆使用您的 Nextcloud 同步各個裝置上的聯絡人，並在線上編輯。\n\n* 🚀 **與其他 Nextcloud 應用程式整合！** 目前有電子郵件與日曆，還會有更多。\n* 🎉 **不會忘記生日！** 您可以將生日與其他重複的活動與您的 Nextcloud 日曆同步。\n* 👥 **分享通訊錄！** 您想與您的朋友或同事分享您的聯絡人嗎？沒問題！\n* 🙈 **我們並沒有重新發明輪子！** 以超棒且開放的 SabreDAV 函式庫為基礎。",
    "Copy to full name" : "複製到全名",
    "Omit year" : "省略年份",
    "Could not save the setting" : "無法儲存設定",
    "Allow updating avatars from social media" : "允許從社群媒體更新大頭照",
    "External invitations" : "外部邀請",
    "Allow creating invites without an email address (link-only)" : "允許在不提供電子郵件地址的情況下建立邀請（僅連結）",
    "Show the \"Copy encoded invite\" button on invite details" : "在邀請詳細資訊上顯示「複製已編碼的邀請」",
    "Organization chart" : "組織圖表",
    "There was an error fetching the member list" : "擷取成員清單時發生錯誤",
    "Teams" : "團隊",
    "Please select a team" : "請選取團隊",
    "Loading team…" : "正在載入團隊……",
    "Loading contacts …" : "正在載入聯絡人……",
    "There are no contacts yet" : "目前沒有連絡人",
    "Create contact" : "建立聯絡人",
    "There are no contacts in this group" : "群組中沒有連絡人",
    "Create contacts" : "建立聯絡人",
    "Add contacts" : "新增聯絡人",
    "Loading invitations…" : "正在載入邀請⋯⋯",
    "Could not load invitations" : "無法載入邀請",
    "Retry" : "重試",
    "There are no invitations" : "沒有邀請",
    "Create invitation" : "建立邀請",
    "Loading …" : "正在載入……",
    "Manage team" : "管理團隊",
    "Leave team" : "離開團隊",
    "Delete team" : "刪除團隊",
    "Setting saved" : "設定已儲存",
    "Failed to save setting" : "儲存設定失敗",
    "Contacts settings" : "聯絡人設定",
    "General" : "一般",
    "Update avatars from social media" : "從社群媒體更新大頭照",
    "Refreshed once per week" : "每週重新整理一次",
    "Address books" : "通訊錄",
    "Tried to drop an invalid contact!" : "嘗試丟棄無效的聯絡人",
    "Rename" : "重新命名",
    "Export" : "匯出",
    "Send email" : "傳送電子郵件",
    "Send email as BCC" : "以密件副本傳送電子郵件",
    "Delete" : "刪除",
    "Show all groups" : "顯示所有群組",
    "Collapse groups" : "折疊群組",
    "Show all teams" : "顯示所有團隊",
    "Collapse teams" : "折疊團隊",
    "Group name cannot be empty" : "群組名稱不能為空",
    "This group already exists" : "該群組已存在",
    "An error occurred while creating the group" : "建立群組時發生錯誤",
    "This team already exists" : "此團隊已存在",
    "An error happened during the creation of the team" : "建立團隊時發生錯誤",
    "Add address book" : "新增通訊錄",
    "Recently contacted" : "最近聯絡",
    "Contact groups" : "聯絡人群組",
    "Create a new contact group" : "建立新聯絡人群組",
    "Contact group name" : "聯絡人群組名稱",
    "Create a new team" : "建立新團隊",
    "Open the contacts app settings" : "開啟通訊錄應用程式設定",
    "_Shared with {num} entity_::_Shared with {num} entities_" : ["與 {num} 個實體分享"],
    "Copied" : "已複製",
    "Cannot copy" : "無法複製",
    "Copy link" : "複製連結",
    "Toggling of address book was not successful" : "通訊錄切換失敗",
    "This will delete the address book and every contacts within it" : "這將會刪除通訊與其中的每個聯絡人",
    "Delete {addressbook}?" : "刪除 {addressbook}？",
    "This will unshare the address book and every contacts within it" : "這將會取消分享通訊錄與其中的每個聯絡人",
    "Unshare {addressbook}?" : "取消分享 {addressbook}？",
    "Deletion of address book was not successful." : "刪除通訊錄失敗。",
    "Renaming of address book was not successful." : "重新命名通訊錄失敗。",
    "{addressbookname} (Hidden)" : "{addressbookname}（隱藏）",
    "Download" : "下載",
    "Show" : "顯示",
    "Unshare from me" : "取消與我分享",
    "_%n contact_::_%n contacts_" : ["%n 位聯絡人"],
    "_%n group_::_%n groups_" : ["%n 個群組"],
    "Share with users or groups" : "與使用者或群組分享",
    "Share with users" : "與使用者分享",
    "No users or groups" : "沒有使用者或群組",
    "Unable to delete the share" : "無法刪除這個分享",
    "Unable to change permissions" : "無法變更權限",
    "can create and edit" : "可以建立並編輯",
    "Choose a vCard file to import" : "選取要匯入的 vCard 檔案",
    "Import into the {addressbookName} address book" : "匯入至 {addressbookName} 通訊錄",
    "Select local file" : "選取本機檔案",
    "Import from files" : "從檔案匯入",
    "Importing is disabled because there are no address books available" : "已停用匯入，因為沒有可用的通訊錄",
    "An error occurred, unable to create the address book" : "發生錯誤，無法建立通訊錄",
    "New address book" : "新通訊錄",
    "Add new address book" : "加入新的通訊錄",
    "Cancel" : "取消",
    "Add" : "Add",
    "First name" : "名",
    "Last name" : "姓",
    "Phonetic first name" : "語音名",
    "Phonetic last name" : "語音姓",
    "Display name" : "顯示名稱",
    "Last modified" : "上次修改",
    "Sort contacts by" : "按以下條件對聯絡人排序：",
    "Manages" : "管理",
    "Oversees" : "監督",
    "An error happened during the config change" : "變更設定時發生錯誤",
    "Enforce password protection on files shared to this team" : "對分享到此團隊的檔案加上密碼保護",
    "Use a unique password for all shares to this team" : "對此團隊的所有分享使用獨一無二的密碼",
    "Unique password …" : "獨一無二的密碼……",
    "Save" : "儲存",
    "Change unique password" : "變更獨一無二的密碼",
    "Failed to save password. Please try again later." : "儲存密碼失敗。請稍後再試。",
    "Close" : "關閉",
    "Choose a team picture" : "選擇團隊圖片",
    "There is no description for this team" : "此團隊沒有描述",
    "Enter a description for the team" : "輸入團隊的描述",
    "Folder" : "Folder",
    "New folder" : "新資料夾",
    "Folder name" : "資料夾名稱",
    "This will create a regular folder shared with the team. To create a Team Folder, please contact your {productName} administrator" : "這將會建立分享給團隊的一般資料夾。要建立團隊資料夾，請聯絡您的 {productName} 管理員",
    "Talk conversation" : "Talk 對話",
    "New Talk conversation" : "新 Talk 對話",
    "Conversation name" : "對話名稱",
    "Collective" : "知識庫",
    "Calendar" : "日曆",
    "New calendar" : "新日曆",
    "Calendar name" : "日曆名稱",
    "Unknown resource type" : "未知的資源類型",
    "Team calendar \"{resourceName}\" created and shared with team" : "已建立團隊日曆「{resourceName}」並分享給團隊",
    "{resourceType} \"{resourceName}\" created and shared with team" : "已建立 {resourceType}「{resourceName}」並分享給團隊",
    "A calendar named \"{name}\" already exists. Please choose a different name." : "名為「{name}」的日曆已存在。請選擇其他名稱。",
    "Failed to create {resourceType}: {error}" : "建立 {resourceType} 失敗：{error}",
    "Please select a valid png or jpg file" : "請選取有效的 png 或 jpg 檔案",
    "Error picking team picture" : "挑選團隊圖片時發生錯誤",
    "Error cropping avatar picture" : "裁剪大頭照圖片時發生錯誤",
    "An error happened while saving {fields}" : "儲存 {fields} 時發生錯誤",
    "Team name" : "團隊名稱",
    "Team owner" : "團隊擁有者",
    "Upload team picture" : "上傳團隊圖片",
    "Choose from Nextcloud Files" : "從 Nextcloud Files 選擇",
    "Delete picture" : "刪除圖片",
    "Edit" : "編輯",
    "Request to join" : "要求加入",
    "Create" : "建立",
    "Show in Calendar" : "在日曆中顯示",
    "Your request to join this team is pending approval" : "您加入此團隊的請求正在等待批准",
    "You are not a member of {circle}" : "您不是 {circle} 的成員",
    "Members" : "成員",
    "Edit team picture" : "編輯團隊圖片",
    "Apply" : "套用",
    "Confirm" : "確認",
    "No other contacts available to select as line manager" : "無其他聯絡人可選為行管理員",
    "Add more info" : "新增更多資訊",
    "More fields" : "更多欄位",
    "Please select a valid format" : "請選取有效格式",
    "Invalid image" : "圖片無效",
    "Error cropping picture" : "裁剪照片時發生錯誤",
    "Pick an avatar" : "選擇一個大頭照",
    "Pick" : "挑選",
    "Error while processing the picture." : "處理相片時錯誤。",
    "Avatar downloaded from social network" : "從社群網路下載大頭照",
    "Avatar already up to date" : "大頭照已是最新",
    "Avatar download failed" : "大頭照下載失敗",
    "Crop contact photo" : "裁剪聯絡人照片",
    "Upload a new picture" : "上傳一張新的圖片",
    "Choose from Files" : "從檔案選取",
    "Download picture" : "下載圖片",
    "Clone contact" : "再製連絡人",
    "This contact is in read-only mode. You do not have permission to edit this contact." : "此聯絡人處於唯讀模式。您無權編輯此聯絡人。",
    "The contact you were trying to edit has changed. Please manually refresh the contact. Any further edits will be discarded." : "您嘗試編輯的聯絡人已變更。請手動重新整理聯絡人。任何進一步的編輯都會被丟棄。",
    "Address book" : "通訊錄",
    "Add contact to Birthday Calendar" : "將聯絡人新增至生日行事曆",
    "Exclude contact from Birthday Calendar" : "從生日行事曆排除聯絡人",
    "{title} at {organization}" : "{organization} 的 {title}",
    "Name" : "名稱",
    "Syntax error. Cannot open the contact." : "語法錯誤。無法開啟聯絡人。",
    "The contact does not exist on the server anymore." : "伺服器上不再存在該聯絡人。",
    "Unable to retrieve the contact from the server, please check your network connection." : "無法從伺服器擷取聯絡人，請檢查您的網路連線。",
    "An error occurred while trying to move the contact" : "嘗試移動聯絡人時發生錯誤",
    "An error occurred while trying to copy the contact" : "嘗試複製聯絡人時發生錯誤",
    "Unable to update contact" : "無法更新聯絡人",
    "No contact selected" : "未選擇聯絡人",
    "Select a contact on the list to begin" : "在列表中選擇一個聯絡人以開始",
    "Title" : "標題",
    "Company" : "公司",
    "Go to talk conversation" : "前往對話",
    "View profile" : "檢視個人檔案",
    "This contact was broken and received a fix. Please review the content and click here to save it." : "此聯絡人的資料有問題，已修復。請審閱內容並點擊此處以儲存。",
    "Edit profile" : "編輯個人檔案",
    "Generate QR Code" : "產生 QR Code",
    "Contact vCard as QR code" : "QR Code 形式的聯絡人 vCard",
    "Select address book" : "選擇通訊錄",
    "Media shares with you" : "與您分享的媒體",
    "Talk conversations with you" : "與您的 Talk 對話",
    "Calendar events with you" : "有您的日曆事件",
    "Deck cards with you" : "有您的 Deck 卡片",
    "No shared items with this contact" : "沒有與該聯絡人分享的項目",
    "This contact cannot be moved" : "此聯絡人無法移動",
    "This contact cannot be grouped" : "此聯絡人無法加入群組",
    "Add contacts to groups" : "新增聯絡人到群組",
    "Move contacts to addressbook" : "將聯絡人移動到通訊錄",
    "Select groups" : "選取群組",
    "Select addressbook" : "選取通訊錄",
    "Selected contacts" : "已選取聯絡人",
    "Please note that only {count} of the {total} contacts can be added to a group" : "請注意：在 {total} 個聯絡人中，僅能新增 {count} 個至群組",
    "Please note that only {count} of the {total} contacts can be moved" : "請注意：在 {total} 個聯絡人中，僅能移動 {count} 個聯絡人",
    "Move" : "Move",
    "Unselect {name}" : "取消選取 {name}",
    "Select {name}" : "選取 {name}",
    "Could not update favorite status" : "無法更新喜愛狀態",
    "from {addressbook}" : "來自 {addressbook}",
    "Remove from favorites" : "從喜愛移除",
    "Add to favorites" : "新增至喜愛",
    "Confirm merging contacts" : "確認合併聯絡人",
    "The selected contacts have conflicting information. Choose which information to keep" : "選定的聯絡人有互相衝突的資訊。請選擇要保留的資訊",
    "Contacts can be merged" : "可以合併聯絡人",
    "Groups" : "群組",
    "Select groups to add the merged contact to" : "選取要新增合併聯絡人的群組",
    "Merge contacts" : "合併聯絡人",
    "_Delete {number} contact_::_Delete {number} contacts_" : ["刪除 {number} 個聯絡人"],
    "Please select at least one editable contact to delete" : "請選取至少一個可編輯的聯絡人來刪除",
    "Please select two editable contacts to merge" : "請選取兩個可編輯的聯絡人進行合併",
    "_Add {number} contact to group_::_Add {number} contacts to group_" : ["新增 {number} 個聯絡人至群組"],
    "Please select at least one editable contact to add to a group" : "請選取至少一個可編輯的聯絡人以新增至群組",
    "_Move {number} contact to addressbook_::_Move {number} contacts to addressbook_" : ["將 {number} 個聯絡人移動至通訊錄"],
    "Please select at least one editable contact to move to an addressbook" : "請選取至少一個可編輯的聯絡人以移動至通訊錄",
    "Are you sure you want to proceed?" : "您想要繼續嗎？",
    "Add contacts to group" : "新增聯絡人至群組",
    "Search contacts …" : "搜尋聯絡人……",
    "Unselect {number}" : "取消選取 {number}",
    "Add to {group}" : "新增至 {group}",
    "Add members to {group}" : "新增成員至 {group}",
    "Please note that you can only add contacts from writable address books to contact groups. Contacts from read-only address books, such as the system address book, cannot be added." : "請注意，您只能將可寫通訊錄中的聯絡人新增至聯絡人群組。來自唯讀通訊錄（例如系統通訊錄）的聯絡人則無法新增。",
    "Remove {type}" : "移除 {type}",
    "Add to group" : "新增至群組",
    "Add members to group" : "新增成員至群組",
    "Search {types}" : "搜尋 {types}",
    "Add guest" : "新增訪客",
    "Search for people to add" : "搜尋要新增的人",
    "No results" : "沒有結果",
    "Add {type}" : "新增 {type}",
    "New team name" : "新團隊名稱",
    "Personal team" : "個人團隊",
    "This team will only be visible to you. Other members will not be able to see or use it." : "此團隊僅有您可見。其他成員將無法看到或使用它。",
    "Local team" : "本地團隊",
    "This team will not be shared with the other instances of the global scale" : "這個團隊不會與全球的其他站台共享",
    "Create team" : "建立團隊",
    "Promote as sole owner" : "將其權限升級為唯一擁有者",
    "Promote to {level}" : "將其權限升級為 {level}",
    "Demote to {level}" : "將其權限降級為 {level}",
    "Are you sure you want to leave this team? This action cannot be undone." : "您確定您想要離開此團隊嗎？此動作無法還原。",
    "Leave team failed." : "離開團隊失敗。",
    "Could not delete the member {displayName}" : "無法刪除成員 {displayName}",
    "Could not change the member level to {level}" : "無法變更成員等級至 {level}",
    "Could not accept membership request" : "無法接受成員請求",
    "Accept membership request" : "接受成員資格請求",
    "Reject membership request" : "拒絕成員資格請求",
    "Manage level" : "管理等級",
    "Remove member" : "移除成員",
    "Unable to get the results" : "無法取得結果",
    "Some members could not be added" : "無法新增部份成員",
    "There was an issue adding members to the team" : "將成員新增至團隊時發生錯誤",
    "Loading members list …" : "正在載入成員清單……",
    "The list of members is only visible to members of this team" : "成員清單僅有此團隊的成員可見",
    "You currently have no access to the member list" : "您目前無權存取成員清單",
    "Add to {team}" : "新增至 {team}",
    "Invite members to {team}" : "邀請成員至 {team}",
    "Pending" : "擱置中",
    "This invite does not look valid. Check that you copied it completely or ask the sender to generate a new one." : "這份邀請似乎無效。請確認您是否已完整複製該邀請，或請寄送者重新產生一份。",
    "Accept invitation" : "接受邀請",
    "Accepting will add the inviter to your contacts list and in return, your contact info will be sent to the inviter. From there on you can start sharing data with each other." : "若接受邀請，系統將把邀請者加入您的聯絡人清單，同時您的聯絡資訊也會傳送給邀請者。從此之後，您們便可以開始互相分享資料。",
    "Invite link or code (required)" : "邀請連結或代碼（必填）",
    "Paste the invite link, or an invite code (token@provider), you received from the other person." : "請貼上您從對方那裡收到的邀請連結，或邀請代碼 (token@provider)。",
    "Accept" : "接受",
    "Please enter an email address." : "請輸入電子郵件地址。",
    "The recipient will receive an email with the invite link. Their email address will be saved on the invite so you can resend later." : "收件者將收到一封附有邀請連結的電子郵件。他們的電子郵件地址會儲存在邀請中，以便您日後重新發送。",
    "Recipient email (required)" : "收件者電子郵件（必填）",
    "email@example.com" : "email@example.com",
    "Personal message (optional)" : "個人訊息（選填）",
    "Message to include in the email" : "要包含在電子郵件中的訊息",
    "Sending…" : "正在傳送⋯⋯",
    "Send" : "傳送",
    "Invite code" : "邀請碼",
    "Cloud provider" : "雲端提供者",
    "Encoded invite copied to clipboard" : "編碼過的邀請已複製到剪貼簿",
    "Invite code copied to clipboard" : "邀請碼已複製到剪貼簿",
    "Invite link copied to clipboard" : "邀請連結已複製到剪貼簿",
    "Copied to clipboard" : "已複製到剪貼簿",
    "Failed to copy to clipboard" : "複製到剪貼簿失敗",
    "Could not resend invite" : "無法重新傳送邀請",
    "Invite revoked" : "已撤銷邀請",
    "Could not revoke invite" : "無法撤銷邀請",
    "Invite sent to {email}" : "邀請已傳送至 {email}",
    "Could not send invite" : "無法傳送邀請",
    "No invitation selected" : "未選取邀請",
    "Select an invitation on the list to begin" : "選取清單上的邀請以開始",
    "External invitation" : "外部邀請",
    "Label" : "標籤",
    "Sent to" : "傳送至",
    "Created" : "已建立",
    "Expires" : "到期日",
    "More ways to share" : "更多分享的方式",
    "Useful for sharing through a chat app or for manual acceptance." : "適用於透過聊天應用程式分享，或進行手動確認。",
    "Revoke invitation" : "撤銷邀請",
    "Resend email" : "重新傳送電子郵件",
    "Send via email" : "透過電子郵件傳送",
    "Send invitation via email" : "透過電子郵件傳送邀請",
    "{name} invites you to exchange cloud accounts and contact information." : "{name} 邀請您交換雲端帳號與聯絡人資訊。",
    "The invite link and code are added automatically when you send the invitation." : "邀請連結與代碼會在您傳送邀請時自動新增。",
    "Recipient email" : "收件者電子郵件",
    "Invite someone outside your organization to collaborate" : "邀請組織外部的人士進行協作",
    "After the invitee accepts the invite, both of you will appear in each other's contacts list and you can start sharing data with each other." : "當受邀者接受邀請後，你們雙方都會出現在彼此的聯絡人清單中，屆時便可以開始互相分享資料。",
    "Send invite via email" : "透過電子郵件傳送邀請",
    "Hide email preview" : "隱藏電子郵件預覽",
    "Show email preview" : "顯示電子郵件預覽",
    "This is what {recipient} will receive:" : "{recipient} 將會收到如下的內容：",
    "If you do not send an email, you will need to share the invite link yourself." : "若您未傳送電子郵件，您就必須自行分享邀請連結。",
    "Invite link" : "邀請連結",
    "Copy invite link to clipboard" : "複製邀請連結至剪貼簿",
    "Copy invite code to clipboard" : "複製邀請碼至剪貼簿",
    "Encoded invite" : "編碼過的邀請",
    "Copy encoded invite to clipboard" : "複製編碼過的邀請至剪貼簿",
    "Search invites…" : "搜尋邀請⋯⋯",
    "Could not discover that provider. Check the address and try again." : "無法探索提供者。檢查地址並重試。",
    "Select your server" : "選取您的伺服器",
    "Type to search" : "輸入以搜尋",
    "No servers match your search." : "沒有符合您搜尋的伺服器。",
    "No servers are currently available." : "目前沒有可用的伺服器。",
    "Your server not listed? Enter one manually." : "您的伺服器未列在清單中？請手動輸入。",
    "Continue" : "繼續",
    "You need an invite link for this feature to work." : "您需要一個邀請連結，此功能才能生效。",
    "Select chart …" : "選取圖表……",
    "Chart" : "圖表",
    "Select type" : "選取類型",
    "Add contact in group" : "新增聯絡人到群組",
    "None" : "無",
    "copy" : "複製",
    "Select option" : "選取選項",
    "JavaScript URIs are not allowed" : "不允許 JavaScript URI",
    "Notes" : "筆記",
    "send an email" : "傳送電子郵件",
    "Personal dates" : "個人日期",
    "Add property of this type" : "新增此類型的屬性",
    "Member" : "成員",
    "This is a read-only group managed by administrators. Group members can only view this group." : "此為由管理員管理的唯讀群組。群組成員僅能檢視此群組。",
    "Send invitation" : "傳送邀請",
    "Generate invitation" : "產生邀請",
    "This invite link is incomplete. Ask the sender to generate a new one." : "此邀請連結不完整。請要求傳送者產生新的。",
    "Unable to create the contact." : "無法建立聯絡人",
    "Contact not found" : "找不到聯絡人",
    "Address book {addressbook} not found" : "找不到通訊錄 {addressbook}",
    "Group {group} not found" : "找不到群組 {group}",
    "Could not accept invite" : "無法接受邀請",
    "Could not create invite" : "無法建立邀請",
    "Add member" : "新增成員",
    "New contact" : "新聯絡人",
    "_{success} contact added to {name}_::_{success} contacts added to {name}_" : ["{success} 個聯絡人已新增至 {name}"],
    "_Adding {success} contact to {name}_::_Adding {success} contacts to {name}_" : ["已新增 {success} 個聯絡人至 {name}"],
    "_{count} error_::_{count} errors_" : ["{count} 個錯誤"],
    "_Importing %n contact into {addressbook}_::_Importing %n contacts into {addressbook}_" : ["正在匯入 %n 個聯絡人至 {addressbook}"],
    "_Done importing %n contact into {addressbook}_::_Done importing %n contacts into {addressbook}_" : ["完成匯入 %n 個聯絡人至 {addressbook}"],
    "No data for this contact" : "此聯絡人無資料",
    "No data for this contact on their profile" : "此聯絡人的個人檔案中沒有資料",
    "Import" : "匯入",
    "Are you sure you want to import this contact file?" : "您確定您想要匯入此聯絡人檔案嗎？",
    "Could not copy" : "無法複製",
    "Join team" : "加入團隊",
    "You are about to leave {circle}.\nAre you sure?" : "您將要離開 {circle}。\n您確定嗎？",
    "Please confirm team leave" : "請確認您要離開團隊",
    "Could not leave the team {displayName}" : "無法離開團隊 {displayName}",
    "Unable to join the team" : "無法加入團隊",
    "You are about to delete {circle}.\nAre you sure?" : "您將要刪除 {circle}。\n您確定嗎？",
    "Please confirm team deletion" : "請確認您要刪除團隊",
    "Unable to delete the team" : "無法刪除這個團隊",
    "Confirm enabling federation" : "確認啟用聯盟功能",
    "Enabling this will prevent {circle} from being a member of other teams.\nAre you sure?" : "啟用後，{circle} 將無法加入其他團隊。\n您確定嗎？",
    "Enable federation" : "啟用聯盟",
    "Link copied to the clipboard" : "連結已複製到剪貼簿",
    "Could not copy link to the clipboard." : "無法複製連結至剪貼簿。",
    "Not grouped" : "未歸類",
    "Create your own teams for sharing. Add Nextcloud users, contacts, or anyone via email." : "建立您用來分享的團隊。新增 Nextcloud 使用者、聯絡人或透過電子郵件新增任何人。",
    "Team" : "團隊",
    "User" : "使用者",
    "Group" : "群組",
    "Email" : "電子郵件",
    "Contact" : "聯絡人",
    "Moderator" : "主持人",
    "Admin" : "管理員",
    "Owner" : "擁有者",
    "Invites" : "邀請",
    "Anyone can request membership" : "任何人都可以請求成員資格",
    "Members need to accept invitation" : "成員必須接受邀請",
    "Memberships must be confirmed/accepted by a Moderator (requires \"Anyone can request membership\")" : "成員資格必須由主持人確認／接受（必須為「任何人都可以請求成員資格）",
    "Members can also invite" : "成員也可以邀請",
    "Membership" : "成員",
    "Prevent teams from being a member of another team" : "避免團隊成為其他團隊的成員",
    "Federation" : "聯盟式",
    "Allow federated members" : "允許聯盟式成員",
    "Privacy" : "隱私權",
    "Visible to everyone" : "對所有人可見",
    "users" : "使用者",
    "Users" : "使用者",
    "groups" : "群組",
    "federated users" : "聯盟使用者",
    "Federated users" : "聯盟使用者",
    "teams" : "團隊",
    "email addresses" : "電子郵件地址",
    "Email addresses" : "電子郵件地址",
    "contacts" : "聯絡人",
    "Link-only invite" : "僅連結的邀請",
    "Detailed name" : "詳細名稱",
    "Additional names" : "別名/中間名",
    "Prefix" : "前綴",
    "Suffix" : "後綴",
    "Nickname" : "暱稱",
    "Website" : "網站",
    "Location" : "地點",
    "Federated Cloud ID" : "雲端聯邦 ID",
    "Home" : "住家",
    "Work" : "工作",
    "Other" : "其他",
    "Address" : "地址",
    "Post office box" : "郵政信箱",
    "Extended address" : "擴展地址",
    "City" : "城市",
    "State or province" : "州或省",
    "Postal code" : "郵遞區號",
    "Country" : "國家",
    "Birthday" : "生日",
    "Place of birth" : "出生地",
    "Anniversary" : "週年",
    "Date of death" : "卒日",
    "Place of death" : "死亡地",
    "Instant messaging" : "即時通訊",
    "Phone" : "電話",
    "Mobile" : "行動電話",
    "Work mobile" : "工作行動電話",
    "Home mobile" : "家用電話",
    "Fax" : "傳真",
    "Fax home" : "傳真（家）",
    "Fax work" : "傳真（公司）",
    "Pager" : "呼叫器",
    "Voice" : "語音",
    "Car" : "車子",
    "Work pager" : "工作呼叫器",
    "Line manager" : "生產線經理",
    "Social network" : "社群網路",
    "Relationship to you" : "與您的關係",
    "Spouse" : "配偶",
    "Child" : "小孩",
    "Mother" : "母親",
    "Father" : "父親",
    "Parent" : "父母",
    "Brother" : "兄弟",
    "Sister" : "姊妹",
    "Relative" : "親屬",
    "Friend" : "朋友",
    "Colleague" : "同事",
    "Assistant" : "助理",
    "Related contacts" : "相關聯絡人",
    "Agent" : "代理人",
    "Emergency" : "緊急",
    "Co-worker" : "同事",
    "Gender" : "性別",
    "Female" : "女性",
    "Male" : "男性",
    "Unknown" : "不明",
    "Time zone" : "時區",
    "Spoken languages" : "會說的語言",
    "_{failed} contact failed to be read_::_{failed} contacts failed to be read_" : ["{failed} 個聯絡人讀取失敗"],
    "An error has occurred in team(s). Check the console for more details." : "團隊中出現錯誤。請檢查主控台以取得更多詳細資訊。",
    "Unable to create team {circleName}" : "無法建立團隊 {circleName}",
    "Unable to delete team {circleId}" : "無法刪除團隊 {circleId}",
    "Could not update favorite state" : "無法更新喜愛狀態",
    "Unable to delete contact" : "無法刪除聯絡人",
    "Value copied to the clipboard" : "值複製給剪貼簿",
    "Could not copy value to the clipboard." : "無法複製值到剪貼簿。",
    "Deck board" : "Deck 看板",
    "New Deck board" : "新 Deck 看板",
    "Board name" : "看板名稱",
    "Deck app is not installed. Please install it to create team boards." : "未安裝 Deck 應用程式。請安裝以建立團隊看板。",
    "Pick an address book" : "選取一個通訊錄",
    "Select Date" : "選取日期",
    "note" : "備註",
    "email" : "電子郵件",
    "Create your own groups for sharing. Add Nextcloud users, contacts, or anyone via email." : "建立專屬群組以進行分享。您可以加入 Nextcloud 使用者、通訊錄中的聯絡人，或透過電子郵件邀請任何人加入。"
},
"nplurals=1; plural=0;");
