.org-chart-node[data-v-c955ad94]{background-color:var(--color-main-background);height:175px;border-radius:var(--border-radius-large);overflow:visible}.org-chart-node__avatar[data-v-c955ad94]{margin-top:-30px;border:1px solid var(--color-border)}.org-chart-node .inner-box[data-v-c955ad94]{display:flex;flex-direction:column;align-items:center;height:175px;padding-top:0;margin-top:30px;border:1px solid var(--color-border);border-radius:var(--border-radius-large);background-color:var(--color-main-background)}.org-chart-node .inner-box .main-container[data-v-c955ad94]{padding:20px;text-align:center;flex:1}.org-chart-node .inner-box .main-container .fullName[data-v-c955ad94]{color:var(--color-primary-element);font-weight:700}.org-chart-node .inner-box .main-container .title[data-v-c955ad94]{margin-top:4px}.org-chart-node .inner-box .description[data-v-c955ad94]{display:flex;justify-content:space-between;width:100%;padding:15px}.org-chart-node .inner-box-highlight[data-v-c955ad94]{border:2px solid var(--color-primary-element)!important}.org-chart-node .panel[data-v-c955ad94]{width:100%;margin:-34px -1px 0;background-color:var(--color-primary-element);height:15px;border-start-start-radius:var(--border-radius-large);border-start-end-radius:var(--border-radius-large)}.org-chart{display:flex;flex-direction:column;height:100%}.org-chart__menu{display:flex;flex-direction:row;justify-content:flex-start;border:1px solid var(--color-border)}.org-chart__menu h3{padding-inline:50px 10px;margin:9px 0}.org-chart__container{display:flex;background-color:var(--color-main-background);height:100%}.org-chart__container svg{height:100%}
