OC.L10N.register(
    "contacts",
    {
    "Import contacts" : "Імпорт контактів",
    "Details" : "Деталі",
    "All contacts" : "Всі контакти",
    "_Imported %n contact_::_Imported %n contacts_" : ["Імпортовано %n контакт","Імпортовано %n контакти","Імпортовано %n контактів","Імпортовано %n контактів"],
    "_(skipped %n contact)_::_(skipped %n contacts)_" : ["(пропущено %n контакт)","(пропущено %n контакти)","(пропущено %n контактів)","(пропущено %n контактів)"],
    "Contacts" : "Контакти",
    "A contacts app for Nextcloud" : "Застосунок для керування контактами у хмарі Nextcloud",
    "The Nextcloud contacts app is a user interface for Nextcloud's CardDAV server. Easily sync contacts from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Currently Mail and Calendar – more to come.\n* 🎉 **Never forget a birthday!** You can sync birthdays and other recurring events with your Nextcloud Calendar.\n* 👥 **Sharing of Adressbooks!** You want to share your contacts with your friends or coworkers? No problem!\n* 🙈 **We’re not reinventing the wheel!** Based on the great and open SabreDAV library." : "Застосунок Nextcloud \"Контакти\" надає зручний користувацький інтерфейс для оперування контактними даними в хмарі Nextcloud за допомогою протоколу CardDAV. Ви зможете легко синхронізувати контакти між різними пристроями з хмарою, редагувати контакти в онлайні.\n* 🚀 **Інтеграція з іншими застосункамиNextcloud! ** Наразі, ви можете синхронізувати контакти із застосунками \"Пошта\" та \"Календар\", інтеграція з рештою застосунків очікується.\n* 🎉 **Завжди пам'ятайте про дати народження! ** Ви зможете синхронізовувати дати народження та інші важливі події, що повторюються, з календарем в хмарі.\n* 👥 **Обмін адресними книгами!** Ви зможете легко поділитися вашими контактами з друзями або колегами.\n* 🙈 **Ми не винаходили колеса! ** Сервіс створено на основі відкритої бібліотеки SabreDAV.",
    "Copy to full name" : "Копіювати до повного імени",
    "Omit year" : "Не включати рік",
    "Allow updating avatars from social media" : "Дозволити оновлення аватарок контактів із соціальних мереж",
    "Organization chart" : "Органограма",
    "There was an error fetching the member list" : "Помилка під час отримання списку учасників",
    "Teams" : "Команди",
    "Please select a team" : "Будь ласка, оберіть команду",
    "Loading team…" : "Завантаження команди...",
    "Loading contacts …" : "Завантаження контактів …",
    "There are no contacts yet" : "Контакти відсутні",
    "Create contact" : "Створити контакт",
    "There are no contacts in this group" : "В цій групі відсутні контакти",
    "Create contacts" : "Створити контакти",
    "Add contacts" : "Додати контакти",
    "Retry" : "Спробувати ще раз",
    "Loading …" : "Завантаження…",
    "Manage team" : "Керувати командою",
    "Leave team" : "Залишити команду",
    "Delete team" : "Вилучити команду",
    "Setting saved" : "Налаштування збережено",
    "Failed to save setting" : "Не вдалося зберегти налаштування",
    "Contacts settings" : "Налаштування",
    "General" : "Загальне",
    "Update avatars from social media" : "Оновлювати аватарки з соціальних мереж",
    "Refreshed once per week" : "Оновлюється щотижня",
    "Address books" : "Адресні книги",
    "Tried to drop an invalid contact!" : "Спроба додати недійсний контакт!",
    "Rename" : "Перейменувати",
    "Export" : "Експорт",
    "Send email" : "Надіслати лист",
    "Send email as BCC" : "Надіслати лист ел.поштою у прихованій копії",
    "Delete" : "Вилучити",
    "Show all groups" : "Показувати всі групи",
    "Collapse groups" : "Згорнути групи",
    "Show all teams" : "Показати всі команди",
    "Collapse teams" : "Згорнути команди",
    "Group name cannot be empty" : "Назва групи не може бути порожньою",
    "This group already exists" : "Така група вже існує",
    "An error occurred while creating the group" : "Помилка під час створення групи",
    "This team already exists" : "Така команда вже існує",
    "An error happened during the creation of the team" : "Помилка під час створення команди",
    "Add address book" : "Додати адресну книгу",
    "Recently contacted" : "Нещодавні контакти",
    "Contact groups" : "Групи контактів",
    "Create a new contact group" : "Створити нову групу контактів",
    "Contact group name" : "Назва групи контактів",
    "Create a new team" : "Створити нову команду",
    "Open the contacts app settings" : "Відкрити налаштування застосунку \"Контакти\"",
    "_Shared with {num} entity_::_Shared with {num} entities_" : ["Спільний доступ з {num} об'єктом","Спільний доступ з {num} об'єктами","Спільний доступ з {num} об'єктами","Спільний доступ з {num} об'єктами"],
    "Copied" : "Скопійовано",
    "Cannot copy" : "Не вдалося скопіювати",
    "Copy link" : "Копіювати посилання",
    "Toggling of address book was not successful" : "Не вдалося перемкнути адресну книгу",
    "This will delete the address book and every contacts within it" : "Це призведе до вилучення адресної книги та контактів у ній",
    "Delete {addressbook}?" : "Вилучити {addressbook}?",
    "This will unshare the address book and every contacts within it" : "Це призведе до того, що адресну книгу та всі контакти в ній буде від'єднано",
    "Unshare {addressbook}?" : "Від'єднати {addressbook}?",
    "Deletion of address book was not successful." : "Не вдалося вилучити адресну книгу",
    "Renaming of address book was not successful." : "Не вдалося перейменувати адресну книгу",
    "{addressbookname} (Hidden)" : "{addressbookname} (Невидима)",
    "Download" : "Звантажити",
    "Show" : "Показати",
    "Unshare from me" : "Вийти зі спільного доступу",
    "_%n contact_::_%n contacts_" : ["%n контакт","%n контакти","%n контактів","%n контактів"],
    "_%n group_::_%n groups_" : ["%n група","%n групи","%n груп","%n груп"],
    "Share with users or groups" : "Поділитися з користувачами або групами",
    "Share with users" : "Поділитися",
    "No users or groups" : "Відсутні користувачі або групи",
    "Unable to delete the share" : "Неможливо вилучити спільний ресурс",
    "Unable to change permissions" : "Неможливо змінити права доступу",
    "can create and edit" : "може створювати та редагувати",
    "Choose a vCard file to import" : "Виберіть файл vCard для імпорту",
    "Import into the {addressbookName} address book" : "Імпорт до адресної книги {addressbookName}",
    "Select local file" : "Виберіть файл на вашому комп'ютері",
    "Import from files" : "Імпорт з файлів",
    "Importing is disabled because there are no address books available" : "Імпорт недоступний, оскільки відсутні адресні книги",
    "An error occurred, unable to create the address book" : "Помилка: неможливо створити адресну книгу",
    "New address book" : "Нова адресна книга",
    "Add new address book" : "Нова адресна книга",
    "Cancel" : "Скасувати",
    "Add" : "Додати",
    "First name" : "Ім'я",
    "Last name" : "Прізвище",
    "Phonetic first name" : "Ім'я за вимовою",
    "Phonetic last name" : "Прізвище за вимовою",
    "Display name" : "Ім'я для показу",
    "Last modified" : "Востаннє змінено",
    "Sort contacts by" : "Впорядковувати контакти за",
    "Manages" : "Керує",
    "Oversees" : "Наглядає",
    "An error happened during the config change" : "Помилка під час внесення змін до конфігурації",
    "Enforce password protection on files shared to this team" : "Вимагати захист паролем файлів, якими поділилися з цією командою",
    "Use a unique password for all shares to this team" : "Використовувати унікальний пароль для всіх спільних ресурсів для цієї команди",
    "Unique password …" : "Унікальний пароль …",
    "Save" : "Зберегти",
    "Change unique password" : "Змінити унікальний пароль",
    "Failed to save password. Please try again later." : "Не вдалося зберегти пароль. Спробуйте пізніше.",
    "Close" : "Закрити",
    "Choose a team picture" : "Вибрати зображення команди",
    "There is no description for this team" : "Відсутній опис цієї команди",
    "Enter a description for the team" : "Додайте опис команди",
    "Folder" : "Folder",
    "New folder" : "Новий каталог",
    "Folder name" : "Назва каталогу",
    "This will create a regular folder shared with the team. To create a Team Folder, please contact your {productName} administrator" : "Це створить каталог зі спільним доступом для всієї команди. Щоби створити каталог команди, сконтактуйте з адміністратором {productName}.",
    "Talk conversation" : "Розмова Talk",
    "New Talk conversation" : "Нова розмова Talk",
    "Conversation name" : "Назва розмови",
    "Collective" : "Колектив",
    "Calendar" : "Календар",
    "New calendar" : "Новий календар",
    "Calendar name" : "Назва календаря",
    "Unknown resource type" : "Невідомий тип ресурсу",
    "Team calendar \"{resourceName}\" created and shared with team" : "Календар команди \"{resourceName}\" створено та надано у доступ команді",
    "{resourceType} \"{resourceName}\" created and shared with team" : "{resourceType} \"{resourceName}\" створено та надано доступ команді",
    "A calendar named \"{name}\" already exists. Please choose a different name." : "Календар з назвою \"{name}\" вже існує. Виберіть іншу назву.",
    "Failed to create {resourceType}: {error}" : "Не вдалося створити {resourceType}: {error}",
    "Please select a valid png or jpg file" : "Виберіть дійсний файл PNG або JPG",
    "Error picking team picture" : "Помилка під час вибору зображення команди",
    "Error cropping avatar picture" : "Помилка під час кадрування зображення",
    "An error happened while saving {fields}" : "Під час збереження {fields} сталася помилка",
    "Team name" : "Назва команди",
    "Team owner" : "Власник команди",
    "Upload team picture" : "Завантажити зображення команди",
    "Choose from Nextcloud Files" : "Вибрати з файлів у Nextcloud",
    "Delete picture" : "Вилучити зображення",
    "Edit" : "Редагувати",
    "Request to join" : "Запит на приєднання",
    "Create" : "Створити",
    "Show in Calendar" : "Показувати у календарі",
    "Your request to join this team is pending approval" : "Ваш запит на додавання до команди очікує підтвердження",
    "You are not a member of {circle}" : "Ви є учасником кола {circle}",
    "Members" : "Учасники",
    "Edit team picture" : "Редагувати зображення команди",
    "Apply" : "Застосувати",
    "Confirm" : "Підтвердити",
    "No other contacts available to select as line manager" : "Відсутні контакти для вибору безпосереднього керівника.",
    "Add more info" : "Додати більше даних",
    "More fields" : "Більше полів",
    "Please select a valid format" : "Виберіть дійсний формат",
    "Invalid image" : "Недійсне зображення",
    "Error cropping picture" : "Помилка з обрізанням зображення",
    "Pick an avatar" : "Оберіть аватарку",
    "Pick" : "Вибрати",
    "Error while processing the picture." : "Помилка під час обробки зображення.",
    "Avatar downloaded from social network" : "Аватарку вставлено із соціальної мережі",
    "Avatar already up to date" : "Аватарка є актуальною",
    "Avatar download failed" : "Не вдалося звантажити аватарку",
    "Crop contact photo" : "Обрізати світлину контакту",
    "Upload a new picture" : "Завантажити нове зображення",
    "Choose from Files" : "Вибрати з Файлів",
    "Download picture" : "Звантажити зображення",
    "Clone contact" : "Копіювати контакт",
    "This contact is in read-only mode. You do not have permission to edit this contact." : "Доступ до цього контакту лише у режимі читання. У вас відсутні права на редагування.",
    "The contact you were trying to edit has changed. Please manually refresh the contact. Any further edits will be discarded." : "Дані контакту, який ви намагаєтеся відредагувати, змінено. Будь ласка, оновіть сторінку. Усі подальші зміни буде проігноровано.",
    "Address book" : "Адресна книга",
    "Add contact to Birthday Calendar" : "Додати контакт до календаря днів народжень",
    "Exclude contact from Birthday Calendar" : "Не показувати у календарі",
    "{title} at {organization}" : "{title} у {organization}",
    "Name" : "Ім'я",
    "Syntax error. Cannot open the contact." : "Синтаксична помилка. Неможливо відкрити контакт.",
    "The contact does not exist on the server anymore." : "Цей контакт більше не доступний на цьому сервері.",
    "Unable to retrieve the contact from the server, please check your network connection." : "Неможливо отримати контакт з сервера, будь ласка, перевірте ваше мережеве з'єднання.",
    "An error occurred while trying to move the contact" : "Помилка під час переміщення контакту",
    "An error occurred while trying to copy the contact" : "Помилка під час копіювання контакту",
    "Unable to update contact" : "Не вдалося оновити контакт",
    "No contact selected" : "Контакт не вибрано",
    "Select a contact on the list to begin" : "Для початку оберіть контакт зі списку",
    "Title" : "Заголовок",
    "Company" : "Компанія",
    "Go to talk conversation" : "Перейти до розмви у Talk",
    "View profile" : "Переглянути профіль",
    "This contact was broken and received a fix. Please review the content and click here to save it." : "Дані цього контакту було пошкоджено та виправлено. Будь ласка, перегляньте вміст та натисніть тут, щоби зберегти їх.",
    "Edit profile" : "Редагувати профіль",
    "Generate QR Code" : "Створити QR-код",
    "Contact vCard as QR code" : "Контактна vCard у вигляді QR-коду",
    "Select address book" : "Виберіть адресну книгу",
    "Media shares with you" : "Медійні матер'яли, якими поділілися з вами",
    "Talk conversations with you" : "Розмови Talk з вами",
    "Calendar events with you" : "Календарні події з вами",
    "Deck cards with you" : "Картки Deck з вами",
    "No shared items with this contact" : "Відсутні спільні ресурси",
    "This contact cannot be moved" : "Цей контакт неможливо перемістити",
    "This contact cannot be grouped" : "Цей контакт неможливо додати до групи",
    "Add contacts to groups" : "Додати контакти до групи",
    "Move contacts to addressbook" : "Перемістити контакти до адресної книги",
    "Select groups" : "Вибрати групи",
    "Select addressbook" : "Вибрати адресну книгу",
    "Selected contacts" : "Вибрані контакти",
    "Please note that only {count} of the {total} contacts can be added to a group" : "Зауважте, що лише {count} із {total} контактів можна додати до групи.",
    "Please note that only {count} of the {total} contacts can be moved" : "Зауважте, що лише {count} із {total} контактів можна перемістити",
    "Move" : "Move",
    "Unselect {name}" : "Зняти вибір {name}",
    "Select {name}" : "Вибрати {name}",
    "Could not update favorite status" : "Не вдалося оновити статус із зірочкою",
    "from {addressbook}" : "з {addressbook}",
    "Remove from favorites" : "Прибрати зірочку",
    "Add to favorites" : "Додати зірочку",
    "Confirm merging contacts" : "Підтвердити об'єднання контактів",
    "The selected contacts have conflicting information. Choose which information to keep" : "Вибрані контакти містять суперечливу інформацію. Виберіть, яку інформацію зберегти.",
    "Contacts can be merged" : "Контакти можна об'єднати",
    "Groups" : "Групи",
    "Select groups to add the merged contact to" : "Виберіть групи, до яких потрібно додати об'єднаний контакт",
    "Merge contacts" : "Об'єднати контакти",
    "_Delete {number} contact_::_Delete {number} contacts_" : ["Вилучити {number} контакт","Вилучити {number} контакти","Вилучити {number} контактів","Вилучити {number} контактів"],
    "Please select at least one editable contact to delete" : "Виберіть щонайменше один контакт, який ви бажаєте вилучити",
    "Please select two editable contacts to merge" : "Виберіть два редаговані контакти для об'єднання",
    "_Add {number} contact to group_::_Add {number} contacts to group_" : ["Додати {number} контакт до групи","Додати {number} контакти до групи","Додати {number} контактів до групи","Додати {number} контактів до групи"],
    "Please select at least one editable contact to add to a group" : "Виберіть щонайменше один контакт, який можна редагувати, який потрібно додати до групи",
    "_Move {number} contact to addressbook_::_Move {number} contacts to addressbook_" : ["Перемістити {number} контакт до адресної книги","Перемістити {number} контакти до адресної книги","Перемістити {number} контактів до адресної книги","Перемістити {number} контактів до адресної книги"],
    "Please select at least one editable contact to move to an addressbook" : "Виберіть щонайменше один контакт, який можна редагувати, який потрібно перемістити до адресної книги",
    "Are you sure you want to proceed?" : "Дійсно продовжити?",
    "Add contacts to group" : "Додати контакти до групи",
    "Search contacts …" : "Пошук контактів …",
    "Unselect {number}" : "Зняти виділення {number}",
    "Add to {group}" : "Додати до {group}",
    "Add members to {group}" : "Додати учасників до {group}",
    "Please note that you can only add contacts from writable address books to contact groups. Contacts from read-only address books, such as the system address book, cannot be added." : "Зауважте, можна додавати контакти тільки з адресних книг, відкритих на запис, до груп контактів. Контакти з адресних книг, до яких є доступ тільки для читання, напр., системна адресна книга, неможливо додати.",
    "Remove {type}" : "Вилучити {type}",
    "Add to group" : "Додати до групи",
    "Add members to group" : "Додатии учасників до групи",
    "Search {types}" : "Шукати {types}",
    "Add guest" : "Додати гостя",
    "Search for people to add" : "Шукати контакти для додавання",
    "No results" : "Немає результатів",
    "Add {type}" : "Додати {type}",
    "New team name" : "Нова назва команди",
    "Personal team" : "Приватна команда",
    "This team will only be visible to you. Other members will not be able to see or use it." : "Ця команда буде доступна тільки для вас. Решта учасників не побачать її та не зможуть її використовувати.",
    "Local team" : "Локальна команда",
    "This team will not be shared with the other instances of the global scale" : "Цієї командою не можна буде поділитися з іншими хмарними примірниками у разі налаштованого глобального режиму спільного доступу.",
    "Create team" : "Створити команду",
    "Promote as sole owner" : "Зробити єдиним власником",
    "Promote to {level}" : "Підвищити до рівня {level}",
    "Demote to {level}" : "Понизити до рівня {level}",
    "Are you sure you want to leave this team? This action cannot be undone." : "Дійсно залишити цю команду? Цю дію неможливо буде скасувати.",
    "Leave team failed." : "Не вдалося вийти з команди.",
    "Could not delete the member {displayName}" : "Неможливо вилучити учасника {displayName}",
    "Could not change the member level to {level}" : "Неможливо змінити рівень участи до {level}",
    "Could not accept membership request" : "Неможливо прийняти запит на участь",
    "Accept membership request" : "Прийняти запит на участь",
    "Reject membership request" : "Відхилити запит на участь",
    "Manage level" : "Рівень керування",
    "Remove member" : "Вилучити учасника",
    "Unable to get the results" : "Неможливо отримати результати",
    "Some members could not be added" : "Неможливо додати окремих учасників",
    "There was an issue adding members to the team" : "Помилка під час додавання учасників до цієї команди",
    "Loading members list …" : "Завантаження списку учасників …",
    "The list of members is only visible to members of this team" : "Перелік учасників доступний лише учасникам цієї команди",
    "You currently have no access to the member list" : "Зараз у ас відсутній доступ до списку учасників",
    "Add to {team}" : "Додати до {team}",
    "Invite members to {team}" : "Запросити учасників до {team}",
    "Pending" : "Очікування",
    "Accept" : "Прийняти",
    "Select chart …" : "Виберіть діаграму …",
    "Chart" : "Діаграма",
    "Select type" : "Виберіть вид",
    "Add contact in group" : "Додати контакт до групи",
    "None" : "Відсутній",
    "copy" : "копіювати",
    "Select option" : "Виберіть",
    "JavaScript URIs are not allowed" : "URI Javascript не дозволено",
    "Notes" : "Примітки",
    "send an email" : "надіслати ел. пошту",
    "Personal dates" : "Приватні дати",
    "Add property of this type" : "Додайте властивості такого типу",
    "Member" : "Учасник",
    "This is a read-only group managed by administrators. Group members can only view this group." : "Це група з правами для читання, якою керують адміністратори. Учасники групи можуть лише переглядати цю групу.",
    "Unable to create the contact." : "Неможливо створити контакт.",
    "Contact not found" : "Контакт не знайдено",
    "Address book {addressbook} not found" : "Адресну книгу {addressbook} не знайдено",
    "Group {group} not found" : "Групу {group} не знайдено",
    "Add member" : "Додати учасника",
    "New contact" : "Новий контакт",
    "_{success} contact added to {name}_::_{success} contacts added to {name}_" : ["{success} контакт додано до {name}","{success} контакти додано до {name}","{success} контактів додано до {name}","{success} контактів додано до {name}"],
    "_Adding {success} contact to {name}_::_Adding {success} contacts to {name}_" : ["Додавання {success} контакту до {name}","Додавання {success} контактів до {name}","Додавання {success} контактів до {name}","Додавання {success} контактів до {name}"],
    "_{count} error_::_{count} errors_" : ["{count} помилку","{count} помилки","{count} помилок","{count} помилок"],
    "_Importing %n contact into {addressbook}_::_Importing %n contacts into {addressbook}_" : ["Імпорт %n контакту до {addressbook}","Імпорт %n контактів до {addressbook}","Імпорт %n контактів до {addressbook}","Імпорт %n контактів до {addressbook}"],
    "_Done importing %n contact into {addressbook}_::_Done importing %n contacts into {addressbook}_" : ["Виконано імпорт %n контакту до {addressbook}","Виконано імпорт %n контактів до {addressbook}","Виконано імпорт %n контактів до {addressbook}","Виконано імпорт %n контактів до {addressbook}"],
    "No data for this contact" : "Відсутні дані для цього контакту",
    "No data for this contact on their profile" : "Відсутні дані для цього контакту для їхнього профілю",
    "Import" : "Імпорт",
    "Are you sure you want to import this contact file?" : "Дійсно імпортувати цей файл з контактами?",
    "Could not copy" : "Неможливо скопіювати",
    "Join team" : "Долучитися до команди",
    "You are about to leave {circle}.\nAre you sure?" : "Ви збираєтеся залишити коло {circle}.\nПродовжити?",
    "Please confirm team leave" : "Підтвердіть, що ви виходите із команди",
    "Could not leave the team {displayName}" : "Не вдалося вийти із команди {displayName}",
    "Unable to join the team" : "Не вдалося долучитися до команди",
    "You are about to delete {circle}.\nAre you sure?" : "Ви намагаєтеся вилучити коло {circle}.\nПродовжити?",
    "Please confirm team deletion" : "Підтвердіть вилучення команди",
    "Unable to delete the team" : "Не вдалося вилучити команду",
    "Confirm enabling federation" : "Підтвердити увімкнення контактів для об'єднаних хмар",
    "Enabling this will prevent {circle} from being a member of other teams.\nAre you sure?" : "Після увімкнення {circle} не буде учасником інших команд.\nДійсно продовжити? ",
    "Enable federation" : "Увімкнути контакти для об'єднаних хмар",
    "Link copied to the clipboard" : "Посилання скопійовано до буфера обміну",
    "Could not copy link to the clipboard." : "Неможливо скопіювати посилання до буфера обміну",
    "Not grouped" : "Поза групами",
    "Create your own teams for sharing. Add Nextcloud users, contacts, or anyone via email." : "Створюйте власні команди для спільної роботи. Додавайте до команд користувачів Nextcloud, ваші контакти або будь-кого через ел. пошту.",
    "Team" : "Команда",
    "User" : "Користувач",
    "Group" : "Група",
    "Email" : "Ел.пошта",
    "Contact" : "Контакт",
    "Moderator" : "Модератор",
    "Admin" : "Адміністратор",
    "Owner" : "Власник",
    "Invites" : "Запрошення",
    "Anyone can request membership" : "Будь-хто може надіслати запит на участь",
    "Members need to accept invitation" : "Учасники мають прийняти запрошення",
    "Memberships must be confirmed/accepted by a Moderator (requires \"Anyone can request membership\")" : "Участь має бути підтверджено/прийнято модератором (вимагає параметру \"Будь-хто може надіслати запит на участь\")",
    "Members can also invite" : "Учасники також можуть запрошувати",
    "Membership" : "Членство",
    "Prevent teams from being a member of another team" : "Заборонити командам бути учасниками інших команд",
    "Federation" : "Об'єднані хмари",
    "Allow federated members" : "Додати учасників об'єднаних хмар",
    "Privacy" : "Конфіденційність",
    "Visible to everyone" : "Видно для всіх",
    "users" : "користувачі",
    "Users" : "Користувачі",
    "groups" : "групи",
    "federated users" : "користувачі з об'єднаних хмар",
    "Federated users" : "Користувачі з об'єднаних хмар",
    "teams" : "команди",
    "email addresses" : "адреси ел. пошти",
    "Email addresses" : "Адреси ел. пошти",
    "contacts" : "контакти",
    "Detailed name" : "Повне ім'я",
    "Additional names" : "Додаткові імена",
    "Prefix" : "Префікс",
    "Suffix" : "Суфікс",
    "Nickname" : "Прізвисько",
    "Website" : "Вебсайт",
    "Location" : "Розташування",
    "Federated Cloud ID" : "Ідентифікатор хмари",
    "Home" : "Дім",
    "Work" : "Робочий",
    "Other" : "Інше",
    "Address" : "Адреса",
    "Post office box" : "Аб.скринька",
    "Extended address" : "Розширена адреса",
    "City" : "Місто",
    "State or province" : "Область або регіон",
    "Postal code" : "Поштовий індекс",
    "Country" : "Країна",
    "Birthday" : "Дата народження",
    "Place of birth" : "Місце народження",
    "Anniversary" : "Річниця",
    "Date of death" : "Дата смерти",
    "Place of death" : "Місце смерти",
    "Instant messaging" : "Месенджер",
    "Phone" : "Телефон",
    "Mobile" : "Мобільний",
    "Work mobile" : "Роб. мобільний",
    "Home mobile" : "Дом. мобільний",
    "Fax" : "Факс",
    "Fax home" : "Дом. факс",
    "Fax work" : "Роб. факс",
    "Pager" : "Пейджер",
    "Voice" : "Голос",
    "Car" : "В автомобілі",
    "Work pager" : "Роб. пейджер",
    "Line manager" : "Безпосередній керівник",
    "Social network" : "Сторінка у соціальній мережі",
    "Relationship to you" : "Взаємини з вами",
    "Spouse" : "Чоловік/дружина",
    "Child" : "Дитина",
    "Mother" : "Мати",
    "Father" : "Батько",
    "Parent" : "Батьки",
    "Brother" : "Брат",
    "Sister" : "Сестра",
    "Relative" : "Родина",
    "Friend" : "Друг",
    "Colleague" : "Колега",
    "Assistant" : "Асистент",
    "Related contacts" : "Пов'язані контакти",
    "Agent" : "Агент",
    "Emergency" : "У разі небезпеки",
    "Co-worker" : "Колега",
    "Gender" : "Стать",
    "Female" : "Жінка",
    "Male" : "Чоловік",
    "Unknown" : "Невідомо",
    "Time zone" : "Часова зона",
    "Spoken languages" : "Мови",
    "_{failed} contact failed to be read_::_{failed} contacts failed to be read_" : ["{failed} контакт не прочитано","{failed} контактів не прочитано","{failed} контактів не прочитано","{failed} контактів не прочитано"],
    "An error has occurred in team(s). Check the console for more details." : "Помилка з командою(-ами). Перевірте консоль для отримання докладної інформації.",
    "Unable to create team {circleName}" : "Не вдалося створити команду {circleName}",
    "Unable to delete team {circleId}" : "Не вдалося вилучити команду {circleId}",
    "Could not update favorite state" : "Не вдалося оновити статус із зірочкою",
    "Unable to delete contact" : "Неможливо вилучити контакт",
    "Value copied to the clipboard" : "Значення скопійовано до буфера обміну",
    "Could not copy value to the clipboard." : "Не вдалося скопіювати значення до буфера обміну",
    "Deck board" : "Дошка",
    "New Deck board" : "Нова дошка",
    "Board name" : "Назва дошки",
    "Deck app is not installed. Please install it to create team boards." : "Застосунок Deck не встановлено. Встановіть його, щоби створювати дошки команди.",
    "Pick an address book" : "Виберіть адресну книгу",
    "Select Date" : "Вкажіть дату",
    "note" : "примітка",
    "email" : "ел. пошта",
    "Create your own groups for sharing. Add Nextcloud users, contacts, or anyone via email." : "Створюйте власні групи для спільної роботи. Додавайте до груп користувачів Nextcloud, ваші контакти або будь-кого через ел. пошту."
},
"nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");
