OC.L10N.register(
    "contacts",
    {
    "Import contacts" : "Kter inermisen",
    "Details" : "Talqayt",
    "Contacts" : "Inermisen",
    "Teams" : "Tirebbuyaɛ",
    "Add contacts" : "Rnu inermisen",
    "Delete team" : "Sefsex tarbaɛt",
    "General" : "Amatu",
    "Rename" : "Beddel isem",
    "Export" : "Sifeḍ",
    "Send email" : "Azen imayl",
    "Delete" : "Kkes",
    "Copied" : "Yettwanɣel",
    "Copy link" : "Nɣel aseɣwen",
    "Download" : "Sider",
    "Show" : "Sken-d",
    "Cancel" : "Sefsex",
    "Add" : "Rnu",
    "First name" : "Isem amezwaru",
    "Last name" : "Isem twacult",
    "Display name" : "Isem ara d-yettwaskanen",
    "Last modified" : "Asnifel aneggaru",
    "Save" : "Sekles",
    "Close" : "Mdel",
    "Folder" : "Akaram",
    "New folder" : "Akaram amaynut",
    "Folder name" : "Isem n ukaram",
    "Conversation name" : "Isem n udiwenni",
    "Calendar" : "Awitay",
    "Edit" : "Ẓreg",
    "Request to join" : "Asuter i tmerna",
    "Create" : "Snulfu-d",
    "Members" : "Imedrawen",
    "Apply" : "Snes",
    "Confirm" : "Serggeg",
    "Pick" : "Fren",
    "Choose from Files" : "Fren seg yifuyla",
    "Name" : "Nom",
    "Title" : "Azwel",
    "Company" : "Taṛmist",
    "Edit profile" : "Ẓreg amaɣnu",
    "Move" : "Smutti",
    "Remove from favorites" : "Remove from favorites",
    "Add to favorites" : "Rnu ar ismenyifen",
    "Groups" : "Igrawen",
    "Merge contacts" : "Smezdi inermisen",
    "Add to group" : "Rnu-t ɣer ugraw",
    "No results" : "Ulac igmad",
    "Pending" : "Yegguni",
    "Chart" : "Ameskan",
    "Select type" : "Fren anaw",
    "None" : "Ula d yiwen",
    "copy" : "nɣel",
    "Notes" : "Tizmilin",
    "Member" : "Aεeggal",
    "Contact not found" : "Ur yettwaf ara unermis",
    "New contact" : "Anermis amaynut",
    "Import" : "Kter",
    "Team" : "Tarbaɛt",
    "User" : "Aseqdac",
    "Group" : "Agraw",
    "Email" : "Imayl",
    "Contact" : "Anermes",
    "Moderator" : "Aseɣyad",
    "Admin" : "Anedbal",
    "Owner" : "Amli",
    "Invites" : "Inced-d",
    "Membership" : "Altaɣ",
    "Privacy" : "Tabaḍnit",
    "Users" : "Iseqdacen",
    "groups" : "igrawen",
    "Email addresses" : "Tansiwin n yimayl",
    "contacts" : "inermisen",
    "Prefix" : "Azwir",
    "Suffix" : "Adfir",
    "Nickname" : "Tasaẓlut",
    "Website" : "Asmel web",
    "Location" : "Adig",
    "Home" : "Asnubeg",
    "Work" : "Amahil",
    "Other" : "Ayen nniḍen",
    "Address" : "Adresse",
    "Post office box" : "Tanaka n lpusṭa",
    "City" : "Tiɣremt",
    "Postal code" : "Tangalt n lbuṣṭa",
    "Country" : "Tamurt",
    "Birthday" : "Azemz n tlalit",
    "Anniversary" : "Amulli",
    "Phone" : "Tiliɣri",
    "Mobile" : "Aziraz",
    "Fax" : "Faks",
    "Pager" : "Pager",
    "Voice" : "Taɣect",
    "Car" : "Takeṛṛust",
    "Child" : "Aqrur",
    "Mother" : "Yemma",
    "Father" : "Baba",
    "Parent" : "Amarraw",
    "Brother" : "Gma",
    "Sister" : "Weltma",
    "Relative" : "Amassaɣ",
    "Friend" : "Amdakkel",
    "Assistant" : "Tallalt",
    "Agent" : "Ameggi",
    "Emergency" : "Amerwas",
    "Gender" : "Taswit",
    "Female" : "Tawtemt",
    "Male" : "Awtem",
    "Unknown" : "Arussin",
    "Time zone" : "Tamnaḍt tasragant",
    "note" : "tazmilt",
    "email" : "imayl"
},
"nplurals=2; plural=(n != 1);");
