OC.L10N.register(
    "contacts",
    {
    "Import contacts" : "Importar contactos",
    "Details" : "Detalles",
    "All contacts" : "Todos los contactos",
    "_Imported %n contact_::_Imported %n contacts_" : ["%n contacto importado","%n contactos importados","%n contactos importados"],
    "_(skipped %n contact)_::_(skipped %n contacts)_" : ["(%ncontacto omitido)","(%ncontactos omitidos)","(%ncontactos omitidos)"],
    "Contacts" : "Contactos",
    "A contacts app for Nextcloud" : "Una app de contactos para Nextcloud.",
    "The Nextcloud contacts app is a user interface for Nextcloud's CardDAV server. Easily sync contacts from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Currently Mail and Calendar – more to come.\n* 🎉 **Never forget a birthday!** You can sync birthdays and other recurring events with your Nextcloud Calendar.\n* 👥 **Sharing of Adressbooks!** You want to share your contacts with your friends or coworkers? No problem!\n* 🙈 **We’re not reinventing the wheel!** Based on the great and open SabreDAV library." : "La app de Contactos de Nextcloud es una interfaz de usuario para el servidor CardDAV de Nextcloud. Sincroniza fácilmente los contactos de varios dispositivos con tu Nextcloud y edítalos en línea\n\n* 🚀 **Integración con otras apps de Nextcloud.** Actualmente Correo y Calendario; más por llegar.\n* 🎉 **No olvides nunca un calendario.** Puedes sincronizar los calendarios y otros eventos recurrentes con tu calendario de Nextcloud.\n* 👥 **Compartir libretas de dirección.** ¿Quieres compartir tus contactos con tus amigos y colegas? ¡No hay problema!\n* 🙈 **No reinventamos la rueda.l** Basada en la gran biblioteca de código abierto SabreDAV.",
    "Copy to full name" : "Copiar al nombre completo",
    "Omit year" : "Omitir el año",
    "Allow updating avatars from social media" : "Permitir la actualización de avatares desde medios sociales",
    "Organization chart" : "Organigrama de la organización",
    "There was an error fetching the member list" : "Ha ocurrido un error al recuperar la lista de miembros",
    "Teams" : "Equipos",
    "Please select a team" : "Por favor, seleccione un equipo",
    "Loading team…" : "Cargando equipo…",
    "Loading contacts …" : "Cargando contactos…",
    "There are no contacts yet" : "Aún no hay contactos",
    "Create contact" : "Crear contacto",
    "There are no contacts in this group" : "No hay contactos en este grupo",
    "Create contacts" : "Crear contactos",
    "Add contacts" : "Añadir contactos",
    "Retry" : "Reintentar",
    "Loading …" : "Cargando…",
    "Manage team" : "Gestionar equipo",
    "Leave team" : "Abandonar equipo",
    "Delete team" : "Eliminar equipo",
    "Setting saved" : "Configuración guardada",
    "Failed to save setting" : "Fallo al guardar la configuración",
    "Contacts settings" : "Ajustes de contactos",
    "General" : "General",
    "Update avatars from social media" : "Actualizar avatares desde redes sociales",
    "Refreshed once per week" : "Refrescado una vez por semana",
    "Address books" : "Libretas de direcciones",
    "Rename" : "Cambiar nombre",
    "Export" : "Exportar",
    "Send email" : "Enviar correo electrónico",
    "Send email as BCC" : "Enviar correo como CCO",
    "Delete" : "Eliminar",
    "Show all groups" : "Mostrar todos los grupos",
    "Collapse groups" : "Colapsar grupos",
    "Show all teams" : "Mostrar todos los equipos",
    "Collapse teams" : "Colapsar equipos",
    "Group name cannot be empty" : "El nombre del grupo no puede estar vacío",
    "This group already exists" : "Este grupo ya existe",
    "An error occurred while creating the group" : "Ha ocurrido un error al crear el grupo",
    "This team already exists" : "Este equipo ya existe",
    "An error happened during the creation of the team" : "Ocurrió un error mientras se creaba el equipo",
    "Recently contacted" : "Contactados recientemente",
    "Contact groups" : "Grupos de contactos",
    "Create a new contact group" : "Crear un nuevo grupo de contactos",
    "Contact group name" : "Nombre del grupo de contactos",
    "Create a new team" : "Crear equipo nuevo",
    "Open the contacts app settings" : "Abrir las ajustes de la aplicación Contactos",
    "_Shared with {num} entity_::_Shared with {num} entities_" : ["Compartido con {num} entidad","Compartido con {num} entidades","Compartido con {num} entidades"],
    "Copied" : "Copiado",
    "Cannot copy" : "No se ha podido copiar",
    "Copy link" : "Copiar enlace",
    "Toggling of address book was not successful" : "El cambio de la libreta de direcciones falló",
    "This will delete the address book and every contacts within it" : "Esto eliminará la libreta de direcciones y todos los contactos que hay en ella",
    "Delete {addressbook}?" : "¿Eliminar {addressbook}?",
    "This will unshare the address book and every contacts within it" : "Esto causará que la libreta de direcciones se deje de compartir, así como cualquier contacto en ella",
    "Unshare {addressbook}?" : "¿Dejar de compartir {addressbook}?",
    "Deletion of address book was not successful." : "El borrado de la libreta de direcciones falló.",
    "Renaming of address book was not successful." : "El renombrado de la libreta de direcciones falló.",
    "{addressbookname} (Hidden)" : "{addressbookname} (oculto)",
    "Download" : "Descargar",
    "Show" : "Mostrar",
    "Unshare from me" : "Dejar de compartir conmigo",
    "_%n contact_::_%n contacts_" : ["%n contacto","%n contactos","%n contactos"],
    "_%n group_::_%n groups_" : ["%n grupo","%n grupos","%n grupos"],
    "Share with users or groups" : "Compartir con otros usuarios o grupos",
    "Share with users" : "Compartir con los usuarios",
    "No users or groups" : "No hay usuarios ni grupos.",
    "Unable to delete the share" : "No se ha podido eliminar el recurso compartido",
    "Unable to change permissions" : "No se han podido cambiar los permisos",
    "can create and edit" : "puede crear y editar",
    "Choose a vCard file to import" : "Elija un archivo vCard para importar",
    "Import into the {addressbookName} address book" : "Importar en la libreta de direcciones {addressbookName}",
    "Select local file" : "Selecciona archivo local",
    "Import from files" : "Importar desde archivos",
    "Importing is disabled because there are no address books available" : "Importar está desactivado porque no hay libretas de direcciones disponibles",
    "An error occurred, unable to create the address book" : "Ha ocurrido un error, no se ha podido crear la libreta de direcciones",
    "New address book" : "Nueva libreta de contactos",
    "Add new address book" : "Agregar nueva libreta de direcciones",
    "Cancel" : "Cancelar",
    "Add" : "Añadir",
    "First name" : "Nombre",
    "Last name" : "Apellido",
    "Phonetic first name" : "Nombre fonético",
    "Phonetic last name" : "Apellido fonético",
    "Display name" : "Nombre mostrado",
    "Last modified" : "Última modificación",
    "Sort contacts by" : "Ordenar contactos por",
    "Manages" : "Gestiona",
    "Oversees" : "Vigila",
    "An error happened during the config change" : "Ha ocurrido un error durante el cambio de la configuración",
    "Enforce password protection on files shared to this team" : "Implantar la protección con contraseña en los archivos compartidos en este equipo",
    "Use a unique password for all shares to this team" : "Utilizar una contraseña única para todos los recursos compartidos en este equipo",
    "Unique password …" : "Contraseña única…",
    "Save" : "Guardar",
    "Change unique password" : "Cambiar la contraseña única",
    "Failed to save password. Please try again later." : "Fallo al guardar la contraseña. Por favor, inténtelo de nuevo más tarde.",
    "Close" : "Cerrar",
    "There is no description for this team" : "No hay descripción para este equipo",
    "Enter a description for the team" : "Ingrese una descripción para el equipo",
    "Folder" : "Carpeta",
    "New folder" : "Nueva carpeta",
    "Folder name" : "Nombre de la carpeta",
    "This will create a regular folder shared with the team. To create a Team Folder, please contact your {productName} administrator" : "Esto creará una carpeta normal compartida con el equipo. Para crear una carpeta de equipo, por favor contacta con tu {productName}administrador",
    "Talk conversation" : "Conversación de Talk",
    "New Talk conversation" : "Nueva conversación de Talk",
    "Conversation name" : "Nombre de la conversación",
    "Collective" : "Colectivo",
    "Calendar" : "Calendario",
    "New calendar" : "Nuevo calendario",
    "Calendar name" : "Nombre del calendario",
    "Unknown resource type" : "Tipo de recurso desconocido",
    "Team calendar \"{resourceName}\" created and shared with team" : "Calendario de equipo «{resourceName}» creado y compartido con el equipo",
    "{resourceType} \"{resourceName}\" created and shared with team" : "{resourceType}\"{resourceName}\" creado y compartido con el equipo",
    "A calendar named \"{name}\" already exists. Please choose a different name." : "Ya existe un calendario llamado «{name}». Por favor, escoge un nombre diferente.",
    "Failed to create {resourceType}: {error}" : "Fallo al crear {resourceType}:{error}",
    "An error happened while saving {fields}" : "Ocurrió un error mientras se guardaba {fields}",
    "Team name" : "Nombre del equipo",
    "Team owner" : "Propietario del equipo",
    "Delete picture" : "Eliminar imagen",
    "Edit" : "Editar",
    "Request to join" : "Solicitar unirse",
    "Create" : "Crear",
    "Show in Calendar" : "Mostrar en calendario",
    "Your request to join this team is pending approval" : "Su solicitud para unirse está en espera de aprobación",
    "You are not a member of {circle}" : "Ud. no es miembro de {circle}",
    "Members" : "Miembros",
    "Confirm" : "Confirmar",
    "Add more info" : "Añadir más información",
    "More fields" : "Mas campos",
    "Please select a valid format" : "Por favor, seleccione un formato válido",
    "Invalid image" : "La imagen no es válida",
    "Error cropping picture" : "Error al recortar la foto",
    "Pick an avatar" : "Escoger un avatar",
    "Pick" : "Elegir",
    "Error while processing the picture." : "Error al procesar la imagen",
    "Avatar downloaded from social network" : "Avatar descargado desde red social",
    "Avatar already up to date" : "Avatar ya actualizado",
    "Avatar download failed" : "Descarga del avatar fallido",
    "Crop contact photo" : "Recortar foto del contacto",
    "Upload a new picture" : "Subir una imagen nueva",
    "Choose from Files" : "Escoger desde Archivos",
    "Download picture" : "Descargar imagen",
    "Clone contact" : "Clonar contacto",
    "This contact is in read-only mode. You do not have permission to edit this contact." : "El contacto está en modo de sólo lectura. No tiene permiso para editar este contacto.",
    "The contact you were trying to edit has changed. Please manually refresh the contact. Any further edits will be discarded." : "El contacto que estaba intentando editar ha cambiado, Por favor, actualice el contacto manualmente. Cualquier otra edición será descartada.",
    "Address book" : "Libreta de direcciones",
    "Add contact to Birthday Calendar" : "Añadir contacto al calendario de Cumpleaños",
    "Exclude contact from Birthday Calendar" : "Excluir contacto del calendario de Cumpleaños",
    "{title} at {organization}" : "{title} en {organization}",
    "Name" : "Nombre",
    "Syntax error. Cannot open the contact." : "Error de sintaxis. No se puede abrir el contacto",
    "The contact does not exist on the server anymore." : "El contacto ya no existe en el servidor.",
    "Unable to retrieve the contact from the server, please check your network connection." : "Imposible recibir el contacto del servidor, por favor comprueba tu conexión de red.",
    "An error occurred while trying to move the contact" : "Ocurrió un error intentando mover el contacto",
    "An error occurred while trying to copy the contact" : "Ocurrió un error intentando copiar el contacto",
    "Unable to update contact" : "No fue posible actualizar el contacto",
    "No contact selected" : "No hay contactos seleccionados",
    "Select a contact on the list to begin" : "Seleccione un contacto de la lista para comenzar",
    "Title" : "Título",
    "Company" : "Compañía",
    "Go to talk conversation" : "Ir a la conversación de talk",
    "View profile" : "Ver perfil",
    "This contact was broken and received a fix. Please review the content and click here to save it." : "Este contacto estaba dañado y se ha reparado. Por favor, revise el contenido y haga clic aquí para guardarlo.",
    "Edit profile" : "Editar perfil",
    "Generate QR Code" : "Generar código QR",
    "Contact vCard as QR code" : "Contacto vCard como código QR",
    "Select address book" : "Selecciona una libreta de direcciones",
    "Media shares with you" : "Recursos multimedia compartidos con Ud.",
    "Talk conversations with you" : "Conversaciones de Talk con Ud.",
    "Calendar events with you" : "Eventos de calendario con Ud.",
    "Deck cards with you" : "Tarjetas de Deck con Ud.",
    "No shared items with this contact" : "No hay recursos compartidos con este contacto",
    "This contact cannot be moved" : "Este contacto no se puede mover",
    "This contact cannot be grouped" : "Este contacto no se puede agrupar",
    "Add contacts to groups" : "Añadir contactos a grupos",
    "Move contacts to addressbook" : "Mover contactos a libreta de direcciones",
    "Select groups" : "Seleccionar grupos",
    "Select addressbook" : "Seleccionar libreta de contactos",
    "Selected contacts" : "Contactos seleccionados",
    "Please note that only {count} of the {total} contacts can be added to a group" : "Solo {count}de {total}contactos pueden ser añadidos al grupo",
    "Please note that only {count} of the {total} contacts can be moved" : "Solo {count}de{total}contactos se pueden mover",
    "Move" : "Mover",
    "from {addressbook}" : "de {addressbook}",
    "Remove from favorites" : "Quitar de favoritos",
    "Add to favorites" : "Add to favorites",
    "Confirm merging contacts" : "Confirmar la combinación de los contactos",
    "The selected contacts have conflicting information. Choose which information to keep" : "Los contactos seleccionados tienen información conflictiva. Escoja la información a conservar",
    "Contacts can be merged" : "Los contactos pueden ser combinados",
    "Groups" : "Grupos",
    "Select groups to add the merged contact to" : "Seleccione los grupos a los que se añadirá el contacto combinado",
    "Merge contacts" : "Combinar contactos",
    "_Delete {number} contact_::_Delete {number} contacts_" : ["Eliminar {number} contacto","Eliminar {number} contactos","Eliminar {number} contactos"],
    "Please select at least one editable contact to delete" : "Por favor, seleccione al menos un contacto editable a eliminar",
    "Please select two editable contacts to merge" : "Por favor, seleccione dos contactos editables a combinar",
    "_Add {number} contact to group_::_Add {number} contacts to group_" : ["Añadir {number} contacto al grupo","Añadir {number} contactos al grupo","Añadir {number} contactos al grupo"],
    "Please select at least one editable contact to add to a group" : "Por favor, selecciona al menos un contacto editable para añadir al grupo",
    "_Move {number} contact to addressbook_::_Move {number} contacts to addressbook_" : ["Mover {number} contacto a la libreta","Mover {number} contactos a la libreta","Mover {number} contactos a la libreta"],
    "Please select at least one editable contact to move to an addressbook" : "Por favor selecciona al menos un contacto editable para mover a una agenda",
    "Are you sure you want to proceed?" : "¿Está seguro de proceder?",
    "Add contacts to group" : "Añadir contactos a grupo",
    "Search contacts …" : "Buscar contactos ..",
    "Unselect {number}" : "De-seleccionar {number}",
    "Add to {group}" : "Añadir a {group}",
    "Add members to {group}" : "Añadir miembros a {group}",
    "Please note that you can only add contacts from writable address books to contact groups. Contacts from read-only address books, such as the system address book, cannot be added." : "Por favor, tenga en cuenta que solo puede agregar contactos desde las libretas de direcciones a las que puede escribir a los grupos de contactos. Los contactos de las libretas de direcciones de sólo lectura, tales como la libreta de direcciones del sistema, no pueden ser añadidos.",
    "Remove {type}" : "Eliminar {type}",
    "Add to group" : "Añadir a grupo",
    "Add members to group" : "Añadir miembros al grupo",
    "Search {types}" : "Buscar en {types}",
    "Add guest" : "Añadir invitado",
    "Search for people to add" : "Buscar personas para añadir",
    "No results" : "Sin resultados",
    "Add {type}" : "Añadir {type}",
    "New team name" : "Nombre nuevo para el equipo",
    "Personal team" : "Equipo personal",
    "This team will only be visible to you. Other members will not be able to see or use it." : "Este equipo solo será visible para Ud. Otros miembros no podrán utilizarlo o verlo.",
    "Local team" : "Equipo local",
    "This team will not be shared with the other instances of the global scale" : "Este equipo no será compartido con otras instancias de la escala global",
    "Create team" : "Crear equipo",
    "Promote as sole owner" : "Promover como único propietario",
    "Promote to {level}" : "Promover a {level}",
    "Demote to {level}" : "Degradar a {level}",
    "Are you sure you want to leave this team? This action cannot be undone." : "¿Está seguro de abandonar este equipo? Esta acción no se puede deshacer.",
    "Leave team failed." : "Fallo al abandonar equipo.",
    "Could not delete the member {displayName}" : "No se ha podido eliminar el miembro {displayName}",
    "Could not change the member level to {level}" : "No se ha podido modificar el nivel del miembro a {level}",
    "Could not accept membership request" : "No se ha podido aceptar la solicitud de membresía",
    "Accept membership request" : "Aceptar solicitud de membresía",
    "Reject membership request" : "Rechazar solicitud de membresía",
    "Manage level" : "Administrar el nivel",
    "Remove member" : "Eliminar miembro",
    "Unable to get the results" : "No se pudieron obtener los resultados",
    "Some members could not be added" : "Algunos miembros no se han podido añadir",
    "There was an issue adding members to the team" : "Ocurrió un problema al añadir miembros al equipo",
    "Loading members list …" : "Cargando lista de miembros  …",
    "The list of members is only visible to members of this team" : "La lista de miembros solo es visible para los miembros de este equipo",
    "You currently have no access to the member list" : "Actualmente no tiene acceso a la lista de miembros",
    "Add to {team}" : "Añadir a {team}",
    "Invite members to {team}" : "Invitar a miembros a {team}",
    "Pending" : "Pendiente",
    "Accept" : "Aceptar",
    "Select chart …" : "Seleccionar organigrama …",
    "Chart" : "Organigrama",
    "Select type" : "Selecciona tipo",
    "Add contact in group" : "Añadir contacto en grupo",
    "None" : "Ninguno",
    "copy" : "copiar",
    "Select option" : "Selecciona opción",
    "Notes" : "Notas",
    "send an email" : "enviar correo electrónico",
    "Personal dates" : "Fechas personales",
    "Add property of this type" : "Añadir una propiedad de este tipo",
    "Member" : "Miembro",
    "This is a read-only group managed by administrators. Group members can only view this group." : "Este es un grupo de sólo lectura gestionado por los administradores. Los miembros del grupo solo pueden ver este grupo.",
    "Unable to create the contact." : "No se ha podido crear el contacto.",
    "Contact not found" : "Contacto no encontrado",
    "Group {group} not found" : "Grupo {group} no encontrado",
    "Add member" : "Añadir miembro",
    "New contact" : "Nuevo contacto",
    "_{success} contact added to {name}_::_{success} contacts added to {name}_" : ["{success} contacto añadido a {name}","{success} contactos añadidos a {name}","{success} contactos añadidos a {name}"],
    "_Adding {success} contact to {name}_::_Adding {success} contacts to {name}_" : ["Añadiendo {success} contacto a {name}","Añadiendo {success} contactos a {name}","Añadiendo {success} contactos a {name}"],
    "_{count} error_::_{count} errors_" : ["{count} error","{count} errores","{count} errores"],
    "_Importing %n contact into {addressbook}_::_Importing %n contacts into {addressbook}_" : ["Importando %n contacto en {addressbook}","Importando %n contactos en {addressbook}","Importando %n contactos en {addressbook}"],
    "_Done importing %n contact into {addressbook}_::_Done importing %n contacts into {addressbook}_" : ["Importación de %n contacto en {addressbook} finalizada","Importación de %n contactos en {addressbook} finalizada","Importación de %n contactos en {addressbook} finalizada"],
    "No data for this contact" : "No hay datos para este contacto",
    "No data for this contact on their profile" : "No hay datos para este contacto en el perfil del mismo",
    "Import" : "Importar",
    "Are you sure you want to import this contact file?" : "¿Está seguro de querer importar este archivo de contacto?",
    "Could not copy" : "No se ha podido copiar",
    "Join team" : "Unirse al equipo",
    "You are about to leave {circle}.\nAre you sure?" : "Está a punto de salir de {circle}.\n¿Está seguro?",
    "Please confirm team leave" : "Por favor confirme el abandono del equipo",
    "Could not leave the team {displayName}" : "No se pudo abandonar el equipo {displayName}",
    "Unable to join the team" : "No es posible unirse al equipo",
    "You are about to delete {circle}.\nAre you sure?" : "Está a punto de eliminar {circle}.\n¿Desea continuar?",
    "Please confirm team deletion" : "Por favor, confirme la eliminación del equipo",
    "Unable to delete the team" : "No fue posible eliminar el equipo",
    "Confirm enabling federation" : "Confirmar activado de federación",
    "Enabling this will prevent {circle} from being a member of other teams.\nAre you sure?" : "Activar esto prevendrá que {circle}sea miembro de otros equipos.\n¿Está seguro?",
    "Enable federation" : "Activar federación",
    "Link copied to the clipboard" : "Enlace copiado al portapapeles",
    "Could not copy link to the clipboard." : "No se pudo copiar el enlace al portapapeles.",
    "Not grouped" : "No agrupado",
    "Team" : "Equipo",
    "User" : "Usuario",
    "Group" : "Grupo",
    "Email" : "Correo electrónico",
    "Contact" : "Contacto",
    "Moderator" : "Moderador",
    "Admin" : "Administrador",
    "Owner" : "Propietario",
    "Invites" : "Invitaciones",
    "Anyone can request membership" : "Cualquiera puede solicitar membresía",
    "Members need to accept invitation" : "Los miembros deben aceptar la invitación",
    "Memberships must be confirmed/accepted by a Moderator (requires \"Anyone can request membership\")" : "Las membresías deben ser confirmadas/aceptadas por un moderador (requiere \"Cualquiera puede solicitar ser miembro\")",
    "Members can also invite" : "Los miembros también pueden invitar",
    "Membership" : "Membresía",
    "Prevent teams from being a member of another team" : "Evitar que los equipos sean miembros de otros equipos",
    "Federation" : "Federación",
    "Allow federated members" : "Permitir miembros federados",
    "Privacy" : "Privacidad",
    "Visible to everyone" : "Visible para todo el mundo",
    "users" : "usuarios",
    "Users" : "Usuarios",
    "groups" : "grupos",
    "federated users" : "usuarios federados",
    "Federated users" : "Usuarios federados",
    "teams" : "equipos",
    "email addresses" : "direcciones de correo electrónico",
    "Email addresses" : "Direcciones de correo electrónico",
    "contacts" : "contactos",
    "Detailed name" : "Nombre",
    "Additional names" : "Nombres adicionales",
    "Prefix" : "Prefijo",
    "Suffix" : "Sufijo",
    "Nickname" : "Apodo",
    "Website" : "Sitio web",
    "Location" : "Ubicación",
    "Federated Cloud ID" : "ID Nube Federada",
    "Home" : "Casa",
    "Work" : "Trabajo",
    "Other" : "Otro",
    "Address" : "Dirección",
    "Post office box" : "Apartado de correos",
    "Extended address" : "Dirección extendida",
    "City" : "Ciudad",
    "State or province" : "Estado o provincia",
    "Postal code" : "Código postal",
    "Country" : "País",
    "Birthday" : "Fecha de nacimiento",
    "Place of birth" : "Lugar de nacimiento",
    "Anniversary" : "Aniversario",
    "Date of death" : "Fecha de fallecimiento",
    "Place of death" : "Lugar de fallecimiento",
    "Instant messaging" : "Mensajería instantánea",
    "Phone" : "Teléfono",
    "Mobile" : "Móvil",
    "Work mobile" : "Móvil del trabajo",
    "Home mobile" : "Casa móvil",
    "Fax" : "Fax",
    "Fax home" : "Fax de casa",
    "Fax work" : "Fax del trabajo",
    "Pager" : "Localizador",
    "Voice" : "Voz",
    "Car" : "Coche",
    "Work pager" : "Busca del trabajo",
    "Line manager" : "Gerente de línea",
    "Social network" : "Redes sociales",
    "Relationship to you" : "Relación contigo",
    "Spouse" : "Cónyuge",
    "Child" : "Hijo",
    "Mother" : "Madre",
    "Father" : "Padre",
    "Parent" : "Progenitor",
    "Brother" : "Hermano",
    "Sister" : "Hermana",
    "Relative" : "Pariente",
    "Friend" : "Amigo",
    "Colleague" : "Colega",
    "Assistant" : "Asistente",
    "Related contacts" : "Contactos relacionados",
    "Agent" : "Agente",
    "Emergency" : "Emergencia",
    "Co-worker" : "Compañero de trabajo",
    "Gender" : "Género",
    "Female" : "Mujer",
    "Male" : "Hombre",
    "Unknown" : "Desconocido",
    "Time zone" : "Zona horaria",
    "Spoken languages" : "Idiomas hablados",
    "_{failed} contact failed to be read_::_{failed} contacts failed to be read_" : ["{failed} contacto no se ha podido leer","{failed} contactos no se han podido leer","{failed} contactos no se han podido leer"],
    "An error has occurred in team(s). Check the console for more details." : "Ha ocurrido un error en el/los equipo(s). Verifique la consola para más detalles.",
    "Unable to create team {circleName}" : "No fue posible crear el equipo {circleName}",
    "Unable to delete team {circleId}" : "No se pudo eliminar el equipo {circleId}",
    "Unable to delete contact" : "No se ha podido eliminar el contacto",
    "Value copied to the clipboard" : "Copiado al portapapeles",
    "Could not copy value to the clipboard." : "No se pudo copiar al portapapeles",
    "Deck board" : "Tablero de Deck",
    "New Deck board" : "Nuevo tablero de Deck",
    "Board name" : "Nombre del tablero",
    "Deck app is not installed. Please install it to create team boards." : "La app Deck no está instalada. Por favor, instálala para crear tableros de equipo.",
    "Pick an address book" : "Escoge una libreta de direcciones",
    "Select Date" : "Seleccione la fecha",
    "note" : "nota",
    "email" : "correo electrónico"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
