OC.L10N.register(
    "contacts",
    {
    "Import contacts" : "Importovat kontakty",
    "Details" : "Podrobnosti",
    "All contacts" : "Všechny kontakty",
    "_Imported %n contact_::_Imported %n contacts_" : ["Naimportován %n kontakt","Naimportovány %n kontakty","Naimportováno %n kontaktů","Naimportovány %n kontakty"],
    "_(skipped %n contact)_::_(skipped %n contacts)_" : ["(přeskočen %n kontakt)","(přeskočeny %n kontakty)","(přeskočeno %n kontaktů)","(přeskočeny %n kontakty)"],
    "Contacts" : "Kontakty",
    "A contacts app for Nextcloud" : "Aplikace pro správu kontaktů pro Nextcloud",
    "The Nextcloud contacts app is a user interface for Nextcloud's CardDAV server. Easily sync contacts from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Currently Mail and Calendar – more to come.\n* 🎉 **Never forget a birthday!** You can sync birthdays and other recurring events with your Nextcloud Calendar.\n* 👥 **Sharing of Adressbooks!** You want to share your contacts with your friends or coworkers? No problem!\n* 🙈 **We’re not reinventing the wheel!** Based on the great and open SabreDAV library." : "Nextcloud aplikace Kontakty je uživatelské rozhraní k CardDAV serveru, vestavěnému v Nextcloud. Jednoduše synchronizujte kontakty z různých zařízení se svým Nextcloud a upravujte je online.\n\n* 🚀 **Napojení na ostatní Nextcloud aplikace!** Nyní E-mailový klient a Kalendář – další jsou na cestě.\n* 🎉 **Nikdy nezapomeňte na něčí narozeniny!** Je možné synchronizovat narozeniny a ostatní opakující se události s vaším Nextcloud Kalendářem.\n* 👥 **Sdílení adresářů kontaktů!** Chcete sdílet své kontakty s přáteli nebo spolupracovníky? Žádný problém!\n* 🙈 **Nevymýšlíme znovu kolo!** Založeno na skvělé a otevřené softwarové knihovně SabreDAV.",
    "Copy to full name" : "Zkopírovat do celého jména",
    "Omit year" : "Vynechat rok",
    "Allow updating avatars from social media" : "Povolit aktualizaci zástupných obrázků ze sociálních sítí",
    "Organization chart" : "Organizační graf",
    "There was an error fetching the member list" : "Při získávání seznamu členů došlo k chybě",
    "Teams" : "Týmy",
    "Please select a team" : "Vyberte tým",
    "Loading team…" : "Načítání týmu …",
    "Loading contacts …" : "Načítání kontaktů …",
    "There are no contacts yet" : "Zatím zde nejsou žádné kontakty",
    "Create contact" : "Vytvořit kontakt",
    "There are no contacts in this group" : "V této skupině nejsou žádné kontakty",
    "Create contacts" : "Vytvořit kontakty",
    "Add contacts" : "Přidat kontakty",
    "Retry" : "Zkusit znovu",
    "Loading …" : "Načítání …",
    "Manage team" : "Spravovat tým",
    "Leave team" : "Opustit tým",
    "Delete team" : "Smazat tým",
    "Setting saved" : "Nastavení uložena",
    "Failed to save setting" : "Nastavení se nepodařilo uložit",
    "Contacts settings" : "Nastavení pro Kontakty",
    "General" : "Obecné",
    "Update avatars from social media" : "Aktualizovat zástupné obrázky ze sociálních médií",
    "Refreshed once per week" : "Znovu načteno jednou týdně",
    "Address books" : "Adresáře kontaktů",
    "Tried to drop an invalid contact!" : "Pokus o zahození neplatného kontaktu!",
    "Rename" : "Přejmenovat",
    "Export" : "Exportovat",
    "Send email" : "Odeslat e-mail",
    "Send email as BCC" : "Odeslat e-mail jako skrytou kopii (bcc)",
    "Delete" : "Smazat",
    "Show all groups" : "Zobrazit všechny skupiny",
    "Collapse groups" : "Sbalit skupiny",
    "Show all teams" : "Zobrazit veškeré týmy",
    "Collapse teams" : "Sbalit týmy",
    "Group name cannot be empty" : "Skupinu je třeba nějak nazvat",
    "This group already exists" : "Tato skupina už existuje",
    "An error occurred while creating the group" : "Při vytváření skupiny došlo k chybě",
    "This team already exists" : "Tento tým už existuje",
    "An error happened during the creation of the team" : "V průběhu vytváření týmu došlo k chybě",
    "Recently contacted" : "Nedávno kontaktovaní",
    "Contact groups" : "Skupiny kontaktů",
    "Create a new contact group" : "Vytvořit novou skupinu kontaktů",
    "Contact group name" : "Název skupiny kontaktů",
    "Create a new team" : "Vytvořit nový tým",
    "Open the contacts app settings" : "Otevřít nastavení aplikace Kontakty",
    "_Shared with {num} entity_::_Shared with {num} entities_" : ["Sdíleno s {num} entitou","Sdíleno se {num} entitami","Sdíleno s {num} entitami","Sdíleno se {num} entitami"],
    "Copied" : "Zkopírováno",
    "Cannot copy" : "Nelze kopírovat",
    "Copy link" : "Zkopírovat odkaz",
    "Toggling of address book was not successful" : "Vyp/zap. adresáře kontaktů nebylo úspěšné",
    "This will delete the address book and every contacts within it" : "Toto smaže adresář kontaktů a všechny obsažené kontakty",
    "Delete {addressbook}?" : "Smazat {addressbook}?",
    "This will unshare the address book and every contacts within it" : "Toto zruší sdílení adresáře kontaktů (a tím veškerých kontaktů v něm) s vámi",
    "Unshare {addressbook}?" : "Zrušit sdílení {addressbook} vám?",
    "Deletion of address book was not successful." : "Smazání adresáře kontaktů nebylo úspěšné.",
    "Renaming of address book was not successful." : "Přejmenování adresáře kontaktů nebylo úspěšné.",
    "{addressbookname} (Hidden)" : "{addressbookname} (skrytý)",
    "Download" : "Stáhnout",
    "Show" : "Zobrazit",
    "Unshare from me" : "Zrušit sdílení mě",
    "_%n contact_::_%n contacts_" : ["%n kontakt","%n kontakty","%n kontaktů","%n kontakty"],
    "_%n group_::_%n groups_" : ["%n skupina","%n skupiny","%n skupin","%n skupiny"],
    "Share with users or groups" : "Sdílet s uživateli nebo skupinami",
    "Share with users" : "Nasdílet uživatelům",
    "No users or groups" : "Žádní uživatelé nebo skupiny",
    "Unable to delete the share" : "Sdílení se nedaří smazat",
    "Unable to change permissions" : "Oprávnění se nedaří změnit",
    "can create and edit" : "může vytvářet a upravovat",
    "Choose a vCard file to import" : "Vyberte vCard soubor, který chcete importovat",
    "Import into the {addressbookName} address book" : "Importovat do adresáře kontaktů {addressbookName}",
    "Select local file" : "Vybrat místní soubor",
    "Import from files" : "Importovat ze souborů",
    "Importing is disabled because there are no address books available" : "Import je vypnutý, protože nejsou k dispozici žádné adresáře kontaktů",
    "An error occurred, unable to create the address book" : "Vyskytla se chyba, adresář kontaktů se nepodařilo vytvořit",
    "New address book" : "Nový adresář kontaktů",
    "Add new address book" : "Přidat nový adresář kontaktů",
    "Cancel" : "Storno",
    "Add" : "Přidat",
    "First name" : "Jméno",
    "Last name" : "Příjmení",
    "Phonetic first name" : "Jméno foneticky",
    "Phonetic last name" : "Příjmení foneticky",
    "Display name" : "Zobrazované jméno",
    "Last modified" : "Naposledy upraveno",
    "Sort contacts by" : "Řadit kontakty podle",
    "Manages" : "Spravuje",
    "Oversees" : "Dohlíží",
    "An error happened during the config change" : "V průběhu měnění nastavení došlo k chybě",
    "Enforce password protection on files shared to this team" : "Vynutit ochranu heslem na souborech nasdílených tomuto týmu",
    "Use a unique password for all shares to this team" : "Použít neopakující se heslo pro veškerá sdílení tomuto týmu",
    "Unique password …" : "Neopakující se heslo …",
    "Save" : "Uložit",
    "Change unique password" : "Změnit neopakující se heslo",
    "Failed to save password. Please try again later." : "Heslo se nepodařilo uložit. Zkuste to prosím znovu později.",
    "Close" : "Zavřít",
    "There is no description for this team" : "K tomuto týmu neexistuje popis",
    "Enter a description for the team" : "Zadejte popis pro tým",
    "Folder" : "Složka",
    "New folder" : "Nová složka",
    "Folder name" : "Název složky",
    "This will create a regular folder shared with the team. To create a Team Folder, please contact your {productName} administrator" : "Toto vytvoří běžnou složku nasdílenou týmu. Pro vytvoření týmové složky se obraťte na svého správce {productName}",
    "Talk conversation" : "Konverzace v Talk",
    "New Talk conversation" : "Nová konverzace v Talk",
    "Conversation name" : "Název konverzace",
    "Collective" : "Kolektiv",
    "Calendar" : "Kalendář",
    "New calendar" : "Nový kalendář",
    "Calendar name" : "Název kalendáře",
    "Unknown resource type" : "Neznámý typ prostředku",
    "Team calendar \"{resourceName}\" created and shared with team" : "Týmový kalendář „{resourceName}“ vytvořen a nasdílen týmu",
    "{resourceType} \"{resourceName}\" created and shared with team" : "{resourceType} „{resourceName}“ vytvořeno a nasdíleno týmu",
    "A calendar named \"{name}\" already exists. Please choose a different name." : "Kalendář nazvaný „{name}“ už existuje. Zvolte jiný název.",
    "Failed to create {resourceType}: {error}" : "Nepodařilo se vytvořit {resourceType}: {error}",
    "An error happened while saving {fields}" : "Při ukládání {fields} došlo k chybě",
    "Team name" : "Název týmu",
    "Team owner" : "Vlastník týmu",
    "Delete picture" : "Smazat obrázek",
    "Edit" : "Upravit",
    "Request to join" : "Požádat o přidání",
    "Create" : "Vytvořit",
    "Show in Calendar" : "Zobrazit v kalendáři",
    "Your request to join this team is pending approval" : "Vaše žádost o přidání do tohoto týmu čeká na schválení",
    "You are not a member of {circle}" : "Nejste členy {circle}",
    "Members" : "Členové",
    "Apply" : "Použít",
    "Confirm" : "Potvrdit",
    "Add more info" : "Přidat další informace",
    "More fields" : "Další kolonky",
    "Please select a valid format" : "Vyberte platný formát",
    "Invalid image" : "Neplatný obrázek",
    "Error cropping picture" : "Chyba při ořezávání obrázku",
    "Pick an avatar" : "Zvolte avatara",
    "Pick" : "Vybrat",
    "Error while processing the picture." : "Chyba při zpracovávání obrázku.",
    "Avatar downloaded from social network" : "Zástupný obrázek získán ze sociální sítě",
    "Avatar already up to date" : "Zástupný obrázek už je aktuální",
    "Avatar download failed" : "Stažení zástupného obrázku se nezdařilo",
    "Crop contact photo" : "Oříznout fotku kontaktu",
    "Upload a new picture" : "Nahrát nový obrázek",
    "Choose from Files" : "Zvolit ze Souborů",
    "Download picture" : "Stáhnout si obrázek",
    "Clone contact" : "Klonovat kontakt",
    "This contact is in read-only mode. You do not have permission to edit this contact." : "Tento kontakt je v režimu pouze pro čtení. Nemáte oprávnění k úpravě tohoto kontaktu.",
    "The contact you were trying to edit has changed. Please manually refresh the contact. Any further edits will be discarded." : "Kontakt který jste se pokoušeli upravit se mezitím změnil. Ručně ho znovu načtěte. Mezitím provedené úpravy budou zahozeny.",
    "Address book" : "Adresář kontaktů",
    "Add contact to Birthday Calendar" : "Přidat kontakt do kalendáře s narozeninami",
    "Exclude contact from Birthday Calendar" : "Vynechat kontakt z kalendáře s narozeninami",
    "{title} at {organization}" : "{title} v {organization}",
    "Name" : "Zobrazované jméno",
    "Syntax error. Cannot open the contact." : "Chyba syntaxe. Kontakt nelze otevřít.",
    "The contact does not exist on the server anymore." : "Kontakt už na serveru neexistuje.",
    "Unable to retrieve the contact from the server, please check your network connection." : "Kontakt se nedaří získat ze serveru – prosím zkontrolujte své připojení k síti.",
    "An error occurred while trying to move the contact" : "Při pokusu o přesunutí kontaktu došlo k chybě",
    "An error occurred while trying to copy the contact" : "Při pokusu o zkopírování kontaktu došlo k chybě",
    "Unable to update contact" : "Nedaří se zaktualizovat kontakt",
    "No contact selected" : "Nevybrán žádný kontakt",
    "Select a contact on the list to begin" : "Začněte výběrem kontaktu ze seznamu",
    "Title" : "Funkce",
    "Company" : "Společnost/organizace",
    "Go to talk conversation" : "Přejít do konverzace v Talk",
    "View profile" : "Zobrazit profil ",
    "This contact was broken and received a fix. Please review the content and click here to save it." : "Tento kontakt byl poškozený a proto automaticky opraven. Zkontrolujte prosím správnost obsahu a kliknutím sem ho uložte.",
    "Edit profile" : "Upravit profil",
    "Generate QR Code" : "Vytvořit QR kód",
    "Contact vCard as QR code" : "Vizitka (ve formátu vCard) kontaktu jako QR kód",
    "Select address book" : "Vybrat adresář kontaktů",
    "Media shares with you" : "Média vám nasdílená",
    "Talk conversations with you" : "Konverzace v Talk s vámi",
    "Calendar events with you" : "Události v kalendáři s vámi",
    "Deck cards with you" : "Deck karty s vámi",
    "No shared items with this contact" : "S tímto kontaktem nemáte žádné sdílené položky",
    "This contact cannot be moved" : "Tento kontakt není možné přesunout",
    "This contact cannot be grouped" : "Tento kontakt není možné zařadit do skupiny",
    "Add contacts to groups" : "Přidat kontakty do skupiny",
    "Move contacts to addressbook" : "Přesunout kontakty do adresáře",
    "Select groups" : "Vybrat skupiny",
    "Select addressbook" : "Vybrat adresář kontaktů",
    "Selected contacts" : "Vybrané kontakty",
    "Please note that only {count} of the {total} contacts can be added to a group" : "Všimněte si, že pouze {count} z {total} kontaktů je možné přidat do skupiny",
    "Please note that only {count} of the {total} contacts can be moved" : "Všimněte si, že pouze {count} z {total} kontaktů je možné přesunout",
    "Move" : "Přesunout",
    "from {addressbook}" : "od {addressbook}",
    "Add to favorites" : "Přidat do oblíbených",
    "Confirm merging contacts" : "Potvrďte sloučení kontaktů",
    "The selected contacts have conflicting information. Choose which information to keep" : "Označené kontakty mají kolidující informace. Zvolte které informace ponechat",
    "Contacts can be merged" : "Kontakty je možné sloučit",
    "Groups" : "Skupiny",
    "Select groups to add the merged contact to" : "Vyberte skupiny, do kterých sloučený kontakt přidat",
    "Merge contacts" : "Sloučit kontakty",
    "_Delete {number} contact_::_Delete {number} contacts_" : ["Smazat {number} kontakt","Smazat {number} kontakty","Smazat {number} kontaktů","Smazat {number} kontakty"],
    "Please select at least one editable contact to delete" : "Vyberte alespoň jeden kontakt, který je možné upravovat, pro smazání",
    "Please select two editable contacts to merge" : "Vyberte dva kontakty (které můžete upravovat), které sloučit",
    "_Add {number} contact to group_::_Add {number} contacts to group_" : ["Přidat {number} kontakt do skupiny","Přidat {number} kontakty do skupiny","Přidat {number} kontaktů do skupiny","Přidat {number} kontakty do skupiny"],
    "Please select at least one editable contact to add to a group" : "Vyberte alespoň jeden kontakt, který je možné upravovat, pro přidání do skupiny",
    "_Move {number} contact to addressbook_::_Move {number} contacts to addressbook_" : ["Přesunout {number} kontakt do adresáře","Přesunout {number} kontakty do adresáře","Přesunout {number} kontaktů do adresáře","Přesunout {number} kontakty do adresáře"],
    "Please select at least one editable contact to move to an addressbook" : "Vyberte alespoň jeden kontakt, který je možné upravovat, pro přesunutí do adresáře",
    "Are you sure you want to proceed?" : "Opravdu chcete pokračovat?",
    "Add contacts to group" : "Přidat kontakty do skupiny",
    "Search contacts …" : "Hledat v kontaktech …",
    "Unselect {number}" : "Zrušit výběr {number}",
    "Add to {group}" : "Přidat do {group}",
    "Add members to {group}" : "Přidat členy do {group}",
    "Please note that you can only add contacts from writable address books to contact groups. Contacts from read-only address books, such as the system address book, cannot be added." : "Všimněte si, že do skupin kontaktů je možné přidávat kontakty z adresářů kontaktů, do kterých lze zapisovat. Kontakty z adresářů, které jsou pouze pro čtení, jako například systémový adresář kontaktů, není možné přidávat.",
    "Remove {type}" : "Odebrat {type}",
    "Add to group" : "Přidat do skupiny",
    "Add members to group" : "Přidat členy do skupiny",
    "Search {types}" : "Hledat {types}",
    "Add guest" : "Přidat hosta",
    "Search for people to add" : "Vyhledat lidi které přidat",
    "No results" : "Žádné výsledky",
    "Add {type}" : "Přidat {type}",
    "New team name" : "Název pro nový tým",
    "Personal team" : "Osobní tým",
    "This team will only be visible to you. Other members will not be able to see or use it." : "Tento tým bude viditelný pouze vám. Ostatní členové ho neuvidí a nebudou ho moci používat.",
    "Local team" : "Místní tým",
    "This team will not be shared with the other instances of the global scale" : "Tento tým nebude sdílen s ostatními instancemi globálního rozsahu",
    "Create team" : "Vytvořit tým",
    "Promote as sole owner" : "Povýšit na jediného vlastníka",
    "Promote to {level}" : "Povýšit na {level}",
    "Demote to {level}" : "Degradovat na {level}",
    "Are you sure you want to leave this team? This action cannot be undone." : "Opravdu chcete tento tým opustit? Tuto akci nelze vzít zpět.",
    "Leave team failed." : "Opuštění týmu se nezdařilo",
    "Could not delete the member {displayName}" : "Nedaří se smazat člena {displayName}",
    "Could not change the member level to {level}" : "Nedaří se změnit oprávnění člena na stupeň {level}",
    "Could not accept membership request" : "Žádost o členství nemohla být přijata",
    "Accept membership request" : "Přijmout žádost o členství",
    "Reject membership request" : "Odmítnout žádost o členství",
    "Manage level" : "Spravovat stupeň",
    "Remove member" : "Odebrat člena",
    "Unable to get the results" : "Nedaří se získat výsledky",
    "Some members could not be added" : "Některé členy nebylo možné přidat",
    "There was an issue adding members to the team" : "Došlo k potížím při přidávání členů do týmu",
    "Loading members list …" : "Načítání seznamu členů …",
    "The list of members is only visible to members of this team" : "Seznam členů je viditelný pouze členům tohoto týmu",
    "You currently have no access to the member list" : "V tuto chvíli nemáte přístup k seznamu členů",
    "Add to {team}" : "Přidat do {team}",
    "Invite members to {team}" : "Pozvat členy do {team}",
    "Pending" : "Čekající",
    "Accept" : "Přijmout",
    "Label" : "Štítek",
    "Select chart …" : "Vybrat graf …",
    "Chart" : "Graf",
    "Select type" : "Vybrat typ",
    "Add contact in group" : "Přidat kontakt do skupiny",
    "None" : "Žádné",
    "copy" : "zkopírovat",
    "Select option" : "Vybrat volbu",
    "Notes" : "Poznámky",
    "send an email" : "odeslat e-mail",
    "Personal dates" : "Osobní data",
    "Add property of this type" : "Přidat vlastnost tohoto typu",
    "Member" : "Člen",
    "This is a read-only group managed by administrators. Group members can only view this group." : "Toto je skupina pouze pro čtení spravovaná správci. Členové skupiny si tuto skupinu mohou pouze zobrazovat.",
    "Unable to create the contact." : "Nedaří se vytvořit kontakt.",
    "Contact not found" : "Kontakt nenalezen",
    "Group {group} not found" : "Skupina {group} nenalezena",
    "Add member" : "Přidat člena",
    "New contact" : "Nový kontakt",
    "_{success} contact added to {name}_::_{success} contacts added to {name}_" : ["{success} kontakt přidán do {name}","{success} kontakty přidány do {name}","{success} kontaktů přidáno do {name}","{success} kontakty přidány do {name}"],
    "_Adding {success} contact to {name}_::_Adding {success} contacts to {name}_" : ["Přidává se {success} kontakt do {name}","Přidávají se {success} kontakty do {name}","Přidává se {success} kontaktů do {name}","Přidávají se {success} kontakty do {name}"],
    "_{count} error_::_{count} errors_" : ["{count} chyba","{count} chyby","{count} chyb","{count} chyby"],
    "_Importing %n contact into {addressbook}_::_Importing %n contacts into {addressbook}_" : ["Importuje se %n kontakt do {addressbook}","Importují se %n kontakty do {addressbook}","Importuje se %n kontaktů do {addressbook}","Importují se %n kontakty do {addressbook}"],
    "_Done importing %n contact into {addressbook}_::_Done importing %n contacts into {addressbook}_" : ["Dokončen import %n kontaktu do {addressbook}","Dokončen import %n kontaktů do {addressbook}","Dokončen import %n kontaktů do {addressbook}","Dokončen import %n kontaktů do {addressbook}"],
    "No data for this contact" : "Žádné údaje pro tento kontakt",
    "No data for this contact on their profile" : "Žádné údaje pro tento kontakt v jeho profilu",
    "Import" : "Importovat",
    "Are you sure you want to import this contact file?" : "Opravdu chcete tento soubor s kontakty naimportovat?",
    "Could not copy" : "Nedaří se zkopírovat",
    "Join team" : "Připojit se k týmu",
    "You are about to leave {circle}.\nAre you sure?" : "Chystáte se opustit  {circle}.\nOpravdu to chcete?",
    "Please confirm team leave" : "Potvrďte úmysl opustit tým",
    "Could not leave the team {displayName}" : "Nedaří se opustit tým {displayName}",
    "Unable to join the team" : "K týmu se nedaří připojit",
    "You are about to delete {circle}.\nAre you sure?" : "Chystáte se smazat {circle}.\nOpravdu to chcete?",
    "Please confirm team deletion" : "Potvrďte úmysl smazat tým",
    "Unable to delete the team" : "Tým se nedaří smazat",
    "Confirm enabling federation" : "Potvrďte zapnutí federování",
    "Enabling this will prevent {circle} from being a member of other teams.\nAre you sure?" : "Zapnutí tohoto bude bránit {circle} aby bylo členem ostatních týmů.\nOpravdu to chcete?",
    "Enable federation" : "Zapnout federování",
    "Link copied to the clipboard" : "Odkaz zkopírován do schránky",
    "Could not copy link to the clipboard." : "Odkaz se nedaří zkopírovat do schránky.",
    "Not grouped" : "Neseskupené",
    "Team" : "Tým",
    "User" : "Uživatel",
    "Group" : "Skupina",
    "Email" : "E-mail",
    "Contact" : "Kontakt",
    "Moderator" : "Moderátor",
    "Admin" : "Správce",
    "Owner" : "Vlastník",
    "Invites" : "Pozvání",
    "Anyone can request membership" : "O členství si může požádat kdokoli",
    "Members need to accept invitation" : "Je třeba, aby členové pozvání přijali",
    "Memberships must be confirmed/accepted by a Moderator (requires \"Anyone can request membership\")" : "Členství bude muset být potvrzeno/přijato moderátorem (vyžaduje „Kdokoli může zažádat o členství“)",
    "Members can also invite" : "Členové také mohou zvát",
    "Membership" : "Členství",
    "Prevent teams from being a member of another team" : "Zabránit týmu aby byl členem jiného okruhu",
    "Federation" : "Federování",
    "Allow federated members" : "Umožnit federované členy",
    "Privacy" : "Soukromí",
    "Visible to everyone" : "Viditelné všem",
    "users" : "uživatelé",
    "Users" : "Uživatelé",
    "groups" : "skupiny",
    "federated users" : "fedorovaní uživatelé",
    "Federated users" : "Federovaní uživatelé",
    "teams" : "týmy",
    "email addresses" : "e-mailové adresy",
    "Email addresses" : "E-mailové adresy",
    "contacts" : "kontakty",
    "Detailed name" : "Jméno podrobně",
    "Additional names" : "Další jména",
    "Prefix" : "Předpona",
    "Suffix" : "Přípona",
    "Nickname" : "Přezdívka",
    "Website" : "Webová stránka",
    "Location" : "Umístění",
    "Federated Cloud ID" : "Identifikátor v rámci federovaného cloudu",
    "Home" : "Domů",
    "Work" : "Práce",
    "Other" : "Jiný",
    "Address" : "Adresa",
    "Post office box" : "P.O. box",
    "Extended address" : "Rozšířená adresa",
    "City" : "Město",
    "State or province" : "Stát nebo provincie",
    "Postal code" : "Směrovací číslo",
    "Country" : "Země",
    "Birthday" : "Narozeniny",
    "Place of birth" : "Místo narození",
    "Anniversary" : "Výročí",
    "Date of death" : "Datum úmrtí",
    "Place of death" : "Místo úmrtí",
    "Instant messaging" : "Komunikátor",
    "Phone" : "Telefon",
    "Mobile" : "Mobil",
    "Work mobile" : "Pracovní mobil",
    "Home mobile" : "Osobní mobil",
    "Fax" : "Fax",
    "Fax home" : "Fax domů",
    "Fax work" : "Fax do práce",
    "Pager" : "Pager",
    "Voice" : "Hlas",
    "Car" : "Auto",
    "Work pager" : "Pracovní pager",
    "Line manager" : "Nadřízený",
    "Social network" : "Sociální síť",
    "Relationship to you" : "Souvislost s vámi",
    "Spouse" : "Partner(ka)",
    "Child" : "Dítě",
    "Mother" : "Matka",
    "Father" : "Otec",
    "Parent" : "Rodič",
    "Brother" : "Bratr",
    "Sister" : "Sestra",
    "Relative" : "Příbuzný",
    "Friend" : "Kamarád(ka)",
    "Colleague" : "Kolega",
    "Assistant" : "Asistent",
    "Related contacts" : "Související kontakty",
    "Agent" : "Agent",
    "Emergency" : "Nouze",
    "Co-worker" : "Spolupracovník",
    "Gender" : "Pohlaví",
    "Female" : "Žena",
    "Male" : "Muž",
    "Unknown" : "Neznámé",
    "Time zone" : "Časové pásmo",
    "Spoken languages" : "Jazyky, kterými hovoří",
    "_{failed} contact failed to be read_::_{failed} contacts failed to be read_" : ["{failed} kontakt se nepodařilo načíst","{failed} kontakty se nepodařilo načíst","{failed} kontaktů se nepodařilo načíst","{failed} kontakty se nepodařilo načíst"],
    "An error has occurred in team(s). Check the console for more details." : "V Týmy došlo k chybě. Další podrobnosti naleznete v konzoli.",
    "Unable to create team {circleName}" : "Nedaří se vytvořit tým {circleName}",
    "Unable to delete team {circleId}" : "Nedaří se smazat tým {circleId}",
    "Unable to delete contact" : "Nedaří se smazat kontakt",
    "Value copied to the clipboard" : "Hodnota zkopírována do schránky",
    "Could not copy value to the clipboard." : "Nebylo možné zkopírovat hodnotu do schránky.",
    "Deck board" : "Tabule aplikace Deck",
    "New Deck board" : "Nová tabule v aplikaci Deck",
    "Board name" : "Název tabule",
    "Deck app is not installed. Please install it to create team boards." : "Aplikace Deck není nainstalována. Pokud chcete vytvářet týmové tabule, nainstalujte ji.",
    "Pick an address book" : "Zvolit adresář kontaktů",
    "Select Date" : "Vybrat datum",
    "note" : "poznámka",
    "email" : "e-mail"
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");
