OC.L10N.register(
    "contacts",
    {
    "Import contacts" : "Importer des contacts",
    "Details" : "Détails",
    "All contacts" : "Tous les contacts",
    "Email address is required." : "L'adresse e-mail est requise.",
    "An open invite already exists." : "Une invitation a déjà été lancée.",
    "Could not accept invite because no authenticated user was found." : "Impossible d'accepter l'invitation car aucun utilisateur authentifié n'a été trouvé.",
    "The invite provider is invalid or not allowed." : "Le fournisseur d'invitation n'est pas valide ou n'est pas autorisé.",
    "Unable to accept this invitation. You are trying to accept an outgoing invitation." : "Impossible d'accepter cette invitation. Vous êtes en train d'essayer d'accepter une invitation sortante.",
    "Could not accept invite because the remote provider returned an invalid response." : "Impossible d'accepter l'invitation car le fournisseur distant a renvoyé une réponse non valide.",
    "The remote provider accepted the invite, but this server could not create the local contact." : "Le fournisseur distant a accepté l'invitation mais ce serveur n'a pas pu créer de contact local.",
    "Cannot resend: no email address" : "Renvoi impossible : aucune adresse e-mail",
    "Invite has already been accepted." : "L'invitation a déjà été acceptée.",
    "Invite has expired. Please create a new one." : "L'invitation a expiré. Veuillez en créer une nouvelle.",
    "This is a copy of an invite sent to you previously by %1$s on %2$s" : "C'est une copie d'une invitation qui vous a été envoyée précédemment par %1$s le %2$s",
    "Invite already has an email address." : "L'invitation a déjà une adresse e-mail.",
    "An open invite for this email already exists." : "Une invitation a déjà été lancée pour cette adresse e-mail.",
    "OCM invites are disabled." : "Les invitations OCM sont désactivées.",
    "Recipient email address is invalid." : "L'adresse e-mail du destinataire n'est pas valide.",
    "%1$s via %2$s" : "%1$s via %2$s",
    "%1$s invites you to exchange contact information." : "%1$s vous invite à échanger des informations de contact.",
    "This is a copy of the invitation you've sent to %1$s" : "C'est une copie de l'invitation que vous avez envoyée à %1$s",
    "Hi there," : "Bonjour,",
    "This will allow you to share data with each other." : "Cela vous permettra de partager des données l'un avec l'autre.",
    "To accept this invite, click the link below and sign in with your cloud provider:" : "Pour accepter cette invitation, cliquez sur le lien ci-dessous et connectez-vous à votre fournisseur de cloud :",
    "Invitation details:" : "Détails de l'invitation :",
    "Invite code: %1$s" : "Code d'invitation : %1$s",
    "Encoded invite: %1$s" : "Invitation encodée : %1$s",
    "To accept this invite, use the url below to sign in with your cloud provider:" : "Pour accepter cette invitation, utilisez l'URL ci-dessous pour vous connecter à votre fournisseur de cloud :",
    "_Imported %n contact_::_Imported %n contacts_" : ["%n contact importé","%n contacts importés","%n contacts importés"],
    "_(skipped %n contact)_::_(skipped %n contacts)_" : ["(%n contact ignoré)","(%n contacts ignorés)","(%n contacts ignorés)"],
    "Contacts" : "Contacts",
    "A contacts app for Nextcloud" : "Application contacts pour Nextcloud",
    "The Nextcloud contacts app is a user interface for Nextcloud's CardDAV server. Easily sync contacts from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Currently Mail and Calendar – more to come.\n* 🎉 **Never forget a birthday!** You can sync birthdays and other recurring events with your Nextcloud Calendar.\n* 👥 **Sharing of Adressbooks!** You want to share your contacts with your friends or coworkers? No problem!\n* 🙈 **We’re not reinventing the wheel!** Based on the great and open SabreDAV library." : "L'application de contacts Nextcloud est une interface utilisateur pour le serveur CardDAV de Nextcloud. Synchronisez facilement les contacts de divers appareils avec votre Nextcloud et modifiez-les en ligne.\n\n* 🚀 ** Intégration avec d'autres applications Nextcloud! ** Actuellement Mail et  agenda - plus à venir.\n* 🎉 ** N'oubliez jamais plus d'anniversaire! ** Vous pouvez synchroniser les anniversaires et autres événements récurrents avec votre agenda Nextcloud.\n* 👥 ** Partage de carnet d’adresses !  ** Vous souhaitez partager vos contacts avec vos amis ou vos collègues? Aucun problème!\n* 🙈 ** Nous ne réinventons pas la roue! ** Basé sur la superbe bibliothèque ouverte SabreDAV.",
    "Copy to full name" : "Copier dans le nom complet",
    "Omit year" : "Ignorer l'année",
    "Could not save the setting" : "Impossible d'enregistrer les paramètres",
    "Allow updating avatars from social media" : "Autoriser la mise à jour des avatars à partir des réseaux sociaux",
    "External invitations" : "Invitations externes",
    "Allow creating invites without an email address (link-only)" : "Autoriser la création d'invitations sans adresse e-mail (lien uniquement)",
    "Show the \"Copy encoded invite\" button on invite details" : "Afficher le bouton « Copier l'invitation encodée » sur les détails de l'invitation",
    "Organization chart" : "Organigramme",
    "There was an error fetching the member list" : "Erreur lors de la récupération de la liste des membres",
    "Teams" : "Équipes",
    "Please select a team" : "Veuillez sélectionner une équipe",
    "Loading team…" : "Chargement de l'équipe...",
    "Loading contacts …" : "Chargement des contacts …",
    "There are no contacts yet" : "Il n'y a aucun contact pour l’instant",
    "Create contact" : "Créer un contact",
    "There are no contacts in this group" : "Il n'y a aucun contact dans ce groupe",
    "Create contacts" : "Créer des contacts",
    "Add contacts" : "Ajouter des contacts",
    "Loading invitations…" : "Chargement des invitations…",
    "Could not load invitations" : "Impossible de charger les invitations",
    "Retry" : "Réessayer",
    "There are no invitations" : "Il n'y a aucune invitation",
    "Loading …" : "Chargement …",
    "Manage team" : "Gérer l'équipe",
    "Leave team" : "Quitter l'équipe",
    "Delete team" : "Supprimer l'équipe",
    "Setting saved" : "Paramètre enregistré",
    "Failed to save setting" : "Impossible d'enregistrer les paramètres",
    "Contacts settings" : "Paramètres de Contacts",
    "General" : "Général",
    "Update avatars from social media" : "Mettre à jour les avatars à partir des réseaux sociaux",
    "Refreshed once per week" : "Rafraîchi une fois par semaine",
    "Address books" : "Carnets d'adresses",
    "Tried to drop an invalid contact!" : "Impossible de déposer un contact non valide !",
    "Rename" : "Renommer",
    "Export" : "Exporter",
    "Send email" : "Envoyer un e-mail",
    "Send email as BCC" : "Envoyer un e-mail en CCI",
    "Delete" : "Supprimer",
    "Show all groups" : "Afficher tous les groupes",
    "Collapse groups" : "Replier les groupes",
    "Show all teams" : "Afficher toutes les équipes",
    "Collapse teams" : "Replier les équipes ",
    "Group name cannot be empty" : "Le nom du groupe ne peut pas être vide",
    "This group already exists" : "Ce groupe existe déjà",
    "An error occurred while creating the group" : "Une erreur est survenue lors de la création du groupe",
    "This team already exists" : "Cette équipe existe déjà",
    "An error happened during the creation of the team" : "Une erreur est survenue lors de la création de l'équipe",
    "Add address book" : "Ajouter un carnet d'adresses",
    "Recently contacted" : "Contacté récemment",
    "Contact groups" : "Groupes de contacts",
    "Create a new contact group" : "Créer un nouveau groupe de contacts",
    "Contact group name" : "Nom du groupe de contacts",
    "Create a new team" : "Créer une nouvelle équipe",
    "Open the contacts app settings" : "Ouvrir les paramètres de l'application Contacts",
    "_Shared with {num} entity_::_Shared with {num} entities_" : ["Partagé avec {num} entité","Partagé avec {num} entités","Partagé avec {num} entités"],
    "Copied" : "Copié",
    "Cannot copy" : "Impossible de copier",
    "Copy link" : "Copier le lien",
    "Toggling of address book was not successful" : "L'activation ou désactivation du carnet d'adresses a échoué",
    "This will delete the address book and every contacts within it" : "Le carnet d'adresses ainsi que tous les contacts qu'il contient va être supprimé",
    "Delete {addressbook}?" : "Supprimer {addressbook} ?",
    "This will unshare the address book and every contacts within it" : "Le carnet d’adresses ainsi que tous les contacts qu’il contient ne sera plus partagé",
    "Unshare {addressbook}?" : "Cesser le partage {addressbook} ?",
    "Deletion of address book was not successful." : "La suppression du carnet d'adresses a échoué.",
    "Renaming of address book was not successful." : "Le renommage du carnet d'adresses a échoué.",
    "{addressbookname} (Hidden)" : "{addressbookname} (Caché)",
    "Download" : "Télécharger",
    "Show" : "Afficher",
    "Unshare from me" : "Quitter ce partage",
    "_%n contact_::_%n contacts_" : ["%n contact","%n contacts","%n contacts"],
    "_%n group_::_%n groups_" : ["%n groupe","%n groupes","%n groupes"],
    "Share with users or groups" : "Partager avec des utilisateurs ou des groupes",
    "Share with users" : "Share with users",
    "No users or groups" : "Aucun utilisateur ou groupe",
    "Unable to delete the share" : "Impossible de supprimer le partage",
    "Unable to change permissions" : "Impossible de modifier les autorisations",
    "can create and edit" : "peut créer et modifier",
    "Choose a vCard file to import" : "Sélectionnez un fichier vCard à importer",
    "Import into the {addressbookName} address book" : "Importer dans le carnet d'adresses {addressbookName}",
    "Select local file" : "Sélectionner un fichier local",
    "Import from files" : "Importer depuis Fichiers",
    "Importing is disabled because there are no address books available" : "L'import n'est pas disponible car il n'existe aucun carnet d'adresses",
    "An error occurred, unable to create the address book" : "Une erreur est survenue, impossible de créer le carnet d'adresses",
    "New address book" : "Nouveau carnet d'adresses",
    "Add new address book" : "Ajouter un nouveau carnet d'adresses",
    "Cancel" : "Annuler",
    "Add" : "Ajouter",
    "First name" : "Prénom",
    "Last name" : "Nom",
    "Phonetic first name" : "Prénom phonétique",
    "Phonetic last name" : "Nom de famille phonétique",
    "Display name" : "Nom affiché",
    "Last modified" : "Dernière modification",
    "Sort contacts by" : "Trier les contacts par",
    "Manages" : "Gère",
    "Oversees" : "Supervise",
    "An error happened during the config change" : "Erreur lors du changement de configuration",
    "Enforce password protection on files shared to this team" : "Renforcer la sécurité des partages de fichiers effectués vers cette équipe avec des mots de passe",
    "Use a unique password for all shares to this team" : "Utilisez un mot de passe unique pour tous les partages vers cette équipe",
    "Unique password …" : "Mot de passe unique …",
    "Save" : "Enregistrer",
    "Change unique password" : "Modifier le mot de passe unique",
    "Failed to save password. Please try again later." : "Impossible d'enregistrer le mot de passe. Veuillez réessayer plus tard.",
    "Close" : "Fermer",
    "Choose a team picture" : "Choisir une image pour l’équipe",
    "There is no description for this team" : "Il n'y a pas de description pour cette équipe",
    "Enter a description for the team" : "Entrez une description pour cette équipe",
    "Folder" : "Dossier",
    "New folder" : "Nouveau dossier",
    "Folder name" : "Nom du dossier",
    "This will create a regular folder shared with the team. To create a Team Folder, please contact your {productName} administrator" : "Cela va créer un dossier standard partagé avec l'équipe. Pour créer un dossier d'équipe, merci de contacter l'administrateur de {productName} ",
    "Talk conversation" : "Conversation Talk",
    "New Talk conversation" : "Nouvelle conversation Talk",
    "Conversation name" : "Nom de la conversation",
    "Collective" : "Collectif",
    "Calendar" : "Agenda",
    "New calendar" : "Nouveau calendrier",
    "Calendar name" : "Nom du calendrier",
    "Unknown resource type" : "Type de ressource inconnu",
    "Team calendar \"{resourceName}\" created and shared with team" : "Calendrier de l'équipe \"{resourceName}\" créé et partagé avec l'équipe",
    "{resourceType} \"{resourceName}\" created and shared with team" : "{resourceType} \"{resourceName}\" créé et partagé avec l'équipe",
    "A calendar named \"{name}\" already exists. Please choose a different name." : "Un calendrier nommé \"{name}\" existe déjà. Veuillez en choisir un autre.",
    "Failed to create {resourceType}: {error}" : "Échec de la création {resourceType}: {error}",
    "Please select a valid png or jpg file" : "Veuillez sélectionner un fichier PNG ou JPG valide",
    "Error picking team picture" : "Erreur lors de la sélection de l’image de l’équipe",
    "Error cropping avatar picture" : "Erreur lors du recadrage de l’avatar",
    "An error happened while saving {fields}" : "Une erreur est survenue lors de l'enregistrement de {fields}",
    "Team name" : "Nom de l'équipe",
    "Team owner" : "Propriétaire de l'équipe",
    "Upload team picture" : "Téléverser une image pour l’équipe",
    "Choose from Nextcloud Files" : "Choisir dans les fichiers Nextcloud",
    "Delete picture" : "Supprimer l'image",
    "Edit" : "Modifier",
    "Request to join" : "Demander à rejoindre",
    "Create" : "Créer",
    "Show in Calendar" : "Afficher dans le calendrier",
    "Your request to join this team is pending approval" : "Votre demande pour rejoindre cette équipe est en attente d'approbation",
    "You are not a member of {circle}" : "Vous n'êtes pas un membre de {circle}",
    "Members" : "Membres",
    "Edit team picture" : "Modifier l’image de l’équipe",
    "Apply" : "Appliquer",
    "Confirm" : "Confirmer",
    "No other contacts available to select as line manager" : "Aucun autre contact n’est disponible pour être sélectionné comme responsable hiérarchique",
    "Add more info" : "Ajouter plus d'informations",
    "More fields" : "Plus de champs",
    "Please select a valid format" : "Veuillez sélectionner un format valide",
    "Invalid image" : "Image invalide",
    "Error cropping picture" : "Erreur de recadrage de l'image",
    "Pick an avatar" : "Sélectionnez un avatar",
    "Pick" : "Choisir",
    "Error while processing the picture." : "Erreur lors du traitement de  l'image.",
    "Avatar downloaded from social network" : "Avatar téléchargé à partir des réseaux sociaux",
    "Avatar already up to date" : "Avatar déjà à jour",
    "Avatar download failed" : "Téléchargement de l'avatar échoué",
    "Crop contact photo" : "Recadrer la photo du contact",
    "Upload a new picture" : "Téléverser une nouvelle image",
    "Choose from Files" : "Sélectionner depuis les fichiers",
    "Download picture" : "Télécharger l'image",
    "Clone contact" : "Dupliquer le contact",
    "This contact is in read-only mode. You do not have permission to edit this contact." : "Ce contact est en lecture seule. Vous n'avez pas les autorisations pour modifier ce contact.",
    "The contact you were trying to edit has changed. Please manually refresh the contact. Any further edits will be discarded." : "Le contact que vous essayiez de modifier a changé. Merci de rafraîchir manuellement le contact. Vos modifications seront abandonnées. ",
    "Address book" : "Carnet d'adresses",
    "Add contact to Birthday Calendar" : "Ajouter le contact à l'agenda d’anniversaire",
    "Exclude contact from Birthday Calendar" : "Exclure le contact de l'agenda d'anniversaire",
    "{title} at {organization}" : "{title} chez {organization}",
    "Name" : "Nom",
    "Syntax error. Cannot open the contact." : "Erreur de syntaxe. Impossible de lire le contact.",
    "The contact does not exist on the server anymore." : "Le contact n'existe plus sur le serveur.",
    "Unable to retrieve the contact from the server, please check your network connection." : "Impossible de récupérer le contact à partir du serveur, s'il vous plait vérifiez votre connexion internet.",
    "An error occurred while trying to move the contact" : "Une erreur est survenue lors du déplacement du contact",
    "An error occurred while trying to copy the contact" : "Une erreur est survenue lors de la copie du contact",
    "Unable to update contact" : "Impossible de mettre à jour le contact",
    "No contact selected" : "Aucun contact sélectionné",
    "Select a contact on the list to begin" : "Sélectionnez un contact dans la liste pour commencer",
    "Title" : "Fonction",
    "Company" : "Société",
    "Go to talk conversation" : "Aller à la conversation Talk",
    "View profile" : "Voir le profile",
    "This contact was broken and received a fix. Please review the content and click here to save it." : "Ce contact a été tronqué et a été corrigé. Veuillez en examiner le contenu, puis cliquez ici pour l’enregistrer.",
    "Edit profile" : "Modifier le profil",
    "Generate QR Code" : "Générer un QR code",
    "Contact vCard as QR code" : "Contact vCard comme QR code",
    "Select address book" : "Sélectionner un carnet d'adresses",
    "Media shares with you" : "Média partagés avec vous",
    "Talk conversations with you" : "Conversations Talk avec vous",
    "Calendar events with you" : "Agendas avec vous",
    "Deck cards with you" : "Cartes Deck partagées avec vous",
    "No shared items with this contact" : "Aucun éléments partagés avec ce contact",
    "This contact cannot be moved" : "Ce contact ne peut pas être déplacé",
    "This contact cannot be grouped" : "Ce contact ne peut pas être groupé",
    "Add contacts to groups" : "Ajouter des contacts à des groupes",
    "Move contacts to addressbook" : "Déplacer des contacts dans des carnets d'adresses",
    "Select groups" : "Sélectionner des groupes",
    "Select addressbook" : "Sélectionner un carnet d'adresses",
    "Selected contacts" : "Contacts sélectionnés",
    "Please note that only {count} of the {total} contacts can be added to a group" : "Merci de noter que seul(s) {count} contact(s) parmi {total} peut/peuvent être ajouté(s) au groupe",
    "Please note that only {count} of the {total} contacts can be moved" : "Merci de noter que seul(s) {count} contact(s) parmi {total} peut/peuvent être déplacé(s)",
    "Move" : "Déplacer",
    "Unselect {name}" : "Désélectionner {name}",
    "Select {name}" : "Sélectionner {name}",
    "Could not update favorite status" : "Impossible de mettre à jour le statut de favori",
    "from {addressbook}" : "de {addressbook}",
    "Remove from favorites" : "Retirer des favoris",
    "Add to favorites" : "Ajouter aux favoris",
    "Confirm merging contacts" : "Confirmer la fusion des contacts",
    "The selected contacts have conflicting information. Choose which information to keep" : "Les contacts sélectionnés contiennent des informations en conflit. Choisissez les informations à conserver.",
    "Contacts can be merged" : "Les contacts peuvent être fusionnés",
    "Groups" : "Groupes",
    "Select groups to add the merged contact to" : "Sélectionner les groupes auxquels ajouter le contact fusionné",
    "Merge contacts" : "Fusionner les contacts",
    "_Delete {number} contact_::_Delete {number} contacts_" : ["Supprimer {number} contact","Supprimer {number} contacts","Supprimer {number} contacts"],
    "Please select at least one editable contact to delete" : "Veuillez sélectionner au moins un contact modifiable à supprimer",
    "Please select two editable contacts to merge" : "Veuillez sélectionner deux contacts modifiables à fusionner",
    "_Add {number} contact to group_::_Add {number} contacts to group_" : ["Ajouter {number} contact au groupe","Ajouter {number} contacts au groupe","Ajouter {number} contacts au groupe"],
    "Please select at least one editable contact to add to a group" : "Merci de sélectionner au moins un contact modifiable à ajouter au groupe",
    "_Move {number} contact to addressbook_::_Move {number} contacts to addressbook_" : ["Déplacer {number} contact dans le carnet d'adresses","Déplacer {number} contacts dans le carnet d'adresses","Déplacer {number} contacts dans le carnet d'adresses"],
    "Please select at least one editable contact to move to an addressbook" : "Merci de sélectionner au moins un contact modifiable à déplacer dans un carnet d'adresses",
    "Are you sure you want to proceed?" : "Êtes-vous sûr de vouloir continuer ?",
    "Add contacts to group" : "Ajouter des contacts à un groupe",
    "Search contacts …" : "Rechercher un contact …",
    "Unselect {number}" : "Désélectionner {number}",
    "Add to {group}" : "Ajouter à {group}",
    "Add members to {group}" : "Ajouter des membres à {group}",
    "Please note that you can only add contacts from writable address books to contact groups. Contacts from read-only address books, such as the system address book, cannot be added." : "Veuillez noter que vous ne pouvez ajouter à des groupes de contacts que des contacts provenant de carnets d'adresses modifiables. Les contacts provenant de carnets d'adresses en lecture seule, tels que le carnet d'adresses système, ne peuvent pas être ajoutés.",
    "Remove {type}" : "Retirer {type}",
    "Add to group" : "Ajouter au groupe",
    "Add members to group" : "Ajouter des membres au groupe",
    "Search {types}" : "Rechercher {types}",
    "Add guest" : "Ajouter un invité",
    "Search for people to add" : "Chercher des personnes à ajouter",
    "No results" : "Aucun résultat",
    "Add {type}" : "Ajouter des {type}",
    "New team name" : "Nom de la nouvelle équipe",
    "Personal team" : "Équipe personnelle",
    "This team will only be visible to you. Other members will not be able to see or use it." : "Cette équipe sera uniquement visible par vous. Les autres membres ne pourront ni le voir, ni l'utiliser.",
    "Local team" : "Équipe locale",
    "This team will not be shared with the other instances of the global scale" : "Cette équipe ne sera pas partagée avec les autres instances à l'échelle globale",
    "Create team" : "Créer une équipe",
    "Promote as sole owner" : "Promouvoir seul propriétaire",
    "Promote to {level}" : "Promouvoir {level}",
    "Demote to {level}" : "Rétrograder {level}",
    "Are you sure you want to leave this team? This action cannot be undone." : "Êtes-vous sûr de vouloir quitter cette équipe ? Cette action ne peut pas être annulée.",
    "Leave team failed." : "Échec de la sortie de l'équipe.",
    "Could not delete the member {displayName}" : "Impossible de supprimer le membre {displayName}",
    "Could not change the member level to {level}" : "Impossible de changer le niveau du membre vers {level}",
    "Could not accept membership request" : "Impossible d'accepter la demande d'adhésion",
    "Accept membership request" : "Accepter la demande d'adhésion",
    "Reject membership request" : "Rejeter la demande d'adhésion",
    "Manage level" : "Définir le rôle",
    "Remove member" : "Retirer le membre",
    "Unable to get the results" : "Impossible de récupérer les résultats",
    "Some members could not be added" : "Certains membres n'ont pas pu être ajoutés",
    "There was an issue adding members to the team" : "Erreur lors de l'ajout de membres à l'équipe",
    "Loading members list …" : "Chargement de la liste des membres …",
    "The list of members is only visible to members of this team" : "La liste des membres est uniquement visible par les membres de cette équipe",
    "You currently have no access to the member list" : "Vous n'avez actuellement pas accès à la liste des membres",
    "Add to {team}" : "Ajouter à {team}",
    "Invite members to {team}" : "Inviter des membres dans {team}",
    "Pending" : "En attente",
    "This invite does not look valid. Check that you copied it completely or ask the sender to generate a new one." : "Cette invitation ne semble pas valide. Vérifiez que vous l'avez copiée en entier ou demandez à l'expéditeur d'en générer une nouvelle.",
    "Accept invitation" : "Accepter l'invitation",
    "Accepting will add the inviter to your contacts list and in return, your contact info will be sent to the inviter. From there on you can start sharing data with each other." : "Accepter l'invitation ajoutera la personne qui vous invite à votre liste de contacts et, en retour, vos informations de contact lui seront envoyées. À partir de ce moment, vous pourrez commencer à partager des données l'un avec l'autre.",
    "Invite link or code (required)" : "Lien ou code d'invitation (requis)",
    "Paste the invite link, or an invite code (token@provider), you received from the other person." : "Collez le lien d'invitation, ou un code d'invitation (jeton@fournisseur), que vous avez reçu de l'autre personne.",
    "Accept" : "Accepter",
    "Please enter an email address." : "Veuillez entrer une adresse e-mail.",
    "The recipient will receive an email with the invite link. Their email address will be saved on the invite so you can resend later." : "Le destinataire va recevoir un e-mail avec le lien d'invitation. Son adresse e-mail sera enregistrée sur l'invitation afin que vous puissiez la renvoyer plus tard.",
    "Recipient email (required)" : "E-mail du destinataire (requis)",
    "email@example.com" : "email@exemple.com",
    "Personal message (optional)" : "Message personnel (facultatif)",
    "Message to include in the email" : "Message à inclure dans l'e-mail",
    "Sending…" : "Envoi en cours…",
    "Invite code" : "Code d'invitation",
    "Cloud provider" : "Fournisseur de cloud",
    "Encoded invite copied to clipboard" : "Invitation encodée copiée dans le presse-papiers",
    "Invite code copied to clipboard" : "Code d'invitation copié dans le presse-papiers",
    "Invite link copied to clipboard" : "Lien d'invitation copié dans le presse-papiers",
    "Copied to clipboard" : "Copié dans le presse-papiers",
    "Failed to copy to clipboard" : "Échec de la copie dans le presse-papiers",
    "Could not resend invite" : "Impossible de renvoyer l'invitation",
    "Invite revoked" : "Invitation révoquée",
    "Could not revoke invite" : "Impossible de révoquer l'invitation",
    "Invite sent to {email}" : "Invitation envoyée à {email}",
    "Could not send invite" : "Impossible d'envoyer l'invitation",
    "No invitation selected" : "Aucune invitation sélectionnée",
    "Select an invitation on the list to begin" : "Sélectionnez une invitation dans la liste pour commencer",
    "External invitation" : "Invitation externe",
    "Label" : "Libellé",
    "Sent to" : "Envoyer à",
    "Created" : "Créé",
    "Expires" : "Expire",
    "Revoke invitation" : "Révoquer l'invitation",
    "Resend email" : "Renvoyer l'e-mail",
    "Send via email" : "Envoyer par e-mail",
    "The invite link and code are added automatically when you send the invitation." : "Le lien et le code d'invitation ont été ajoutés automatiquement quand vous avez envoyé l'invitation.",
    "Recipient email" : "E-mail du destinataire",
    "Hide email preview" : "Cacher la prévisualisation de l'e-mail",
    "Show email preview" : "Afficher la prévisualisation de l'e-mail",
    "This is what {recipient} will receive:" : "Voici ce que {recipient} va recevoir :",
    "If you do not send an email, you will need to share the invite link yourself." : "Si vous n'envoyez pas d'e-mail, vous devrez partager le lien d'invitation vous-même.",
    "Invite link" : "Lien d'invitation",
    "Copy invite link to clipboard" : "Copier le lien d'invitation dans le presse-papiers",
    "Copy invite code to clipboard" : "Copier le code d'invitation dans le presse-papiers",
    "Copy encoded invite to clipboard" : "Copier l'invitation encodée dans le presse-papiers",
    "Could not discover that provider. Check the address and try again." : "Impossible de découvrir ce fournisseur. Vérifiez l'adresse et réessayez.",
    "Select your server" : "Sélectionnez votre serveur",
    "Type to search" : "Tapez pour rechercher",
    "No servers match your search." : "Aucun serveur ne correspond à votre recherche.",
    "No servers are currently available." : "Aucun serveur n'est actuellement disponible.",
    "Your server not listed? Enter one manually." : "Votre serveur n'est pas listé ? Saisissez-le manuellement.",
    "You need an invite link for this feature to work." : "Vous avez besoin d'un lien d'invitation pour que cela fonctionne.",
    "Select chart …" : "Sélectionnez un organigramme …",
    "Chart" : "Organigramme",
    "Select type" : "Sélectionnez le type",
    "Add contact in group" : "Ajouter le contact dans un groupe",
    "None" : "Aucun",
    "copy" : "copier",
    "Select option" : "Sélectionnez une option",
    "JavaScript URIs are not allowed" : "Les URI JavaScript ne sont pas autorisées",
    "Notes" : "Notes",
    "send an email" : "Envoyer un email",
    "Personal dates" : "Dates personnelles",
    "Add property of this type" : "Ajouter une propriété de ce type",
    "Member" : "Membre",
    "This is a read-only group managed by administrators. Group members can only view this group." : "Il s'agit d'un groupe en lecture seule, géré par les administrateurs. Seuls les membres du groupe peuvent consulter ce groupe.",
    "This invite link is incomplete. Ask the sender to generate a new one." : "Le lien d'invitation n'est pas complet. Demandez à l'expéditeur d'en générer un nouveau.",
    "Unable to create the contact." : "Impossible de créer le contact.",
    "Contact not found" : "Contact introuvable",
    "Address book {addressbook} not found" : "Carnet d'adresses {addressbook} introuvable",
    "Group {group} not found" : "Groupe {group} introuvable",
    "Could not accept invite" : "Impossible d'accepter l'invitation",
    "Could not create invite" : "Impossible de créer l'invitation",
    "Add member" : "Ajouter un membre",
    "New contact" : "Nouveau contact",
    "_{success} contact added to {name}_::_{success} contacts added to {name}_" : ["{success} contact ajouté à {name}","{success} contacts ajoutés à {name}","{success} contacts ajoutés à {name}"],
    "_Adding {success} contact to {name}_::_Adding {success} contacts to {name}_" : ["Ajouter {success} contact à {name}","Ajouter {success} contacts à {name}","Ajouter {success} contacts à {name}"],
    "_{count} error_::_{count} errors_" : ["{count} erreur","{count} erreurs","{count} erreurs"],
    "_Importing %n contact into {addressbook}_::_Importing %n contacts into {addressbook}_" : ["Import de %n contact dans {addressbook}","Import de %n contacts dans {addressbook}","Import de %n contacts dans {addressbook}"],
    "_Done importing %n contact into {addressbook}_::_Done importing %n contacts into {addressbook}_" : ["Import de %n contact dans {addressbook} terminé","Import de %n contacts dans {addressbook} terminé","Import de %n contacts dans {addressbook} terminé"],
    "No data for this contact" : "Aucune donnée sur ce contact",
    "No data for this contact on their profile" : "Aucune donnée de ce contact sur son profil",
    "Import" : "Importer",
    "Are you sure you want to import this contact file?" : "Êtes-vous sûr de vouloir importer ce fichier de contact ?",
    "Could not copy" : "Impossible de copier",
    "Join team" : "Rejoindre l'équipe",
    "You are about to leave {circle}.\nAre you sure?" : "Vous êtes sur le point de quitter le cercle {circle}.\nÊtes-vous sûr ?",
    "Please confirm team leave" : "Confirmer votre départ de l'équipe",
    "Could not leave the team {displayName}" : "Impossible de quitter l'équipe {displayName}",
    "Unable to join the team" : "Impossible de rejoindre l'équipe",
    "You are about to delete {circle}.\nAre you sure?" : "Vous êtes sur le point de supprimer {circle}.\nÊtes-vous sûr ?",
    "Please confirm team deletion" : "Confirmez la suppression de l'équipe",
    "Unable to delete the team" : "Impossible de supprimer l'équipe",
    "Confirm enabling federation" : "Confirmer l’activation de la fédération",
    "Enabling this will prevent {circle} from being a member of other teams.\nAre you sure?" : "L’activation de cette option empêchera {circle} d’être membre d’autres équipes.\nÊtes-vous sûr de vouloir continuer ?",
    "Enable federation" : "Activer la fédération",
    "Link copied to the clipboard" : "Lien copié dans le presse-papier",
    "Could not copy link to the clipboard." : "Impossible de copier le lien dans le presse-papier",
    "Not grouped" : "Non groupé",
    "Create your own teams for sharing. Add Nextcloud users, contacts, or anyone via email." : "Créez vos propres équipes pour le partage. Ajoutez des utilisateurs Nextcloud, des contacts ou toute autre personne par e-mail.",
    "Team" : "Équipe",
    "User" : "Utilisateur",
    "Group" : "Groupe",
    "Email" : "E-mail",
    "Contact" : "Contact",
    "Moderator" : "Modérateur",
    "Admin" : "Administrateur",
    "Owner" : "Propriétaire",
    "Invites" : "Invitations et adhésions",
    "Anyone can request membership" : "Tout le monde peut demander à adhérer",
    "Members need to accept invitation" : "Les membres doivent accepter l'invitation",
    "Memberships must be confirmed/accepted by a Moderator (requires \"Anyone can request membership\")" : "Les adhésions doivent être confirmées/acceptées par un modérateur (nécessite « Tout le monde peut demander à adhérer »)",
    "Members can also invite" : "Les membres peuvent aussi inviter",
    "Membership" : "Adhésion",
    "Prevent teams from being a member of another team" : "Empêcher l'équipe d'être membre d'une autre équipe",
    "Federation" : "Fédération",
    "Allow federated members" : "Autoriser les membres fédérés",
    "Privacy" : "Confidentialité",
    "Visible to everyone" : "Visible pour tous",
    "users" : "utilisateurs",
    "Users" : "Utilisateurs",
    "groups" : "groupes",
    "federated users" : "utilisateurs fédérés",
    "Federated users" : "Utilisateurs fédérés",
    "teams" : "équipes",
    "email addresses" : "adresses mail",
    "Email addresses" : "Adresses e-mail",
    "contacts" : "contacts",
    "Detailed name" : "Nom détaillé",
    "Additional names" : "Noms supplémentaires",
    "Prefix" : "Civilité",
    "Suffix" : "Suffixe",
    "Nickname" : "Surnom",
    "Website" : "Site web",
    "Location" : "Position",
    "Federated Cloud ID" : "ID de Cloud Fédéré",
    "Home" : "Personnel",
    "Work" : "Professionnel",
    "Other" : "Autre",
    "Address" : "Adresse",
    "Post office box" : "Boîte postale",
    "Extended address" : "Adresse étendue",
    "City" : "Ville",
    "State or province" : "État ou région",
    "Postal code" : "Code postal",
    "Country" : "Pays",
    "Birthday" : "Anniversaire",
    "Place of birth" : "Lieu de naissance",
    "Anniversary" : "Autre date",
    "Date of death" : "Date de décès",
    "Place of death" : "Lieu du décès",
    "Instant messaging" : "Messagerie instantanée",
    "Phone" : "Téléphone",
    "Mobile" : "Mobile",
    "Work mobile" : "Téléphone portable professionnel",
    "Home mobile" : "Téléphone portable personnel",
    "Fax" : "Fax",
    "Fax home" : "Fax personnel",
    "Fax work" : "Fax professionnel",
    "Pager" : "Bipeur",
    "Voice" : "Voix",
    "Car" : "Voiture",
    "Work pager" : "Bipper professionnel",
    "Line manager" : "Supérieur hiérarchique",
    "Social network" : "Réseau social",
    "Relationship to you" : "Relation avec vous",
    "Spouse" : "Conjoint",
    "Child" : "Enfant",
    "Mother" : "Mère",
    "Father" : "Père",
    "Parent" : "Parent",
    "Brother" : "Frère",
    "Sister" : "Sœur",
    "Relative" : "Membre de la famille",
    "Friend" : "Ami",
    "Colleague" : "Collègue",
    "Assistant" : "Assistant",
    "Related contacts" : "Contacts liés",
    "Agent" : "Agent",
    "Emergency" : "Urgence",
    "Co-worker" : "Collaborateur",
    "Gender" : "Sexe",
    "Female" : "Femme",
    "Male" : "Homme",
    "Unknown" : "Inconnu",
    "Time zone" : "Fuseau horaire",
    "Spoken languages" : "Langues parlées",
    "_{failed} contact failed to be read_::_{failed} contacts failed to be read_" : ["Erreur de lecture pour {failed} contact","Erreur de lecture pour {failed} contacts","Erreur de lecture pour {failed} contacts"],
    "An error has occurred in team(s). Check the console for more details." : "Une erreur est survenue dans le(s) équipe(s). Vérifiez la console pour plus de détails.",
    "Unable to create team {circleName}" : "Impossible de créer l'équipe {circleName}",
    "Unable to delete team {circleId}" : "Impossible de supprimer l'équipe {circleId}",
    "Could not update favorite state" : "Impossible de mettre à jour le statut de favori",
    "Unable to delete contact" : "Impossible de supprimer le contact.",
    "Value copied to the clipboard" : "Valeur copiée dans le presse-papiers",
    "Could not copy value to the clipboard." : "Impossible de copier la valeur dans le presse-papiers.",
    "Deck board" : "Tableau Deck",
    "New Deck board" : "Nouvelle fiche Deck",
    "Board name" : "Nom de tableau",
    "Deck app is not installed. Please install it to create team boards." : "L'application Deck n'est pas installée. Veuillez l'installer pour créer des tableaux d'équipe.",
    "Pick an address book" : "Sélectionner un carnet d'adresses",
    "Select Date" : "Sélectionnez une date",
    "note" : "note",
    "email" : "email",
    "Create your own groups for sharing. Add Nextcloud users, contacts, or anyone via email." : "Créez vos propres groupes effectuer des partages. Ajoutez des utilisateurs Nextcloud, des contacts ou n'importe qui par e-mail."
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
