OC.L10N.register(
    "contacts",
    {
    "Import contacts" : "Importer kontakter",
    "Details" : "Detaljer",
    "All contacts" : "Alle kontakter",
    "Contacts" : "Kontakter",
    "A contacts app for Nextcloud" : "En kontaktapp for Nextcloud",
    "The Nextcloud contacts app is a user interface for Nextcloud's CardDAV server. Easily sync contacts from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Currently Mail and Calendar – more to come.\n* 🎉 **Never forget a birthday!** You can sync birthdays and other recurring events with your Nextcloud Calendar.\n* 👥 **Sharing of Adressbooks!** You want to share your contacts with your friends or coworkers? No problem!\n* 🙈 **We’re not reinventing the wheel!** Based on the great and open SabreDAV library." : "Nextcloud-kontaktappen er et brukergrensesnitt for Nextclouds CardDAV-server. Synkroniser enkelt kontakter fra forskjellige enheter med Nextcloud og rediger dem på nett.\n\n* 🚀 **Integrasjon med andre Nextcloud-apper!** Foreløpig E-post og Kalender - mer kommer.\n* 🎉 **Aldri glem en bursdag!** Du kan synkronisere bursdager og andre tilbakevendende hendelser med Nextcloud-kalenderen din.\n* 👥 **Deling av adressebøker!** Vil du dele kontaktene dine med venner eller kolleger? Ingen problem!\n* 🙈 **Vi finner ikke opp hjulet på nytt!** Basert på det store og åpne SabreDAV-biblioteket.",
    "Copy to full name" : "Kopier til fullt navn",
    "Omit year" : "Utelat år",
    "Allow updating avatars from social media" : "Tillat oppdatering av avatarer fra sosiale medier",
    "Organization chart" : "Organisasjonskart",
    "There was an error fetching the member list" : "Det oppstod en feil under henting av medlemslisten",
    "Teams" : "Lag",
    "Please select a team" : "Vennligst velg et lag",
    "Loading team…" : "Laster lag...",
    "There are no contacts yet" : "Det finnes ingen kontakter enda",
    "Create contact" : "Opprett kontakt",
    "There are no contacts in this group" : "Det finnes ingen kontaker i denne gruppen",
    "Create contacts" : "Opprett kontakter",
    "Add contacts" : "Legg til kontaker",
    "Retry" : "Prøv på nytt",
    "Manage team" : "Behandle lag",
    "Leave team" : "Forlat lag",
    "Delete team" : "Slett lag",
    "Contacts settings" : "Kontaktinnstillinger",
    "Update avatars from social media" : "Oppdater avatarer fra sosiale medier",
    "Address books" : "Adressebøker",
    "Rename" : "Gi nytt navn",
    "Export" : "Eksporter",
    "Send email" : "Send e-post",
    "Send email as BCC" : "Send e-post som blindkopi",
    "Delete" : "Slett",
    "Show all groups" : "Vis alle grupper",
    "Collapse groups" : "Kollapse grupper",
    "Show all teams" : "Vis alle lag",
    "Collapse teams" : "Skjul lag",
    "This group already exists" : "Denne gruppen finnes allerede",
    "This team already exists" : "Dette laget finnes allerede",
    "An error happened during the creation of the team" : "En feil oppstod under oppretting av laget",
    "Recently contacted" : "Nylig kontaktet",
    "Contact groups" : "Kontaktgrupper",
    "Create a new contact group" : "Opprett en ny kontaktgruppe",
    "Contact group name" : "Kontaktgruppenavn",
    "Create a new team" : "Opprett et nytt lag",
    "Open the contacts app settings" : "Åpne innstillingene for kontakterappen",
    "_Shared with {num} entity_::_Shared with {num} entities_" : ["Delt med {num} entitet","Delt med {num} entiteter"],
    "Copied" : "Kopiert",
    "Cannot copy" : "Kan ikke kopiere",
    "Copy link" : "Kopier lenke",
    "Toggling of address book was not successful" : "Veksling av adressebok var ikke vellykket",
    "This will delete the address book and every contacts within it" : "Dette vil slette adresseboken og alle kontakter i den",
    "Delete {addressbook}?" : "Slette {addressbook}?",
    "This will unshare the address book and every contacts within it" : "Dette vil oppheve delingen av adresseboken og alle kontakter i den",
    "Unshare {addressbook}?" : "Oppheve deling av {addressbook}?",
    "Deletion of address book was not successful." : "Sletting av adressebok var ikke vellykket.",
    "Renaming of address book was not successful." : "Omdøping av adresseboken var ikke vellykket.",
    "Download" : "Last ned",
    "Show" : "Vis",
    "Unshare from me" : "Fjern deling fra meg",
    "_%n contact_::_%n contacts_" : ["%n kontakt","%n kontakter"],
    "_%n group_::_%n groups_" : ["%n gruppe","%n grupper"],
    "Share with users or groups" : "Del med brukere eller grupper",
    "Share with users" : "Del med brukere",
    "No users or groups" : "Ingen brukere eller grupper",
    "Unable to delete the share" : "Kan ikke slette delingen",
    "Unable to change permissions" : "Kan ikke endre tillatelser",
    "Choose a vCard file to import" : "Velg en vCard-fil å importere",
    "Import into the {addressbookName} address book" : "Importer til {addressbookName}-adresseboken",
    "Select local file" : "Velg lokal fil",
    "Import from files" : "Importer fra filer",
    "Importing is disabled because there are no address books available" : "Import er deaktivert fordi det ikke finnes noen tilgjengelige adressebøker",
    "An error occurred, unable to create the address book" : "Det oppstod en feil, kan ikke opprette adresseboken",
    "Add new address book" : "Legg til ny adressebok",
    "Cancel" : "Avbryt",
    "Add" : "Legg til",
    "First name" : "Fornavn",
    "Last name" : "Etternavn",
    "Phonetic first name" : "Fonetisk fornavn",
    "Phonetic last name" : "Fonetisk etternavn",
    "Display name" : "Visningsnavn",
    "Last modified" : "Sist endret",
    "Manages" : "Håndterer",
    "Oversees" : "Overvåker",
    "An error happened during the config change" : "Det oppstod en feil under konfigurasjonsendringen",
    "Enforce password protection on files shared to this team" : "Håndhev passordbeskyttelse på filer som deles med dette laget",
    "Use a unique password for all shares to this team" : "Bruk et unikt passord for alle delinger i dette laget",
    "Save" : "Lagre",
    "Change unique password" : "Endre unikt passord",
    "Failed to save password. Please try again later." : "Lagring av passord feilet. Forsøk igjen senere.",
    "Close" : "Lukk",
    "There is no description for this team" : "Det er ingen beskrivelse for dette laget",
    "Enter a description for the team" : "Angi en beskrivelse for laget",
    "Folder" : "Folder",
    "Team name" : "Lagnavn",
    "Delete picture" : "Slett bilde",
    "Edit" : "Redigere",
    "Request to join" : "Spør om å bli med",
    "Create" : "Ny",
    "Your request to join this team is pending approval" : "Forespørselen din om å bli med i dette laget venter på godkjenning",
    "You are not a member of {circle}" : "Du er ikke medlem av {circle}",
    "Members" : "Medlemmer",
    "Confirm" : "Bekreft",
    "Add more info" : "Legg til mer info",
    "More fields" : "Flere felt",
    "Please select a valid format" : "Vennligst velg et gyldig format",
    "Invalid image" : "Ugyldig bilde",
    "Error cropping picture" : "Feil ved beskjæring av bilde",
    "Pick an avatar" : "Velg en avatar",
    "Error while processing the picture." : "Feil under behandling av bildet.",
    "Avatar downloaded from social network" : "Avatar lastet ned fra sosialt nettverk",
    "Avatar already up to date" : "Avatar er allerede oppdatert",
    "Avatar download failed" : "Nedlasting av avatar feilet",
    "Crop contact photo" : "Beskjær kontaktbilde",
    "Upload a new picture" : "Last opp et nytt bilde",
    "Choose from Files" : "Velg fra Filer",
    "Download picture" : "Last ned bilde",
    "Clone contact" : "Dupliser kontakt",
    "This contact is in read-only mode. You do not have permission to edit this contact." : "Kontakten er skrivebeskyttet. Du har ikke tillatelse til å redigere denne kontakten.",
    "The contact you were trying to edit has changed. Please manually refresh the contact. Any further edits will be discarded." : "Kontakten du prøvde å redigere, har blitt endret. Vennligst oppdater manuelt. Ytterligere endringer vil ikke kunne lagres.",
    "Address book" : "Adressebok",
    "Add contact to Birthday Calendar" : "Legg til kontakt til bursdagskalender",
    "Exclude contact from Birthday Calendar" : "Ekskluder kontakt fra bursdagskalender",
    "{title} at {organization}" : "{title} ved {organization}",
    "Name" : "Navn",
    "Syntax error. Cannot open the contact." : "Syntaksfeil. Kan ikke åpne kontakten.",
    "The contact does not exist on the server anymore." : "Kontakten eksisterer ikke på serveren lenger.",
    "Unable to retrieve the contact from the server, please check your network connection." : "Kan ikke hente kontakten fra serveren, vennligst sjekk nettverkstilkoblingen.",
    "An error occurred while trying to move the contact" : "Det oppstod en feil under forsøk på å flytte kontakten",
    "An error occurred while trying to copy the contact" : "Det oppstod en feil under forsøk på å kopiere kontakten",
    "Unable to update contact" : "Ikke i stand til å oppdatere kontakten",
    "No contact selected" : "Ingen kontakt valgt",
    "Select a contact on the list to begin" : "Velg en kontakt fra listen for å begynne",
    "Title" : "Tittel",
    "Company" : "Bedrift",
    "Go to talk conversation" : "Gå til tale-samtale",
    "View profile" : "Se profil",
    "This contact was broken and received a fix. Please review the content and click here to save it." : "Denne kontakten ble ødelagt og fikk en løsning. Se gjennom innholdet og klikk her for å lagre det.",
    "Edit profile" : "Rediger profil",
    "Generate QR Code" : "Generer QR-kode",
    "Contact vCard as QR code" : "Kontakt vCard som QR-kode",
    "Select address book" : "Velg adressebok",
    "Media shares with you" : "Mediadelinger med deg",
    "Talk conversations with you" : "Talk-samtaler med deg",
    "Calendar events with you" : "Kalenderhendelser med deg",
    "Deck cards with you" : "Deck-kort med deg",
    "No shared items with this contact" : "Ingen delte elementer med denne kontakten",
    "Move" : "Move",
    "Remove from favorites" : "Fjern fra favoritter",
    "Add to favorites" : "Legg til i favoritter",
    "Add to {group}" : "Legg til i {group}",
    "Remove {type}" : "Fjern {type}",
    "Add to group" : "Legg til gruppe",
    "Search {types}" : "Søk {types}",
    "Search for people to add" : "Søk etter personer å legge til",
    "No results" : "Ingen resultater",
    "Add {type}" : "Legg til {type}",
    "New team name" : "Nytt lagnavn",
    "Personal team" : "Personlig lag",
    "This team will only be visible to you. Other members will not be able to see or use it." : "Dette laget vil bare være synlig for deg. Andre medlemmer vil ikke kunne se eller bruke den.",
    "Local team" : "Lokalt lag",
    "This team will not be shared with the other instances of the global scale" : "Dette laget vil ikke bli delt med de andre forekomstene av den globale skalaen",
    "Create team" : "Opprett lag",
    "Promote as sole owner" : "Fremme som eneeier",
    "Promote to {level}" : "Fremme til {level}",
    "Demote to {level}" : "Nedgradere til {level}",
    "Could not delete the member {displayName}" : "Kunne ikke slette medlemmet {displayName}",
    "Could not change the member level to {level}" : "Kunne ikke endre medlemsnivå til {level}",
    "Could not accept membership request" : "Kunne ikke godta medlemskapsforespørsel",
    "Accept membership request" : "Godta medlemskapsforespørsel",
    "Reject membership request" : "Avvis medlemskapsforespørsel",
    "Manage level" : "Håndtere nivå",
    "Remove member" : "Fjern medlem",
    "Unable to get the results" : "Får ikke tak i resultatene",
    "Some members could not be added" : "Noen medlemmer kunne ikke legges til",
    "There was an issue adding members to the team" : "Det oppstod et problem med å legge til medlemmer til dette laget",
    "The list of members is only visible to members of this team" : "Listen over medlemmer er kun synlig for medlemmer av dette laget",
    "You currently have no access to the member list" : "Du har for øyeblikket ingen adgang til medlemslisten",
    "Pending" : "Venter",
    "Accept" : "Aksepter",
    "Chart" : "Kart",
    "Select type" : "Velg type",
    "Add contact in group" : "Legg kontakt til gruppe",
    "None" : "Ingen",
    "Select option" : "Velg innstilling",
    "Notes" : "Notater",
    "Add property of this type" : "Legg til egenskap for denne typen",
    "Member" : "Medlem",
    "Unable to create the contact." : "Kontakten kunne ikke opprettes.",
    "Contact not found" : "Kontakten ble ikke funnet",
    "Group {group} not found" : "Fant ikke gruppen {group}",
    "Add member" : "Legg til et medlem",
    "New contact" : "Ny kontakt",
    "_{success} contact added to {name}_::_{success} contacts added to {name}_" : ["{success} kontakt lagt til {name}","{success} kontakter lagt til {name}"],
    "_Adding {success} contact to {name}_::_Adding {success} contacts to {name}_" : ["Legger til {success} kontakt til {name}","Legger til {success} kontakter til {name}"],
    "_{count} error_::_{count} errors_" : ["{count} feil","{count} feil"],
    "_Importing %n contact into {addressbook}_::_Importing %n contacts into {addressbook}_" : ["Importerer %n kontakt til {addressbook}","Importerer %n kontakter til {addressbook}"],
    "_Done importing %n contact into {addressbook}_::_Done importing %n contacts into {addressbook}_" : ["Ferdig med å importere %n kontakt til {addressbook}","Ferdig med å importere %n kontakter til {addressbook}"],
    "Import" : "Importer",
    "Are you sure you want to import this contact file?" : "Er du sikker på at du vil importere denne kontaktfilen?",
    "Could not copy" : "Kunne ikke kopiere",
    "Join team" : "Bli med i laget",
    "You are about to leave {circle}.\nAre you sure?" : "Du er i ferd med å forlate {circle}.\nEr du sikker?",
    "Please confirm team leave" : "Vennligst bekreft å forlate laget",
    "Could not leave the team {displayName}" : "Kunne ikke forlate laget {displayName}",
    "Unable to join the team" : "Ikke i stand til å bli med i laget",
    "You are about to delete {circle}.\nAre you sure?" : "Du er i ferd med å slette {circle}.\nEr du sikker?",
    "Please confirm team deletion" : "Vennligst bekreft sletting av lag",
    "Unable to delete the team" : "Ikke i stand til å slette laget",
    "Link copied to the clipboard" : "Lenke kopiert til utklippstavlen",
    "Could not copy link to the clipboard." : "Kunne ikke kopiere lenke til utklippstavlen",
    "Not grouped" : "Ikke gruppert",
    "Team" : "Lag",
    "User" : "Bruker",
    "Group" : "Gruppe",
    "Email" : "E-post",
    "Contact" : "Kontakt",
    "Moderator" : "Moderator",
    "Admin" : "Administrator",
    "Owner" : "Eier",
    "Invites" : "Invitasjoner",
    "Anyone can request membership" : "Alle kan be om medlemskap",
    "Members need to accept invitation" : "Medlemmer må godta invitasjonen",
    "Memberships must be confirmed/accepted by a Moderator (requires \"Anyone can request membership\")" : "Medlemskap må bekreftes / aksepteres av en moderator (krever \"Alle kan be om medlemskap\")",
    "Members can also invite" : "Medlemmer kan også invitere",
    "Prevent teams from being a member of another team" : "Hindre lag fra å kunne bli medlem av en annet lag",
    "Visible to everyone" : "Synlig for alle",
    "users" : "brukere",
    "Users" : "Brukere",
    "groups" : "grupper",
    "teams" : "lag",
    "email addresses" : "e-postadresser",
    "Email addresses" : "E-postadresser",
    "Detailed name" : "Detaljert navn",
    "Additional names" : "Ev. mellomnavn",
    "Prefix" : "Prefiks",
    "Suffix" : "Suffiks",
    "Nickname" : "Kallenavn",
    "Website" : "Nettsted",
    "Location" : "Sted",
    "Federated Cloud ID" : "ID for sammenknyttet sky",
    "Home" : "Hjem",
    "Work" : "Jobb",
    "Other" : "Annet",
    "Address" : "Adresse",
    "Post office box" : "Postboks",
    "Extended address" : "Utvidet adresse",
    "City" : "By",
    "State or province" : "Stat eller fylke",
    "Postal code" : "Postnummer",
    "Country" : "Land",
    "Birthday" : "Bursdag",
    "Anniversary" : "Jubileum",
    "Date of death" : "Dødsdato",
    "Instant messaging" : "Direktemeldinger",
    "Phone" : "Telefon",
    "Mobile" : "Mobil",
    "Work mobile" : "Arbeidstelefon",
    "Home mobile" : "Hjemmemobil",
    "Fax" : "Faks",
    "Fax home" : "Faks hjemme",
    "Fax work" : "Faks jobb",
    "Pager" : "Pager",
    "Voice" : "Svarer",
    "Car" : "Bil",
    "Work pager" : "Arbeidspersonsøker",
    "Line manager" : "Linjeleder",
    "Social network" : "Sosialt nettverk",
    "Relationship to you" : "Relasjon til deg",
    "Spouse" : "Ektefelle",
    "Child" : "Barn",
    "Mother" : "Mor",
    "Father" : "Far",
    "Parent" : "Forelder",
    "Brother" : "Bror",
    "Sister" : "Søster",
    "Relative" : "Slektning",
    "Friend" : "Venn",
    "Colleague" : "Kollega",
    "Assistant" : "Assistent",
    "Related contacts" : "Relaterte kontakter",
    "Agent" : "Agent",
    "Emergency" : "Nødstilfelle",
    "Co-worker" : "Kollega",
    "Gender" : "Kjønn",
    "Female" : "Mann",
    "Male" : "Dame",
    "Unknown" : "Ukjent",
    "Time zone" : "Tidssone",
    "Spoken languages" : "Talte språk",
    "_{failed} contact failed to be read_::_{failed} contacts failed to be read_" : ["{failed} kontakt kunne ikke bli lest inn","{failed} kontakter kunne ikke bli lest inn"],
    "An error has occurred in team(s). Check the console for more details." : "Det har oppstått en feil i laget(ene). Sjekk konsollen hvis du vil ha mer informasjon.",
    "Unable to create team {circleName}" : "Ikke i stand til å opprette lag {circleName}",
    "Unable to delete team {circleId}" : "Ikke i stand til å slette lag {circleId}",
    "Unable to delete contact" : "Ikke i stand til å slette kontakt",
    "Pick an address book" : "Velg en adressebok",
    "Select Date" : "Velg dato"
},
"nplurals=2; plural=(n != 1);");
