OC.L10N.register(
    "contacts",
    {
    "Import contacts" : "Importeer contactpersonen",
    "Details" : "Details",
    "All contacts" : "Alle contactpersonen",
    "_Imported %n contact_::_Imported %n contacts_" : ["%n contactpersonen geïmporteerd"," %n contactpersonen geïmporteerd"],
    "_(skipped %n contact)_::_(skipped %n contacts)_" : ["(%n contactpersoon overgeslagen)","(%n contactpersonen overgeslagen)"],
    "Contacts" : "Contactpersonen",
    "A contacts app for Nextcloud" : "Een contactpersonen app voor Nextcloud",
    "The Nextcloud contacts app is a user interface for Nextcloud's CardDAV server. Easily sync contacts from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Currently Mail and Calendar – more to come.\n* 🎉 **Never forget a birthday!** You can sync birthdays and other recurring events with your Nextcloud Calendar.\n* 👥 **Sharing of Adressbooks!** You want to share your contacts with your friends or coworkers? No problem!\n* 🙈 **We’re not reinventing the wheel!** Based on the great and open SabreDAV library." : "De contactpersonen app is een gebruikersinterface voor de Nextcloud's CardDAV server. Eenvoudig synchroniseren van contacten vanuit verschillende apparaten met jouw Nextcloud en online bewerken ervan.\n\n* 🚀 **Integratie met andere Nextcloud apps!** Momenteel Mail en Agenda - meer volgt later.\n* 🎉 **vergeet geen enkele verjaardag!** Je kunt verjaardagen en andere herhalende afspraken synchroniseren met je Nextcloud Agenda.\n* 👥 **Delen van adresboeken!** Wil je jouw contactpersonen delen met vrienden of collega's? Geen probleem!\n* 🙈 **We vinden het wiel niet opnieuw uit!** Gebaseerd op de fraaie SabreDAV library.",
    "Copy to full name" : "Kopiëren naar volledige naam",
    "Omit year" : "Jaar weglaten",
    "Allow updating avatars from social media" : "Sta het bijwerken van avatars van sociale media toe",
    "Organization chart" : "Organisatiestructuur",
    "There was an error fetching the member list" : "Er trad fout op bij het ophalen van de ledenlijst",
    "Teams" : "Teams",
    "Please select a team" : "Selecteer een team",
    "Loading team…" : "Team laden..",
    "Loading contacts …" : "Contactpersonen laden …",
    "There are no contacts yet" : "Er zijn nog geen contactpersonen",
    "Create contact" : "Contactpersoon aanmaken",
    "There are no contacts in this group" : "Er zijn geen contactpersonen in deze groep",
    "Create contacts" : "Contactpersonen aanmaken",
    "Add contacts" : "Toevoegen contactpersonen",
    "Retry" : "Opnieuw proberen",
    "Loading …" : "Bezig met laden …",
    "Manage team" : "Team beheren",
    "Leave team" : "Team verlaten",
    "Delete team" : "Team verwijderen",
    "Setting saved" : "Instelling opgeslagen",
    "Failed to save setting" : "Instelling opslaan niet gelukt",
    "Contacts settings" : "Contactinstellingen",
    "General" : "Algemeen",
    "Update avatars from social media" : "Avatars van sociale media bijwerken",
    "Refreshed once per week" : "Eenmaal per week vernieuwd",
    "Address books" : "Adresboeken",
    "Tried to drop an invalid contact!" : "Geprobeerd een ongeldig contact los te laten!",
    "Rename" : "Hernoemen",
    "Export" : "Export",
    "Send email" : "Stuur e-mail",
    "Send email as BCC" : "Stuur e-mail als BCC",
    "Delete" : "Verwijderen",
    "Show all groups" : "Toon alle groepen",
    "Collapse groups" : "Groepen samenvouwen",
    "Show all teams" : "Alle teams weergeven",
    "Collapse teams" : "Teams samenvouwen",
    "Group name cannot be empty" : "Groepsnaam is vereist",
    "This group already exists" : "Deze groep bestaat al",
    "An error occurred while creating the group" : "Er is een fout opgetreden tijdens het aanmaken van de groep",
    "This team already exists" : "Dit team bestaat al",
    "An error happened during the creation of the team" : "Er is een fout opgetreden tijdens het aanmaken van het team.",
    "Recently contacted" : "Recentelijk gecontacteerd",
    "Contact groups" : "Contactgroepen",
    "Create a new contact group" : "Maak een nieuwe contactgroep",
    "Contact group name" : "Contactgroepnaam",
    "Create a new team" : "Nieuw team aanmaken",
    "Open the contacts app settings" : "Open instellingen van de contacten app",
    "_Shared with {num} entity_::_Shared with {num} entities_" : ["Gedeeld met {num} andere","Gedeeld met {num} anderen"],
    "Copied" : "Gekopieerd",
    "Cannot copy" : "Kan niet kopiëren",
    "Copy link" : "Link kopiëren",
    "Toggling of address book was not successful" : "Omwisseling van adresboek is niet gelukt",
    "This will delete the address book and every contacts within it" : "Dit verwijdert het adresboek en alle contactpersonen daarbinnen",
    "Delete {addressbook}?" : "Verwijderen {addressbook}?",
    "This will unshare the address book and every contacts within it" : "Hierdoor wordt het adresboek en alle contacten daarin niet langer gedeeld.",
    "Unshare {addressbook}?" : "{addressbook} niet langer delen?",
    "Deletion of address book was not successful." : "Verwijderen adresboek is niet gelukt.",
    "Renaming of address book was not successful." : "Hernoemen adresboek is niet gelukt.",
    "{addressbookname} (Hidden)" : "{addressbookname} (Verborgen)",
    "Download" : "Downloaden",
    "Show" : "Tonen",
    "Unshare from me" : "Niet meer delen met mij",
    "_%n contact_::_%n contacts_" : ["%n contactpersoon","%n contactpersonen"],
    "_%n group_::_%n groups_" : ["%n groep","%n groepen"],
    "Share with users or groups" : "Delen met gebruikers of groepen",
    "Share with users" : "Delen met gebruikers",
    "No users or groups" : "Geen gebruikers of groepen",
    "Unable to delete the share" : "Kan de share niet verwijderen",
    "Unable to change permissions" : "Kan de machtigingen niet wijzigen",
    "can create and edit" : "kan maken en bewerken",
    "Choose a vCard file to import" : "Kies een vCard bestand om te importeren",
    "Import into the {addressbookName} address book" : "Importeren in het {addressbookName} adresboek",
    "Select local file" : "Selecteer lokaal bestand",
    "Import from files" : "Importeren uit bestanden",
    "Importing is disabled because there are no address books available" : "Importeren is uitgeschakeld omdat er geen adresboeken beschikbaar zijn",
    "An error occurred, unable to create the address book" : "Er is een fout opgetreden, het adresboek kan niet worden aangemaakt.",
    "New address book" : "Nieuw adresboek",
    "Add new address book" : "Nieuw adresboek toevoegen",
    "Cancel" : "Annuleren",
    "Add" : "Toevoegen",
    "First name" : "Voornaam",
    "Last name" : "Achternaam",
    "Phonetic first name" : "Fonetische voornaam",
    "Phonetic last name" : "Fonetische achternaam",
    "Display name" : "Weergavenaam",
    "Last modified" : "Laatst gewijzigd",
    "Sort contacts by" : "Sorteer contactpersonen op",
    "Manages" : "Leid",
    "Oversees" : "Houdt toezicht op",
    "An error happened during the config change" : "Er trad een fout op bij de config-wijziging",
    "Enforce password protection on files shared to this team" : "Wachtwoordbeveiliging afdwingen voor bestanden die met dit team worden gedeeld",
    "Use a unique password for all shares to this team" : "Gebruik een uniek wachtwoord voor alle shares voor dit team",
    "Unique password …" : "Uniek wachtwoord …",
    "Save" : "Opslaan",
    "Change unique password" : "Wijzig uniek wachtwoord",
    "Failed to save password. Please try again later." : "Niet gelukt om het wachtwoord op te slaan. Probeer aub later nogmaals.",
    "Close" : "Afsluiten",
    "Choose a team picture" : "Kies een teamafbeelding",
    "There is no description for this team" : "Er is geen beschrijving voor dit team",
    "Enter a description for the team" : "Voer een beschrijving in voor het team",
    "Folder" : "Map",
    "New folder" : "Nieuwe map",
    "Folder name" : "Mapnaam",
    "This will create a regular folder shared with the team. To create a Team Folder, please contact your {productName} administrator" : "Hiermee wordt een gewone map aangemaakt die met het team wordt gedeeld. Om een Team map aan te te maken, neem contact op met uw {productName} beheerder",
    "Talk conversation" : "Talk gesprek",
    "New Talk conversation" : "Nieuw Talk gesprek",
    "Conversation name" : "Gespreksnaam",
    "Collective" : "Collectief",
    "Calendar" : "Agenda",
    "New calendar" : "Nieuwe agenda",
    "Calendar name" : "Agendanaam",
    "Unknown resource type" : "Onbekend type bron",
    "Team calendar \"{resourceName}\" created and shared with team" : "Teamagenda \"{resourceName}\" aangemaakt en gedeeld met team",
    "{resourceType} \"{resourceName}\" created and shared with team" : "{resourceType} \"{resourceName}\" gemaakt en gedeeld met het team",
    "A calendar named \"{name}\" already exists. Please choose a different name." : "Er bestaat al een agenda met de naam \"{name}\".  Kies een andere naam.",
    "Failed to create {resourceType}: {error}" : "Aanmaken van {resourceType}: {error} mislukt",
    "Please select a valid png or jpg file" : "Selecteer een geldig png- of jpg-bestand",
    "Error picking team picture" : "Fout bij kiezen van teamafbeelding",
    "Error cropping avatar picture" : "Fout bij bijsnijden van avatarafbeelding",
    "An error happened while saving {fields}" : "Er is een fout opgetreden tijden het opslaan van {fields}",
    "Team name" : "Team naam",
    "Team owner" : "Team eigenaar",
    "Upload team picture" : "Teamafbeelding uploaden",
    "Choose from Nextcloud Files" : "Kiezen uit Nextcloud Bestanden",
    "Delete picture" : "Verwijder afbeelding",
    "Edit" : "Bewerken",
    "Request to join" : "Aanvraag voor deelname",
    "Create" : "Maak",
    "Show in Calendar" : "Toon in Agenda",
    "Your request to join this team is pending approval" : "Je verzoek tot deelname aan het team wacht op bevestiging",
    "You are not a member of {circle}" : "Je bent geen lid van {circle}",
    "Members" : "Leden",
    "Edit team picture" : "Teamafbeelding bewerken",
    "Apply" : "Toepassen",
    "Confirm" : "Bevestigen",
    "No other contacts available to select as line manager" : "Geen andere contacten beschikbaar om als lijnmanager te selecteren",
    "Add more info" : "Meer informatie toevoegen",
    "More fields" : "Meer velden",
    "Please select a valid format" : "Selecteer alstublieft een geldig formaat",
    "Invalid image" : "Afbeelding ongeldig",
    "Error cropping picture" : "Fout bij het bijsnijden van de afbeelding",
    "Pick an avatar" : "Kies een avatar",
    "Pick" : "Selecteren",
    "Error while processing the picture." : "Fout bij het verwerken van de afbeelding.",
    "Avatar downloaded from social network" : "Avatar gedownload van sociaal netwerk",
    "Avatar already up to date" : "Avatar is al up-to-date",
    "Avatar download failed" : "Avatar downloaden is mislukt",
    "Crop contact photo" : "Crop contactfoto",
    "Upload a new picture" : "Uploaden nieuwe afbeelding",
    "Choose from Files" : "Kies uit Bestanden",
    "Download picture" : "Download afbeelding",
    "Clone contact" : "Klonen contactpersoon",
    "This contact is in read-only mode. You do not have permission to edit this contact." : "Deze contactpersoon is alleen-leesbaar. Je hebt niet de machtiging om deze contactpersoon te bewerken.",
    "The contact you were trying to edit has changed. Please manually refresh the contact. Any further edits will be discarded." : "De contactpersoon die je wilde bewerken is gewijzigd. Ververs de contactgegevens handmatig. Verdere wijzigingen worden genegeerd.",
    "Address book" : "Adresboek",
    "Add contact to Birthday Calendar" : "Contactpersoon toevoegen aan verjaardagskalender",
    "Exclude contact from Birthday Calendar" : "Contactpersoon uitsluiten van verjaardagskalender",
    "{title} at {organization}" : "{title} bij {organization}",
    "Name" : "Naam",
    "Syntax error. Cannot open the contact." : "Syntaxfout. Kan de contactpersoon niet openen.",
    "The contact does not exist on the server anymore." : "Het contact bestaat niet meer op de server.",
    "Unable to retrieve the contact from the server, please check your network connection." : "Kan contactpersoon niet ophalen van de server. Controleer je netwerkverbinding.",
    "An error occurred while trying to move the contact" : "Er trad een fout op bij het verplaatsen van de contactpersoon",
    "An error occurred while trying to copy the contact" : "Er trad een fout op bij het kopiëren van de contactpersoon",
    "Unable to update contact" : "Niet in staat om contactpersoon bij te werken",
    "No contact selected" : "Geen contactpersoon geselecteerd",
    "Select a contact on the list to begin" : "Selecteer een contactpersoon in de lijst om te beginnen",
    "Title" : "Titel",
    "Company" : "Organisatie",
    "Go to talk conversation" : "Ga naar het Talk gesprek",
    "View profile" : "Bekijk profiel",
    "This contact was broken and received a fix. Please review the content and click here to save it." : "Dit contactpersoon was beschadigd en is hersteld. Controleer alstublieft of de contactpersoon correct hersteld is en klik hier om het te bewaren.",
    "Edit profile" : "Bewerken profiel",
    "Generate QR Code" : "Genereer QR code",
    "Contact vCard as QR code" : "Contactpersoon vCard als QR code",
    "Select address book" : "Selecteer adresboek",
    "Media shares with you" : "Media deelt met jou",
    "Talk conversations with you" : "Talk gesprekken met jou ",
    "Calendar events with you" : "Agenda-gebeurtenissen met jou",
    "Deck cards with you" : "Deck kaarten met je",
    "No shared items with this contact" : "Geen gedeelde items met deze contactpersoon",
    "This contact cannot be moved" : "Dit contactpersoon kan niet worden verplaatst",
    "This contact cannot be grouped" : "Dit contactpersoon kan niet worden gegroupeerd",
    "Add contacts to groups" : "Voeg contactpersonen toe aan groep",
    "Move contacts to addressbook" : "Verplaats contactpersonen naar adresboek",
    "Select groups" : "Selecteer groepen",
    "Select addressbook" : "Selecteer adresboek",
    "Selected contacts" : "Selecteer contactpersonen",
    "Please note that only {count} of the {total} contacts can be added to a group" : "Let op dat maar {count} van de {total} contactpersonen kan worden toegevoegd aan een groep",
    "Please note that only {count} of the {total} contacts can be moved" : "Let op dat maar {count} van de {total} contactpersonen kan worden verplaatst",
    "Move" : "Verplaats",
    "Could not update favorite status" : "Kon favorietstatus niet bijwerken",
    "from {addressbook}" : "van {addressbook}",
    "Remove from favorites" : "Verwijderen uit favorieten",
    "Add to favorites" : "Voeg toe aan favorieten",
    "Confirm merging contacts" : "Bevestig samenvoegen contactpersonen",
    "The selected contacts have conflicting information. Choose which information to keep" : "De geselecteerde contactpersonen hebben conflicterende informatie. Kies welke informatie behouden moet worden",
    "Contacts can be merged" : "Contactpersonen kunnen worden samengevoegd",
    "Groups" : "Groepen",
    "Select groups to add the merged contact to" : "Selecteer groepen om de samengevoegde contactpersonen aan toe te voegen",
    "Merge contacts" : "Voeg contactpersonen samen",
    "_Delete {number} contact_::_Delete {number} contacts_" : ["Verwijder {number} contactpersoon","Verwijder {number} contactpersonen"],
    "Please select at least one editable contact to delete" : "Selecteer op zijn minst één bewerkbare contactpersoon om te wiisen",
    "Please select two editable contacts to merge" : "Selecteer twee bewerkbare contactpersonen om samen te voegen",
    "_Add {number} contact to group_::_Add {number} contacts to group_" : ["Voeg {number} contactpersoon aan groep","Voeg {number} contactpersonen aan groep"],
    "Please select at least one editable contact to add to a group" : "Kies minimaal één aanpasbare contactpersoon om te verplaatsen naar een groep",
    "_Move {number} contact to addressbook_::_Move {number} contacts to addressbook_" : ["Verplaats {number} contactpersoon naar adressenboek","Verplaats {number} contactpersonen naar adressenboek"],
    "Please select at least one editable contact to move to an addressbook" : "Kies minimaal één aanpasbare contactpersoon om te verplaatsen naar een adressenboek",
    "Are you sure you want to proceed?" : "Weet je zeker dat je door wil gaan?",
    "Add contacts to group" : "Voeg contactpersonen toe aan groep",
    "Search contacts …" : "Doorzoek contactpersonen …",
    "Unselect {number}" : "Deselecteer {number}",
    "Add to {group}" : "Toevoegen aan {group}",
    "Add members to {group}" : "Voeg leden toe aan {group}",
    "Please note that you can only add contacts from writable address books to contact groups. Contacts from read-only address books, such as the system address book, cannot be added." : "Let op: je kunt alleen contacten uit beschrijfbare adresboeken aan contactgroepen toevoegen. Contacten uit alleen-lezen adresboeken, zoals het systeemadresboek, kunnen niet worden toegevoegd.",
    "Remove {type}" : "Verwijder {type}",
    "Add to group" : "Toevoegen aan een groep",
    "Add members to group" : "Voeg leden toe aan groep",
    "Search {types}" : "Zoeken naar {types}",
    "Add guest" : "Voeg gast toe",
    "Search for people to add" : "Zoek naar toe te voegen personen",
    "No results" : "Geen resultaten",
    "Add {type}" : "{type} toevoegen",
    "New team name" : "Nieuwe teamnaam",
    "Personal team" : "Persoonlijk team",
    "This team will only be visible to you. Other members will not be able to see or use it." : "Dit team is alleen zichtbaar voor jou. Andere leden kunnen het niet zien of gebruiken.",
    "Local team" : "Lokaal team",
    "This team will not be shared with the other instances of the global scale" : "Dit team zal niet worden gedeeld met andere instanties of globaal.",
    "Create team" : "Team maken",
    "Promote as sole owner" : "Promoveer tot enige eigenaar",
    "Promote to {level}" : "Promoveer naar {level}",
    "Demote to {level}" : "Terugzetten naar {level}",
    "Are you sure you want to leave this team? This action cannot be undone." : "Weet je zeker dat je dit team wil verlaten? Deze actie kan niet ongedaan worden gemaakt.",
    "Leave team failed." : "Verlaten van team mislukt.",
    "Could not delete the member {displayName}" : "Kon lid {displayName} niet verwijderen",
    "Could not change the member level to {level}" : "Kon lidmaatschapsniveau niet wijzigen naar {level}",
    "Could not accept membership request" : "Kon lidmaatschapsverzoek niet accepteren",
    "Accept membership request" : "Accepteer het lidmaatschapsverzoek",
    "Reject membership request" : "Weiger lidmaatschapsverzoek",
    "Manage level" : "Beheren niveau",
    "Remove member" : "Verwijder lid",
    "Unable to get the results" : "Kan de resultaten niet ophalen",
    "Some members could not be added" : "Sommige leden konden niet worden toegevoegd",
    "There was an issue adding members to the team" : "Er was een probleem tijden het toevoegen van leden aan het team",
    "Loading members list …" : "Ledenlijst aan het ophalen …",
    "The list of members is only visible to members of this team" : "De lijst met teamleden is alleen zichtbaar voor leden van het team",
    "You currently have no access to the member list" : "Je hebt momenteel geen toegang tot de ledenlijst",
    "Add to {team}" : "Toevoegen aan {team}",
    "Invite members to {team}" : "Nodig leden uit voor {team}",
    "Pending" : "In behandeling",
    "Select chart …" : "Selecteer diagram …",
    "Chart" : "Grafiek",
    "Select type" : "Selecteer type",
    "Add contact in group" : "Voeg contactpersoon aan groep toe",
    "None" : "Geen",
    "copy" : "kopieër",
    "Select option" : "Selecteer optie",
    "JavaScript URIs are not allowed" : "JavaScript URIs zijn niet toegestaan",
    "Notes" : "Notities",
    "send an email" : "verstuur een e-mail",
    "Personal dates" : "Persoonlijke data",
    "Add property of this type" : "Voeg eigenschap van dit type toe",
    "Member" : "Lid",
    "This is a read-only group managed by administrators. Group members can only view this group." : "Dit is een alleen-lezen groep die wordt beheerd door de beheerders. Groepsleden kunnen deze groep alleen bekijken.",
    "Unable to create the contact." : "Kan contactpersoon niet aanmaken.",
    "Contact not found" : "Contactpersoon niet gevonden",
    "Group {group} not found" : "Groep {group} niet gevonden",
    "Add member" : "Toevoegen lid",
    "New contact" : "Nieuwe contactpersoon",
    "_{success} contact added to {name}_::_{success} contacts added to {name}_" : ["{success} contactpersoon toegevoegd aan {name}","{success} contactpersonen toegevoegd aan {name}"],
    "_Adding {success} contact to {name}_::_Adding {success} contacts to {name}_" : ["{success} contactpersonen aan het toevoegen aan {name}","{success} contactpersonen aan het toevoegen aan {name}"],
    "_{count} error_::_{count} errors_" : ["{count} fout","{count} fouten"],
    "_Importing %n contact into {addressbook}_::_Importing %n contacts into {addressbook}_" : ["Importeren %n contactpersoon in {addressbook}","Importeren %n contactpersonen in {addressbook}"],
    "_Done importing %n contact into {addressbook}_::_Done importing %n contacts into {addressbook}_" : ["Klaar met het importeren van %n contactpersoon in {addressbook}","Klaar met het importeren van %n contactpersonen in {addressbook}"],
    "No data for this contact" : "Geen data voor dit contactpersoon",
    "No data for this contact on their profile" : "Geen data voor dit contactpersoon op hun profiel",
    "Import" : "Importeren",
    "Are you sure you want to import this contact file?" : "Weet je zeker dat je dit contactpersonen bestand wil importeren?",
    "Could not copy" : "Kon niet kopiëren",
    "Join team" : "Neem deel aan team",
    "You are about to leave {circle}.\nAre you sure?" : "Je gaat kring {circle} verlaten.\nWeet je het zeker?",
    "Please confirm team leave" : "Bevestig verlaten van team",
    "Could not leave the team {displayName}" : "Kan team {displayName} niet verlaten",
    "Unable to join the team" : "Kan niet deelnemen aan team",
    "You are about to delete {circle}.\nAre you sure?" : "Je gaat kring {circle} verwijderen.\nWeet je het zeker?",
    "Please confirm team deletion" : "Bevestig verwijdering van team",
    "Unable to delete the team" : "Kan het team niet verwijderen",
    "Confirm enabling federation" : "Inschakelen van federatie bevestigen",
    "Enabling this will prevent {circle} from being a member of other teams.\nAre you sure?" : "Dit activeren voorkomt dat {circle} lid wordt van andere teams.\nWeet je het zeker?",
    "Enable federation" : "Federatie inschakelen",
    "Link copied to the clipboard" : "Link gekopieerd naar het klembord",
    "Could not copy link to the clipboard." : "Kon link niet kopiëren naar het klembord.",
    "Not grouped" : "Niet gegroepeerd",
    "Create your own teams for sharing. Add Nextcloud users, contacts, or anyone via email." : "Maak je eigen teams om te delen. Voeg Nextcloud-gebruikers, contacten of iedereen via e-mail toe.",
    "Team" : "Team",
    "User" : "Gebruiker",
    "Group" : "Groep",
    "Email" : "Email",
    "Contact" : "Contactpersoon",
    "Moderator" : "Moderator",
    "Admin" : "Beheerder",
    "Owner" : "Eigenaar",
    "Invites" : "Uitnodigingen",
    "Anyone can request membership" : "Iedereen kan lid worden",
    "Members need to accept invitation" : "Leden moeten de uitnodiging accepteren",
    "Memberships must be confirmed/accepted by a Moderator (requires \"Anyone can request membership\")" : "Lidmaatschap moet worden bevestigd/geaccepteerd door een Moderator (vereist \"Iedereen kan lidmaatschap aanvragen\")",
    "Members can also invite" : "Leden kunnen anderen uitnodigen",
    "Membership" : "Lidmaatschap",
    "Prevent teams from being a member of another team" : "Voorkom dat teams lid worden van een ander team",
    "Federation" : "Federatie",
    "Allow federated members" : "Sta federatieleden toe",
    "Privacy" : "Privacy",
    "Visible to everyone" : "Zichtbaar voor iedereen",
    "users" : "gebruikers",
    "Users" : "Gebruikers",
    "groups" : "groepen",
    "federated users" : "gefedereerde gebruikers",
    "Federated users" : "Gefedereerde gebruikers",
    "teams" : "teams",
    "email addresses" : "e-mailadressen",
    "Email addresses" : "E-mailadressen",
    "contacts" : "contactpersonen",
    "Detailed name" : "Gedetailleerde naam",
    "Additional names" : "Extra namen",
    "Prefix" : "Voorvoegsel",
    "Suffix" : "Achtervoegsel",
    "Nickname" : "Roepnaam",
    "Website" : "Website",
    "Location" : "Locatie",
    "Federated Cloud ID" : "Gefedereerde Cloud ID",
    "Home" : "Thuis",
    "Work" : "Werk",
    "Other" : "Overig",
    "Address" : "Adres",
    "Post office box" : "Postbus",
    "Extended address" : "Uitgebreid adres",
    "City" : "Stad",
    "State or province" : "Staat of provincie",
    "Postal code" : "Postcode",
    "Country" : "Land",
    "Birthday" : "Verjaardag",
    "Place of birth" : "Plaats van geboorte",
    "Anniversary" : "Jubileum",
    "Date of death" : "Sterfdatum",
    "Place of death" : "Plaats van overlijden",
    "Instant messaging" : "Instant messaging",
    "Phone" : "Telefoon",
    "Mobile" : "Mobiel",
    "Work mobile" : "Werk mobiel",
    "Home mobile" : "Thuis mobiel",
    "Fax" : "Fax",
    "Fax home" : "Fax thuis",
    "Fax work" : "Fax werk",
    "Pager" : "Pieper",
    "Voice" : "Stem",
    "Car" : "Auto",
    "Work pager" : "Werk pieper",
    "Line manager" : "Lijnmanager",
    "Social network" : "Sociaal netwerk",
    "Relationship to you" : "Relatie met jou",
    "Spouse" : "Echtgenoot",
    "Child" : "Kind",
    "Mother" : "Moeder",
    "Father" : "Vader",
    "Parent" : "Ouder",
    "Brother" : "Broer",
    "Sister" : "Zus",
    "Relative" : "Familielid",
    "Friend" : "Vriend",
    "Colleague" : "Collega",
    "Assistant" : "Assistent",
    "Related contacts" : "Gerelateerde contactpersonen",
    "Agent" : "Agent",
    "Emergency" : "Nood",
    "Co-worker" : "Medewerker",
    "Gender" : "Geslacht",
    "Female" : "Vrouw",
    "Male" : "Man",
    "Unknown" : "Onbekend",
    "Time zone" : "Tijdzone",
    "Spoken languages" : "Gesproken talen",
    "_{failed} contact failed to be read_::_{failed} contacts failed to be read_" : ["{failed} contactpersoon werd niet ingelezen","{failed} contactpersonen werden niet ingelezen"],
    "An error has occurred in team(s). Check the console for more details." : "Er is een fout opgetreden in team(s). Controleer de console voor meer details.",
    "Unable to create team {circleName}" : "Kan team {circleName} niet aanmaken",
    "Unable to delete team {circleId}" : "Kan team {circleId} niet verwijderen",
    "Could not update favorite state" : "Kon favorietstatus niet bijwerken",
    "Unable to delete contact" : "Kan contactpersoon niet verwijderen",
    "Value copied to the clipboard" : "Waarde gekopieerd van het klembord",
    "Could not copy value to the clipboard." : "Kan waarde niet kopiëren naar het klembord",
    "Deck board" : "Deck bord",
    "New Deck board" : "Nieuw Deck bord",
    "Board name" : "Bordnaam",
    "Deck app is not installed. Please install it to create team boards." : "Deck app is niet geïnstalleerd. Installeer deze om teamborden te maken.",
    "Pick an address book" : "Kies een adresboek",
    "Select Date" : "Selecteer datum",
    "note" : "notitie",
    "email" : "e-mailadres",
    "Create your own groups for sharing. Add Nextcloud users, contacts, or anyone via email." : "Maak je eigen groepen aan om te delen. Voeg Nextcloud gebruikers, contactpersonen of anderen via e-mail toe."
},
"nplurals=2; plural=(n != 1);");
