.empty-content[data-v-6337267c]{width:100%;height:100%}.contact-title[data-v-6337267c]{margin-inline-start:100px;margin-top:40px}[data-v-6337267c] .property__value{font-size:medium!important}.recipient-details-loading[data-v-6337267c]{margin-top:64px}[data-v-6337267c] input{box-shadow:none!important}
