OC.L10N.register(
    "contacts",
    {
    "Import contacts" : "Εισαγωγή επαφών",
    "Details" : "Λεπτομέρειες",
    "All contacts" : "Όλες οι επαφές",
    "_Imported %n contact_::_Imported %n contacts_" : ["Εισήχθη %n επαφή","Εισήχθησαν %n επαφές"],
    "_(skipped %n contact)_::_(skipped %n contacts)_" : ["(παραλείφθηκε %n επαφή)","(παραλείφθηκαν %n επαφές)"],
    "Contacts" : "Επαφές",
    "A contacts app for Nextcloud" : "Εφαρμογή επαφών για το Nextcloud",
    "The Nextcloud contacts app is a user interface for Nextcloud's CardDAV server. Easily sync contacts from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Currently Mail and Calendar – more to come.\n* 🎉 **Never forget a birthday!** You can sync birthdays and other recurring events with your Nextcloud Calendar.\n* 👥 **Sharing of Adressbooks!** You want to share your contacts with your friends or coworkers? No problem!\n* 🙈 **We’re not reinventing the wheel!** Based on the great and open SabreDAV library." : "Η εφαρμογή επαφών του Nextcloud είναι μια διεπαφή χρήστη για τον διακομιστή CardDAV του Nextcloud. Συγχρονίστε εύκολα επαφές από διάφορες συσκευές με το Nextcloud σας και επεξεργαστείτε τις απευθείας.\n\n* 🚀 **Ενσωμάτωση με άλλες εφαρμογές Nextcloud!** Επί του παρόντος με το Mail και το Calendar - έπονται περισσότερα.\n* 🎉 **Ποτέ μην ξεχάσετε γενέθλια!** Μπορείτε να συγχρονίσετε γενέθλια και άλλα επαναλαμβανόμενα γεγονότα με το ημερολόγιο του Nextcloud.\n* 👥 **Κοινή χρήση Βιβλίων διευθύνσεων!** Θέλετε να μοιραστείτε τις επαφές σας με φίλους ή συνεργάτες; Κανένα πρόβλημα!\n* 🙈 **Δεν ανακαλύπτουμε ξανά τον τροχό!** Βασίζεται στην εξαιρετική και ανοιχτή βιβλιοθήκη SabreDAV.",
    "Copy to full name" : "Αντιγραφή στο πλήρες όνομα",
    "Omit year" : "Παράλειψη έτους",
    "Allow updating avatars from social media" : "Να επιτρέπεται η ενημέρωση του άβαταρ από τα μέσα κοινωνικής δικτύωσης",
    "Organization chart" : "Οργανόγραμμα",
    "There was an error fetching the member list" : "Παρουσιάστηκε σφάλμα κατά την ανάκτηση της λίστας μελών",
    "Teams" : "Ομάδες",
    "Please select a team" : "Παρακαλούμε επιλέξτε μια ομάδα",
    "Loading team…" : "Φόρτωση ομάδας…",
    "Loading contacts …" : "Φόρτωση επαφών …",
    "There are no contacts yet" : "Δεν υπάρχουν ακόμη επαφές",
    "Create contact" : "Δημιουργία επαφής",
    "There are no contacts in this group" : "Δεν υπάρχουν επαφές σε αυτήν την ομάδα",
    "Create contacts" : "Δημιουργία επαφών",
    "Add contacts" : "Προσθήκη επαφών",
    "Retry" : "Επανάληψη",
    "Loading …" : "Φόρτωση …",
    "Manage team" : "Διαχείριση ομάδας",
    "Leave team" : "Αποχώρηση από την ομάδα",
    "Delete team" : "Διαγραφή ομάδας",
    "Setting saved" : "Η ρύθμιση αποθηκεύτηκε",
    "Failed to save setting" : "Αποτυχία αποθήκευσης ρύθμισης",
    "Contacts settings" : "Ρυθμίσεις επαφών",
    "General" : "Γενικά",
    "Update avatars from social media" : "Ενημέρωση των άβαταρ από τα κοινωνικά δίκτυα",
    "Refreshed once per week" : "Ανανέωση μία φορά την εβδομάδα",
    "Address books" : "Βιβλία διευθύνσεων",
    "Tried to drop an invalid contact!" : "Έγινε προσπάθεια απόθεσης μη έγκυρης επαφής!",
    "Rename" : "Μετονομασία",
    "Export" : "Εξαγωγή",
    "Send email" : "Αποστολή email",
    "Send email as BCC" : "Αποστολή email ως BCC",
    "Delete" : "Διαγραφή",
    "Show all groups" : "Εμφάνιση όλων των ομάδων",
    "Collapse groups" : "Σύμπτυξη ομάδων",
    "Show all teams" : "Εμφάνιση όλων των ομάδων",
    "Collapse teams" : "Σύμπτυξη ομάδων",
    "Group name cannot be empty" : "Το όνομα της ομάδας δεν μπορεί να είναι κενό",
    "This group already exists" : "Αυτή η ομάδα υπάρχει ήδη",
    "An error occurred while creating the group" : "Προέκυψε σφάλμα κατά τη δημιουργία της ομάδας",
    "This team already exists" : "Αυτή η ομάδα υπάρχει ήδη",
    "An error happened during the creation of the team" : "Παρουσιάστηκε σφάλμα κατά τη δημιουργία της ομάδας",
    "Recently contacted" : "Πρόσφατη επικοινωνία",
    "Contact groups" : "Ομάδες επαφών",
    "Create a new contact group" : "Δημιουργία νέας ομάδας επαφών",
    "Contact group name" : "Όνομα ομάδας επαφών",
    "Create a new team" : "Δημιουργία νέας ομάδας",
    "Open the contacts app settings" : "Άνοιγμα ρυθμίσεων εφαρμογής επαφών",
    "_Shared with {num} entity_::_Shared with {num} entities_" : ["Κοινή χρήση με {num} οντότητα","Κοινή χρήση με {num} οντότητες"],
    "Copied" : "Αντιγράφηκε",
    "Cannot copy" : "Αδυναμία αντιγραφής",
    "Copy link" : "Αντιγραφή συνδέσμου",
    "Toggling of address book was not successful" : "Η εναλλαγή του βιβλίου διευθύνσεων απέτυχε",
    "This will delete the address book and every contacts within it" : "Αυτό θα διαγράψει το βιβλίο διευθύνσεων και όλες τις επαφές σε αυτό",
    "Delete {addressbook}?" : "Διαγραφή {addressbook};",
    "This will unshare the address book and every contacts within it" : "Αυτό θα καταργήσει την κοινή χρήση του βιβλίου διευθύνσεων και όλων των επαφών σε αυτό",
    "Unshare {addressbook}?" : "Κατάργηση κοινής χρήσης {addressbook};",
    "Deletion of address book was not successful." : "Απέτυχε η διαγραφή του βιβλίου διευθύνσεων.",
    "Renaming of address book was not successful." : "Η μετονομασία του βιβλίου διευθύνσεων απέτυχε.",
    "{addressbookname} (Hidden)" : "{addressbookname} (Κρυφό)",
    "Download" : "Λήψη",
    "Show" : "Εμφάνιση",
    "Unshare from me" : "Κατάργηση κοινής χρήσης από εμένα",
    "_%n contact_::_%n contacts_" : ["%n επαφή","%n επαφές"],
    "_%n group_::_%n groups_" : ["%n ομάδα","%n ομάδες"],
    "Share with users or groups" : "Διαμοιρασμός με χρήστες ή ομάδες",
    "Share with users" : "Κοινή χρήση με χρήστες",
    "No users or groups" : "Δεν υπάρχουν χρήστες ή ομάδες",
    "Unable to delete the share" : "Δεν είναι δυνατή η διαγραφή της κοινής χρήσης",
    "Unable to change permissions" : "Δεν είναι δυνατή η αλλαγή δικαιωμάτων",
    "can create and edit" : "μπορεί να δημιουργήσει και να επεξεργαστεί",
    "Choose a vCard file to import" : "Επιλογή αρχείου vCard για εισαγωγή",
    "Import into the {addressbookName} address book" : "Εισαγωγή στο βιβλίο διευθύνσεων {addressbookName}",
    "Select local file" : "Επιλογή τοπικού αρχείου",
    "Import from files" : "Εισαγωγή από αρχεία",
    "Importing is disabled because there are no address books available" : "Η λειτουργία εισαγωγής απενεργοποιήθηκε, καθώς δεν βρέθηκε κάποιο βιβλίο διευθύνσεων διαθέσιμο",
    "An error occurred, unable to create the address book" : "Παρουσιάστηκε σφάλμα, δεν ήταν δυνατή η δημιουργία του βιβλίου διευθύνσεων",
    "New address book" : "Νέο βιβλίο διευθύνσεων",
    "Add new address book" : "Προσθήκη νέου βιβλίου διευθύνσεων",
    "Cancel" : "Ακύρωση",
    "Add" : "Προσθήκη",
    "First name" : "Όνομα",
    "Last name" : "Επώνυμο",
    "Phonetic first name" : "Φωνητικό πρώτο όνομα",
    "Phonetic last name" : "Φωνητικό επώνυμο",
    "Display name" : "Εμφανιζόμενο όνομα",
    "Last modified" : "Τελευταία τροποποίηση",
    "Sort contacts by" : "Ταξινόμηση επαφών ανά",
    "Manages" : "Διαχειρίζεται",
    "Oversees" : "Επιβλέπει",
    "An error happened during the config change" : "Παρουσιάστηκε σφάλμα κατά την αλλαγή της ρύθμισης",
    "Enforce password protection on files shared to this team" : "Εφαρμογή προστασίας με κωδικό σε αρχεία που κοινοποιούνται σε αυτήν την ομάδα",
    "Use a unique password for all shares to this team" : "Χρήση ενός μοναδικού κωδικού για όλα τα κοινόχρηστα στοιχεία σε αυτήν την ομάδα",
    "Unique password …" : "Μοναδικό συνθηματικό …",
    "Save" : "Αποθήκευση",
    "Change unique password" : "Αλλαγή μοναδικού κωδικού πρόσβασης",
    "Failed to save password. Please try again later." : "Αποτυχία αποθήκευσης κωδικού πρόσβασης. Παρακαλώ προσπαθήστε ξανά αργότερα.",
    "Close" : "Κλείσιμο",
    "Choose a team picture" : "Επιλογή εικόνας ομάδας",
    "There is no description for this team" : "Δεν υπάρχει περιγραφή για αυτήν την ομάδα",
    "Enter a description for the team" : "Εισάγετε μια περιγραφή για την ομάδα",
    "Folder" : "Φάκελος",
    "New folder" : "Νέος φάκελος",
    "Folder name" : "Όνομα φακέλου",
    "This will create a regular folder shared with the team. To create a Team Folder, please contact your {productName} administrator" : "Αυτό θα δημιουργήσει έναν κανονικό φάκελο με κοινή χρήση για την ομάδα. Για να δημιουργήσετε έναν φάκελο ομάδας, επικοινωνήστε με τον διαχειριστή του {productName}",
    "Talk conversation" : "Συνομιλία Talk",
    "New Talk conversation" : "Νέα συνομιλία Talk",
    "Conversation name" : "Όνομα συνομιλίας",
    "Collective" : "Συλλογή",
    "Calendar" : "Ημερολόγιο",
    "New calendar" : "Νέο ημερολόγιο",
    "Calendar name" : "Όνομα ημερολογίου",
    "Unknown resource type" : "Άγνωστος τύπος πόρου",
    "Team calendar \"{resourceName}\" created and shared with team" : "Το ημερολόγιο ομάδας \"{resourceName}\" δημιουργήθηκε και κοινοποιήθηκε στην ομάδα",
    "{resourceType} \"{resourceName}\" created and shared with team" : "Ο πόρος {resourceType} \"{resourceName}\" δημιουργήθηκε και κοινοποιήθηκε στην ομάδα",
    "A calendar named \"{name}\" already exists. Please choose a different name." : "Ένα ημερολόγιο με το όνομα \"{name}\" υπάρχει ήδη. Παρακαλούμε επιλέξτε διαφορετικό όνομα.",
    "Failed to create {resourceType}: {error}" : "Αποτυχία δημιουργίας {resourceType}: {error}",
    "Please select a valid png or jpg file" : "Παρακαλούμε επιλέξτε ένα έγκυρο αρχείο png ή jpg",
    "Error picking team picture" : "Σφάλμα κατά την επιλογή εικόνας ομάδας",
    "Error cropping avatar picture" : "Σφάλμα κατά την περικοπή της εικόνας του άβαταρ",
    "An error happened while saving {fields}" : "Παρουσιάστηκε σφάλμα κατά την αποθήκευση του {fields}",
    "Team name" : "Όνομα ομάδας",
    "Team owner" : "Ιδιοκτήτης ομάδας",
    "Upload team picture" : "Μεταφόρτωση εικόνας ομάδας",
    "Choose from Nextcloud Files" : "Επιλογή από τα Αρχεία Nextcloud",
    "Delete picture" : "Διαγραφή εικόνας",
    "Edit" : "Επεξεργασία",
    "Request to join" : "Αίτημα συμμετοχής",
    "Create" : "Δημιουργία",
    "Show in Calendar" : "Εμφάνιση στο Ημερολόγιο",
    "Your request to join this team is pending approval" : "Το αίτημά σας για συμμετοχή σε αυτήν την ομάδα αναμένει έγκριση",
    "You are not a member of {circle}" : "Δεν είστε μέλος της ομάδας {circle}",
    "Members" : "Μέλη",
    "Edit team picture" : "Επεξεργασία εικόνας ομάδας",
    "Apply" : "Εφαρμογή",
    "Confirm" : "Επιβεβαίωση",
    "No other contacts available to select as line manager" : "Δεν υπάρχουν άλλες διαθέσιμες επαφές για να επιλεγούν ως προϊστάμενος",
    "Add more info" : "Προσθέστε περισσότερες πληροφορίες",
    "More fields" : "Περισσότερα πεδία",
    "Please select a valid format" : "Παρακαλούμε επιλέξτε μια έγκυρη μορφή",
    "Invalid image" : "Μη έγκυρη εικόνα",
    "Error cropping picture" : "Σφάλμα περικοπής εικόνας",
    "Pick an avatar" : "Επιλογή άβαταρ",
    "Pick" : "Επιλογή",
    "Error while processing the picture." : "Σφάλμα κατά την επεξεργασία της εικόνας.",
    "Avatar downloaded from social network" : "Το άβαταρ λήφθηκε από κοινωνικό δίκτυο",
    "Avatar already up to date" : "Το άβαταρ είναι ήδη ενημερωμένο",
    "Avatar download failed" : "Η λήψη του άβαταρ απέτυχε",
    "Crop contact photo" : "Περικοπή φωτογραφίας της επαφής",
    "Upload a new picture" : "Μεταφόρτωση νέας φωτογραφίας",
    "Choose from Files" : "Επιλέξτε από τα Αρχεία",
    "Download picture" : "Λήψη εικόνας",
    "Clone contact" : "Κλωνοποίηση επαφής",
    "This contact is in read-only mode. You do not have permission to edit this contact." : "Η επαφή είναι μόνο για ανάγνωση. Δεν έχετε δικαίωμα επεξεργασίας αυτής της επαφής.",
    "The contact you were trying to edit has changed. Please manually refresh the contact. Any further edits will be discarded." : "Η επαφή που προσπαθούσατε να επεξεργαστείτε έχει αλλάξει. Παρακαλούμε ανανεώστε χειροκίνητα την επαφή. Οποιεσδήποτε περαιτέρω αλλαγές θα απορριφθούν.",
    "Address book" : "Βιβλίο διευθύνσεων",
    "Add contact to Birthday Calendar" : "Προσθήκη επαφής στο Ημερολόγιο γενεθλίων",
    "Exclude contact from Birthday Calendar" : "Εξαίρεση επαφής από το Ημερολόγιο γενεθλίων",
    "{title} at {organization}" : "{title} σε {organization}",
    "Name" : "Όνομα",
    "Syntax error. Cannot open the contact." : "Σφάλμα σύνταξης. Αδυναμία ανοίγματος της επαφής.",
    "The contact does not exist on the server anymore." : "Η επαφή δεν υπάρχει πλέον στον διακομιστή.",
    "Unable to retrieve the contact from the server, please check your network connection." : "Δεν είναι δυνατή η λήψη της επαφής από τον διακομιστή, παρακαλούμε ελέγξτε τη σύνδεση δικτύου σας.",
    "An error occurred while trying to move the contact" : "Παρουσιάστηκε σφάλμα κατά την προσπάθεια μετακίνησης της επαφής",
    "An error occurred while trying to copy the contact" : "Παρουσιάστηκε σφάλμα κατά την προσπάθεια αντιγραφής της επαφής",
    "Unable to update contact" : "Αδυναμία ενημέρωσης επαφής",
    "No contact selected" : "Δεν έχει επιλεγεί επαφή",
    "Select a contact on the list to begin" : "Επιλέξτε μια επαφή από τη λίστα για να ξεκινήσετε",
    "Title" : "Τίτλος",
    "Company" : "Εταιρεία",
    "Go to talk conversation" : "Μετάβαση στη συνομιλία Talk",
    "View profile" : "Προβολή προφίλ",
    "This contact was broken and received a fix. Please review the content and click here to save it." : "Αυτή η επαφή ήταν κατεστραμμένη και επιδιορθώθηκε. Παρακαλούμε ελέγξτε το περιεχόμενο και κάντε κλικ εδώ για να την αποθηκεύσετε.",
    "Edit profile" : "Επεξεργασία προφίλ",
    "Generate QR Code" : "Δημιουργία κωδικού QR",
    "Contact vCard as QR code" : "vCard επαφής ως κωδικός QR",
    "Select address book" : "Επιλογή βιβλίου διευθύνσεων",
    "Media shares with you" : "Κοινόχρηστα πολυμέσα με εσάς",
    "Talk conversations with you" : "Συνομιλίες Talk με εσάς",
    "Calendar events with you" : "Συμβάντα ημερολογίου με εσάς",
    "Deck cards with you" : "Κάρτες Deck με εσάς",
    "No shared items with this contact" : "Δεν υπάρχουν κοινόχρηστα στοιχεία με αυτήν την επαφή",
    "This contact cannot be moved" : "Αυτή η επαφή δεν μπορεί να μετακινηθεί",
    "This contact cannot be grouped" : "Αυτή η επαφή δεν μπορεί να ομαδοποιηθεί",
    "Add contacts to groups" : "Προσθήκη επαφών σε ομάδες",
    "Move contacts to addressbook" : "Μετακίνηση επαφών στο βιβλίο διευθύνσεων",
    "Select groups" : "Επιλογή ομάδων",
    "Select addressbook" : "Επιλογή βιβλίου διευθύνσεων",
    "Selected contacts" : "Επιλεγμένες επαφές",
    "Please note that only {count} of the {total} contacts can be added to a group" : "Λάβετε υπόψη ότι μόνο {count} από τις {total} επαφές μπορούν να προστεθούν σε μια ομάδα",
    "Please note that only {count} of the {total} contacts can be moved" : "Λάβετε υπόψη ότι μόνο {count} από τις {total} επαφές μπορούν να μετακινηθούν",
    "Move" : "Μετακίνηση",
    "Unselect {name}" : "Αποεπιλογή {name}",
    "Select {name}" : "Επιλογή {name}",
    "Could not update favorite status" : "Δεν ήταν δυνατή η ενημέρωση της κατάστασης αγαπημένων",
    "from {addressbook}" : "από το {addressbook}",
    "Remove from favorites" : "Αφαίρεση από τα αγαπημένα",
    "Add to favorites" : "Προσθήκη στα αγαπημένα",
    "Confirm merging contacts" : "Επιβεβαίωση συγχώνευσης επαφών",
    "The selected contacts have conflicting information. Choose which information to keep" : "Οι επιλεγμένες επαφές έχουν αντικρουόμενες πληροφορίες. Επιλέξτε ποιες πληροφορίες να διατηρήσετε",
    "Contacts can be merged" : "Οι επαφές μπορούν να συγχωνευτούν",
    "Groups" : "Ομάδες",
    "Select groups to add the merged contact to" : "Επιλέξτε ομάδες στις οποίες θα προστεθεί η συγχωνευμένη επαφή",
    "Merge contacts" : "Συγχώνευση επαφών",
    "_Delete {number} contact_::_Delete {number} contacts_" : ["Διαγραφή {number} επαφής","Διαγραφή {number} επαφών"],
    "Please select at least one editable contact to delete" : "Παρακαλούμε επιλέξτε τουλάχιστον μία επεξεργάσιμη επαφή για διαγραφή",
    "Please select two editable contacts to merge" : "Παρακαλούμε επιλέξτε δύο επεξεργάσιμες επαφές για συγχώνευση",
    "_Add {number} contact to group_::_Add {number} contacts to group_" : ["Προσθήκη {number} επαφής στην ομάδα","Προσθήκη {number} επαφών στην ομάδα"],
    "Please select at least one editable contact to add to a group" : "Παρακαλούμε επιλέξτε τουλάχιστον μία επεξεργάσιμη επαφή για προσθήκη σε ομάδα",
    "_Move {number} contact to addressbook_::_Move {number} contacts to addressbook_" : ["Μετακίνηση {number} επαφής στο βιβλίο διευθύνσεων","Μετακίνηση {number} επαφών στο βιβλίο διευθύνσεων"],
    "Please select at least one editable contact to move to an addressbook" : "Παρακαλούμε επιλέξτε τουλάχιστον μία επεξεργάσιμη επαφή για μετακίνηση σε βιβλίο διευθύνσεων",
    "Are you sure you want to proceed?" : "Είστε σίγουρος/η ότι θέλετε να συνεχίσετε;",
    "Add contacts to group" : "Προσθήκη επαφών σε ομάδα",
    "Search contacts …" : "Αναζήτηση επαφών …",
    "Unselect {number}" : "Αποεπιλογή {number}",
    "Add to {group}" : "Προσθήκη σε {group}",
    "Add members to {group}" : "Προσθήκη μελών σε {group}",
    "Please note that you can only add contacts from writable address books to contact groups. Contacts from read-only address books, such as the system address book, cannot be added." : "Παρακαλούμε σημειώστε ότι μπορείτε να προσθέσετε μόνο επαφές από εγγράψιμα βιβλία διευθύνσεων σε ομάδες επαφών. Οι επαφές από βιβλία διευθύνσεων μόνο για ανάγνωση, όπως το βιβλίο διευθύνσεων του συστήματος, δεν μπορούν να προστεθούν.",
    "Remove {type}" : "Κατάργηση {type}",
    "Add to group" : "Προσθήκη στην ομάδα",
    "Add members to group" : "Προσθήκη μελών στην ομάδα",
    "Search {types}" : "Αναζήτηση {types}",
    "Add guest" : "Προσθήκη επισκέπτη",
    "Search for people to add" : "Αναζητήστε άτομα για προσθήκη",
    "No results" : "Κανένα αποτέλεσμα",
    "Add {type}" : "Προσθήκη {type}",
    "New team name" : "Νέο όνομα ομάδας",
    "Personal team" : "Προσωπική ομάδα",
    "This team will only be visible to you. Other members will not be able to see or use it." : "Αυτή η ομάδα θα είναι ορατή μόνο σε εσάς. Τα άλλα μέλη δεν θα μπορούν να τη δουν ή να τη χρησιμοποιήσουν.",
    "Local team" : "Τοπική ομάδα",
    "This team will not be shared with the other instances of the global scale" : "Αυτή η ομάδα δεν θα κοινοποιείται με τα άλλα στιγμιότυπα της παγκόσμιας κλίμακας",
    "Create team" : "Δημιουργία ομάδας",
    "Promote as sole owner" : "Προαγωγή σε μοναδικό ιδιοκτήτη",
    "Promote to {level}" : "Προαγωγή σε {level}",
    "Demote to {level}" : "Υποβίβαση σε {level}",
    "Are you sure you want to leave this team? This action cannot be undone." : "Είστε σίγουρος/η ότι θέλετε να αποχωρήσετε από αυτήν την ομάδα; Αυτή η ενέργεια δεν μπορεί να αναιρεθεί.",
    "Leave team failed." : "Αποτυχία αποχώρησης από την ομάδα.",
    "Could not delete the member {displayName}" : "Αδυναμία διαγραφής του μέλους {displayName}",
    "Could not change the member level to {level}" : "Δεν ήταν δυνατή η αλλαγή του ρόλου του μέλους σε {level}",
    "Could not accept membership request" : "Δεν ήταν δυνατή η αποδοχή του αιτήματος συμμετοχής",
    "Accept membership request" : "Αποδοχή αιτήματος συμμετοχής",
    "Reject membership request" : "Απόρριψη αιτήματος συμμετοχής",
    "Manage level" : "Διαχείριση ρόλου",
    "Remove member" : "Κατάργηση μέλους",
    "Unable to get the results" : "Δεν είναι δυνατή η λήψη των αποτελεσμάτων",
    "Some members could not be added" : "Δεν ήταν δυνατή η προσθήκη ορισμένων μελών",
    "There was an issue adding members to the team" : "Προέκυψε πρόβλημα κατά την προσθήκη μελών στην ομάδα",
    "Loading members list …" : "Φόρτωση λίστας μελών …",
    "The list of members is only visible to members of this team" : "Η λίστα μελών είναι ορατή μόνο σε μέλη αυτής της ομάδας",
    "You currently have no access to the member list" : "Αυτήν τη στιγμή δεν έχετε πρόσβαση στη λίστα μελών",
    "Add to {team}" : "Προσθήκη σε {team}",
    "Invite members to {team}" : "Πρόσκληση μελών σε {team}",
    "Pending" : "Εκκρεμεί",
    "Accept" : "Αποδοχή",
    "Send" : "Αποστολή",
    "Created" : "Δημιουργήθηκε",
    "Select chart …" : "Επιλέξτε διάγραμμα …",
    "Chart" : "Διάγραμμα",
    "Select type" : "Επιλέξτε τύπο",
    "Add contact in group" : "Προσθήκη επαφής στην ομάδα",
    "None" : "Κανένα",
    "copy" : "αντιγραφή",
    "Select option" : "Επιλέξτε μια επιλογή",
    "JavaScript URIs are not allowed" : "Δεν επιτρέπονται τα JavaScript URI",
    "Notes" : "Σημειώσεις",
    "send an email" : "αποστολή email",
    "Personal dates" : "Προσωπικές ημερομηνίες",
    "Add property of this type" : "Προσθήκη ιδιότητας αυτού του τύπου",
    "Member" : "Μέλος",
    "This is a read-only group managed by administrators. Group members can only view this group." : "Αυτή είναι μια ομάδα μόνο για ανάγνωση που διαχειρίζονται οι διαχειριστές. Τα μέλη της ομάδας μπορούν μόνο να προβάλλουν αυτήν την ομάδα.",
    "Unable to create the contact." : "Αδυναμία δημιουργίας της επαφής.",
    "Contact not found" : "Δεν βρέθηκε η επαφή",
    "Group {group} not found" : "Η ομάδα {group} δεν βρέθηκε",
    "Add member" : "Προσθήκη μέλους",
    "New contact" : "Νέα επαφή",
    "_{success} contact added to {name}_::_{success} contacts added to {name}_" : ["Προστέθηκε {success} επαφή στο {name}","Προστέθηκαν {success} επαφές στο {name}"],
    "_Adding {success} contact to {name}_::_Adding {success} contacts to {name}_" : ["Προσθήκη {success} επαφής στο {name}","Προσθήκη {success} επαφών στο {name}"],
    "_{count} error_::_{count} errors_" : ["{count} σφάλμα","{count} σφάλματα"],
    "_Importing %n contact into {addressbook}_::_Importing %n contacts into {addressbook}_" : ["Εισαγωγή %n επαφής στο {addressbook}","Εισαγωγή %n επαφών στο {addressbook}"],
    "_Done importing %n contact into {addressbook}_::_Done importing %n contacts into {addressbook}_" : ["Ολοκληρώθηκε η εισαγωγή %n επαφής στο {addressbook}","Ολοκληρώθηκε η εισαγωγή %n επαφών στο {addressbook}"],
    "No data for this contact" : "Δεν υπάρχουν δεδομένα για αυτήν την επαφή",
    "No data for this contact on their profile" : "Δεν υπάρχουν δεδομένα για αυτήν την επαφή στο προφίλ τους",
    "Import" : "Εισαγωγή",
    "Are you sure you want to import this contact file?" : "Είστε σίγουρος/η ότι θέλετε να εισαγάγετε αυτό το αρχείο επαφών;",
    "Could not copy" : "Δεν ήταν δυνατή η αντιγραφή",
    "Join team" : "Συμμετοχή στην ομάδα",
    "You are about to leave {circle}.\nAre you sure?" : "Πρόκειται να αποχωρήσετε από την ομάδα {circle}.\nΕίστε σίγουρος/η;",
    "Please confirm team leave" : "Παρακαλώ επιβεβαιώστε την αποχώρηση από την ομάδα",
    "Could not leave the team {displayName}" : "Δεν ήταν δυνατή η αποχώρηση από την ομάδα {displayName}",
    "Unable to join the team" : "Αδυναμία συμμετοχής στην ομάδα",
    "You are about to delete {circle}.\nAre you sure?" : "Πρόκειται να διαγράψετε την ομάδα {circle}.\nΕίστε σίγουρος/η;",
    "Please confirm team deletion" : "Παρακαλώ επιβεβαιώστε τη διαγραφή της ομάδας",
    "Unable to delete the team" : "Αδυναμία διαγραφής της ομάδας",
    "Confirm enabling federation" : "Επιβεβαίωση ενεργοποίησης federation",
    "Enabling this will prevent {circle} from being a member of other teams.\nAre you sure?" : "Η ενεργοποίηση αυτής της επιλογής θα αποτρέψει την ομάδα {circle} από το να είναι μέλος άλλων ομάδων.\nΕίστε σίγουρος/η;",
    "Enable federation" : "Ενεργοποίηση federation",
    "Link copied to the clipboard" : "Ο σύνδεσμος αντιγράφηκε στο πρόχειρο",
    "Could not copy link to the clipboard." : "Δεν ήταν δυνατή η αντιγραφή του συνδέσμου στο πρόχειρο.",
    "Not grouped" : "Χωρίς ομάδα",
    "Create your own teams for sharing. Add Nextcloud users, contacts, or anyone via email." : "Δημιουργήστε τις δικές σας ομάδες για κοινή χρήση. Προσθέστε χρήστες του Nextcloud, επαφές ή οποιονδήποτε μέσω email.",
    "Team" : "Ομάδα",
    "User" : "Χρήστης",
    "Group" : "Ομάδα",
    "Email" : "Ηλ. ταχυδρομείο",
    "Contact" : "Επαφή",
    "Moderator" : "Συντονιστής",
    "Admin" : "Διαχειριστής",
    "Owner" : "Ιδιοκτήτης",
    "Invites" : "Προσκλήσεις",
    "Anyone can request membership" : "Οποιοσδήποτε μπορεί να αιτηθεί συμμετοχή",
    "Members need to accept invitation" : "Τα μέλη πρέπει να αποδεχτούν την πρόσκληση",
    "Memberships must be confirmed/accepted by a Moderator (requires \"Anyone can request membership\")" : "Οι συμμετοχές πρέπει να επιβεβαιωθούν/γίνουν αποδεκτές από έναν Συντονιστή (απαιτείται \"Οποιοσδήποτε μπορεί να ζητήσει συμμετοχή\")",
    "Members can also invite" : "Τα μέλη μπορούν επίσης να προσκαλέσουν",
    "Membership" : "Συμμετοχή",
    "Prevent teams from being a member of another team" : "Αποτροπή ομάδων από το να είναι μέλη άλλης ομάδας",
    "Federation" : "Federation",
    "Allow federated members" : "Να επιτρέπονται μέλη μέσω federation",
    "Privacy" : "Απόρρητο",
    "Visible to everyone" : "Ορατό σε όλους",
    "users" : "χρήστες",
    "Users" : "Χρήστες",
    "groups" : "ομάδες",
    "federated users" : "χρήστες federation",
    "Federated users" : "Χρήστες federation",
    "teams" : "ομάδες",
    "email addresses" : "διευθύνσεις email",
    "Email addresses" : "Διευθύνσεις email",
    "contacts" : "επαφές",
    "Detailed name" : "Λεπτομερές όνομα",
    "Additional names" : "Επιπλέον ονόματα",
    "Prefix" : "Πρόθεμα",
    "Suffix" : "Κατάληξη",
    "Nickname" : "Παρατσούκλι",
    "Website" : "Ιστοσελίδα",
    "Location" : "Τοποθεσία",
    "Federated Cloud ID" : "Federated Cloud ID",
    "Home" : "Σπίτι",
    "Work" : "Εργασία",
    "Other" : "Άλλο",
    "Address" : "Διεύθυνση",
    "Post office box" : "Ταχυδρομική θυρίδα",
    "Extended address" : "Εκτεταμένη διεύθυνση",
    "City" : "Πόλη",
    "State or province" : "Νομός ή περιφέρεια",
    "Postal code" : "Ταχυδρομικός Κώδικας",
    "Country" : "Χώρα",
    "Birthday" : "Γενέθλια",
    "Place of birth" : "Τόπος γέννησης",
    "Anniversary" : "Επέτειος",
    "Date of death" : "Ημερομηνία θανάτου",
    "Place of death" : "Τόπος θανάτου",
    "Instant messaging" : "Άμεσα μηνύματα",
    "Phone" : "Τηλέφωνο",
    "Mobile" : "Κινητό",
    "Work mobile" : "Κινητό εργασίας",
    "Home mobile" : "Κινητό οικίας",
    "Fax" : "Φαξ",
    "Fax home" : "Φαξ οικίας",
    "Fax work" : "Φαξ εργασίας",
    "Pager" : "Βομβητής",
    "Voice" : "Φωνή",
    "Car" : "Αυτοκίνητο",
    "Work pager" : "Βομβητής εργασίας",
    "Line manager" : "Προϊστάμενος",
    "Social network" : "Κοινωνικό δίκτυο",
    "Relationship to you" : "Σχέση με εσάς",
    "Spouse" : "Σύζυγος",
    "Child" : "Παιδί",
    "Mother" : "Μητέρα",
    "Father" : "Πατέρας",
    "Parent" : "Γονέας",
    "Brother" : "Αδελφός",
    "Sister" : "Αδελφή",
    "Relative" : "Συγγενής",
    "Friend" : "Φίλος",
    "Colleague" : "Συνάδελφος",
    "Assistant" : "Βοηθός",
    "Related contacts" : "Σχετικές επαφές",
    "Agent" : "Αντιπρόσωπος",
    "Emergency" : "Έκτακτη ανάγκη",
    "Co-worker" : "Συνάδελφος",
    "Gender" : "Φύλο",
    "Female" : "Θήλυ",
    "Male" : "Άρρεν",
    "Unknown" : "Άγνωστο",
    "Time zone" : "Ζώνη ώρας",
    "Spoken languages" : "Ομιλούμενες γλώσσες",
    "_{failed} contact failed to be read_::_{failed} contacts failed to be read_" : ["Αποτυχία ανάγνωσης {failed} επαφής","Αποτυχία ανάγνωσης {failed} επαφών"],
    "An error has occurred in team(s). Check the console for more details." : "Παρουσιάστηκε σφάλμα στην ομάδα/ομάδες. Ελέγξτε την κονσόλα για περισσότερες λεπτομέρειες.",
    "Unable to create team {circleName}" : "Αδυναμία δημιουργίας ομάδας {circleName}",
    "Unable to delete team {circleId}" : "Αδυναμία διαγραφής ομάδας {circleId}",
    "Could not update favorite state" : "Δεν ήταν δυνατή η ενημέρωση της κατάστασης αγαπημένου",
    "Unable to delete contact" : "Δεν είναι δυνατή η διαγραφή της επαφής",
    "Value copied to the clipboard" : "Η τιμή αντιγράφηκε στο πρόχειρο",
    "Could not copy value to the clipboard." : "Δεν ήταν δυνατή η αντιγραφή της τιμής στο πρόχειρο.",
    "Deck board" : "Πίνακας Deck",
    "New Deck board" : "Νέος πίνακας Deck",
    "Board name" : "Όνομα πίνακα",
    "Deck app is not installed. Please install it to create team boards." : "Η εφαρμογή Deck δεν είναι εγκατεστημένη. Παρακαλώ εγκαταστήστε την για να δημιουργήσετε πίνακες ομάδας.",
    "Pick an address book" : "Επιλέξτε ένα βιβλίο διευθύνσεων",
    "Select Date" : "Επιλέξτε ημερομηνία",
    "note" : "σημείωση",
    "email" : "email",
    "Create your own groups for sharing. Add Nextcloud users, contacts, or anyone via email." : "Δημιουργήστε τις δικές σας ομάδες για κοινή χρήση. Προσθέστε χρήστες του Nextcloud, επαφές ή οποιονδήποτε μέσω email."
},
"nplurals=2; plural=(n != 1);");
