OC.L10N.register(
    "contacts",
    {
    "Import contacts" : "Importér kontakter",
    "Details" : "Detaljer",
    "All contacts" : "Alle kontakter",
    "Contacts" : "Kontakter",
    "A contacts app for Nextcloud" : "En kontakt-app til Nextcloud",
    "The Nextcloud contacts app is a user interface for Nextcloud's CardDAV server. Easily sync contacts from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Currently Mail and Calendar – more to come.\n* 🎉 **Never forget a birthday!** You can sync birthdays and other recurring events with your Nextcloud Calendar.\n* 👥 **Sharing of Adressbooks!** You want to share your contacts with your friends or coworkers? No problem!\n* 🙈 **We’re not reinventing the wheel!** Based on the great and open SabreDAV library." : "Nextcloud kontakt app-en er en brugerflade til Nextclouds CardDAV server. Synkroniser let kontakter fra forskellige enheder med din Nextcloud og rediger dem online.\n\n* 🚀 **Integreret med andre Nextcloud apps!** For nuværende Mail og kalender - og flere på vej.\n* 🎉 **Glem aldrig en fødselsdag!** Du kan synkornisere fødselsdage og andre tilbagevendende begivenheder med din Nextcloud kalender.\n* 👥 **Deling af adressebøger!** Vil du dele dine kontakter med dine venner og kolleger? Ikke noget problem!\n* 🙈 **Vi er ikke i gang med at genopfinde hjulet!** Baseret på det alle tiders bibliotek SabreDAV.",
    "Copy to full name" : "Kopier til fuldt navn",
    "Omit year" : "Udelad år",
    "Allow updating avatars from social media" : "Tillad opdatering af avatarer fra sociale medier",
    "Organization chart" : "Organisationsdiagram",
    "There was an error fetching the member list" : "Der opstod en fejl under hentning af medlemslisten",
    "Teams" : "Teams",
    "Please select a team" : "Vælg venligst et team",
    "Loading team…" : "Indlæser team...",
    "There are no contacts yet" : "Der er ingen kontakter endnu",
    "Create contact" : "Opret kontakt",
    "There are no contacts in this group" : "Der er ingen kontakter i denne gruppe",
    "Create contacts" : "Opret kontakter",
    "Add contacts" : "Tilføj kontakter",
    "Retry" : "Prøv igen",
    "Loading …" : "Indlæser...",
    "Manage team" : "Styr teams",
    "Leave team" : "Forlad team",
    "Delete team" : "Slet team",
    "Contacts settings" : "Kontaktindstillinger",
    "General" : "Generelt",
    "Update avatars from social media" : "Opdatér avatarer fra sociale medier",
    "Address books" : "Adressebøger",
    "Rename" : "Omdøb",
    "Export" : "Eksportér",
    "Send email" : "Send e-mail",
    "Send email as BCC" : "Send e-mail som BCC",
    "Delete" : "Slet",
    "Show all groups" : "Vis alle grupper",
    "Collapse groups" : "Skjul grupper",
    "Show all teams" : "Vis alle teams",
    "Collapse teams" : "Kollaps teams",
    "Group name cannot be empty" : "Gruppenavnet må ikke være tomt",
    "This group already exists" : "Denne gruppe eksisterer allerede",
    "An error occurred while creating the group" : "En fejl opstod under oprettelse af gruppen",
    "This team already exists" : "Dette team eksisterer allerede",
    "An error happened during the creation of the team" : "En fejl er opstået under oprettelsen af teamet",
    "Recently contacted" : "For nylig kontaktet",
    "Contact groups" : "Kontaktgrupper",
    "Create a new contact group" : "Opret en ny kontaktgruppe",
    "Contact group name" : "Navn på kontaktgruppe",
    "Create a new team" : "Opret et nyt team",
    "Open the contacts app settings" : "Åben kontaktens app indstillinger",
    "_Shared with {num} entity_::_Shared with {num} entities_" : ["Delt med {num} element","Delt med {num} elementer"],
    "Copied" : "opieret",
    "Cannot copy" : "Kan ikke kopiere",
    "Copy link" : "Kopier link",
    "Toggling of address book was not successful" : "Skift af adressebog lykkedes ikke",
    "This will delete the address book and every contacts within it" : "Dette vil slette adressebogen og alle kontakter i den",
    "Delete {addressbook}?" : "Vil du slette {adressebog}?",
    "This will unshare the address book and every contacts within it" : "Dette vil fjerne delingen af adressebogen og alle kontakter i den",
    "Unshare {addressbook}?" : "Del ikke {addressbook}?",
    "Deletion of address book was not successful." : "Sletning af adressebog lykkedes ikke.",
    "Renaming of address book was not successful." : "Omdøbning af adressebog lykkedes ikke.",
    "Download" : "Download",
    "Show" : "Vis",
    "Unshare from me" : "Del ikke med mig",
    "_%n contact_::_%n contacts_" : ["%n kontaktperson","%n kontaktpersoner"],
    "_%n group_::_%n groups_" : ["%n gruppe","%n grupper"],
    "Share with users or groups" : "Del med brugere eller grupper",
    "Share with users" : "Del med brugere",
    "No users or groups" : "Ingen brugere eller grupper",
    "Unable to delete the share" : "Delingen kunne ikke slettes",
    "Unable to change permissions" : "Kan ikke ændre tilladelser",
    "Choose a vCard file to import" : "Vælg en vCard fil at importere",
    "Import into the {addressbookName} address book" : "Importér til adressebogen {addressbookName}",
    "Select local file" : "Vælg lokal fil",
    "Import from files" : "Importér fra filer",
    "Importing is disabled because there are no address books available" : "Indlæsning er deaktiveret da der ikke er nogen adressebog tilgængelig",
    "An error occurred, unable to create the address book" : "Der opstod en fejl, og adressebogen kunne ikke oprettes",
    "Add new address book" : "Tilføj ny adressebog",
    "Cancel" : "Annullér",
    "Add" : "Add",
    "First name" : "Fornavn",
    "Last name" : "Efternavn",
    "Phonetic first name" : "Fonetisk fornavn",
    "Phonetic last name" : "Fonetisk efternavn",
    "Display name" : "Vist navn",
    "Last modified" : "Sidst ændret",
    "Manages" : "Leder",
    "Oversees" : "Overvåger",
    "An error happened during the config change" : "Der opstod en fejl under konfigurationsændringen",
    "Enforce password protection on files shared to this team" : "Styrk adgangskodebeskyttelse på filer der er delt med dette team",
    "Use a unique password for all shares to this team" : "Anvend en unik adgangskode for alle delinger med dette team",
    "Save" : "Gem",
    "Change unique password" : "Skift unik adgangskode",
    "Failed to save password. Please try again later." : "Adgangskoden kunne ikke gemmes. Prøv igen senere.",
    "Close" : "Luk",
    "There is no description for this team" : "Der er ingen beskrivelse for dette team",
    "Enter a description for the team" : "Angiv en beskrivelse for dette team",
    "Folder" : "Mappe",
    "Talk conversation" : "Talk samtale",
    "New Talk conversation" : "Ny Talk samtale",
    "Calendar" : "Kalender",
    "Team name" : "Teamnavn",
    "Delete picture" : "Slet billede",
    "Edit" : "Redigér",
    "Request to join" : "Anmod om at deltage",
    "Create" : "Opret",
    "Your request to join this team is pending approval" : "Din anmodning om at deltage i dette team afventer godkendelse",
    "You are not a member of {circle}" : "Du er ikke medlem af {circle}",
    "Members" : "Medlemmer",
    "Confirm" : "Bekræft",
    "Add more info" : "Tilføj flere informationer",
    "More fields" : "Flere felter",
    "Please select a valid format" : "Vælg venligst et gyldigt format",
    "Invalid image" : "Ugyldigt billede",
    "Error cropping picture" : "Fejl ved beskæring af billede",
    "Pick an avatar" : "Vælg en avatar",
    "Pick" : "Vælg",
    "Error while processing the picture." : "Fejl under behandling af billedet.",
    "Avatar downloaded from social network" : "Avatar downloadet fra sociale netværk",
    "Avatar already up to date" : "Avatar er allerede opdateret",
    "Avatar download failed" : "Avatar-download mislykkedes",
    "Crop contact photo" : "Beskær billede",
    "Upload a new picture" : "Upload et nyt billede",
    "Choose from Files" : "Vælg fra Filer",
    "Download picture" : "Hent billede",
    "Clone contact" : "Klon kontakt",
    "This contact is in read-only mode. You do not have permission to edit this contact." : "Kontakten er skrivebeskyttet. Du har ikke tilladelse til at redigere denne kontakt.",
    "The contact you were trying to edit has changed. Please manually refresh the contact. Any further edits will be discarded." : "Kontakten du er i gang med at redigere er ændret. Venligst genopfrisk kontaktvisningen manuelt. Alle videre modifikationer vil blive tabt.",
    "Address book" : "Adressebog",
    "Add contact to Birthday Calendar" : "Tilføj kontakt til fødselsdagskalender",
    "Exclude contact from Birthday Calendar" : "Udelad kontakt fra fødselsdagskalender",
    "{title} at {organization}" : "{title} hos {organization}",
    "Name" : "Navn",
    "Syntax error. Cannot open the contact." : "Syntaks fejl. Kan ikke åbne kontakt.",
    "The contact does not exist on the server anymore." : "Kontakten findes ikke længere på serveren.",
    "Unable to retrieve the contact from the server, please check your network connection." : "Kan ikke hente kontakten fra serveren. Tjek venligst din netværksforbindelse.",
    "An error occurred while trying to move the contact" : "Der opstod en fejl under forsøget på at flytte kontakten",
    "An error occurred while trying to copy the contact" : "Der opstod en fejl under forsøget på at kopiere kontakten",
    "Unable to update contact" : "Kan ikke opdatere kontakten",
    "No contact selected" : "Ingen kontakt valgt",
    "Select a contact on the list to begin" : "Vælg en kontakt fra listen for at begynde",
    "Title" : "Titel",
    "Company" : "Firma",
    "Go to talk conversation" : "Gå til Talk samtale",
    "View profile" : "Vis profil",
    "This contact was broken and received a fix. Please review the content and click here to save it." : "Der var en fejl i denne kontakt, som er blevet rettet . Gennemgå indholdet, og klik her for at gemme det.",
    "Edit profile" : "Redigér profil",
    "Generate QR Code" : "Generer QR-kode",
    "Contact vCard as QR code" : "Kontakt vCard som QR-kode",
    "Select address book" : "Vælg adressebog",
    "Media shares with you" : "Medier delt med dig",
    "Talk conversations with you" : "Talk samtaler med dig",
    "Calendar events with you" : "Kalenderbegivenheder med dig",
    "Deck cards with you" : "Opslagskort med dig",
    "No shared items with this contact" : "Ingen delte elementer med denne kontakt",
    "Move" : "Flyt",
    "Remove from favorites" : "Fjern fra favoritter",
    "Add to favorites" : "Tilføj til favoritter",
    "Groups" : "Grupper",
    "Add to {group}" : "Føj til {gruppe}",
    "Remove {type}" : "Fjern {type}",
    "Add to group" : "Tilføj til gruppe",
    "Search {types}" : "Søg efter {typer}",
    "Search for people to add" : "Søg efter personer at tilføje",
    "No results" : "Ingen resultater",
    "Add {type}" : "Tilføj {type}",
    "New team name" : "Nyt teamnavn",
    "Personal team" : "Personligt team",
    "This team will only be visible to you. Other members will not be able to see or use it." : "Dette team vil kun være synligt for dig. Andre medlemmer vil ikke kunne se det eller anvende det.",
    "Local team" : "Lokalt team",
    "This team will not be shared with the other instances of the global scale" : "Dette team vil ikke blive delt med andre instanser af den globale skala",
    "Create team" : "Opret team",
    "Promote as sole owner" : "Fremhæv som eneejer",
    "Promote to {level}" : "Forfrem til {level}",
    "Demote to {level}" : "Nedryk til {level}",
    "Could not delete the member {displayName}" : "Kunne ikke slette medlemmet {displayName}",
    "Could not change the member level to {level}" : "Kunne ikke ændre medlemsniveauet til {level}",
    "Could not accept membership request" : "Kunne ikke acceptere medlemsanmodning",
    "Accept membership request" : "Accepter anmodning om medlemskab",
    "Reject membership request" : "Afvis anmodning om medlemskab",
    "Manage level" : "Administrer niveau",
    "Remove member" : "Fjern medlem",
    "Unable to get the results" : "Ude af stand til at få resultaterne",
    "Some members could not be added" : "Nogle medlemmer kunne ikke tilføjes",
    "There was an issue adding members to the team" : "Der var et problem med tilføjelse af medlemmer til teamet",
    "The list of members is only visible to members of this team" : "Listen af medlemmer er kun synlig for medlemmer af dette team",
    "You currently have no access to the member list" : "Du har i øjeblikket ingen adgang til medlemslisten",
    "Pending" : "Afventer",
    "Accept" : "Accepter",
    "Created" : "Oprettet",
    "Type to search" : "Type der skal søges",
    "Continue" : "Fortsæt",
    "Chart" : "Diagram",
    "Select type" : "Vælg type",
    "Add contact in group" : "Føj kontakt til gruppe",
    "None" : "Ingen",
    "Select option" : "Vælg indstilling",
    "Notes" : "Noter",
    "Add property of this type" : "Tilføj element af denne type",
    "Member" : "Medlem",
    "Unable to create the contact." : "Kontakten kunne ikke oprettes.",
    "Contact not found" : "Kontakten kunne ikke findes",
    "Group {group} not found" : "Gruppen {gruppe} blev ikke fundet",
    "Add member" : "Tilføj medlem",
    "New contact" : "Ny kontakt",
    "_{success} contact added to {name}_::_{success} contacts added to {name}_" : ["{success} kontakt føjet til {name}","{success} kontakter føjet til {name}"],
    "_Adding {success} contact to {name}_::_Adding {success} contacts to {name}_" : ["Føjer {success} kontakt til {name}","Tilføjer {success} kontakter til {name}"],
    "_{count} error_::_{count} errors_" : ["{count} fejl","{count} fejl"],
    "_Importing %n contact into {addressbook}_::_Importing %n contacts into {addressbook}_" : ["Importerer %n kontakt til {addressbook}","Importerer %n kontakter til {addressbook}"],
    "_Done importing %n contact into {addressbook}_::_Done importing %n contacts into {addressbook}_" : ["Færdig med import af %n kontakt til {addressbook}","Færdig med import af %n kontakter til {addressbook}"],
    "No data for this contact" : "Ingen data for denne kontakt",
    "No data for this contact on their profile" : "Ingen data for denne kontakt på deres profil",
    "Import" : "Importér",
    "Are you sure you want to import this contact file?" : "Er du sikker på at du ønsker at importere denne kontaktfil?",
    "Could not copy" : "Kunne ikke kopiere",
    "Join team" : "Deltag i team",
    "You are about to leave {circle}.\nAre you sure?" : "Du er ved at forlade {circle}.\nEr du sikker?",
    "Please confirm team leave" : "Bekræft venligst at du forlader teamet",
    "Could not leave the team {displayName}" : "Kunne ikke forlade teamet {displayName}",
    "Unable to join the team" : "Kunne ikke deltage i teamet",
    "You are about to delete {circle}.\nAre you sure?" : "Du er ved at slette {circle}.\nEr du sikker?",
    "Please confirm team deletion" : "Bekræft venligst sletning af teamet",
    "Unable to delete the team" : "Kan ikke slette teamet",
    "Link copied to the clipboard" : "Linket er kopieret til udklipsholderen",
    "Could not copy link to the clipboard." : "Kunne ikke kopiere linket til udklipsholderen.",
    "Not grouped" : "Ikke i gruppe",
    "Team" : "Team",
    "User" : "Bruger",
    "Group" : "Gruppe",
    "Email" : "E-mail",
    "Contact" : "takt",
    "Moderator" : "Moderator",
    "Admin" : "Admin",
    "Owner" : "Ejer",
    "Invites" : "Inviterede",
    "Anyone can request membership" : "Alle kan anmode om medlemskab",
    "Members need to accept invitation" : "Medlemmer skal acceptere invitationen",
    "Memberships must be confirmed/accepted by a Moderator (requires \"Anyone can request membership\")" : "Medlemskaber skal bekræftes/accepteres af en moderator (kræver \"Alle kan anmode om medlemskab\")",
    "Members can also invite" : "Medlemmer kan også invitere",
    "Prevent teams from being a member of another team" : "Forhindre teams i at være medlem af et andet team",
    "Privacy" : "Privatliv",
    "Visible to everyone" : "Synlig for alle",
    "users" : "brugere",
    "Users" : "Brugere",
    "groups" : "grupper",
    "teams" : "teams",
    "email addresses" : "e-mailadresser",
    "Email addresses" : "E-mailadresser",
    "contacts" : "kontakter",
    "Detailed name" : "Detaljeret navn",
    "Additional names" : "Mellemnavne",
    "Prefix" : "Præfiks",
    "Suffix" : "Suffiks",
    "Nickname" : "Kaldenavn",
    "Website" : "Hjemmeside",
    "Location" : "Sted",
    "Federated Cloud ID" : "Federated Cloud ID",
    "Home" : "Hjemme",
    "Work" : "Arbejde",
    "Other" : "Andet",
    "Address" : "Adresse",
    "Post office box" : "Postboks",
    "Extended address" : "Udvidet adresse",
    "City" : "By",
    "State or province" : "Stat eller provins",
    "Postal code" : "Postnummer",
    "Country" : "Land",
    "Birthday" : "Fødselsdag",
    "Place of birth" : "Fødested",
    "Anniversary" : "Årsdag",
    "Date of death" : "Dødsdato",
    "Place of death" : "Dødssted",
    "Instant messaging" : "Instant Messaging",
    "Phone" : "Telefon",
    "Mobile" : "Mobil",
    "Work mobile" : "Arbdejsmobil",
    "Home mobile" : "Hjemmemobil",
    "Fax" : "Fax",
    "Fax home" : "Fax hjemme",
    "Fax work" : "Fax arbejde",
    "Pager" : "Personsøger",
    "Voice" : "Telefonsvarer",
    "Car" : "Bil",
    "Work pager" : "Arbejdespager ",
    "Line manager" : "Linjeleder",
    "Social network" : "Socialt netværk",
    "Relationship to you" : "Forhold til dig",
    "Spouse" : "Ægtefælle",
    "Child" : "Barn",
    "Mother" : "Mor",
    "Father" : "Far",
    "Parent" : "Forælder",
    "Brother" : "Bror",
    "Sister" : "Søster",
    "Relative" : "Slægtning",
    "Friend" : "Ven",
    "Colleague" : "Kollega",
    "Assistant" : "Assistent",
    "Related contacts" : "Relaterede kontakter",
    "Agent" : "Agent",
    "Emergency" : "Nødstilfælde",
    "Co-worker" : "Kollega",
    "Gender" : "Køn",
    "Female" : "Kvinde",
    "Male" : "Mand",
    "Unknown" : "Ukendt",
    "Time zone" : "Tidszone",
    "Spoken languages" : "Talte sprog",
    "_{failed} contact failed to be read_::_{failed} contacts failed to be read_" : ["{failed} kontakt kunne ikke indlæses","{failed} kontakter kunne ikke indlæses"],
    "An error has occurred in team(s). Check the console for more details." : "En fejl er opstået i team(s). Kontroller konsollen for flere detaljer.",
    "Unable to create team {circleName}" : "Kan ikke oprette team {circleName}",
    "Unable to delete team {circleId}" : "Kan ikke slette team {circleId}",
    "Unable to delete contact" : "Kan ikke slette kontakten",
    "Pick an address book" : "Vælg en adressebog",
    "Select Date" : "Vælg dato"
},
"nplurals=2; plural=(n != 1);");
