OC.L10N.register(
    "contacts",
    {
    "Import contacts" : "Uvozi stike",
    "Details" : "Podrobnosti",
    "All contacts" : "Vsi stiki",
    "Contacts" : "Stiki",
    "A contacts app for Nextcloud" : "Program za urejanje stikov Nextcloud",
    "The Nextcloud contacts app is a user interface for Nextcloud's CardDAV server. Easily sync contacts from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Currently Mail and Calendar – more to come.\n* 🎉 **Never forget a birthday!** You can sync birthdays and other recurring events with your Nextcloud Calendar.\n* 👥 **Sharing of Adressbooks!** You want to share your contacts with your friends or coworkers? No problem!\n* 🙈 **We’re not reinventing the wheel!** Based on the great and open SabreDAV library." : "Program Stiki je vmesnik za strežnik Nextcloud CardDAV. Omogoča enostavno usklajevanje stikov z različnih naprav v okolje Nextcloud in urejanje/dodajanje z uporabo spletnega vmesnika.\n\n* **Tesna povezanost z drugimi programi Nextcloud!** – trenutno s Pošto in Koledarjem – še več pa kmalu.\n* **Opomniki za rojstne dneve!** – te je mogoče uskladiti in opredeliti kot ponavljajoče se dogodke znotraj koledarja Nextcloud.\n* **Souporaba imenika!** – če želite omogočiti souporabo s prijatelji in sodelavci – Ni problema!\n* **Ne odkrivamo po nepotrebnem spet kolesa!** – program je zasnovan na odlični odprtokodni knjižnici SabreDAV.",
    "Copy to full name" : "Kopiraj v polno ime",
    "Omit year" : "Izpusti leto",
    "Allow updating avatars from social media" : "Omogoči posodabljanje podobe iz družbenih omrežij",
    "Organization chart" : "Organizacijska shema",
    "There was an error fetching the member list" : "Prišlo je do napake med pridobivanjem seznama članov",
    "Teams" : "Skupine",
    "Please select a team" : "Izbor skupine",
    "Loading team…" : "Poteka nalaganje skupin ...",
    "There are no contacts yet" : "Ni še vpisanih stikov",
    "Create contact" : "Ustvari stik",
    "There are no contacts in this group" : "V tej skupini ni stikov",
    "Create contacts" : "Ustvari stike",
    "Add contacts" : "Dodaj stike",
    "Retry" : "Poskusi znova",
    "Leave team" : "Zapusti skupino",
    "Delete team" : "Izbriši skupino",
    "Contacts settings" : "Nastavitve stikov",
    "Update avatars from social media" : "Posodobi podobe iz družbenega omrežija",
    "Address books" : "Imeniki",
    "Rename" : "Preimenuj",
    "Export" : "Izvozi",
    "Send email" : "Pošlji elektronsko sporočilo",
    "Send email as BCC" : "Pošlji kot elektronsko sporočilo kot skrito",
    "Delete" : "Izbriši",
    "Show all groups" : "Pokaži vse skupine",
    "Collapse groups" : "Zloži skupine",
    "Show all teams" : "Pokaži vse skupine",
    "Collapse teams" : "Zloži skupine",
    "This group already exists" : "Ta skupina že obstaja",
    "This team already exists" : "Ta skupina že obstaja",
    "An error happened during the creation of the team" : "Prišlo je do napake med ustvarjanjem skupine",
    "Recently contacted" : "Nedavno v stiku",
    "Contact groups" : "Skupine stikov",
    "Create a new contact group" : "Ustvari novo skupino stikov",
    "Contact group name" : "Ime skupine stikov",
    "Create a new team" : "Ustvari novo skupino",
    "_Shared with {num} entity_::_Shared with {num} entities_" : ["V souporabi s skupno {num} uporabnikom ali skupino","V souporabi s skupno {num} uporabnikoma ali skupinama","V souporabi s skupno {num} uporabniki ali skupinami","V souporabi s skupno {num} uporabniki ali skupinami"],
    "Copied" : "Kopirano!",
    "Cannot copy" : "Predmeta ni mogoče kopirati",
    "Copy link" : "Kopiraj povezavo",
    "Toggling of address book was not successful" : "Preklop imenika je spodletel",
    "This will delete the address book and every contacts within it" : "S tem dejanjem boste izbrisali imenik in vse stike v njem.",
    "Delete {addressbook}?" : "Ali želite izbrisati imenik {addressbook} ?",
    "This will unshare the address book and every contacts within it" : "S tem dejanjem boste odstranili souporabo imenika in s tem vse stike v njem.",
    "Unshare {addressbook}?" : "Ali želite odstraniti souporabo imenika {addressbook} ?",
    "Deletion of address book was not successful." : "Brisanje imenika je spodletelo.",
    "Renaming of address book was not successful." : "Preimenovanje imenika je spodletelo.",
    "Download" : "Prejmi",
    "Show" : "Pokaži",
    "Unshare from me" : "Prekini souporabo z mano",
    "_%n contact_::_%n contacts_" : ["%n stik","%n stika","%n stiki","%n stikov"],
    "_%n group_::_%n groups_" : ["%n skupina","%n skupini","%n skupine","%n skupin"],
    "Share with users or groups" : "Souporaba z uporabniki ali skupinami",
    "Share with users" : "Souporaba z uporabniki",
    "No users or groups" : "Ni uporabnikov oziroma skupin",
    "Unable to delete the share" : "Mesta souporabe ni mogoče izbrisati.",
    "Unable to change permissions" : "Ni mogoče spremeniti dovoljenj.",
    "Choose a vCard file to import" : "Izbor datoteke vCard za uvoz",
    "Import into the {addressbookName} address book" : "Uvozi v imenik {addressbookName}",
    "Select local file" : "Izbor krajevne datoteke",
    "Import from files" : "Uvozi iz datotek",
    "Importing is disabled because there are no address books available" : "Uvoz je onemogočen, ker ni mogoče najti razpoložljivega imenika.",
    "An error occurred, unable to create the address book" : "Prišlo je do napake, zato ni mogoče ustvariti imenika.",
    "Add new address book" : "Dodaj nov imenik",
    "Cancel" : "Prekliči",
    "Add" : "Dodaj",
    "First name" : "Ime",
    "Last name" : "Priimek",
    "Phonetic first name" : "Fonetično ime",
    "Phonetic last name" : "Fonetično priimek",
    "Display name" : "Prikazano ime",
    "Last modified" : "Nazadnje spremenjeno",
    "Manages" : "Upravlja",
    "Oversees" : "Nadzira",
    "An error happened during the config change" : "Prišlo je do napake med poskusom spremembe nastavitev",
    "Enforce password protection on files shared to this team" : "Za to skupino vsili zaščito datotek v souporabi z geslom ",
    "Use a unique password for all shares to this team" : "Za to skupino uporabi enoznačno geslo za vse predmete v souporabi",
    "Save" : "Shrani",
    "Change unique password" : "Spremeni enoznačno geslo",
    "Failed to save password. Please try again later." : "Shranjevanje gesla je spodletelo. Poskusite znova kasneje.",
    "Close" : "Zapri",
    "There is no description for this team" : "Za to skupino ni navedenega opisa",
    "Enter a description for the team" : "Vpišite opis skupine",
    "Folder" : "Folder",
    "Conversation name" : "Naslov pogovora",
    "Team name" : "Naziv skupine",
    "Delete picture" : "Izbriši sliko",
    "Edit" : "Uredi",
    "Request to join" : "Zahtevaj članstvo",
    "Create" : "Ustvari",
    "Your request to join this team is pending approval" : "Zahteva za vstop v skupino čaka na potrditev",
    "You are not a member of {circle}" : "Niste še član kroga {circle}",
    "Members" : "Člani",
    "Confirm" : "Potrdi",
    "Add more info" : "Dodaj več podrobnosti",
    "More fields" : "Več polj",
    "Please select a valid format" : "Izberi veljavni zapis",
    "Invalid image" : "Neveljavna slika",
    "Error cropping picture" : "Napaka obrezovanja slike",
    "Pick an avatar" : "Izbor podobe",
    "Error while processing the picture." : "Prišlo je do napake med obdelavo slike.",
    "Avatar downloaded from social network" : "Podoba je prejeta z družbenega omrežja",
    "Avatar already up to date" : "Podoba je že posodobljena",
    "Avatar download failed" : "Prejem podobe je spodletel",
    "Crop contact photo" : "Obreži sliko stika",
    "Upload a new picture" : "Pošlji novo sliko",
    "Choose from Files" : "Izbor iz oblaka",
    "Download picture" : "Prejmi sliko",
    "Clone contact" : "Kloniraj stik",
    "This contact is in read-only mode. You do not have permission to edit this contact." : "Ta stik je le za branje. Za urejanje so zahtevana posebna dovoljenja.",
    "The contact you were trying to edit has changed. Please manually refresh the contact. Any further edits will be discarded." : "Stik, ki ga skušate urediti je spremenjen. Stike je treba ročno osvežiti, vsa nadaljnja urejanja pa bodo izbrisana.",
    "Address book" : "Imenik",
    "Add contact to Birthday Calendar" : "Dodaj stik v koledar rojstnih dni",
    "Exclude contact from Birthday Calendar" : "Izloči stik iz koledarja rojstnih dni",
    "{title} at {organization}" : "{title} pri {organization}",
    "Name" : "Ime",
    "Syntax error. Cannot open the contact." : "Napaka skladnje. Ni mogoče odpreti podatkov stika.",
    "The contact does not exist on the server anymore." : "Stik na strežniku več ne obstaja.",
    "Unable to retrieve the contact from the server, please check your network connection." : "Ni mogoče pridobiti stika s strežnika. Preverite omrežno povezavo.",
    "An error occurred while trying to move the contact" : "Prišlo je do napake med premikanjem stika",
    "An error occurred while trying to copy the contact" : "Prišlo je do napake med kopiranjem stika",
    "Unable to update contact" : "Ni mogoče posodobiti stika",
    "No contact selected" : "Ni izbranega stika",
    "Select a contact on the list to begin" : "Izberite stik s seznama za začetek",
    "Title" : "Naziv",
    "Company" : "Ustanova",
    "Go to talk conversation" : "Pojdi na pogovor",
    "View profile" : "Pokaži profil",
    "This contact was broken and received a fix. Please review the content and click here to save it." : "Podatki tega stika so bili okvarjeni in nato popravljeni. Preverite pravilnost podatkov in kliknite za shranjevanje.",
    "Edit profile" : "Uredi profil",
    "Generate QR Code" : "Ustvari kodo QR",
    "Contact vCard as QR code" : "Kartica vCard stika kot koda QR",
    "Select address book" : "Izbor imenika",
    "Media shares with you" : "V souporabi z vami",
    "Talk conversations with you" : "Pogovori v souporabi z vami",
    "Calendar events with you" : "Dogodki koledarja v souporabi z vami",
    "Deck cards with you" : "Kartice Deck v souporabi z vami",
    "No shared items with this contact" : "Ni predmetov v souporabi s tem stikom",
    "Move" : "Move",
    "Remove from favorites" : "Remove from favorites",
    "Add to favorites" : "Add to favorites",
    "Add to {group}" : "Dodaj skupino {group}",
    "Remove {type}" : "Odstrani {type}",
    "Add to group" : "Dodaj skupino",
    "Search {types}" : "Poišči {types}",
    "Search for people to add" : "Poišči osebe za dodajanje",
    "No results" : "Ni zadetkov",
    "Add {type}" : "Dodaj {type}",
    "New team name" : "Novo ime skupine",
    "Personal team" : "Osebna skupina",
    "This team will only be visible to you. Other members will not be able to see or use it." : "Ta skupina je videna le vam. Drugi člani je ne bodo videli niti je ne bodo mogli uporabljati.",
    "Local team" : "Krajevna skupina",
    "This team will not be shared with the other instances of the global scale" : "Ta skupina ne bo v souporabi z drugimi splošnimi povezavami",
    "Create team" : "Ustvari skupino",
    "Promote as sole owner" : "Povišaj v edinega lastnika",
    "Promote to {level}" : "Povišaj na raven {level}",
    "Demote to {level}" : "Ponižaj na raven {level}",
    "Could not delete the member {displayName}" : "Člana {displayName} ni mogoče izbrisati.",
    "Could not change the member level to {level}" : "Ni mogoče spremeniti ravni člana na raven {level}",
    "Could not accept membership request" : "Zahteve za članstvo ni mogoče sprejeti",
    "Accept membership request" : "Sprejmi zahtevo za članstvo",
    "Reject membership request" : "Zavrni zahtevo za članstvo",
    "Manage level" : "Upravljanje ravni",
    "Remove member" : "Odstrani člana",
    "Unable to get the results" : "Ni mogoče pridobiti zadetkov",
    "Some members could not be added" : "Nekaterih članov ni mogoče dodati",
    "There was an issue adding members to the team" : "Prišlo je do napake med dodajanjem članov v skupino",
    "The list of members is only visible to members of this team" : "Seznam članov je viden le članom te skupine",
    "You currently have no access to the member list" : "Trenutno nimate dostopa do seznama članov",
    "Pending" : "Na čakanju",
    "Label" : "Oznaka",
    "Created" : "Ustvarjeno",
    "Chart" : "Diagram",
    "Select type" : "Izbor vrste",
    "Add contact in group" : "Dodaj stik v skupino",
    "None" : "Brez",
    "Select option" : "Izbor možnosti",
    "Notes" : "Opombe",
    "Add property of this type" : "Dodaj lastnost te vrste",
    "Member" : "Član",
    "Unable to create the contact." : "Ni mogoče ustvariti stika.",
    "Contact not found" : "Stika ni mogoče najti",
    "Group {group} not found" : "Skupine {group} ni mogoče najti",
    "Add member" : "Dodaj člana",
    "New contact" : "Nov stik",
    "_{success} contact added to {name}_::_{success} contacts added to {name}_" : ["{success} stik je dodan v {name}.","{success} stika sta dodana v {name}.","{success} stiki so dodani v {name}.","{success} stikov je dodanih v {name}."],
    "_Adding {success} contact to {name}_::_Adding {success} contacts to {name}_" : ["Poteka dodajanje {success} stika v {name}","Poteka dodajanje {success} stikov v {name}","Poteka dodajanje {success} stikov v {name}","Poteka dodajanje {success} stikov v {name}"],
    "_{count} error_::_{count} errors_" : ["{count} napaka","{count} napaki","{count} napake","{count} napak"],
    "_Importing %n contact into {addressbook}_::_Importing %n contacts into {addressbook}_" : ["Poteka uvažanje %n stika v imenik {addressbook}","Poteka uvažanje %n stikov v imenik {addressbook}","Poteka uvažanje %n stikov v imenik {addressbook}","Poteka uvažanje %n stikov v imenik {addressbook}"],
    "_Done importing %n contact into {addressbook}_::_Done importing %n contacts into {addressbook}_" : ["Končano je uvažanje %n stika v imenik {addressbook}","Končano je uvažanje %n stikov v imenik {addressbook}","Končano je uvažanje %n stikov v imenik {addressbook}","Končano je uvažanje %n stikov v imenik {addressbook}"],
    "Import" : "Uvozi",
    "Are you sure you want to import this contact file?" : "Ali ste prepričani, da želite uvoziti to datoteko stikov?",
    "Could not copy" : "Predmeta ni mogoče kopirati",
    "Join team" : "Pridruži se skupini",
    "You are about to leave {circle}.\nAre you sure?" : "Zapuščate krog {circle}.\nAli ste prepričani, da želite to storiti?",
    "Please confirm team leave" : "Potrdite odhod iz skupine",
    "Could not leave the team {displayName}" : "Skupine {displayName} ni mogoče zapustiti",
    "Unable to join the team" : "Ni se mogoče pridružiti skupini",
    "You are about to delete {circle}.\nAre you sure?" : "Izbrisati želite krog {circle}.\nAli ste prepričani, da želite to storiti?",
    "Please confirm team deletion" : "Potrdite brisanje skupine",
    "Unable to delete the team" : "Skupine ni mogoče izbrisati.",
    "Link copied to the clipboard" : "Povezava je kopirana v odložišče",
    "Could not copy link to the clipboard." : "Povezave ni mogoče kopirati v odložišče",
    "Not grouped" : "Brez skupine",
    "Team" : "Skupina",
    "User" : "Uporabnik",
    "Group" : "Skupina",
    "Email" : "Elektronski naslov",
    "Contact" : "Stik",
    "Moderator" : "Moderator",
    "Admin" : "Skrbnik",
    "Owner" : "Lastnik",
    "Invites" : "Povabljeni",
    "Anyone can request membership" : "Vsakdo lahko pošlje zahtevo za članstvo",
    "Members need to accept invitation" : "Člani morajo sprejeti zahtevo",
    "Members can also invite" : "Člani lahko tudi vabijo druge udeležence",
    "Visible to everyone" : "Vidno vsem",
    "Users" : "Uporabniki",
    "Email addresses" : "Elektronski naslovi",
    "Detailed name" : "Podrobno ime",
    "Additional names" : "Druga imena",
    "Prefix" : "Predpona",
    "Suffix" : "Pripona",
    "Nickname" : "Vzdevek",
    "Website" : "Spletna stran",
    "Location" : "Mesto",
    "Federated Cloud ID" : "ID zveznega oblaka",
    "Home" : "Doma",
    "Work" : "Služba",
    "Other" : "Drugo",
    "Address" : "Naslov",
    "Post office box" : "Poštni predal",
    "Extended address" : "Razširjen naslov",
    "City" : "Mesto",
    "State or province" : "Zvezna država ali provinca",
    "Postal code" : "Poštna številka",
    "Country" : "Država",
    "Birthday" : "Datum rojstva",
    "Anniversary" : "Obletnica",
    "Date of death" : "Datum smrti",
    "Instant messaging" : "Hipni sporočilnik",
    "Phone" : "Telefon",
    "Mobile" : "Mobilni",
    "Work mobile" : "Službeni mobilni",
    "Home mobile" : "Osebni mobilni",
    "Fax" : "Faks",
    "Fax home" : "Faks doma",
    "Fax work" : "Faks služba",
    "Pager" : "Pozivnik",
    "Voice" : "Glasovna pošta",
    "Car" : "Avto",
    "Work pager" : "Pozivnik",
    "Social network" : "Družbeno omrežje",
    "Relationship to you" : "Odnos z vami",
    "Spouse" : "Partner",
    "Child" : "Otrok",
    "Mother" : "Mati",
    "Father" : "Oče",
    "Parent" : "Starš",
    "Brother" : "Brat",
    "Sister" : "Sestra",
    "Relative" : "Sorodnik",
    "Friend" : "Prijatelj",
    "Colleague" : "Znanec",
    "Assistant" : "Pomočnik",
    "Related contacts" : "Povezani stiki",
    "Agent" : "Zastopnik",
    "Emergency" : "Stik v sili",
    "Co-worker" : "Sodelavec",
    "Gender" : "Spol",
    "Female" : "Ženski",
    "Male" : "Moški",
    "Unknown" : "Neznan",
    "Time zone" : "Časovni pas",
    "Spoken languages" : "Govorjeni jezik",
    "_{failed} contact failed to be read_::_{failed} contacts failed to be read_" : ["{failed} stika ni mogoče prebrati","{failed} stikov ni mogoče prebrati","{failed} stikov ni mogoče prebrati","{failed} stikov ni mogoče prebrati"],
    "An error has occurred in team(s). Check the console for more details." : "Prišlo je do napake v nekaterih skupinah. Preverite konzolo za več podrobnosti.",
    "Unable to delete contact" : "Ni mogoče izbrisati stika",
    "Pick an address book" : "Izbor imenika",
    "Select Date" : "Izbor datuma"
},
"nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
